@charset "utf-8";
/*!
 * @title Web Experience Toolkit (WET) / Boîte à outils de l'expérience Web (BOEW)
 * @license wet-boew.github.io/wet-boew/License-en.html / wet-boew.github.io/wet-boew/Licence-fr.html
 * v12.5.0 - 2022-12-13
 *
 */
ul[class*=cnjnctn-type-] {
	list-style:none;
	padding-left:0;
}
[class*=cnjnctn-type-] {
	display: flex;
	flex-wrap: nowrap;
	flex-direction: column;
	margin-bottom: 15px;
	margin-right: 0px;
	margin-top: 15px;
	min-height: 60px;
	position: relative;
}
[class*=cnjnctn-type-]>[class*=cnjnctn-col]:not(:first-child):after {
	background-image: linear-gradient(to bottom, #6f6f6f, #6f6f6f);
	background-size: 3px;
	content: ' ';
	height: 100%;
	left: 0;
	position: absolute;
	top: 0;
 	width: 3px;
}
[class*=cnjnctn-type-]>[class*=cnjnctn-col] {
	padding-left: 15px;
	padding-right: 15px;
	width: 100%;
}
[class*=cnjnctn-type-]>[class*=cnjnctn-col]> :first-child:not([class*=mrgn-tp-]) {
	margin-top: 0px;
}
[class*=cnjnctn-type-]>[class*=cnjnctn-col]> :last-child:not([class*=mrgn-bttm-]) {
	margin-bottom: 0px;
}
[class*=cnjnctn-type-]>[class*=cnjnctn-col]:not(:last-child) {
	margin-bottom: 30px;
	margin-right: 30px;
}
[class*=cnjnctn-type-]>[class*=cnjnctn-col]:not(:first-child) {
	margin-top: 30px;
}
[class*=cnjnctn-type-]>[class*=cnjnctn-col]:not(:first-child):before {
	border-color: #6f6f6f;
	border-style: solid;
	box-sizing: content-box;
	font-size: 16px;
	font-weight: 600;
	height: 30px;
	left: auto;
	line-height: 28px;
	margin-top: -53px;
	padding: 4px;
	position: absolute;
	text-align: center;
	width: 30px;
}
.cnjnctn-type-or>[class*=cnjnctn-col]:not(:first-child):before {
	border-radius: 50%;
	border-width: 3px;
}
.cnjnctn-type-and>[class*=cnjnctn-col]:not(:first-child):before {
	border-width: 3px 0px 3px 0px;
}
html:lang(en) .cnjnctn-type-and>[class*=cnjnctn-col]:not(:first-child):before {
	content: "and";
}
html:lang(fr) .cnjnctn-type-and>[class*=cnjnctn-col]:not(:first-child):before {
	content: "et";
}
html:lang(en) .cnjnctn-type-or>[class*=cnjnctn-col]:not(:first-child):before {
	content: "or";
}
html:lang(fr) .cnjnctn-type-or>[class*=cnjnctn-col]:not(:first-child):before {
	content: "ou";
}
[class*=cnjnctn-type-]>.cnjnctn-col-90 {
	flex-basis: 90%
}
[class*=cnjnctn-type-]>.cnjnctn-col-80 {
	flex-basis: 80%
}
[class*=cnjnctn-type-]>.cnjnctn-col-75 {
	flex-basis: 75%
}
[class*=cnjnctn-type-]>.cnjnctn-col-70 {
	flex-basis: 70%
}
[class*=cnjnctn-type-]>.cnjnctn-col-60 {
	flex-basis: 60%
}
[class*=cnjnctn-type-]>.cnjnctn-col-50 {
	flex-basis: 50%
}
[class*=cnjnctn-type-]>.cnjnctn-col-40 {
	flex-basis: 40%
}
[class*=cnjnctn-type-]>.cnjnctn-col-30 {
	flex-basis: 30%
}
[class*=cnjnctn-type-]>.cnjnctn-col-25 {
	flex-basis: 25%
}
[class*=cnjnctn-type-]>.cnjnctn-col-20 {
	flex-basis: 20%
}
[class*=cnjnctn-type-].cnjnctn-xs {
	flex-direction: row;
	margin-left: -15px;
	margin-right: -15px;
}
[class*=cnjnctn-type-].cnjnctn-xs>[class*=cnjnctn-col]:not(:first-child):after {
	background-image: linear-gradient(to bottom, #6f6f6f 6px, #6f6f6f 6px, rgba(0,0,0,0) 6px, rgba(0,0,0,0) 46px, #6f6f6f 46px, #6f6f6f 46px);
}
[class*=cnjnctn-type-].cnjnctn-xs>[class*=cnjnctn-col]:not(:first-child) {
	margin-left: 30px;
   	position: relative;
}
[class*=cnjnctn-type-].cnjnctn-xs>[class*=cnjnctn-col]:not(:first-child):after {
  	margin-left: -31px;
}
.cnjnctn-type-or.cnjnctn-xs>[class*=cnjnctn-col]:not(:first-child):before {
	margin-left: -67px;
}
.cnjnctn-type-and.cnjnctn-xs>[class*=cnjnctn-col]:not(:first-child):before {
	margin-left: -65.5px;
}
[class*=cnjnctn-type-].cnjnctn-xs>[class*=cnjnctn-col]:not(:first-child):before {
	margin-top: 4px;
}
[class*=cnjnctn-type-].cnjnctn-xs>[class*=cnjnctn-col]:not(:last-child) {
	margin-bottom: 0px;
}
[class*=cnjnctn-type-].cnjnctn-xs>[class*=cnjnctn-col]:not(:first-child) {
	margin-top: 0px;
}
.cnjnctn-type-and.cnjnctn-xs>[class*=cnjnctn-col]:not(:first-child):before {
	border-width: 3px 0px 3px 0px;
}
[class*=cnjnctn-type-]:not(:is(.cnjnctn-sm, .cnjnctn-md, .cnjnctn-lg)).brdr-0>[class*=cnjnctn-col]:after {
 background-image:none;
}
 [class*=cnjnctn-type-]:not(:is(.cnjnctn-sm, .cnjnctn-md, .cnjnctn-lg)).brdr-0>[class*=cnjnctn-col] {
 padding-left: 0px;
 padding-right: 0px;
}

@media all and (min-width: 768px) {
[class*=cnjnctn-type-].cnjnctn-sm {
	border-left: 0px solid transparent;
	flex-direction: row;
	margin-left: -15px;
	margin-right: -15px;
}
[class*=cnjnctn-type-].cnjnctn-sm>[class*=cnjnctn-col]:not(:first-child) {
	margin-left: 30px;
  	position: relative;
}
[class*=cnjnctn-type-].cnjnctn-sm>[class*=cnjnctn-col]:not(:first-child):after {
  	margin-left: -31px;
}
.cnjnctn-type-or.cnjnctn-sm>[class*=cnjnctn-col]:not(:first-child):before {
	margin-left: -67px;
}
.cnjnctn-type-and.cnjnctn-sm>[class*=cnjnctn-col]:not(:first-child):before {
	margin-left: -65.5px;
}
[class*=cnjnctn-type-].cnjnctn-sm>[class*=cnjnctn-col]:not(:first-child):before {
	margin-top: 4px;
}
[class*=cnjnctn-type-].cnjnctn-sm>[class*=cnjnctn-col]:not(:last-child) {
	margin-bottom: 0px;
}
[class*=cnjnctn-type-].cnjnctn-sm>[class*=cnjnctn-col]:not(:first-child) {
	margin-top: 0px;
}
[class*=cnjnctn-type-].cnjnctn-sm>[class*=cnjnctn-col]:not(:first-child):after {
	background-image: linear-gradient(to bottom, #6f6f6f 6px, #6f6f6f 6px, rgba(0,0,0,0) 6px, rgba(0,0,0,0) 46px, #6f6f6f 46px, #6f6f6f 46px);
}
.cnjnctn-type-and.cnjnctn-sm>[class*=cnjnctn-col]:not(:first-child):before {
	border-width: 3px 0px 3px 0px;
}
}

@media all and (min-width: 992px) {
[class*=cnjnctn-type-].cnjnctn-md {
	border-left: 0px solid transparent;
	flex-direction: row;
	margin-left: -15px;
	margin-right: -15px;
}
[class*=cnjnctn-type-].cnjnctn-md>[class*=cnjnctn-col]:not(:first-child) {
	margin-left: 30px;
    position: relative;
}
[class*=cnjnctn-type-].cnjnctn-md>[class*=cnjnctn-col]:not(:first-child):after {
  	margin-left: -31px;
}
.cnjnctn-type-or.cnjnctn-md>[class*=cnjnctn-col]:not(:first-child):before {
	margin-left: -67px;
}
.cnjnctn-type-and.cnjnctn-md>[class*=cnjnctn-col]:not(:first-child):before {
	margin-left: -65.5px;
}
[class*=cnjnctn-type-].cnjnctn-md>[class*=cnjnctn-col]:not(:first-child):before {
	margin-top: 4px;
}
[class*=cnjnctn-type-].cnjnctn-md>[class*=cnjnctn-col]:not(:last-child) {
	margin-bottom: 0px;
}
[class*=cnjnctn-type-].cnjnctn-md>[class*=cnjnctn-col]:not(:first-child) {
	margin-top: 0px;
}
[class*=cnjnctn-type-].cnjnctn-md>[class*=cnjnctn-col]:not(:first-child):after {
	background-image: linear-gradient(to bottom, #6f6f6f 6px, #6f6f6f 6px, rgba(0,0,0,0) 6px, rgba(0,0,0,0) 46px, #6f6f6f 46px, #6f6f6f 46px);
}
.cnjnctn-type-and.cnjnctn-md>[class*=cnjnctn-col]:not(:first-child):before {
	border-width: 3px 0px 3px 0px;
}
}

@media all and (min-width: 1200px) {
[class*=cnjnctn-type-].cnjnctn-lg {
	border-left: 0px solid transparent;
	flex-direction: row;
	margin-left: -15px;
	margin-right: -15px;
}
[class*=cnjnctn-type-].cnjnctn-lg>[class*=cnjnctn-col]:not(:first-child) {
	margin-left: 30px;
   	position: relative;
}
[class*=cnjnctn-type-].cnjnctn-lg>[class*=cnjnctn-col]:not(:first-child):after {
  margin-left: -31px;
}
.cnjnctn-type-or.cnjnctn-lg>[class*=cnjnctn-col]:not(:first-child):before {
	margin-left: -67px;
}
.cnjnctn-type-and.cnjnctn-lg>[class*=cnjnctn-col]:not(:first-child):before {
	margin-left: -65.5px;
}
[class*=cnjnctn-type-].cnjnctn-lg>[class*=cnjnctn-col]:not(:first-child):before {
	margin-top: 4px;
}
[class*=cnjnctn-type-].cnjnctn-lg>[class*=cnjnctn-col]:not(:last-child) {
	margin-bottom: 0px;
}
[class*=cnjnctn-type-].cnjnctn-lg>[class*=cnjnctn-col]:not(:first-child) {
	margin-top: 0px;
}
[class*=cnjnctn-type-].cnjnctn-lg>[class*=cnjnctn-col]:not(:first-child):after {
	background-image: linear-gradient(to bottom, #6f6f6f 6px, #6f6f6f 6px, rgba(0,0,0,0) 6px, rgba(0,0,0,0) 46px, #6f6f6f 46px, #6f6f6f 46px);
}
.cnjnctn-type-and.cnjnctn-lg>[class*=cnjnctn-col]:not(:first-child):before {
	border-width: 3px 0px 3px 0px;
}
}

ol.lst-stps, .lst-stps {
	counter-reset: item;
	margin-bottom: 30px;
	padding-left: 0;
}
ol.lst-stps, ol.lst-stps-sub, .lst-stps, .lst-stps-sub {
	list-style-type: none;
}
ol.lst-stps>li, .lst-stps>.lst-stps-itm {
	content: counter(item);
	counter-increment: item;
}
ol.lst-stps>li, ol.lst-stps-sub>li, .lst-stps .lst-stps-itm {
	min-height: 3em;
	padding-left: 3.6em;
	padding-right: 15px;
}
ol.lst-stps-sub>li, .lst-stps-sub .lst-stps-itm {
	padding-left: 2.8em;
}
ol.lst-stps.ld-zr ol.lst-stps-sub>li, .lst-stps.ld-zr .lst-stps-itm {
	padding-left: 4em;
}
ol.lst-stps.ld-zr>li, ol.lst-stps.ld-zr ol.lst-stps-sub>li, .lst-stps.ld-zr .lst-stps-itm {
	min-height: 4em;
}
ol.lst-stps>li:not(:first-child), ol.lst-stps-sub>li:not(:first-child), .lst-stps .lst-stps-itm:not(:first-child) {
	margin-top: 20px;
}
ol.lst-stps.ld-zr>li:not(:first-child), .lst-stps.ld-zr .lst-stps-itm:not(:first-child) {
	margin-top: 40px;
}
ol.lst-stps>li:before, .lst-stps .lst-stps-itm:before {
	content: counter(item);
}
ol.lst-stps.ld-zr>li:before, .lst-stps.ld-zr .lst-stps-itm:before {
	content: counter(item, decimal-leading-zero);
	counter-increment: li;
	font-size: 1.6em;
	margin-left: -2.4em;
	min-width: 2em;
}
ol.lst-stps.ld-zr ol.lst-stps-sub>li:before, .lst-stps.ld-zr .lst-stps-sub .lst-stps-itm:before {
	margin-left: -3.4em;
	min-width: 2.8em;
}
ol.lst-stps-sub, .lst-stps-sub {
	clear: both;
	counter-reset: subitem;
	margin-top: 15px;
	padding-left: 0px;
}
ol.lst-stps>li:before, ol.lst-stps ol.lst-stps-sub>li:before, .lst-stps .lst-stps-itm:before, .lst-stps-sub .lst-stps-itm:before {
	border-color: #26374a;
	border-style: solid;
	border-width: 3px;
	float: left;
	font-family: Lato, sans-serif;
	font-weight: 600;
	margin-right: 10px;
	position: relative;
	text-align: center;
}
ol.lst-stps:not(.ld-zr)>li:before, ol.lst-stps:not(.ld-zr) ol.lst-stps-sub>li:before, .lst-stps:not(.ld-zr) .lst-stps-itm:before, .lst-stps:not(.ld-zr) .lst-stps-sub .lst-stps-itm:before {
	background-color: #fff;
	-webkit-border-radius: 50%;
	-moz-border-radius: 50%;
	border-radius: 50%;
	box-sizing: content-box;
	line-height: 2;
	margin-left: -3.2em;
	margin-top: -8px;
	text-align: center;
	width: 2em;
}
ol.lst-stps.ld-zr>li:before, ol.lst-stps.ld-zr>li ol.lst-stps-sub>li:before, .lst-stps.ld-zr .lst-stps-itm:before, .lst-stps.ld-zr .lst-stps-sub .lst-stps-itm:before {
	border-bottom-width: 0px;
	border-left-width: 0px;
	border-top-width: 0px;
	line-height: 1.4;
	padding-bottom: 0.8em;
	padding-right: 8px;
}
ol.lst-stps-sub>li:before, .lst-stps .lst-stps-sub .lst-stps-itm:before {
	counter-increment: subitem;
}
ol.lst-stps:not(.ld-zr)>li ol.lst-stps-sub>li:before, .lst-stps:not(.ld-zr) .lst-stps-sub .lst-stps-itm:before {
	content: counter(item) "" counter(subitem, lower-alpha) "";
	font-size: 0.8em;
	margin-top: -2px;
}
ol.lst-stps.ld-zr>li ol.lst-stps-sub>li:before, .lst-stps.ld-zr .lst-stps-sub .lst-stps-itm:before {
	content: counter(item, decimal-leading-zero) "" counter(subitem, lower-alpha) "";
	font-size: 1.2em;
}
 ol.lst-stps li :first-of-type:is(h2, h3, h4, h5, h6, p), .lst-stps .lst-stps-itm :first-of-type:is(h2, h3, h4, h5, h6, p) {
 margin-top: auto;
}
ol.lst-stps.stps-strpd>li, ol.lst-stps.stps-strpd>li ol.lst-stps-sub.stps-strpd>li, .lst-stps.stps-strpd .lst-stps-itm, .lst-stps.stps-strpd .lst-stps-sub.stps-strpd .lst-stps-itm {
	padding-bottom: 20px;
	padding-top: 20px;
}
ol.lst-stps.stps-strpd>li>:last-child, ol.lst-stps.stps-strpd ol.lst-stps-sub.stps-strpd>li>:last-child, .lst-stps.stps-strpd .lst-stps-itm>:last-child, .lst-stps.stps-strpd .lst-stps-sub.stps-strpd .lst-stps-itm>:last-child {
	margin-bottom: 0px;
}
ol.lst-stps.stps-strpd>li:not(:first-child), ol.lst-stps.stps-strpd ol.lst-stps-sub.stps-strpd>li:not(:first-child), .lst-stps.stps-strpd .lst-stps-itm:not(:first-child), .lst-stps.stps-strpd .lst-stps-sub.stps-strpd .lst-stps-itm:not(:first-child) {
	margin-top: 0px;
}
ol.lst-stps.stps-strpd>li:nth-child(odd), ol.lst-stps.stps-strpd>li:nth-child(even)>ol.lst-stps-sub.stps-strpd>li:nth-child(odd), ol.lst-stps.stps-strpd>li:nth-child(odd)>ol.lst-stps-sub.stps-strpd>li:nth-child(even), .lst-stps.stps-strpd>.lst-stps-itm:nth-child(odd), .lst-stps.stps-strpd>.lst-stps-itm:nth-child(even)>.lst-stps-sub.stps-strpd>.lst-stps-itm:nth-child(odd), .lst-stps.stps-strpd>.lst-stps-itm:nth-child(odd)>.lst-stps-sub.stps-strpd>.lst-stps-itm:nth-child(even).lst-stps.stps-strpd>.lst-stps-itm:nth-child(odd), .lst-stps.stps-strpd>.lst-stps-itm:nth-child(even)>.lst-stps-sub.stps-strpd>.lst-stps-itm:nth-child(odd), .lst-stps.stps-strpd>.lst-stps-itm:nth-child(odd)>.lst-stps-sub.stps-strpd>.lst-stps-itm:nth-child(even) {
	background-color: #f5f5f5;
}
ol.lst-stps.stps-strpd>li:nth-child(odd)>ol.lst-stps-sub.stps-strpd>li:nth-child(odd), .lst-stps.stps-strpd>.lst-stps-itm:nth-child(odd)>.lst-stps-sub.stps-strpd>.lst-stps-itm:nth-child(odd) {
	background-color: #fff!important;
}
ol.lst-stps:not(.ld-zr).stps-strpd ol.lst-stps-sub.stps-strpd>li, .lst-stps:not(.ld-zr).stps-strpd .lst-stps-sub.stps-strpd .lst-stps-itm {
	padding-left: 3.4em;
}
ol.lst-stps.ld-zr.stps-strpd>li, .lst-stps.ld-zr.stps-strpd>.lst-stps-itm {
	padding-left: 4em;
}
ol.lst-stps.ld-zr.stps-strpd>li, ol.ld-zr ol.lst-stps-sub.stps-strpd>li, .lst-stps.ld-zr.stps-strpd .lst-stps-itm, .lst-stps-sub.stps-strpd .lst-stps-itm {
	min-height: 5em;
	padding-left: 4.4em;
}

@media all and (max-width: 767px) {
ol.lst-stps.ld-zr>li:before, ol.lst-stps.ld-zr>li ol.lst-stps-sub>li:before, .lst-stps.ld-zr .lst-stps-itm:before, .lst-stps.ld-zr .lst-stps-sub .lst-stps-itm:before {
	left: 5px;
}
ol.lst-stps:not(.ld-zr)>li:before, .lst-stps:not(.ld-zr) .lst-stps-itm:before {
	font-size: 0.8em;
	margin-top: -5px;
}
ol.lst-stps:not(.ld-zr)>li ol.lst-stps-sub>li:before, .lst-stps:not(.ld-zr) .lst-stps-sub .lst-stps-itm:before {
	font-size: 0.7em;
	margin-top: -3px;
}
ol.lst-stps>li, ol.lst-stps>li ol.lst-stps-sub>li, .lst-stps .lst-stps-itm, .lst-stps .lst-stps-sub .lst-stps-itm {
	padding-left: 2.6em;
}
ol.lst-stps.ld-zr>li ol.lst-stps-sub>li, .lst-stps.ld-zr .lst-stps-sub .lst-stps-itm {
	padding-left: 3em;
}
ol.lst-stps.ld-zr>li:before, .lst-stps.ld-zr .lst-stps-itm:before {
	font-size: 1.2em;
	padding-bottom: 25px;
}
ol.lst-stps.ld-zr>li, .lst-stps.ld-zr .lst-stps-itm {
	min-height: 5em;
}
ol.lst-stps.ld-zr>li ol.lst-stps-sub>li:before, .lst-stps.ld-zr .lst-stps-sub .lst-stps-itm:before {
	font-size: 1em;
}
ol.lst-stps.stps-strpd>li, ol.lst-stps.stps-strpd>li ol.lst-stps-sub.stps-strpd>li, .lst-stps.stps-strpd .lst-stps-itm, .lst-stps.stps-strpd .lst-stps-sub.stps-strpd .lst-stps-itm {
	margin-top: 0px;
	padding-bottom: 0.8em;
	padding-top: 0.8em;
}
ol.lst-stps.stps-strpd>li, .lst-stps.stps-strpd .lst-stps-itm {
	padding-left: 3em;
}
ol.lst-stps.stps-strpd.ld-zr>li, .lst-stps.stps-strpd.ld-zr .lst-stps-itm {
	padding-left: 3.4em;
}
ol.lst-stps.stps-strpd>li ol.lst-stps-sub.stps-strpd>li, .lst-stps.stps-strpd .lst-stps-sub .lst-stps-itm {
	padding-left: 3.5em;
}
}

.svgimagemap {
	width: 50%;
	margin: auto;
}

.svgimagemap path {
	stroke: #FFFFFF;
	stroke-width: 5px;
}

.svgimagemap polygon {
	stroke: #FFFFFF;
	stroke-width: 5px;
}

.svgimagemap .border-emphasis {
   stroke-width: 14px;
}
.st0 {
	fill: #122E33;
	stroke:#FFFFFF;
	text-align:center;
}

.st1 {
	fill: #99BDC0;
	stroke:#FFFFFF;
}

.st2 {
	fill: #337C81;
	stroke:#FFFFFF;
}

.st3 {
	fill: #075C62;
	stroke:#FFFFFF;
}

.st4 {
	fill: #F1F2F2;
	stroke:#FFFFFF;
	font-family: 'Noto Sans',sans-serif;
	font-size: 66.613px;
}

.st5 {
	font-family: 'Noto Sans',sans-serif;
	font-size: 66.613px;
}

.st6 {
	font-family: 'Noto Sans',sans-serif;
	font-size: 66.613px;
}

.st7 {
	fill: #414042;
	font-family: 'Noto Sans',sans-serif;
	font-size: 66.613px;
}

.svgimagemap a { text-decoration: none; }
.svgimagemap a:hover .st0,.svgimagemap a:active .st0,.svgimagemap a:focus .st0,.svgimagemap a:hover .st1,.svgimagemap a:active .st1, .svgimagemap a:focus .st1, .svgimagemap  a:hover .st2, .svgimagemap  a:active .st2, .svgimagemap  a:focus .st2, .svgimagemap a:hover .st3, .svgimagemap a:active .st3 , .svgimagemap a:focus .st3 {
	fill: #FA4F56;
	
}
