@charset "utf-8";
/*!
 * @title Web Experience Toolkit (WET) / Boîte à outils de l'expérience Web (BOEW)
 * @license wet-boew.github.io/wet-boew/License-en.html / wet-boew.github.io/wet-boew/Licence-fr.html
 * v12.5.0 - 2022-12-13
 *
 */
.splash .sp-bx img {
	height: 20px;
	width: 214px; }
	@media (min-width: 992px) {
		.splash .sp-bx img {
			height: 100%;
			width: 100%; } }

.splash .sp-bx .btn {
	min-width: 75px; }
	@media (min-width: 992px) {
		.splash .sp-bx .btn {
			min-width: 100px; } }

.splash .sp-bx-bt img {
	height: 20px;
	width: 82px; }
	@media (min-width: 992px) {
		.splash .sp-bx-bt img {
			height: 100%;
			width: 100%; } }
