@charset "utf-8";
/*!
 * @title Web Experience Toolkit (WET) / Boîte à outils de l'expérience Web (BOEW)
 * @license wet-boew.github.io/wet-boew/License-en.html / wet-boew.github.io/wet-boew/Licence-fr.html
 * v12.5.0 - 2022-12-13
 *
 */
/* Thematic red */
.bg-canadaday {
    background-color: #A30D26;
}

.panel-canadaday,
hr.brdr-canadaday {
    border-color: #A30D26;
}

/* Hover and focus state */
a.bg-canadaday:hover,
a.bg-canadaday:focus,
button.bg-canadaday:hover,
button.bg-canadaday:focus {
    background-color: #800613;
}

/* Active state */
a.bg-canadaday:active,
a.bg-canadaday:active:focus,
a.bg-canadaday:active:hover,
button.bg-canadaday:active {
    background-color: #680106 !important;
}

/* Force link text to remain white for hover, focus and active states. */
a.bg-canadaday:hover,
a.bg-canadaday:focus,
a.bg-canadaday:active {
    color: #fff !important;
}
    
/* Thematic beige */
.bg-canadaday-beige {
    background-color: #F9F1DE;
}
/* Hover and focus state */
a.bg-canadaday-beige:hover,
a.bg-canadaday-beige:focus,
button.bg-canadaday-beige:hover,
button.bg-canadaday-beige:focus {
    background-color: #F9E0C1;
}
/* Active state */
a.bg-canadaday-beige:active,
a.bg-canadaday-beige:active:focus,
a.bg-canadaday-beige:active:hover,
button.bg-canadaday-beige:active {
    background-color: #F6D3B2 !important;
}
/* Force link text to remain black for hover, focus and active states. */
a.bg-canadaday-beige:hover,
a.bg-canadaday-beige:focus,
a.bg-canadaday-beige:active {
    color: #333;
}

/* Thematic blue */
.bg-winterlude {
    background-color: #003c77;
}
.panel-winterlude,
hr.brdr-winterlude {
    border-color: #003c77;
}
/* Hover and focus state */
a.bg-winterlude:hover,
a.bg-winterlude:focus,
button.bg-winterlude:hover,
button.bg-winterlude:focus {
    background-color: #2c6cb5 !important;
}
/* Active state */
a.bg-winterlude:active,
a.bg-winterlude:active:focus,
a.bg-winterlude:active:hover,
button.bg-winterlude:active,
button.bg-winterlude:active:focus,
button.bg-winterlude:active:hover {
    background-color: #000000 !important;
}
/* Force link text to remain white for hover, focus and active states. */
a.bg-winterlude:hover,
a.bg-winterlude:focus,
a.bg-winterlude:active,
button.bg-winterlude:hover,
button.bg-winterlude:focus,
button.bg-winterlude:active {
    color: #fff !important;
}

/* Thematic light blue */
.bg-winterlude-lightblue {
    background-color: #c7e6f5;
}
/* Hover and focus state */
a.bg-winterlude-lightblue:hover,
a.bg-winterlude-lightblue:focus,
button.bg-winterlude-lightblue:hover,
button.bg-winterlude-lightblue:focus {
    color: #000 !important;
    background-color: #84c8e6 !important;
}
/* Active state */
a.bg-winterlude-lightblue:active,
a.bg-winterlude-lightblue:active:focus,
a.bg-winterlude-lightblue:active:hover,
button.bg-winterlude-lightblue:active,
button.bg-winterlude-lightblue:active:focus,
button.bg-winterlude-lightblue:active:hover {
    color: #000 !important;
    background-color: #009ec9 !important;
}

/* Thematic Heading 1 */
@media screen and (min-width: 768px) {
    h1.winterlude {
        font-size: 2.4em;
    }
}
@media screen and (min-width: 992px) {
    h1.winterlude {
        font-size: 2.8em;
    }
}
h1.winterlude {
    border-bottom: none !important;
}
h1.winterlude::after {
    border-bottom: 0.18em solid #2c6cb5 !important;
    content: "";
    display: block;
    padding-bottom: 8px;
    width: 0.95em;
}
