@charset "UTF-8";
/*
 * Web Experience Toolkit (WET) / Boîte à outils de l'expérience Web (BOEW)
 * wet-boew.github.io/wet-boew/License-en.html / wet-boew.github.io/wet-boew/Licence-fr.html
 */
.wb-al-cnt, .wb-al-cnt .wb-al {
	max-height: 18em; }

.wb-al-cnt {
	border: 1px solid transparent;
	margin-top: -6px;
	position: absolute;
	z-index: 50; }
	.wb-al-cnt .wb-al {
		background: #fff;
		border: 1px solid #666;
		border-top: 0;
		list-style-type: none;
		overflow: auto;
		padding-left: 0;
		width: 100%; }
		.wb-al-cnt .wb-al .al-lbl {
			float: right;
			padding-left: 10px; }
		.wb-al-cnt .wb-al a {
			color: #000;
			display: block;
			padding-left: 10px;
			text-decoration: none; }
			.wb-al-cnt .wb-al a:hover, .wb-al-cnt .wb-al a:focus {
				background: #406c93;
				color: #fff; }
