@charset "utf-8";
/*!
 * @title Web Experience Toolkit (WET) / Boîte à outils de l'expérience Web (BOEW)
 * @license wet-boew.github.io/wet-boew/License-en.html / wet-boew.github.io/wet-boew/Licence-fr.html
 * v12.5.0 - 2022-12-13
 *
 */
/*
 Global variables for GCWeb
 */
/* Headings font-sizes */
/* Small font-size */
/* Font weight */
/*
Left menu variables
*/
/*
 * Web Experience Toolkit (WET) / Boîte à outils de l'expérience Web (BOEW)
 * wet-boew.github.io/wet-boew/License-en.html / wet-boew.github.io/wet-boew/Licence-fr.html
 */
/*
 * HOW TO USE THIS FILE
 * Use this file to override Bootstrap variables and WET custom variables.
 * If there is a Bootstrap variable not shown here that you want to override, go to "../node_modules/bootstrap-sass/assets/stylesheets/bootstrap/variables" to view the variables that you can override. Simply copy and paste the variable and its applicable section (if applicable) from the Bootstrap file into this override file and override the variables as applicable.
 */
.splash object,
.splash img {
	height: auto;
	max-width: 100%; }

.splash img {
	margin-bottom: .375em; }

.splash #bg {
	height: 200%;
	left: -50%;
	position: fixed;
	top: -50%;
	width: 200%; }
	.splash #bg img {
		bottom: 0;
		left: 0;
		margin: auto;
		min-height: 50%;
		min-width: 50%;
		position: absolute;
		right: 0;
		top: 0; }

.splash .sp-bx {
	background-color: #f8f8f8;
	padding: 30px 30px 19px; }
	.splash .sp-bx .btn {
		-webkit-box-shadow: 0 4px #ddd;
		        box-shadow: 0 4px #ddd;
		margin-bottom: 14px;
		margin-top: 35px;
		min-width: 110px; }
		@media (min-width: 992px) {
			.splash .sp-bx .btn {
				min-width: 138px;
				padding: .5em 1.5em; } }
	.splash .sp-bx .hght-inhrt + p .btn {
		margin-top: 10px; }

.splash .glyphicon {
	color: #9e9e9e;
	font-size: 5px;
	top: -3px; }

.splash .sp-lk:link, .splash .sp-lk:visited {
	color: #335075;
	text-decoration: none; }

.splash .sp-lk:hover, .splash .sp-lk:active {
	color: #335075;
	text-decoration: underline; }

.splash .sp-hb {
	margin: 50px auto;
	width: 300px; }
	@media (min-width: 768px) {
		.splash .sp-hb {
			margin: 50px auto;
			width: 400px; } }
	@media (min-width: 992px) {
		.splash .sp-hb {
			margin: 175px auto;
			width: 500px; } }

.splash .sp-bx-bt {
	background-color: #e1e4e7;
	padding: 30px; }
	@media (min-width: 768px) {
		.splash .sp-bx-bt {
			background-color: #e1e4e7;
			padding: 30px; } }
	@media (min-width: 992px) {
		.splash .sp-bx-bt {
			background-color: #e1e4e7;
			padding: 30px 30px 13px; } }
	@media (min-width: 1200px) {
		.splash .sp-bx-bt {
			background-color: #e1e4e7;
			padding: 30px 30px 13px; } }

.error .box {
	background-color: #e1e4e7;
	margin-bottom: 30px;
	margin-top: 30px;
	padding: 30px; }

.error .h1 {
	border: medium none;
	font-size: 27px;
	margin-bottom: .2em;
	padding-bottom: .2em; }
	.error .h1 img {
		margin-right: 10px; }

.error .srchbox .form-inline {
	margin: 14px;
	white-space: nowrap; }
	.error .srchbox .form-inline .form-control {
		width: 100%; }
	.error .srchbox .form-inline .navbar-form {
		width: 100%; }

.error .srchbox .form-group {
	display: inline-block; }

.error .srchbox input {
	background-color: fff;
	border-color: #fff currentColor #fff #fff;
	-o-border-image: none;
	   border-image: none;
	border-style: solid none solid solid;
	border-width: 1px 0 1px 1px;
	color: #333;
	display: inline-block; }

.error .srchbox button {
	display: inline-block; }

.error .tofpg {
	line-height: 2em;
	margin-top: 18px; }
	.error .tofpg span {
		margin-left: 0;
		margin-right: 15px; }

.xxsmallview .error .h1 img {
	margin-bottom: 35px; }
