@charset "utf-8";
/*!
 * @title Web Experience Toolkit (WET) / Boîte à outils de l'expérience Web (BOEW)
 * @license wet-boew.github.io/wet-boew/License-en.html / wet-boew.github.io/wet-boew/Licence-fr.html
 * v12.5.0 - 2022-12-13
 *
 */
/*
 *
 * Web Experience Toolkit (WET) / Boîte à outils de l'expérience Web (BOEW)
 * wet-boew.github.io/wet-boew/License-en.html / wet-boew.github.io/wet-boew/Licence-fr.html
 *
 */
/*! Global and helpers */
/*
 Global variables for GCWeb
 */
/* Headings font-sizes */
/* Small font-size */
/* Font weight */
/*
Left menu variables
*/
/*
 * Web Experience Toolkit (WET) / Boîte à outils de l'expérience Web (BOEW)
 * wet-boew.github.io/wet-boew/License-en.html / wet-boew.github.io/wet-boew/Licence-fr.html
 */
/*
 * HOW TO USE THIS FILE
 * Use this file to override Bootstrap variables and WET custom variables.
 * If there is a Bootstrap variable not shown here that you want to override, go to "../node_modules/bootstrap-sass/assets/stylesheets/bootstrap/variables" to view the variables that you can override. Simply copy and paste the variable and its applicable section (if applicable) from the Bootstrap file into this override file and override the variables as applicable.
 */
/*
 * Web Experience Toolkit (WET) / Boîte à outils de l'expérience Web (BOEW)
 * wet-boew.github.io/wet-boew/License-en.html / wet-boew.github.io/wet-boew/Licence-fr.html
 */
/*
 * HOW TO USE THIS FILE
 * Use this file to override Bootstrap variables and WET custom variables.
 * If there is a Bootstrap variable not shown here that you want to override, go to "../node_modules/bootstrap-sass/assets/stylesheets/bootstrap/variables" to view the variables that you can override. Simply copy and paste the variable and its applicable section (if applicable) from the Bootstrap file into this override file and override the variables as applicable.
 */
/*
  WET-BOEW
  @title: Bootstrap overrides for WET-BOEW - Helper - Variables
 */
/*
 *  Firefox-safe line height on input[type="reset|button|submit"]
 */
/*
  WET-BOEW
  @title: Helper - Global mixin
 */
/*
  WET-BOEW
  @title: Proximity CSS - Helper mixin
 */
/*
 *
 * Web Experience Toolkit (WET) / Boîte à outils de l'expérience Web (BOEW)
 * wet-boew.github.io/wet-boew/License-en.html / wet-boew.github.io/wet-boew/Licence-fr.html
 *
 * @title: Mixins
 *
 */
/* Theme base styles */
/*
  WET-BOEW
  @title: Helper - Global Placeholders
 */
#wb-bc li:first-child:before, [dir=rtl] #wb-bc li:first-child:before, .pagination.disabled,
.pager.disabled, .pagination > li.disabled,
.pager > li.disabled, [dir=rtl] .pagination [rel="prev"]:before,
[dir=rtl] .pager [rel="prev"]:before, [dir=rtl] .pagination [rel="next"]:after,
[dir=rtl] .pager [rel="next"]:after, #mb-pnl .modal-body h2, table.dataTable thead .sorting-icons, table.dataTable thead .sorting_asc_disabled .sorting-icons:before, table.dataTable thead .sorting_desc_disabled .sorting-icons:after, .dataTables_wrapper .dataTables_paginate .paginate_button.disabled, [dir=rtl] .dataTables_wrapper .dataTables_paginate .paginate_button.previous:before, [dir=rtl] .dataTables_wrapper .dataTables_paginate .paginate_button.next:after, [dir=rtl] .dataTables_wrapper .dataTables_paginate .paginate_button.disabled, .wb-tabs.carousel-s1 [role="tablist"] > li, .wb-tabs.carousel-s2 [role="tablist"] > li {
	display: none; }

.wb-menu .sm.open li, .wb-disable .wb-tabs > details, .wb-disable .wb-tabs > .tabpanels > details {
	display: block; }

.wb-disable .mfp-hide, .wb-disable #wb-srch, .wb-disable #wb-sm, .wb-disable #wb-sec, .wb-disable #wb-info, .wb-disable .wb-overlay {
	display: block !important; }

.wb-menu .menu > li a, .wb-menu .menu > li a:hover, .wb-menu .menu > li a:focus, .wb-menu .active > a {
	text-decoration: none; }

.wb-mltmd.video.waiting .display:after, .wb-enable .wb-twitter .twitter-timeline:after, .geomap-progress:after, .wb-mltmd.video:not(.playing):not(.waiting) .display:after, .wb-mltmd.video.waiting .display:before, .wb-enable .wb-twitter .twitter-timeline:before, .geomap-progress:before, .wb-mltmd.video:not(.playing):not(.waiting) .display:before {
	bottom: 0;
	content: " ";
	height: 100px;
	left: 0;
	margin: auto;
	position: absolute;
	right: 0;
	top: 0;
	width: 100px; }

.wb-mltmd.video.waiting .display:after, .wb-enable .wb-twitter .twitter-timeline:after, .geomap-progress:after, .wb-mltmd.video:not(.playing):not(.waiting) .display:after {
	z-index: 1; }

.wb-mltmd.video.waiting .display:before, .wb-enable .wb-twitter .twitter-timeline:before, .geomap-progress:before, .wb-mltmd.video:not(.playing):not(.waiting) .display:before {
	background: rgba(0, 0, 0, 0.7);
	border-radius: 10px; }

/* TODO: Use bootstrap placeholder when nested extends are supported */
.wb-mltmd.video.waiting .display:after, .wb-enable .wb-twitter .twitter-timeline:after, .geomap-progress:after {
	-webkit-animation-duration: 500ms;
	        animation-duration: 500ms;
	-webkit-animation-iteration-count: infinite;
	        animation-iteration-count: infinite;
	-webkit-animation-name: spin;
	        animation-name: spin;
	-webkit-animation-timing-function: linear;
	        animation-timing-function: linear;
	color: #fff;
	content: "\e031";
	font-family: "Glyphicons Halflings";
	font-size: 3.5em;
	height: 1em;
	line-height: 1.03;
	width: 1em;
	z-index: 2; }

/*! Reset and dependencies */
/*! normalize.css v3.0.3 | MIT License | github.com/necolas/normalize.css */
html {
	font-family: sans-serif;
	-ms-text-size-adjust: 100%;
	-webkit-text-size-adjust: 100%; }

body {
	margin: 0; }

article,
aside,
details,
figcaption,
figure,
footer,
header,
hgroup,
main,
menu,
nav,
section,
summary {
	display: block; }

audio,
canvas,
progress,
video {
	display: inline-block;
	vertical-align: baseline; }

audio:not([controls]) {
	display: none;
	height: 0; }

[hidden],
template {
	display: none; }

a {
	background-color: transparent; }

a:active,
a:hover {
	outline: 0; }

abbr[title] {
	border-bottom: none;
	text-decoration: underline;
	-webkit-text-decoration: underline dotted;
	        text-decoration: underline dotted; }

b,
strong {
	font-weight: bold; }

dfn {
	font-style: italic; }

h1 {
	font-size: 2em;
	margin: 0.67em 0; }

mark {
	background: #ff0;
	color: #000; }

small {
	font-size: 80%; }

sub,
sup {
	font-size: 75%;
	line-height: 0;
	position: relative;
	vertical-align: baseline; }

sup {
	top: -0.5em; }

sub {
	bottom: -0.25em; }

img {
	border: 0; }

svg:not(:root) {
	overflow: hidden; }

figure {
	margin: 1em 40px; }

hr {
	-webkit-box-sizing: content-box;
	        box-sizing: content-box;
	height: 0; }

pre {
	overflow: auto; }

code,
kbd,
pre,
samp {
	font-family: monospace, monospace;
	font-size: 1em; }

button,
input,
optgroup,
select,
textarea {
	color: inherit;
	font: inherit;
	margin: 0; }

button {
	overflow: visible; }

button,
select {
	text-transform: none; }

button,
html input[type="button"],
input[type="reset"],
input[type="submit"] {
	-webkit-appearance: button;
	cursor: pointer; }

button[disabled],
html input[disabled] {
	cursor: default; }

button::-moz-focus-inner,
input::-moz-focus-inner {
	border: 0;
	padding: 0; }

input {
	line-height: normal; }

input[type="checkbox"],
input[type="radio"] {
	-webkit-box-sizing: border-box;
	        box-sizing: border-box;
	padding: 0; }

input[type="number"]::-webkit-inner-spin-button,
input[type="number"]::-webkit-outer-spin-button {
	height: auto; }

input[type="search"] {
	-webkit-appearance: textfield;
	-webkit-box-sizing: content-box;
	        box-sizing: content-box; }

input[type="search"]::-webkit-search-cancel-button,
input[type="search"]::-webkit-search-decoration {
	-webkit-appearance: none; }

fieldset {
	border: 1px solid #c0c0c0;
	margin: 0 2px;
	padding: 0.35em 0.625em 0.75em; }

legend {
	border: 0;
	padding: 0; }

textarea {
	overflow: auto; }

optgroup {
	font-weight: bold; }

table {
	border-collapse: collapse;
	border-spacing: 0; }

td,
th {
	padding: 0; }

/*! Source: https://github.com/h5bp/html5-boilerplate/blob/master/src/css/main.css */
@media print {
	*,
	*:before,
	*:after {
		color: #000 !important;
		text-shadow: none !important;
		background: transparent !important;
		-webkit-box-shadow: none !important;
		        box-shadow: none !important; }
	a,
	a:visited {
		text-decoration: underline; }
	a[href]:after {
		content: " (" attr(href) ")"; }
	abbr[title]:after {
		content: " (" attr(title) ")"; }
	a[href^="#"]:after,
	a[href^="javascript:"]:after {
		content: ""; }
	pre,
	blockquote {
		border: 1px solid #999;
		page-break-inside: avoid; }
	thead {
		display: table-header-group; }
	tr,
	img {
		page-break-inside: avoid; }
	img {
		max-width: 100% !important; }
	p,
	h2,
	h3 {
		orphans: 3;
		widows: 3; }
	h2,
	h3 {
		page-break-after: avoid; }
	.navbar {
		display: none; }
	.btn > .caret,
	.dropup > .btn > .caret {
		border-top-color: #000 !important; }
	.label {
		border: 1px solid #000; }
	.table {
		border-collapse: collapse !important; }
		.table td,
		.table th {
			background-color: #fff !important; }
	.table-bordered th,
	.table-bordered td {
		border: 1px solid #ddd !important; } }

@font-face {
	font-family: "Glyphicons Halflings";
	src: url("../../wet-boew/fonts/glyphicons-halflings-regular.eot");
	src: url("../../wet-boew/fonts/glyphicons-halflings-regular.eot?#iefix") format("embedded-opentype"), url("../../wet-boew/fonts/glyphicons-halflings-regular.woff2") format("woff2"), url("../../wet-boew/fonts/glyphicons-halflings-regular.woff") format("woff"), url("../../wet-boew/fonts/glyphicons-halflings-regular.ttf") format("truetype"), url("../../wet-boew/fonts/glyphicons-halflings-regular.svg#glyphicons_halflingsregular") format("svg"); }

.glyphicon {
	position: relative;
	top: 1px;
	display: inline-block;
	font-family: "Glyphicons Halflings";
	font-style: normal;
	font-weight: 400;
	line-height: 1;
	-webkit-font-smoothing: antialiased;
	-moz-osx-font-smoothing: grayscale; }

.glyphicon-asterisk:before {
	content: "\002a"; }

.glyphicon-plus:before {
	content: "\002b"; }

.glyphicon-euro:before,
.glyphicon-eur:before {
	content: "\20ac"; }

.glyphicon-minus:before {
	content: "\2212"; }

.glyphicon-cloud:before {
	content: "\2601"; }

.glyphicon-envelope:before {
	content: "\2709"; }

.glyphicon-pencil:before {
	content: "\270f"; }

.glyphicon-glass:before {
	content: "\e001"; }

.glyphicon-music:before {
	content: "\e002"; }

.glyphicon-search:before {
	content: "\e003"; }

.glyphicon-heart:before {
	content: "\e005"; }

.glyphicon-star:before {
	content: "\e006"; }

.glyphicon-star-empty:before {
	content: "\e007"; }

.glyphicon-user:before {
	content: "\e008"; }

.glyphicon-film:before {
	content: "\e009"; }

.glyphicon-th-large:before {
	content: "\e010"; }

.glyphicon-th:before {
	content: "\e011"; }

.glyphicon-th-list:before {
	content: "\e012"; }

.glyphicon-ok:before {
	content: "\e013"; }

.glyphicon-remove:before {
	content: "\e014"; }

.glyphicon-zoom-in:before {
	content: "\e015"; }

.glyphicon-zoom-out:before {
	content: "\e016"; }

.glyphicon-off:before {
	content: "\e017"; }

.glyphicon-signal:before {
	content: "\e018"; }

.glyphicon-cog:before {
	content: "\e019"; }

.glyphicon-trash:before {
	content: "\e020"; }

.glyphicon-home:before {
	content: "\e021"; }

.glyphicon-file:before {
	content: "\e022"; }

.glyphicon-time:before {
	content: "\e023"; }

.glyphicon-road:before {
	content: "\e024"; }

.glyphicon-download-alt:before {
	content: "\e025"; }

.glyphicon-download:before {
	content: "\e026"; }

.glyphicon-upload:before {
	content: "\e027"; }

.glyphicon-inbox:before {
	content: "\e028"; }

.glyphicon-play-circle:before {
	content: "\e029"; }

.glyphicon-repeat:before {
	content: "\e030"; }

.glyphicon-refresh:before {
	content: "\e031"; }

.glyphicon-list-alt:before {
	content: "\e032"; }

.glyphicon-lock:before {
	content: "\e033"; }

.glyphicon-flag:before {
	content: "\e034"; }

.glyphicon-headphones:before {
	content: "\e035"; }

.glyphicon-volume-off:before {
	content: "\e036"; }

.glyphicon-volume-down:before {
	content: "\e037"; }

.glyphicon-volume-up:before {
	content: "\e038"; }

.glyphicon-qrcode:before {
	content: "\e039"; }

.glyphicon-barcode:before {
	content: "\e040"; }

.glyphicon-tag:before {
	content: "\e041"; }

.glyphicon-tags:before {
	content: "\e042"; }

.glyphicon-book:before {
	content: "\e043"; }

.glyphicon-bookmark:before {
	content: "\e044"; }

.glyphicon-print:before {
	content: "\e045"; }

.glyphicon-camera:before {
	content: "\e046"; }

.glyphicon-font:before {
	content: "\e047"; }

.glyphicon-bold:before {
	content: "\e048"; }

.glyphicon-italic:before {
	content: "\e049"; }

.glyphicon-text-height:before {
	content: "\e050"; }

.glyphicon-text-width:before {
	content: "\e051"; }

.glyphicon-align-left:before {
	content: "\e052"; }

.glyphicon-align-center:before {
	content: "\e053"; }

.glyphicon-align-right:before {
	content: "\e054"; }

.glyphicon-align-justify:before {
	content: "\e055"; }

.glyphicon-list:before {
	content: "\e056"; }

.glyphicon-indent-left:before {
	content: "\e057"; }

.glyphicon-indent-right:before {
	content: "\e058"; }

.glyphicon-facetime-video:before {
	content: "\e059"; }

.glyphicon-picture:before {
	content: "\e060"; }

.glyphicon-map-marker:before {
	content: "\e062"; }

.glyphicon-adjust:before {
	content: "\e063"; }

.glyphicon-tint:before {
	content: "\e064"; }

.glyphicon-edit:before {
	content: "\e065"; }

.glyphicon-share:before {
	content: "\e066"; }

.glyphicon-check:before {
	content: "\e067"; }

.glyphicon-move:before {
	content: "\e068"; }

.glyphicon-step-backward:before {
	content: "\e069"; }

.glyphicon-fast-backward:before {
	content: "\e070"; }

.glyphicon-backward:before {
	content: "\e071"; }

.glyphicon-play:before {
	content: "\e072"; }

.glyphicon-pause:before {
	content: "\e073"; }

.glyphicon-stop:before {
	content: "\e074"; }

.glyphicon-forward:before {
	content: "\e075"; }

.glyphicon-fast-forward:before {
	content: "\e076"; }

.glyphicon-step-forward:before {
	content: "\e077"; }

.glyphicon-eject:before {
	content: "\e078"; }

.glyphicon-chevron-left:before {
	content: "\e079"; }

.glyphicon-chevron-right:before {
	content: "\e080"; }

.glyphicon-plus-sign:before {
	content: "\e081"; }

.glyphicon-minus-sign:before {
	content: "\e082"; }

.glyphicon-remove-sign:before {
	content: "\e083"; }

.glyphicon-ok-sign:before {
	content: "\e084"; }

.glyphicon-question-sign:before {
	content: "\e085"; }

.glyphicon-info-sign:before {
	content: "\e086"; }

.glyphicon-screenshot:before {
	content: "\e087"; }

.glyphicon-remove-circle:before {
	content: "\e088"; }

.glyphicon-ok-circle:before {
	content: "\e089"; }

.glyphicon-ban-circle:before {
	content: "\e090"; }

.glyphicon-arrow-left:before {
	content: "\e091"; }

.glyphicon-arrow-right:before {
	content: "\e092"; }

.glyphicon-arrow-up:before {
	content: "\e093"; }

.glyphicon-arrow-down:before {
	content: "\e094"; }

.glyphicon-share-alt:before {
	content: "\e095"; }

.glyphicon-resize-full:before {
	content: "\e096"; }

.glyphicon-resize-small:before {
	content: "\e097"; }

.glyphicon-exclamation-sign:before {
	content: "\e101"; }

.glyphicon-gift:before {
	content: "\e102"; }

.glyphicon-leaf:before {
	content: "\e103"; }

.glyphicon-fire:before {
	content: "\e104"; }

.glyphicon-eye-open:before {
	content: "\e105"; }

.glyphicon-eye-close:before {
	content: "\e106"; }

.glyphicon-warning-sign:before {
	content: "\e107"; }

.glyphicon-plane:before {
	content: "\e108"; }

.glyphicon-calendar:before {
	content: "\e109"; }

.glyphicon-random:before {
	content: "\e110"; }

.glyphicon-comment:before {
	content: "\e111"; }

.glyphicon-magnet:before {
	content: "\e112"; }

.glyphicon-chevron-up:before {
	content: "\e113"; }

.glyphicon-chevron-down:before {
	content: "\e114"; }

.glyphicon-retweet:before {
	content: "\e115"; }

.glyphicon-shopping-cart:before {
	content: "\e116"; }

.glyphicon-folder-close:before {
	content: "\e117"; }

.glyphicon-folder-open:before {
	content: "\e118"; }

.glyphicon-resize-vertical:before {
	content: "\e119"; }

.glyphicon-resize-horizontal:before {
	content: "\e120"; }

.glyphicon-hdd:before {
	content: "\e121"; }

.glyphicon-bullhorn:before {
	content: "\e122"; }

.glyphicon-bell:before {
	content: "\e123"; }

.glyphicon-certificate:before {
	content: "\e124"; }

.glyphicon-thumbs-up:before {
	content: "\e125"; }

.glyphicon-thumbs-down:before {
	content: "\e126"; }

.glyphicon-hand-right:before {
	content: "\e127"; }

.glyphicon-hand-left:before {
	content: "\e128"; }

.glyphicon-hand-up:before {
	content: "\e129"; }

.glyphicon-hand-down:before {
	content: "\e130"; }

.glyphicon-circle-arrow-right:before {
	content: "\e131"; }

.glyphicon-circle-arrow-left:before {
	content: "\e132"; }

.glyphicon-circle-arrow-up:before {
	content: "\e133"; }

.glyphicon-circle-arrow-down:before {
	content: "\e134"; }

.glyphicon-globe:before {
	content: "\e135"; }

.glyphicon-wrench:before {
	content: "\e136"; }

.glyphicon-tasks:before {
	content: "\e137"; }

.glyphicon-filter:before {
	content: "\e138"; }

.glyphicon-briefcase:before {
	content: "\e139"; }

.glyphicon-fullscreen:before {
	content: "\e140"; }

.glyphicon-dashboard:before {
	content: "\e141"; }

.glyphicon-paperclip:before {
	content: "\e142"; }

.glyphicon-heart-empty:before {
	content: "\e143"; }

.glyphicon-link:before {
	content: "\e144"; }

.glyphicon-phone:before {
	content: "\e145"; }

.glyphicon-pushpin:before {
	content: "\e146"; }

.glyphicon-usd:before {
	content: "\e148"; }

.glyphicon-gbp:before {
	content: "\e149"; }

.glyphicon-sort:before {
	content: "\e150"; }

.glyphicon-sort-by-alphabet:before {
	content: "\e151"; }

.glyphicon-sort-by-alphabet-alt:before {
	content: "\e152"; }

.glyphicon-sort-by-order:before {
	content: "\e153"; }

.glyphicon-sort-by-order-alt:before {
	content: "\e154"; }

.glyphicon-sort-by-attributes:before {
	content: "\e155"; }

.glyphicon-sort-by-attributes-alt:before {
	content: "\e156"; }

.glyphicon-unchecked:before {
	content: "\e157"; }

.glyphicon-expand:before {
	content: "\e158"; }

.glyphicon-collapse-down:before {
	content: "\e159"; }

.glyphicon-collapse-up:before {
	content: "\e160"; }

.glyphicon-log-in:before {
	content: "\e161"; }

.glyphicon-flash:before {
	content: "\e162"; }

.glyphicon-log-out:before {
	content: "\e163"; }

.glyphicon-new-window:before {
	content: "\e164"; }

.glyphicon-record:before {
	content: "\e165"; }

.glyphicon-save:before {
	content: "\e166"; }

.glyphicon-open:before {
	content: "\e167"; }

.glyphicon-saved:before {
	content: "\e168"; }

.glyphicon-import:before {
	content: "\e169"; }

.glyphicon-export:before {
	content: "\e170"; }

.glyphicon-send:before {
	content: "\e171"; }

.glyphicon-floppy-disk:before {
	content: "\e172"; }

.glyphicon-floppy-saved:before {
	content: "\e173"; }

.glyphicon-floppy-remove:before {
	content: "\e174"; }

.glyphicon-floppy-save:before {
	content: "\e175"; }

.glyphicon-floppy-open:before {
	content: "\e176"; }

.glyphicon-credit-card:before {
	content: "\e177"; }

.glyphicon-transfer:before {
	content: "\e178"; }

.glyphicon-cutlery:before {
	content: "\e179"; }

.glyphicon-header:before {
	content: "\e180"; }

.glyphicon-compressed:before {
	content: "\e181"; }

.glyphicon-earphone:before {
	content: "\e182"; }

.glyphicon-phone-alt:before {
	content: "\e183"; }

.glyphicon-tower:before {
	content: "\e184"; }

.glyphicon-stats:before {
	content: "\e185"; }

.glyphicon-sd-video:before {
	content: "\e186"; }

.glyphicon-hd-video:before {
	content: "\e187"; }

.glyphicon-subtitles:before {
	content: "\e188"; }

.glyphicon-sound-stereo:before {
	content: "\e189"; }

.glyphicon-sound-dolby:before {
	content: "\e190"; }

.glyphicon-sound-5-1:before {
	content: "\e191"; }

.glyphicon-sound-6-1:before {
	content: "\e192"; }

.glyphicon-sound-7-1:before {
	content: "\e193"; }

.glyphicon-copyright-mark:before {
	content: "\e194"; }

.glyphicon-registration-mark:before {
	content: "\e195"; }

.glyphicon-cloud-download:before {
	content: "\e197"; }

.glyphicon-cloud-upload:before {
	content: "\e198"; }

.glyphicon-tree-conifer:before {
	content: "\e199"; }

.glyphicon-tree-deciduous:before {
	content: "\e200"; }

.glyphicon-cd:before {
	content: "\e201"; }

.glyphicon-save-file:before {
	content: "\e202"; }

.glyphicon-open-file:before {
	content: "\e203"; }

.glyphicon-level-up:before {
	content: "\e204"; }

.glyphicon-copy:before {
	content: "\e205"; }

.glyphicon-paste:before {
	content: "\e206"; }

.glyphicon-alert:before {
	content: "\e209"; }

.glyphicon-equalizer:before {
	content: "\e210"; }

.glyphicon-king:before {
	content: "\e211"; }

.glyphicon-queen:before {
	content: "\e212"; }

.glyphicon-pawn:before {
	content: "\e213"; }

.glyphicon-bishop:before {
	content: "\e214"; }

.glyphicon-knight:before {
	content: "\e215"; }

.glyphicon-baby-formula:before {
	content: "\e216"; }

.glyphicon-tent:before {
	content: "\26fa"; }

.glyphicon-blackboard:before {
	content: "\e218"; }

.glyphicon-bed:before {
	content: "\e219"; }

.glyphicon-apple:before {
	content: "\f8ff"; }

.glyphicon-erase:before {
	content: "\e221"; }

.glyphicon-hourglass:before {
	content: "\231b"; }

.glyphicon-lamp:before {
	content: "\e223"; }

.glyphicon-duplicate:before {
	content: "\e224"; }

.glyphicon-piggy-bank:before {
	content: "\e225"; }

.glyphicon-scissors:before {
	content: "\e226"; }

.glyphicon-bitcoin:before {
	content: "\e227"; }

.glyphicon-btc:before {
	content: "\e227"; }

.glyphicon-xbt:before {
	content: "\e227"; }

.glyphicon-yen:before {
	content: "\00a5"; }

.glyphicon-jpy:before {
	content: "\00a5"; }

.glyphicon-ruble:before {
	content: "\20bd"; }

.glyphicon-rub:before {
	content: "\20bd"; }

.glyphicon-scale:before {
	content: "\e230"; }

.glyphicon-ice-lolly:before {
	content: "\e231"; }

.glyphicon-ice-lolly-tasted:before {
	content: "\e232"; }

.glyphicon-education:before {
	content: "\e233"; }

.glyphicon-option-horizontal:before {
	content: "\e234"; }

.glyphicon-option-vertical:before {
	content: "\e235"; }

.glyphicon-menu-hamburger:before {
	content: "\e236"; }

.glyphicon-modal-window:before {
	content: "\e237"; }

.glyphicon-oil:before {
	content: "\e238"; }

.glyphicon-grain:before {
	content: "\e239"; }

.glyphicon-sunglasses:before {
	content: "\e240"; }

.glyphicon-text-size:before {
	content: "\e241"; }

.glyphicon-text-color:before {
	content: "\e242"; }

.glyphicon-text-background:before {
	content: "\e243"; }

.glyphicon-object-align-top:before {
	content: "\e244"; }

.glyphicon-object-align-bottom:before {
	content: "\e245"; }

.glyphicon-object-align-horizontal:before {
	content: "\e246"; }

.glyphicon-object-align-left:before {
	content: "\e247"; }

.glyphicon-object-align-vertical:before {
	content: "\e248"; }

.glyphicon-object-align-right:before {
	content: "\e249"; }

.glyphicon-triangle-right:before {
	content: "\e250"; }

.glyphicon-triangle-left:before {
	content: "\e251"; }

.glyphicon-triangle-bottom:before {
	content: "\e252"; }

.glyphicon-triangle-top:before {
	content: "\e253"; }

.glyphicon-console:before {
	content: "\e254"; }

.glyphicon-superscript:before {
	content: "\e255"; }

.glyphicon-subscript:before {
	content: "\e256"; }

.glyphicon-menu-left:before {
	content: "\e257"; }

.glyphicon-menu-right:before {
	content: "\e258"; }

.glyphicon-menu-down:before {
	content: "\e259"; }

.glyphicon-menu-up:before {
	content: "\e260"; }

/*! Core - HTML */
/*
 *
 * Web Experience Toolkit (WET) / Boîte à outils de l'expérience Web (BOEW)
 * wet-boew.github.io/wet-boew/License-en.html / wet-boew.github.io/wet-boew/Licence-fr.html
 *
 * @title: Glyphicons
 *
 */
main .glyphicon {
	top: 2px; }

.glyphicon-error {
	color: #96323a;
	font-size: 400%; }

@font-face {
	font-family: "gcweb";
	font-style: normal;
	font-weight: normal;
	src: url("../fonts/gcweb_0c4a4eb7974d0a7287c93c02965f9b3f.eot"), url("../fonts/gcweb_0c4a4eb7974d0a7287c93c02965f9b3f.eot?#iefix") format("embedded-opentype"), url("../fonts/gcweb_0c4a4eb7974d0a7287c93c02965f9b3f.woff") format("woff"), url("../fonts/gcweb_0c4a4eb7974d0a7287c93c02965f9b3f.ttf") format("truetype"), url("../fonts/gcweb_0c4a4eb7974d0a7287c93c02965f9b3f.svg#gcweb") format("svg"); }

.icn-sig-en:before,
.icn-sig-fr:before, .cndwrdmrk:before, .cndwrdmrk:after {
	-webkit-font-smoothing: antialiased;
	-webkit-text-stroke: 1px transparent;
	display: block;
	font-family: "gcweb";
	font-style: normal;
	font-variant: normal;
	font-weight: normal;
	line-height: 1;
	text-decoration: none;
	text-shadow: 0 0 1px rgba(0, 0, 0, 0.3);
	text-transform: none;
	-webkit-transform: rotate(0);
	        transform: rotate(0); }

.icn-sig-en,
.icn-sig-fr {
	color: #fff;
	display: inline-block;
	font-size: 1.5em;
	padding: .7em 0 .5em; }
	.icn-sig-en:before,
	.icn-sig-fr:before {
		position: relative; }

:root .icn-sig-en:before,
.icn-sig-fr:before {
	left: -10em; }

.icn-sig-en:before {
	content: "\f102"; }

.icn-sig-fr:before {
	content: "\f103"; }

.cndwrdmrk {
	font-size: 3.5em;
	min-width: 100%;
	position: relative;
	text-decoration: none; }
	.cndwrdmrk:before, .cndwrdmrk:after {
		display: inline;
		position: relative; }
	.cndwrdmrk:before {
		color: #000;
		content: "\f100"; }
	.cndwrdmrk:after {
		color: #f00;
		content: "\f101";
		left: -1em; }

/*
 *
 * Web Experience Toolkit (WET) / Boîte à outils de l'expérience Web (BOEW)
 * wet-boew.github.io/wet-boew/License-en.html / wet-boew.github.io/wet-boew/Licence-fr.html
 *
 * @title: Base Font for GCWeb
 *
 */
/*
 * Font Noto
 *
 * ref. https://fonts.googleapis.com/css?family=Noto+Sans:400,700,400italic,700italic&subset=latin,latin-ext
 * Licence: SIL OPEN FONT LICENSE
 */
/* latin-ext */
@font-face {
	font-display: optional;
	font-family: "Noto Sans";
	font-style: italic;
	font-weight: 400;
	src: url(https://fonts.gstatic.com/s/notosans/v25/o-0OIpQlx3QUlC5A4PNr4ARMQ_m87A.woff2) format("woff2");
	unicode-range: U+0100-024F, U+0259, U+1E00-1EFF, U+2020, U+20A0-20AB, U+20AD-20CF, U+2113, U+2C60-2C7F, U+A720-A7FF; }

/* latin */
@font-face {
	font-display: fallback;
	font-family: "Noto Sans";
	font-style: italic;
	font-weight: 400;
	src: url(https://fonts.gstatic.com/s/notosans/v25/o-0OIpQlx3QUlC5A4PNr4ARCQ_k.woff2) format("woff2");
	unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02BB-02BC, U+02C6, U+02DA, U+02DC, U+2000-206F, U+2074, U+20AC, U+2122, U+2191, U+2193, U+2212, U+2215, U+FEFF, U+FFFD; }

/* latin-ext */
@font-face {
	font-display: optional;
	font-family: "Noto Sans";
	font-style: italic;
	font-weight: 700;
	src: url(https://fonts.gstatic.com/s/notosans/v25/o-0TIpQlx3QUlC5A4PNr4Az5ZuyNzW1aPQ.woff2) format("woff2");
	unicode-range: U+0100-024F, U+0259, U+1E00-1EFF, U+2020, U+20A0-20AB, U+20AD-20CF, U+2113, U+2C60-2C7F, U+A720-A7FF; }

/* latin */
@font-face {
	font-display: optional;
	font-family: "Noto Sans";
	font-style: italic;
	font-weight: 700;
	src: url(https://fonts.gstatic.com/s/notosans/v25/o-0TIpQlx3QUlC5A4PNr4Az5ZuyDzW0.woff2) format("woff2");
	unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02BB-02BC, U+02C6, U+02DA, U+02DC, U+2000-206F, U+2074, U+20AC, U+2122, U+2191, U+2193, U+2212, U+2215, U+FEFF, U+FFFD; }

/* latin-ext */
@font-face {
	font-display: optional;
	font-family: "Noto Sans";
	font-style: normal;
	font-weight: 400;
	src: url(https://fonts.gstatic.com/s/notosans/v25/o-0IIpQlx3QUlC5A4PNr6zRAW_0.woff2) format("woff2");
	unicode-range: U+0100-024F, U+0259, U+1E00-1EFF, U+2020, U+20A0-20AB, U+20AD-20CF, U+2113, U+2C60-2C7F, U+A720-A7FF; }

/* latin */
@font-face {
	font-display: fallback;
	font-family: "Noto Sans";
	font-style: normal;
	font-weight: 400;
	src: url(https://fonts.gstatic.com/s/notosans/v25/o-0IIpQlx3QUlC5A4PNr5TRA.woff2) format("woff2");
	unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02BB-02BC, U+02C6, U+02DA, U+02DC, U+2000-206F, U+2074, U+20AC, U+2122, U+2191, U+2193, U+2212, U+2215, U+FEFF, U+FFFD; }

/* latin-ext */
@font-face {
	font-display: optional;
	font-family: "Noto Sans";
	font-style: normal;
	font-weight: 700;
	src: url(https://fonts.gstatic.com/s/notosans/v25/o-0NIpQlx3QUlC5A4PNjXhFVatyB1Wk.woff2) format("woff2");
	unicode-range: U+0100-024F, U+0259, U+1E00-1EFF, U+2020, U+20A0-20AB, U+20AD-20CF, U+2113, U+2C60-2C7F, U+A720-A7FF; }

/* latin */
@font-face {
	font-display: fallback;
	font-family: "Noto Sans";
	font-style: normal;
	font-weight: 700;
	src: url(https://fonts.gstatic.com/s/notosans/v25/o-0NIpQlx3QUlC5A4PNjXhFVZNyB.woff2) format("woff2");
	unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02BB-02BC, U+02C6, U+02DA, U+02DC, U+2000-206F, U+2074, U+20AC, U+2122, U+2191, U+2193, U+2212, U+2215, U+FEFF, U+FFFD; }

/*
 * Font Lato
 *
 * ref. https://fonts.googleapis.com/css?family=Lato:400,700,400italic,700italic&subset=latin,latin-ext
 * Licence: SIL Open Font License
 */
/* latin-ext */
@font-face {
	font-display: optional;
	font-family: "Lato";
	font-style: italic;
	font-weight: 400;
	src: url(https://fonts.gstatic.com/s/lato/v22/S6u8w4BMUTPHjxsAUi-qJCY.woff2) format("woff2");
	unicode-range: U+0100-024F, U+0259, U+1E00-1EFF, U+2020, U+20A0-20AB, U+20AD-20CF, U+2113, U+2C60-2C7F, U+A720-A7FF; }

/* latin */
@font-face {
	font-display: optional;
	font-family: "Lato";
	font-style: italic;
	font-weight: 400;
	src: url(https://fonts.gstatic.com/s/lato/v22/S6u8w4BMUTPHjxsAXC-q.woff2) format("woff2");
	unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02BB-02BC, U+02C6, U+02DA, U+02DC, U+2000-206F, U+2074, U+20AC, U+2122, U+2191, U+2193, U+2212, U+2215, U+FEFF, U+FFFD; }

/* latin-ext */
@font-face {
	font-display: optional;
	font-family: "Lato";
	font-style: italic;
	font-weight: 700;
	src: url(https://fonts.gstatic.com/s/lato/v22/S6u_w4BMUTPHjxsI5wq_FQft1dw.woff2) format("woff2");
	unicode-range: U+0100-024F, U+0259, U+1E00-1EFF, U+2020, U+20A0-20AB, U+20AD-20CF, U+2113, U+2C60-2C7F, U+A720-A7FF; }

/* latin */
@font-face {
	font-display: fallback;
	font-family: "Lato";
	font-style: italic;
	font-weight: 700;
	src: url(https://fonts.gstatic.com/s/lato/v22/S6u_w4BMUTPHjxsI5wq_Gwft.woff2) format("woff2");
	unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02BB-02BC, U+02C6, U+02DA, U+02DC, U+2000-206F, U+2074, U+20AC, U+2122, U+2191, U+2193, U+2212, U+2215, U+FEFF, U+FFFD; }

/* latin-ext */
@font-face {
	font-display: optional;
	font-family: "Lato";
	font-style: normal;
	font-weight: 400;
	src: url(https://fonts.gstatic.com/s/lato/v22/S6uyw4BMUTPHjxAwXjeu.woff2) format("woff2");
	unicode-range: U+0100-024F, U+0259, U+1E00-1EFF, U+2020, U+20A0-20AB, U+20AD-20CF, U+2113, U+2C60-2C7F, U+A720-A7FF; }

/* latin */
@font-face {
	font-display: optional;
	font-family: "Lato";
	font-style: normal;
	font-weight: 400;
	src: url(https://fonts.gstatic.com/s/lato/v22/S6uyw4BMUTPHjx4wXg.woff2) format("woff2");
	unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02BB-02BC, U+02C6, U+02DA, U+02DC, U+2000-206F, U+2074, U+20AC, U+2122, U+2191, U+2193, U+2212, U+2215, U+FEFF, U+FFFD; }

/* latin-ext */
@font-face {
	font-display: optional;
	font-family: "Lato";
	font-style: normal;
	font-weight: 700;
	src: url(https://fonts.gstatic.com/s/lato/v22/S6u9w4BMUTPHh6UVSwaPGR_p.woff2) format("woff2");
	unicode-range: U+0100-024F, U+0259, U+1E00-1EFF, U+2020, U+20A0-20AB, U+20AD-20CF, U+2113, U+2C60-2C7F, U+A720-A7FF; }

/* latin */
@font-face {
	font-display: fallback;
	font-family: "Lato";
	font-style: normal;
	font-weight: 700;
	src: url(https://fonts.gstatic.com/s/lato/v22/S6u9w4BMUTPHh6UVSwiPGQ.woff2) format("woff2");
	unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02BB-02BC, U+02C6, U+02DA, U+02DC, U+2000-206F, U+2074, U+20AC, U+2122, U+2191, U+2193, U+2212, U+2215, U+FEFF, U+FFFD; }

* {
	-webkit-box-sizing: border-box;
	box-sizing: border-box; }

*:before,
*:after {
	-webkit-box-sizing: border-box;
	box-sizing: border-box; }

html {
	font-size: 10px;
	-webkit-tap-highlight-color: rgba(0, 0, 0, 0); }

body {
	font-family: "Noto Sans", sans-serif;
	font-size: 16px;
	line-height: 1.4375;
	color: #333333;
	background-color: #fff; }

input,
button,
select,
textarea {
	font-family: inherit;
	font-size: inherit;
	line-height: inherit; }

a {
	color: #295376;
	text-decoration: none; }
	a:hover, a:focus {
		color: #0535d2;
		text-decoration: underline; }
	a:focus {
		outline: 5px auto -webkit-focus-ring-color;
		outline-offset: -2px; }

figure {
	margin: 0; }

img {
	vertical-align: middle; }

.img-responsive {
	display: block;
	max-width: 100%;
	height: auto; }

.img-rounded {
	border-radius: 6px; }

.img-thumbnail {
	padding: 4px;
	line-height: 1.4375;
	background-color: #fff;
	border: 1px solid #ddd;
	border-radius: 4px;
	-webkit-transition: all 0.2s ease-in-out;
	transition: all 0.2s ease-in-out;
	display: inline-block;
	max-width: 100%;
	height: auto; }

.img-circle {
	border-radius: 50%; }

hr {
	margin-top: 23px;
	margin-bottom: 23px;
	border: 0;
	border-top: 1px solid #eeeeee; }

.sr-only {
	position: absolute;
	width: 1px;
	height: 1px;
	padding: 0;
	margin: -1px;
	overflow: hidden;
	clip: rect(0, 0, 0, 0);
	border: 0; }

.sr-only-focusable:active, .sr-only-focusable:focus {
	position: static;
	width: auto;
	height: auto;
	margin: 0;
	overflow: visible;
	clip: auto; }

[role="button"] {
	cursor: pointer; }

/*
 *
 * Web Experience Toolkit (WET) / Boîte à outils de l'expérience Web (BOEW)
 * wet-boew.github.io/wet-boew/License-en.html / wet-boew.github.io/wet-boew/Licence-fr.html
 *
 * @title: Scaffolding
 *
 */
html {
	-webkit-font-smoothing: antialiased;
	text-rendering: optimizeLegibility; }

main {
	font-size: 20px;
	line-height: 1.65em; }

.cnt-wdth-lmtd main h2,
main .cnt-wdth-lmtd h2 {
	max-width: 33ch; }

.cnt-wdth-lmtd main h3,
main .cnt-wdth-lmtd h3 {
	max-width: 50ch; }

.cnt-wdth-lmtd main h4,
main .cnt-wdth-lmtd h4 {
	max-width: 59ch; }

.cnt-wdth-lmtd main li,
main .cnt-wdth-lmtd li {
	max-width: 63ch; }

.cnt-wdth-lmtd main p, .cnt-wdth-lmtd main h5, .cnt-wdth-lmtd main h6, .cnt-wdth-lmtd main dt, .cnt-wdth-lmtd main dd,
main .cnt-wdth-lmtd p,
main .cnt-wdth-lmtd h5,
main .cnt-wdth-lmtd h6,
main .cnt-wdth-lmtd dt,
main .cnt-wdth-lmtd dd {
	max-width: 65ch; }

main {
	position: relative; }

a {
	color: #284162; }
	a img.thumbnail:hover {
		-webkit-box-shadow: 1px 1px 5px #999;
		        box-shadow: 1px 1px 5px #999; }
	a.no-undrln {
		text-decoration: none; }

/* Style only the figcaption as the link */
a.figcaption {
	text-decoration: none; }
	a.figcaption:not([class*="text-"]) * :not(figcaption) {
		color: #333333; }
	a.figcaption figure > *:not(blockquote):not(img):not(table):not(div) {
		margin-left: .8ch;
		margin-right: .8ch; }
	a.figcaption figcaption {
		text-decoration: underline; }

h1, h2, h3, h4, h5, h6,
.h1, .h2, .h3, .h4, .h5, .h6 {
	font-family: inherit;
	font-weight: 500;
	line-height: 1.1;
	color: inherit; }
	h1 small,
	h1 .small, h2 small,
	h2 .small, h3 small,
	h3 .small, h4 small,
	h4 .small, h5 small,
	h5 .small, h6 small,
	h6 .small,
	.h1 small,
	.h1 .small, .h2 small,
	.h2 .small, .h3 small,
	.h3 .small, .h4 small,
	.h4 .small, .h5 small,
	.h5 .small, .h6 small,
	.h6 .small {
		font-weight: 400;
		line-height: 1;
		color: #6f6f6f; }

h1, .h1,
h2, .h2,
h3, .h3 {
	margin-top: 23px;
	margin-bottom: 11.5px; }
	h1 small,
	h1 .small, .h1 small,
	.h1 .small,
	h2 small,
	h2 .small, .h2 small,
	.h2 .small,
	h3 small,
	h3 .small, .h3 small,
	.h3 .small {
		font-size: 65%; }

h4, .h4,
h5, .h5,
h6, .h6 {
	margin-top: 11.5px;
	margin-bottom: 11.5px; }
	h4 small,
	h4 .small, .h4 small,
	.h4 .small,
	h5 small,
	h5 .small, .h5 small,
	.h5 .small,
	h6 small,
	h6 .small, .h6 small,
	.h6 .small {
		font-size: 75%; }

h1, .h1 {
	font-size: 1.9em; }

h2, .h2 {
	font-size: 1.8em; }

h3, .h3 {
	font-size: 1.2em; }

h4, .h4 {
	font-size: 1.1em; }

h5, .h5 {
	font-size: 1em; }

h6, .h6 {
	font-size: 0.95em; }

p {
	margin: 0 0 11.5px; }

.lead {
	margin-bottom: 23px;
	font-size: 18px;
	font-weight: 300;
	line-height: 1.4; }
	@media (min-width: 768px) {
		.lead {
			font-size: 24px; } }

small,
.small {
	font-size: 87%; }

mark,
.mark {
	padding: .2em;
	background-color: #fcf8e3; }

.text-left {
	text-align: left; }

.text-right {
	text-align: right; }

.text-center {
	text-align: center; }

.text-justify {
	text-align: justify; }

.text-nowrap {
	white-space: nowrap; }

.text-lowercase {
	text-transform: lowercase; }

.text-uppercase, .initialism {
	text-transform: uppercase; }

.text-capitalize {
	text-transform: capitalize; }

.text-muted {
	color: #6f6f6f; }

.text-primary {
	color: #2572b4; }

a.text-primary:hover,
a.text-primary:focus {
	color: #1c578a; }

.text-success {
	color: #3c763d; }

a.text-success:hover,
a.text-success:focus {
	color: #2b542c; }

.text-info {
	color: #31708f; }

a.text-info:hover,
a.text-info:focus {
	color: #245269; }

.text-warning {
	color: #8a6d3b; }

a.text-warning:hover,
a.text-warning:focus {
	color: #66512c; }

.text-danger {
	color: #a94442; }

a.text-danger:hover,
a.text-danger:focus {
	color: #843534; }

.bg-primary {
	color: #fff; }

.bg-primary {
	background-color: #2572b4; }

a.bg-primary:hover,
a.bg-primary:focus {
	background-color: #1c578a; }

.bg-success {
	background-color: #dff0d8; }

a.bg-success:hover,
a.bg-success:focus {
	background-color: #c1e2b3; }

.bg-info {
	background-color: #d9edf7; }

a.bg-info:hover,
a.bg-info:focus {
	background-color: #afd9ee; }

.bg-warning {
	background-color: #fcf8e3; }

a.bg-warning:hover,
a.bg-warning:focus {
	background-color: #f7ecb5; }

.bg-danger {
	background-color: #f2dede; }

a.bg-danger:hover,
a.bg-danger:focus {
	background-color: #e4b9b9; }

.page-header {
	padding-bottom: 10.5px;
	margin: 46px 0 23px;
	border-bottom: 1px solid #eeeeee; }

ul,
ol {
	margin-top: 0;
	margin-bottom: 11.5px; }
	ul ul,
	ul ol,
	ol ul,
	ol ol {
		margin-bottom: 0; }

.list-unstyled {
	padding-left: 0;
	list-style: none; }

.list-inline {
	padding-left: 0;
	list-style: none;
	margin-left: -5px; }
	.list-inline > li {
		display: inline-block;
		padding-right: 5px;
		padding-left: 5px; }

dl {
	margin-top: 0;
	margin-bottom: 23px; }

dt,
dd {
	line-height: 1.4375; }

dt {
	font-weight: 700; }

dd {
	margin-left: 0; }

.dl-horizontal dd:before, .dl-horizontal dd:after {
	display: table;
	content: " "; }

.dl-horizontal dd:after {
	clear: both; }

@media (min-width: 768px) {
	.dl-horizontal dt {
		float: left;
		width: 160px;
		clear: left;
		text-align: right;
		overflow: hidden;
		text-overflow: ellipsis;
		white-space: nowrap; }
	.dl-horizontal dd {
		margin-left: 180px; } }

abbr[title],
abbr[data-original-title] {
	cursor: help; }

.initialism {
	font-size: 90%; }

blockquote {
	padding: 11.5px 23px;
	margin: 0 0 23px;
	font-size: 20px;
	border-left: 5px solid #eeeeee; }
	blockquote p:last-child,
	blockquote ul:last-child,
	blockquote ol:last-child {
		margin-bottom: 0; }
	blockquote footer,
	blockquote small,
	blockquote .small {
		display: block;
		font-size: 80%;
		line-height: 1.4375;
		color: #6f6f6f; }
		blockquote footer:before,
		blockquote small:before,
		blockquote .small:before {
			content: "\2014 \00A0"; }

.blockquote-reverse,
blockquote.pull-right {
	padding-right: 15px;
	padding-left: 0;
	text-align: right;
	border-right: 5px solid #eeeeee;
	border-left: 0; }
	.blockquote-reverse footer:before,
	.blockquote-reverse small:before,
	.blockquote-reverse .small:before,
	blockquote.pull-right footer:before,
	blockquote.pull-right small:before,
	blockquote.pull-right .small:before {
		content: ""; }
	.blockquote-reverse footer:after,
	.blockquote-reverse small:after,
	.blockquote-reverse .small:after,
	blockquote.pull-right footer:after,
	blockquote.pull-right small:after,
	blockquote.pull-right .small:after {
		content: "\00A0 \2014"; }

address {
	margin-bottom: 23px;
	font-style: normal;
	line-height: 1.4375; }

/*
	WET-BOEW
	@title: Bootstrap overrides for WET-BOEW - Core CSS - heading
 */
/*! Placeholders */
h1,
.h1, h2,
.h2, h3,
.h3, h4,
.h4, h5,
.h5, h6,
.h6 {
	font-weight: 700; }

h1,
.h1, h2,
.h2 {
	margin-top: 38px; }

/*
 *  Heading top margins
 */
h3, .h3 {
	margin-top: 32px; }

h4, .h4 {
	margin-top: 26px; }

h5, .h5 {
	margin-top: 23px; }

h6, .h6 {
	margin-top: 21px; }

/*
 *
 * Web Experience Toolkit (WET) / Boîte à outils de l'expérience Web (BOEW)
 * wet-boew.github.io/wet-boew/License-en.html / wet-boew.github.io/wet-boew/Licence-fr.html
 *
 * @title: Heading
 *
 */
h1 {
	border-bottom: 1px solid #af3c43;
	margin-bottom: .2em;
	margin-top: 1em;
	padding-bottom: .2em; }

h1, .h1, h2, .h2, h3, .h3, h4, .h4, h5, .h5, h6, .h6 {
	font-family: Lato, sans-serif;
	-webkit-font-variant-ligatures: no-common-ligatures;
	        font-variant-ligatures: no-common-ligatures;
	font-weight: 700; }

.h3,
.h4,
.h5,
.h6 {
	border: 0; }

h6, .h6 {
	font-weight: 400; }

/*
  WET-BOEW
  @title: List CSS
 */
.lst-lwr-alph {
	list-style-type: lower-alpha; }

.lst-upr-alph {
	list-style-type: upper-alpha; }

.lst-lwr-rmn {
	list-style-type: lower-roman; }

.lst-upr-rmn {
	list-style-type: upper-roman; }

.lst-num {
	list-style-type: decimal; }

.lst-none {
	list-style-type: none; }

.lst-spcd > li {
	margin-bottom: 10px; }

.lst-spcd ul,
.lst-spcd ol {
	margin-top: 10px; }

/*
 *
 * Web Experience Toolkit (WET) / Boîte à outils de l'expérience Web (BOEW)
 * wet-boew.github.io/wet-boew/License-en.html / wet-boew.github.io/wet-boew/Licence-fr.html
 *
 * @title: Lists
 *
 */
/*
 * List responsive style
 *
 * It has variant defined for some specific views
 * - views/_screen-lg-min
 * - views/_screen-xs-max
 */
.list-responsive > li {
	float: left;
	padding-right: 5px;
	width: 50%; }
	.list-responsive > li:nth-child(2n+2) {
		clear: right; }

.list-responsive:before, .list-responsive:after {
	content: " ";
	display: table; }

.list-responsive:after {
	clear: both; }

/* Double space list items
	Might worth to publish it upstream here instead: https://github.com/wet-boew/wet-boew/blob/master/src/base/lists/_base.scss#L30
 */
.lst-spcd-2 > li {
	margin-bottom: 20px; }

.lst-spcd-2 ul,
.lst-spcd-2 ol {
	margin-top: 20px; }

/* Display lists in columns using Flexbox
 *	Add this class to a ul or ol to distribute its items in columns horizontally. Handles up to 4 columns.
 *	It has variants defined for some specific views:
 *	- _screen-sm-min
 *	- _screen-md-min
 *	- _screen-lg-min
*/
ul[class*=list-col] {
	display: -webkit-box;
	display: -ms-flexbox;
	display: flex;
	-ms-flex-wrap: wrap;
	    flex-wrap: wrap;
	list-style: none;
	padding-left: 0;
	padding-right: 0; }
	ul[class*=list-col] > li {
		-ms-flex-preferred-size: 100%;
		    flex-basis: 100%;
		-webkit-box-flex: 0;
		    -ms-flex-positive: 0;
		        flex-grow: 0;
		-ms-flex-negative: 0;
		    flex-shrink: 0; }

ul.list-col-xs-1 > li {
	-ms-flex-preferred-size: 100%;
	    flex-basis: 100%; }

ul.list-col-xs-2 > li {
	-ms-flex-preferred-size: 50%;
	    flex-basis: 50%; }

ul.list-col-xs-3 > li {
	-ms-flex-preferred-size: 33.33%;
	    flex-basis: 33.33%; }

ul.list-col-xs-4 > li {
	-ms-flex-preferred-size: 25%;
	    flex-basis: 25%; }

/*
	WET-BOEW
	@title: Bootstrap overrides for WET-BOEW - Core CSS
 */
/*! Placeholders */
a.btn, .nav a {
	text-decoration: none; }

/*
 *  Link colour and decoration
 */
a {
	text-decoration: underline; }
	a:visited {
		color: #7834bc; }
	a:not([href]) {
		color: inherit;
		text-decoration: none; }
		a:not([href]):hover, a:not([href]):focus {
			color: inherit;
			outline: none;
			text-decoration: none; }

@media (min-width: 768px) {
	.dl-horizontal.brdr-0 dt,
	.dl-horizontal.brdr-0 dd {
		border: 0 !important; }
	.dl-horizontal dt {
		border-top: 1px solid #ccc;
		padding: 10px 10px 10px 0;
		text-align: left;
		white-space: normal; }
	.dl-horizontal dd {
		border-top: 1px solid #ccc;
		margin-bottom: 3px;
		margin-left: 160px;
		padding: 10px 10px 10px 0; }
	.dl-horizontal dt + dd {
		padding-bottom: 0; } }

/*
 *  Abbreviations with title attributes
 *  Workaround for abbreviations with titles using solid underlines in IE11/Edge in Bootstrap 3.4.0 (via normalize.css 4.0.1-8.0.1):
 *  - Use a dotted underline in browsers that support it (e.g. Firefox, Chrome, etc...)
 *  - Fallback on a dotted bottom border in browsers that don't support it (e.g. IE11, Edge, etc...)
 *  Source: https://github.com/necolas/normalize.css/pull/738#issuecomment-387549760
 *  Created by: @mattbrundage
 */
abbr[title] {
	border-bottom: 1px dotted;
	text-decoration: none; }

@supports ((-webkit-text-decoration: underline dotted) or (text-decoration: underline dotted)) {
	abbr[title] {
		border-bottom: 0;
		-webkit-text-decoration: underline dotted;
		        text-decoration: underline dotted;
		-webkit-text-decoration-skip-ink: none;
		        text-decoration-skip-ink: none; } }

/*
 * Code
 */
code {
	white-space: normal; }

/*
 * Adding space for definition list items
 */
dt {
	margin-bottom: 3px; }

dd {
	margin-bottom: 15px; }

/*
 *  Blockquote font size
 */
blockquote {
	font-size: 16px; }

/*
 *  Right-to-left support
 */
[dir=rtl] .list-unstyled {
	padding-right: 0; }

mark {
	background-color: #ff0;
	color: #000;
	font-weight: 700; }

[hidden] {
	display: none !important; }

q:before, q:after {
	content: ""; }

/*
  WET-BOEW
  @title: Details/summary CSS
 */
summary {
	cursor: pointer; }
	summary:hover, summary:focus {
		background: #ddd;
		color: #000; }
	summary > :first-child {
		display: inline; }

details {
	padding-left: 1.1em;
	padding-right: 1.1em; }
	details > summary {
		margin-left: -1.1em;
		margin-right: -1.1em; }
	details[open] {
		padding-bottom: 1em; }

/*
 *
 * Web Experience Toolkit (WET) / Boîte à outils de l'expérience Web (BOEW)
 * wet-boew.github.io/wet-boew/License-en.html / wet-boew.github.io/wet-boew/Licence-fr.html
 *
 * @title: Details/summary
 *
 */
/* Summaries styled as default buttons */
details[open] > summary.btn-default {
	border: 1px outset #dcdee1;
		border-bottom-left-radius: 4px;
		border-bottom-right-radius: 4px; }

/*
 *
 * Web Experience Toolkit (WET) / Boîte à outils de l'expérience Web (BOEW)
 * wet-boew.github.io/wet-boew/License-en.html / wet-boew.github.io/wet-boew/Licence-fr.html
 *
 * @title: Typography
 *
 */
blockquote {
	font-size: 1em; }

code,
kbd,
pre,
samp {
	font-family: Menlo, Monaco, Consolas, "Courier New", monospace; }

code {
	padding: 2px 4px;
	font-size: 90%;
	color: #c7254e;
	background-color: #f9f2f4;
	border-radius: 4px; }

kbd {
	padding: 2px 4px;
	font-size: 90%;
	color: #fff;
	background-color: #333;
	border-radius: 3px;
	-webkit-box-shadow: inset 0 -1px 0 rgba(0, 0, 0, 0.25);
	        box-shadow: inset 0 -1px 0 rgba(0, 0, 0, 0.25); }
	kbd kbd {
		padding: 0;
		font-size: 100%;
		font-weight: 700;
		-webkit-box-shadow: none;
		        box-shadow: none; }

pre {
	display: block;
	padding: 11px;
	margin: 0 0 11.5px;
	font-size: 15px;
	line-height: 1.4375;
	color: #333333;
	word-break: break-all;
	word-wrap: break-word;
	background-color: #f5f5f5;
	border: 1px solid #ccc;
	border-radius: 4px; }
	pre code {
		padding: 0;
		font-size: inherit;
		color: inherit;
		white-space: pre-wrap;
		background-color: transparent;
		border-radius: 0; }

.pre-scrollable {
	max-height: 340px;
	overflow-y: scroll; }

.container {
	padding-right: 15px;
	padding-left: 15px;
	margin-right: auto;
	margin-left: auto; }
	.container:before, .container:after {
		display: table;
		content: " "; }
	.container:after {
		clear: both; }
	@media (min-width: 768px) {
		.container {
			width: 750px; } }
	@media (min-width: 992px) {
		.container {
			width: 970px; } }
	@media (min-width: 1200px) {
		.container {
			width: 1170px; } }

.container-fluid {
	padding-right: 15px;
	padding-left: 15px;
	margin-right: auto;
	margin-left: auto; }
	.container-fluid:before, .container-fluid:after {
		display: table;
		content: " "; }
	.container-fluid:after {
		clear: both; }

.row {
	margin-right: -15px;
	margin-left: -15px; }
	.row:before, .row:after {
		display: table;
		content: " "; }
	.row:after {
		clear: both; }

.row-no-gutters {
	margin-right: 0;
	margin-left: 0; }
	.row-no-gutters [class*="col-"] {
		padding-right: 0;
		padding-left: 0; }

.col-xs-1, .col-sm-1, .col-md-1, .col-lg-1, .col-xs-2, .col-sm-2, .col-md-2, .col-lg-2, .col-xs-3, .col-sm-3, .col-md-3, .col-lg-3, .col-xs-4, .col-sm-4, .col-md-4, .col-lg-4, .col-xs-5, .col-sm-5, .col-md-5, .col-lg-5, .col-xs-6, .col-sm-6, .col-md-6, .col-lg-6, .col-xs-7, .col-sm-7, .col-md-7, .col-lg-7, .col-xs-8, .col-sm-8, .col-md-8, .col-lg-8, .col-xs-9, .col-sm-9, .col-md-9, .col-lg-9, .col-xs-10, .col-sm-10, .col-md-10, .col-lg-10, .col-xs-11, .col-sm-11, .col-md-11, .col-lg-11, .col-xs-12, .col-sm-12, .col-md-12, .col-lg-12 {
	position: relative;
	min-height: 1px;
	padding-right: 15px;
	padding-left: 15px; }

.col-xs-1, .col-xs-2, .col-xs-3, .col-xs-4, .col-xs-5, .col-xs-6, .col-xs-7, .col-xs-8, .col-xs-9, .col-xs-10, .col-xs-11, .col-xs-12 {
	float: left; }

.col-xs-1 {
	width: 8.3333333333%; }

.col-xs-2 {
	width: 16.6666666667%; }

.col-xs-3 {
	width: 25%; }

.col-xs-4 {
	width: 33.3333333333%; }

.col-xs-5 {
	width: 41.6666666667%; }

.col-xs-6 {
	width: 50%; }

.col-xs-7 {
	width: 58.3333333333%; }

.col-xs-8 {
	width: 66.6666666667%; }

.col-xs-9 {
	width: 75%; }

.col-xs-10 {
	width: 83.3333333333%; }

.col-xs-11 {
	width: 91.6666666667%; }

.col-xs-12 {
	width: 100%; }

.col-xs-pull-0 {
	right: auto; }

.col-xs-pull-1 {
	right: 8.3333333333%; }

.col-xs-pull-2 {
	right: 16.6666666667%; }

.col-xs-pull-3 {
	right: 25%; }

.col-xs-pull-4 {
	right: 33.3333333333%; }

.col-xs-pull-5 {
	right: 41.6666666667%; }

.col-xs-pull-6 {
	right: 50%; }

.col-xs-pull-7 {
	right: 58.3333333333%; }

.col-xs-pull-8 {
	right: 66.6666666667%; }

.col-xs-pull-9 {
	right: 75%; }

.col-xs-pull-10 {
	right: 83.3333333333%; }

.col-xs-pull-11 {
	right: 91.6666666667%; }

.col-xs-pull-12 {
	right: 100%; }

.col-xs-push-0 {
	left: auto; }

.col-xs-push-1 {
	left: 8.3333333333%; }

.col-xs-push-2 {
	left: 16.6666666667%; }

.col-xs-push-3 {
	left: 25%; }

.col-xs-push-4 {
	left: 33.3333333333%; }

.col-xs-push-5 {
	left: 41.6666666667%; }

.col-xs-push-6 {
	left: 50%; }

.col-xs-push-7 {
	left: 58.3333333333%; }

.col-xs-push-8 {
	left: 66.6666666667%; }

.col-xs-push-9 {
	left: 75%; }

.col-xs-push-10 {
	left: 83.3333333333%; }

.col-xs-push-11 {
	left: 91.6666666667%; }

.col-xs-push-12 {
	left: 100%; }

.col-xs-offset-0 {
	margin-left: 0%; }

.col-xs-offset-1 {
	margin-left: 8.3333333333%; }

.col-xs-offset-2 {
	margin-left: 16.6666666667%; }

.col-xs-offset-3 {
	margin-left: 25%; }

.col-xs-offset-4 {
	margin-left: 33.3333333333%; }

.col-xs-offset-5 {
	margin-left: 41.6666666667%; }

.col-xs-offset-6 {
	margin-left: 50%; }

.col-xs-offset-7 {
	margin-left: 58.3333333333%; }

.col-xs-offset-8 {
	margin-left: 66.6666666667%; }

.col-xs-offset-9 {
	margin-left: 75%; }

.col-xs-offset-10 {
	margin-left: 83.3333333333%; }

.col-xs-offset-11 {
	margin-left: 91.6666666667%; }

.col-xs-offset-12 {
	margin-left: 100%; }

@media (min-width: 768px) {
	.col-sm-1, .col-sm-2, .col-sm-3, .col-sm-4, .col-sm-5, .col-sm-6, .col-sm-7, .col-sm-8, .col-sm-9, .col-sm-10, .col-sm-11, .col-sm-12 {
		float: left; }
	.col-sm-1 {
		width: 8.3333333333%; }
	.col-sm-2 {
		width: 16.6666666667%; }
	.col-sm-3 {
		width: 25%; }
	.col-sm-4 {
		width: 33.3333333333%; }
	.col-sm-5 {
		width: 41.6666666667%; }
	.col-sm-6 {
		width: 50%; }
	.col-sm-7 {
		width: 58.3333333333%; }
	.col-sm-8 {
		width: 66.6666666667%; }
	.col-sm-9 {
		width: 75%; }
	.col-sm-10 {
		width: 83.3333333333%; }
	.col-sm-11 {
		width: 91.6666666667%; }
	.col-sm-12 {
		width: 100%; }
	.col-sm-pull-0 {
		right: auto; }
	.col-sm-pull-1 {
		right: 8.3333333333%; }
	.col-sm-pull-2 {
		right: 16.6666666667%; }
	.col-sm-pull-3 {
		right: 25%; }
	.col-sm-pull-4 {
		right: 33.3333333333%; }
	.col-sm-pull-5 {
		right: 41.6666666667%; }
	.col-sm-pull-6 {
		right: 50%; }
	.col-sm-pull-7 {
		right: 58.3333333333%; }
	.col-sm-pull-8 {
		right: 66.6666666667%; }
	.col-sm-pull-9 {
		right: 75%; }
	.col-sm-pull-10 {
		right: 83.3333333333%; }
	.col-sm-pull-11 {
		right: 91.6666666667%; }
	.col-sm-pull-12 {
		right: 100%; }
	.col-sm-push-0 {
		left: auto; }
	.col-sm-push-1 {
		left: 8.3333333333%; }
	.col-sm-push-2 {
		left: 16.6666666667%; }
	.col-sm-push-3 {
		left: 25%; }
	.col-sm-push-4 {
		left: 33.3333333333%; }
	.col-sm-push-5 {
		left: 41.6666666667%; }
	.col-sm-push-6 {
		left: 50%; }
	.col-sm-push-7 {
		left: 58.3333333333%; }
	.col-sm-push-8 {
		left: 66.6666666667%; }
	.col-sm-push-9 {
		left: 75%; }
	.col-sm-push-10 {
		left: 83.3333333333%; }
	.col-sm-push-11 {
		left: 91.6666666667%; }
	.col-sm-push-12 {
		left: 100%; }
	.col-sm-offset-0 {
		margin-left: 0%; }
	.col-sm-offset-1 {
		margin-left: 8.3333333333%; }
	.col-sm-offset-2 {
		margin-left: 16.6666666667%; }
	.col-sm-offset-3 {
		margin-left: 25%; }
	.col-sm-offset-4 {
		margin-left: 33.3333333333%; }
	.col-sm-offset-5 {
		margin-left: 41.6666666667%; }
	.col-sm-offset-6 {
		margin-left: 50%; }
	.col-sm-offset-7 {
		margin-left: 58.3333333333%; }
	.col-sm-offset-8 {
		margin-left: 66.6666666667%; }
	.col-sm-offset-9 {
		margin-left: 75%; }
	.col-sm-offset-10 {
		margin-left: 83.3333333333%; }
	.col-sm-offset-11 {
		margin-left: 91.6666666667%; }
	.col-sm-offset-12 {
		margin-left: 100%; } }

@media (min-width: 992px) {
	.col-md-1, .col-md-2, .col-md-3, .col-md-4, .col-md-5, .col-md-6, .col-md-7, .col-md-8, .col-md-9, .col-md-10, .col-md-11, .col-md-12 {
		float: left; }
	.col-md-1 {
		width: 8.3333333333%; }
	.col-md-2 {
		width: 16.6666666667%; }
	.col-md-3 {
		width: 25%; }
	.col-md-4 {
		width: 33.3333333333%; }
	.col-md-5 {
		width: 41.6666666667%; }
	.col-md-6 {
		width: 50%; }
	.col-md-7 {
		width: 58.3333333333%; }
	.col-md-8 {
		width: 66.6666666667%; }
	.col-md-9 {
		width: 75%; }
	.col-md-10 {
		width: 83.3333333333%; }
	.col-md-11 {
		width: 91.6666666667%; }
	.col-md-12 {
		width: 100%; }
	.col-md-pull-0 {
		right: auto; }
	.col-md-pull-1 {
		right: 8.3333333333%; }
	.col-md-pull-2 {
		right: 16.6666666667%; }
	.col-md-pull-3 {
		right: 25%; }
	.col-md-pull-4 {
		right: 33.3333333333%; }
	.col-md-pull-5 {
		right: 41.6666666667%; }
	.col-md-pull-6 {
		right: 50%; }
	.col-md-pull-7 {
		right: 58.3333333333%; }
	.col-md-pull-8 {
		right: 66.6666666667%; }
	.col-md-pull-9 {
		right: 75%; }
	.col-md-pull-10 {
		right: 83.3333333333%; }
	.col-md-pull-11 {
		right: 91.6666666667%; }
	.col-md-pull-12 {
		right: 100%; }
	.col-md-push-0 {
		left: auto; }
	.col-md-push-1 {
		left: 8.3333333333%; }
	.col-md-push-2 {
		left: 16.6666666667%; }
	.col-md-push-3 {
		left: 25%; }
	.col-md-push-4 {
		left: 33.3333333333%; }
	.col-md-push-5 {
		left: 41.6666666667%; }
	.col-md-push-6 {
		left: 50%; }
	.col-md-push-7 {
		left: 58.3333333333%; }
	.col-md-push-8 {
		left: 66.6666666667%; }
	.col-md-push-9 {
		left: 75%; }
	.col-md-push-10 {
		left: 83.3333333333%; }
	.col-md-push-11 {
		left: 91.6666666667%; }
	.col-md-push-12 {
		left: 100%; }
	.col-md-offset-0 {
		margin-left: 0%; }
	.col-md-offset-1 {
		margin-left: 8.3333333333%; }
	.col-md-offset-2 {
		margin-left: 16.6666666667%; }
	.col-md-offset-3 {
		margin-left: 25%; }
	.col-md-offset-4 {
		margin-left: 33.3333333333%; }
	.col-md-offset-5 {
		margin-left: 41.6666666667%; }
	.col-md-offset-6 {
		margin-left: 50%; }
	.col-md-offset-7 {
		margin-left: 58.3333333333%; }
	.col-md-offset-8 {
		margin-left: 66.6666666667%; }
	.col-md-offset-9 {
		margin-left: 75%; }
	.col-md-offset-10 {
		margin-left: 83.3333333333%; }
	.col-md-offset-11 {
		margin-left: 91.6666666667%; }
	.col-md-offset-12 {
		margin-left: 100%; } }

@media (min-width: 1200px) {
	.col-lg-1, .col-lg-2, .col-lg-3, .col-lg-4, .col-lg-5, .col-lg-6, .col-lg-7, .col-lg-8, .col-lg-9, .col-lg-10, .col-lg-11, .col-lg-12 {
		float: left; }
	.col-lg-1 {
		width: 8.3333333333%; }
	.col-lg-2 {
		width: 16.6666666667%; }
	.col-lg-3 {
		width: 25%; }
	.col-lg-4 {
		width: 33.3333333333%; }
	.col-lg-5 {
		width: 41.6666666667%; }
	.col-lg-6 {
		width: 50%; }
	.col-lg-7 {
		width: 58.3333333333%; }
	.col-lg-8 {
		width: 66.6666666667%; }
	.col-lg-9 {
		width: 75%; }
	.col-lg-10 {
		width: 83.3333333333%; }
	.col-lg-11 {
		width: 91.6666666667%; }
	.col-lg-12 {
		width: 100%; }
	.col-lg-pull-0 {
		right: auto; }
	.col-lg-pull-1 {
		right: 8.3333333333%; }
	.col-lg-pull-2 {
		right: 16.6666666667%; }
	.col-lg-pull-3 {
		right: 25%; }
	.col-lg-pull-4 {
		right: 33.3333333333%; }
	.col-lg-pull-5 {
		right: 41.6666666667%; }
	.col-lg-pull-6 {
		right: 50%; }
	.col-lg-pull-7 {
		right: 58.3333333333%; }
	.col-lg-pull-8 {
		right: 66.6666666667%; }
	.col-lg-pull-9 {
		right: 75%; }
	.col-lg-pull-10 {
		right: 83.3333333333%; }
	.col-lg-pull-11 {
		right: 91.6666666667%; }
	.col-lg-pull-12 {
		right: 100%; }
	.col-lg-push-0 {
		left: auto; }
	.col-lg-push-1 {
		left: 8.3333333333%; }
	.col-lg-push-2 {
		left: 16.6666666667%; }
	.col-lg-push-3 {
		left: 25%; }
	.col-lg-push-4 {
		left: 33.3333333333%; }
	.col-lg-push-5 {
		left: 41.6666666667%; }
	.col-lg-push-6 {
		left: 50%; }
	.col-lg-push-7 {
		left: 58.3333333333%; }
	.col-lg-push-8 {
		left: 66.6666666667%; }
	.col-lg-push-9 {
		left: 75%; }
	.col-lg-push-10 {
		left: 83.3333333333%; }
	.col-lg-push-11 {
		left: 91.6666666667%; }
	.col-lg-push-12 {
		left: 100%; }
	.col-lg-offset-0 {
		margin-left: 0%; }
	.col-lg-offset-1 {
		margin-left: 8.3333333333%; }
	.col-lg-offset-2 {
		margin-left: 16.6666666667%; }
	.col-lg-offset-3 {
		margin-left: 25%; }
	.col-lg-offset-4 {
		margin-left: 33.3333333333%; }
	.col-lg-offset-5 {
		margin-left: 41.6666666667%; }
	.col-lg-offset-6 {
		margin-left: 50%; }
	.col-lg-offset-7 {
		margin-left: 58.3333333333%; }
	.col-lg-offset-8 {
		margin-left: 66.6666666667%; }
	.col-lg-offset-9 {
		margin-left: 75%; }
	.col-lg-offset-10 {
		margin-left: 83.3333333333%; }
	.col-lg-offset-11 {
		margin-left: 91.6666666667%; }
	.col-lg-offset-12 {
		margin-left: 100%; } }

table {
	background-color: transparent; }
	table col[class*="col-"] {
		position: static;
		display: table-column;
		float: none; }
	table td[class*="col-"],
	table th[class*="col-"] {
		position: static;
		display: table-cell;
		float: none; }

caption {
	padding-top: 8px;
	padding-bottom: 8px;
	color: #6f6f6f;
	text-align: left; }

th {
	text-align: left; }

.table {
	width: 100%;
	max-width: 100%;
	margin-bottom: 23px; }
	.table > thead > tr > th,
	.table > thead > tr > td,
	.table > tbody > tr > th,
	.table > tbody > tr > td,
	.table > tfoot > tr > th,
	.table > tfoot > tr > td {
		padding: 8px;
		line-height: 1.4375;
		vertical-align: top;
		border-top: 1px solid #ddd; }
	.table > thead > tr > th {
		vertical-align: bottom;
		border-bottom: 2px solid #ddd; }
	.table > caption + thead > tr:first-child > th,
	.table > caption + thead > tr:first-child > td,
	.table > colgroup + thead > tr:first-child > th,
	.table > colgroup + thead > tr:first-child > td,
	.table > thead:first-child > tr:first-child > th,
	.table > thead:first-child > tr:first-child > td {
		border-top: 0; }
	.table > tbody + tbody {
		border-top: 2px solid #ddd; }
	.table .table {
		background-color: #fff; }

.table-condensed > thead > tr > th,
.table-condensed > thead > tr > td,
.table-condensed > tbody > tr > th,
.table-condensed > tbody > tr > td,
.table-condensed > tfoot > tr > th,
.table-condensed > tfoot > tr > td {
	padding: 5px; }

.table-bordered {
	border: 1px solid #ddd; }
	.table-bordered > thead > tr > th,
	.table-bordered > thead > tr > td,
	.table-bordered > tbody > tr > th,
	.table-bordered > tbody > tr > td,
	.table-bordered > tfoot > tr > th,
	.table-bordered > tfoot > tr > td {
		border: 1px solid #ddd; }
	.table-bordered > thead > tr > th,
	.table-bordered > thead > tr > td {
		border-bottom-width: 2px; }

.table-striped > tbody > tr:nth-of-type(odd) {
	background-color: #f5f5f5; }

.table-hover > tbody > tr:hover {
	background-color: #f0f0f0; }

.table > thead > tr > td.active,
.table > thead > tr > th.active,
.table > thead > tr.active > td,
.table > thead > tr.active > th,
.table > tbody > tr > td.active,
.table > tbody > tr > th.active,
.table > tbody > tr.active > td,
.table > tbody > tr.active > th,
.table > tfoot > tr > td.active,
.table > tfoot > tr > th.active,
.table > tfoot > tr.active > td,
.table > tfoot > tr.active > th {
	background-color: #f0f0f0; }

.table-hover > tbody > tr > td.active:hover,
.table-hover > tbody > tr > th.active:hover,
.table-hover > tbody > tr.active:hover > td,
.table-hover > tbody > tr:hover > .active,
.table-hover > tbody > tr.active:hover > th {
	background-color: #e3e3e3; }

.table > thead > tr > td.success,
.table > thead > tr > th.success,
.table > thead > tr.success > td,
.table > thead > tr.success > th,
.table > tbody > tr > td.success,
.table > tbody > tr > th.success,
.table > tbody > tr.success > td,
.table > tbody > tr.success > th,
.table > tfoot > tr > td.success,
.table > tfoot > tr > th.success,
.table > tfoot > tr.success > td,
.table > tfoot > tr.success > th {
	background-color: #dff0d8; }

.table-hover > tbody > tr > td.success:hover,
.table-hover > tbody > tr > th.success:hover,
.table-hover > tbody > tr.success:hover > td,
.table-hover > tbody > tr:hover > .success,
.table-hover > tbody > tr.success:hover > th {
	background-color: #d0e9c6; }

.table > thead > tr > td.info,
.table > thead > tr > th.info,
.table > thead > tr.info > td,
.table > thead > tr.info > th,
.table > tbody > tr > td.info,
.table > tbody > tr > th.info,
.table > tbody > tr.info > td,
.table > tbody > tr.info > th,
.table > tfoot > tr > td.info,
.table > tfoot > tr > th.info,
.table > tfoot > tr.info > td,
.table > tfoot > tr.info > th {
	background-color: #d9edf7; }

.table-hover > tbody > tr > td.info:hover,
.table-hover > tbody > tr > th.info:hover,
.table-hover > tbody > tr.info:hover > td,
.table-hover > tbody > tr:hover > .info,
.table-hover > tbody > tr.info:hover > th {
	background-color: #c4e3f3; }

.table > thead > tr > td.warning,
.table > thead > tr > th.warning,
.table > thead > tr.warning > td,
.table > thead > tr.warning > th,
.table > tbody > tr > td.warning,
.table > tbody > tr > th.warning,
.table > tbody > tr.warning > td,
.table > tbody > tr.warning > th,
.table > tfoot > tr > td.warning,
.table > tfoot > tr > th.warning,
.table > tfoot > tr.warning > td,
.table > tfoot > tr.warning > th {
	background-color: #fcf8e3; }

.table-hover > tbody > tr > td.warning:hover,
.table-hover > tbody > tr > th.warning:hover,
.table-hover > tbody > tr.warning:hover > td,
.table-hover > tbody > tr:hover > .warning,
.table-hover > tbody > tr.warning:hover > th {
	background-color: #faf2cc; }

.table > thead > tr > td.danger,
.table > thead > tr > th.danger,
.table > thead > tr.danger > td,
.table > thead > tr.danger > th,
.table > tbody > tr > td.danger,
.table > tbody > tr > th.danger,
.table > tbody > tr.danger > td,
.table > tbody > tr.danger > th,
.table > tfoot > tr > td.danger,
.table > tfoot > tr > th.danger,
.table > tfoot > tr.danger > td,
.table > tfoot > tr.danger > th {
	background-color: #f2dede; }

.table-hover > tbody > tr > td.danger:hover,
.table-hover > tbody > tr > th.danger:hover,
.table-hover > tbody > tr.danger:hover > td,
.table-hover > tbody > tr:hover > .danger,
.table-hover > tbody > tr.danger:hover > th {
	background-color: #ebcccc; }

.table-responsive {
	min-height: .01%;
	overflow-x: auto; }
	@media screen and (max-width: 767px) {
		.table-responsive {
			width: 100%;
			margin-bottom: 17.25px;
			overflow-y: hidden;
			-ms-overflow-style: -ms-autohiding-scrollbar;
			border: 1px solid #ddd; }
			.table-responsive > .table {
				margin-bottom: 0; }
				.table-responsive > .table > thead > tr > th,
				.table-responsive > .table > thead > tr > td,
				.table-responsive > .table > tbody > tr > th,
				.table-responsive > .table > tbody > tr > td,
				.table-responsive > .table > tfoot > tr > th,
				.table-responsive > .table > tfoot > tr > td {
					white-space: nowrap; }
			.table-responsive > .table-bordered {
				border: 0; }
				.table-responsive > .table-bordered > thead > tr > th:first-child,
				.table-responsive > .table-bordered > thead > tr > td:first-child,
				.table-responsive > .table-bordered > tbody > tr > th:first-child,
				.table-responsive > .table-bordered > tbody > tr > td:first-child,
				.table-responsive > .table-bordered > tfoot > tr > th:first-child,
				.table-responsive > .table-bordered > tfoot > tr > td:first-child {
					border-left: 0; }
				.table-responsive > .table-bordered > thead > tr > th:last-child,
				.table-responsive > .table-bordered > thead > tr > td:last-child,
				.table-responsive > .table-bordered > tbody > tr > th:last-child,
				.table-responsive > .table-bordered > tbody > tr > td:last-child,
				.table-responsive > .table-bordered > tfoot > tr > th:last-child,
				.table-responsive > .table-bordered > tfoot > tr > td:last-child {
					border-right: 0; }
				.table-responsive > .table-bordered > tbody > tr:last-child > th,
				.table-responsive > .table-bordered > tbody > tr:last-child > td,
				.table-responsive > .table-bordered > tfoot > tr:last-child > th,
				.table-responsive > .table-bordered > tfoot > tr:last-child > td {
					border-bottom: 0; } }

/*
	WET-BOEW
	@title: Bootstrap overrides for WET-BOEW - Core CSS - table
 */
caption {
	color: #333;
	font-size: 1.1em;
	font-weight: bold;
	text-align: center; }

.table-responsive > .table, th, td {
	white-space: normal; }

fieldset {
	min-width: 0;
	padding: 0;
	margin: 0;
	border: 0; }

legend {
	display: block;
	width: 100%;
	padding: 0;
	margin-bottom: 23px;
	font-size: 24px;
	line-height: inherit;
	color: #333333;
	border: 0;
	border-bottom: 1px solid #e5e5e5; }

label {
	display: inline-block;
	max-width: 100%;
	margin-bottom: 5px;
	font-weight: 700; }

input[type="search"] {
	-webkit-box-sizing: border-box;
	box-sizing: border-box;
	-webkit-appearance: none;
	-moz-appearance: none;
	     appearance: none; }

input[type="radio"],
input[type="checkbox"] {
	margin: 4px 0 0;
	margin-top: 1px \9;
	line-height: normal; }
	input[type="radio"][disabled], input[type="radio"].disabled,
	fieldset[disabled] input[type="radio"],
	input[type="checkbox"][disabled],
	input[type="checkbox"].disabled,
	fieldset[disabled]
	input[type="checkbox"] {
		cursor: not-allowed; }

input[type="file"] {
	display: block; }

input[type="range"] {
	display: block;
	width: 100%; }

select[multiple],
select[size] {
	height: auto; }

input[type="file"]:focus,
input[type="radio"]:focus,
input[type="checkbox"]:focus {
	outline: 5px auto -webkit-focus-ring-color;
	outline-offset: -2px; }

output {
	display: block;
	padding-top: 11px;
	font-size: 16px;
	line-height: 1.4375;
	color: #555555; }

.form-control {
	display: block;
	width: 100%;
	height: 37px;
	padding: 10px 14px;
	font-size: 16px;
	line-height: 1.4375;
	color: #555555;
	background-color: #fff;
	background-image: none;
	border: 1px solid #ccc;
	border-radius: 4px;
	-webkit-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075);
	box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075);
	-webkit-transition: border-color ease-in-out 0.15s, box-shadow ease-in-out 0.15s;
	-webkit-transition: border-color ease-in-out 0.15s, -webkit-box-shadow ease-in-out 0.15s;
	transition: border-color ease-in-out 0.15s, -webkit-box-shadow ease-in-out 0.15s;
	transition: border-color ease-in-out 0.15s, box-shadow ease-in-out 0.15s;
	transition: border-color ease-in-out 0.15s, box-shadow ease-in-out 0.15s, -webkit-box-shadow ease-in-out 0.15s; }
	.form-control:focus {
		border-color: #66afe9;
		outline: 0;
		-webkit-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075), 0 0 8px rgba(102, 175, 233, 0.6);
		box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075), 0 0 8px rgba(102, 175, 233, 0.6); }
	.form-control::-moz-placeholder {
		color: #5c5c5c !important;
		opacity: 1; }
	.form-control:-ms-input-placeholder {
		color: #5c5c5c !important; }
	.form-control::-webkit-input-placeholder {
		color: #5c5c5c !important; }
	.form-control::-ms-expand {
		background-color: transparent;
		border: 0; }
	.form-control[disabled], .form-control[readonly],
	fieldset[disabled] .form-control {
		background-color: #eeeeee;
		opacity: 1; }
	.form-control[disabled],
	fieldset[disabled] .form-control {
		cursor: not-allowed; }

textarea.form-control {
	height: auto; }

@media screen and (-webkit-min-device-pixel-ratio: 0) {
	input[type="date"].form-control,
	input[type="time"].form-control,
	input[type="datetime-local"].form-control,
	input[type="month"].form-control {
		line-height: 37px; }
	input[type="date"].input-sm, .input-group-sm > input.form-control[type="date"],
	.input-group-sm > input.input-group-addon[type="date"],
	.input-group-sm > .input-group-btn > input.btn[type="date"],
	.input-group-sm input[type="date"],
	input[type="time"].input-sm,
	.input-group-sm > input.form-control[type="time"],
	.input-group-sm > input.input-group-addon[type="time"],
	.input-group-sm > .input-group-btn > input.btn[type="time"],
	.input-group-sm
	input[type="time"],
	input[type="datetime-local"].input-sm,
	.input-group-sm > input.form-control[type="datetime-local"],
	.input-group-sm > input.input-group-addon[type="datetime-local"],
	.input-group-sm > .input-group-btn > input.btn[type="datetime-local"],
	.input-group-sm
	input[type="datetime-local"],
	input[type="month"].input-sm,
	.input-group-sm > input.form-control[type="month"],
	.input-group-sm > input.input-group-addon[type="month"],
	.input-group-sm > .input-group-btn > input.btn[type="month"],
	.input-group-sm
	input[type="month"] {
		line-height: 33px; }
	input[type="date"].input-lg, .input-group-lg > input.form-control[type="date"],
	.input-group-lg > input.input-group-addon[type="date"],
	.input-group-lg > .input-group-btn > input.btn[type="date"],
	.input-group-lg input[type="date"],
	input[type="time"].input-lg,
	.input-group-lg > input.form-control[type="time"],
	.input-group-lg > input.input-group-addon[type="time"],
	.input-group-lg > .input-group-btn > input.btn[type="time"],
	.input-group-lg
	input[type="time"],
	input[type="datetime-local"].input-lg,
	.input-group-lg > input.form-control[type="datetime-local"],
	.input-group-lg > input.input-group-addon[type="datetime-local"],
	.input-group-lg > .input-group-btn > input.btn[type="datetime-local"],
	.input-group-lg
	input[type="datetime-local"],
	input[type="month"].input-lg,
	.input-group-lg > input.form-control[type="month"],
	.input-group-lg > input.input-group-addon[type="month"],
	.input-group-lg > .input-group-btn > input.btn[type="month"],
	.input-group-lg
	input[type="month"] {
		line-height: 46px; } }

.form-group {
	margin-bottom: 15px; }

.radio,
.checkbox {
	position: relative;
	display: block;
	margin-top: 10px;
	margin-bottom: 10px; }
	.radio.disabled label,
	fieldset[disabled] .radio label,
	.checkbox.disabled label,
	fieldset[disabled]
	.checkbox label {
		cursor: not-allowed; }
	.radio label,
	.checkbox label {
		min-height: 23px;
		padding-left: 20px;
		margin-bottom: 0;
		font-weight: 400;
		cursor: pointer; }

.radio input[type="radio"],
.radio-inline input[type="radio"],
.checkbox input[type="checkbox"],
.checkbox-inline input[type="checkbox"] {
	position: absolute;
	margin-top: 4px \9;
	margin-left: -20px; }

.radio + .radio,
.checkbox + .checkbox {
	margin-top: -5px; }

.radio-inline,
.checkbox-inline {
	position: relative;
	display: inline-block;
	padding-left: 20px;
	margin-bottom: 0;
	font-weight: 400;
	vertical-align: middle;
	cursor: pointer; }
	.radio-inline.disabled,
	fieldset[disabled] .radio-inline,
	.checkbox-inline.disabled,
	fieldset[disabled]
	.checkbox-inline {
		cursor: not-allowed; }

.radio-inline + .radio-inline,
.checkbox-inline + .checkbox-inline {
	margin-top: 0;
	margin-left: 10px; }

.form-control-static {
	min-height: 39px;
	padding-top: 11px;
	padding-bottom: 11px;
	margin-bottom: 0; }
	.form-control-static.input-lg, .input-group-lg > .form-control-static.form-control,
	.input-group-lg > .form-control-static.input-group-addon,
	.input-group-lg > .input-group-btn > .form-control-static.btn, .form-control-static.input-sm, .input-group-sm > .form-control-static.form-control,
	.input-group-sm > .form-control-static.input-group-addon,
	.input-group-sm > .input-group-btn > .form-control-static.btn {
		padding-right: 0;
		padding-left: 0; }

.input-sm, .input-group-sm > .form-control,
.input-group-sm > .input-group-addon,
.input-group-sm > .input-group-btn > .btn {
	height: 33px;
	padding: 5px 10px;
	font-size: 14px;
	line-height: 1.5;
	border-radius: 3px; }

select.input-sm, .input-group-sm > select.form-control,
.input-group-sm > select.input-group-addon,
.input-group-sm > .input-group-btn > select.btn {
	height: 33px;
	line-height: 33px; }

textarea.input-sm, .input-group-sm > textarea.form-control,
.input-group-sm > textarea.input-group-addon,
.input-group-sm > .input-group-btn > textarea.btn,
select[multiple].input-sm,
.input-group-sm > select.form-control[multiple],
.input-group-sm > select.input-group-addon[multiple],
.input-group-sm > .input-group-btn > select.btn[multiple] {
	height: auto; }

.form-group-sm .form-control {
	height: 33px;
	padding: 5px 10px;
	font-size: 14px;
	line-height: 1.5;
	border-radius: 3px; }

.form-group-sm select.form-control {
	height: 33px;
	line-height: 33px; }

.form-group-sm textarea.form-control,
.form-group-sm select[multiple].form-control {
	height: auto; }

.form-group-sm .form-control-static {
	height: 33px;
	min-height: 37px;
	padding: 6px 10px;
	font-size: 14px;
	line-height: 1.5; }

.input-lg, .input-group-lg > .form-control,
.input-group-lg > .input-group-addon,
.input-group-lg > .input-group-btn > .btn {
	height: 46px;
	padding: 10px 16px;
	font-size: 18px;
	line-height: 1.3333333;
	border-radius: 6px; }

select.input-lg, .input-group-lg > select.form-control,
.input-group-lg > select.input-group-addon,
.input-group-lg > .input-group-btn > select.btn {
	height: 46px;
	line-height: 46px; }

textarea.input-lg, .input-group-lg > textarea.form-control,
.input-group-lg > textarea.input-group-addon,
.input-group-lg > .input-group-btn > textarea.btn,
select[multiple].input-lg,
.input-group-lg > select.form-control[multiple],
.input-group-lg > select.input-group-addon[multiple],
.input-group-lg > .input-group-btn > select.btn[multiple] {
	height: auto; }

.form-group-lg .form-control {
	height: 46px;
	padding: 10px 16px;
	font-size: 18px;
	line-height: 1.3333333;
	border-radius: 6px; }

.form-group-lg select.form-control {
	height: 46px;
	line-height: 46px; }

.form-group-lg textarea.form-control,
.form-group-lg select[multiple].form-control {
	height: auto; }

.form-group-lg .form-control-static {
	height: 46px;
	min-height: 41px;
	padding: 11px 16px;
	font-size: 18px;
	line-height: 1.3333333; }

.has-feedback {
	position: relative; }
	.has-feedback .form-control {
		padding-right: 46.25px; }

.form-control-feedback {
	position: absolute;
	top: 0;
	right: 0;
	z-index: 2;
	display: block;
	width: 37px;
	height: 37px;
	line-height: 37px;
	text-align: center;
	pointer-events: none; }

.input-lg + .form-control-feedback, .input-group-lg > .form-control + .form-control-feedback, .input-group-lg > .input-group-addon + .form-control-feedback, .input-group-lg > .input-group-btn > .btn + .form-control-feedback,
.input-group-lg + .form-control-feedback,
.form-group-lg .form-control + .form-control-feedback {
	width: 46px;
	height: 46px;
	line-height: 46px; }

.input-sm + .form-control-feedback, .input-group-sm > .form-control + .form-control-feedback, .input-group-sm > .input-group-addon + .form-control-feedback, .input-group-sm > .input-group-btn > .btn + .form-control-feedback,
.input-group-sm + .form-control-feedback,
.form-group-sm .form-control + .form-control-feedback {
	width: 33px;
	height: 33px;
	line-height: 33px; }

.has-success .help-block,
.has-success .control-label,
.has-success .radio,
.has-success .checkbox,
.has-success .radio-inline,
.has-success .checkbox-inline,
.has-success.radio label,
.has-success.checkbox label,
.has-success.radio-inline label,
.has-success.checkbox-inline label {
	color: #3c763d; }

.has-success .form-control {
	border-color: #3c763d;
	-webkit-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075);
	box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075); }
	.has-success .form-control:focus {
		border-color: #2b542c;
		-webkit-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075), 0 0 6px #67b168;
		box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075), 0 0 6px #67b168; }

.has-success .input-group-addon {
	color: #3c763d;
	background-color: #dff0d8;
	border-color: #3c763d; }

.has-success .form-control-feedback {
	color: #3c763d; }

.has-warning .help-block,
.has-warning .control-label,
.has-warning .radio,
.has-warning .checkbox,
.has-warning .radio-inline,
.has-warning .checkbox-inline,
.has-warning.radio label,
.has-warning.checkbox label,
.has-warning.radio-inline label,
.has-warning.checkbox-inline label {
	color: #8a6d3b; }

.has-warning .form-control {
	border-color: #8a6d3b;
	-webkit-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075);
	box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075); }
	.has-warning .form-control:focus {
		border-color: #66512c;
		-webkit-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075), 0 0 6px #c0a16b;
		box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075), 0 0 6px #c0a16b; }

.has-warning .input-group-addon {
	color: #8a6d3b;
	background-color: #fcf8e3;
	border-color: #8a6d3b; }

.has-warning .form-control-feedback {
	color: #8a6d3b; }

.has-error .help-block,
.has-error .control-label,
.has-error .radio,
.has-error .checkbox,
.has-error .radio-inline,
.has-error .checkbox-inline,
.has-error.radio label,
.has-error.checkbox label,
.has-error.radio-inline label,
.has-error.checkbox-inline label {
	color: #a94442; }

.has-error .form-control {
	border-color: #a94442;
	-webkit-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075);
	box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075); }
	.has-error .form-control:focus {
		border-color: #843534;
		-webkit-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075), 0 0 6px #ce8483;
		box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075), 0 0 6px #ce8483; }

.has-error .input-group-addon {
	color: #a94442;
	background-color: #f2dede;
	border-color: #a94442; }

.has-error .form-control-feedback {
	color: #a94442; }

.has-feedback label ~ .form-control-feedback {
	top: 28px; }

.has-feedback label.sr-only ~ .form-control-feedback {
	top: 0; }

.help-block {
	display: block;
	margin-top: 5px;
	margin-bottom: 10px;
	color: #737373; }

@media (min-width: 768px) {
	.form-inline .form-group {
		display: inline-block;
		margin-bottom: 0;
		vertical-align: middle; }
	.form-inline .form-control {
		display: inline-block;
		width: auto;
		vertical-align: middle; }
	.form-inline .form-control-static {
		display: inline-block; }
	.form-inline .input-group {
		display: inline-table;
		vertical-align: middle; }
		.form-inline .input-group .input-group-addon,
		.form-inline .input-group .input-group-btn,
		.form-inline .input-group .form-control {
			width: auto; }
	.form-inline .input-group > .form-control {
		width: 100%; }
	.form-inline .control-label {
		margin-bottom: 0;
		vertical-align: middle; }
	.form-inline .radio,
	.form-inline .checkbox {
		display: inline-block;
		margin-top: 0;
		margin-bottom: 0;
		vertical-align: middle; }
		.form-inline .radio label,
		.form-inline .checkbox label {
			padding-left: 0; }
	.form-inline .radio input[type="radio"],
	.form-inline .checkbox input[type="checkbox"] {
		position: relative;
		margin-left: 0; }
	.form-inline .has-feedback .form-control-feedback {
		top: 0; } }

.form-horizontal .radio,
.form-horizontal .checkbox,
.form-horizontal .radio-inline,
.form-horizontal .checkbox-inline {
	padding-top: 11px;
	margin-top: 0;
	margin-bottom: 0; }

.form-horizontal .radio,
.form-horizontal .checkbox {
	min-height: 34px; }

.form-horizontal .form-group {
	margin-right: -15px;
	margin-left: -15px; }
	.form-horizontal .form-group:before, .form-horizontal .form-group:after {
		display: table;
		content: " "; }
	.form-horizontal .form-group:after {
		clear: both; }

@media (min-width: 768px) {
	.form-horizontal .control-label {
		padding-top: 11px;
		margin-bottom: 0;
		text-align: right; } }

.form-horizontal .has-feedback .form-control-feedback {
	right: 15px; }

@media (min-width: 768px) {
	.form-horizontal .form-group-lg .control-label {
		padding-top: 11px;
		font-size: 18px; } }

@media (min-width: 768px) {
	.form-horizontal .form-group-sm .control-label {
		padding-top: 6px;
		font-size: 14px; } }

/*
	WET-BOEW
	@title: Bootstrap overrides for WET-BOEW - Core CSS - forms
 */
/*! Placeholders */
fieldset[disabled] .btn, .btn.disabled, .btn[disabled] {
	border-style: solid; }

/*
 *  Firefox-safe line height on input[type="reset|button|submit"]
 */
input[type="reset"], input[type="button"], input[type="submit"] {
	height: 37px; }
	input[type="reset"].btn-lg, .btn-group-lg > input.btn[type="reset"], input[type="reset"].input-lg, .input-group-lg > input.form-control[type="reset"],
	.input-group-lg > input.input-group-addon[type="reset"],
	.input-group-lg > .input-group-btn > input.btn[type="reset"], input[type="button"].btn-lg, .btn-group-lg > input.btn[type="button"], input[type="button"].input-lg, .input-group-lg > input.form-control[type="button"],
	.input-group-lg > input.input-group-addon[type="button"],
	.input-group-lg > .input-group-btn > input.btn[type="button"], input[type="submit"].btn-lg, .btn-group-lg > input.btn[type="submit"], input[type="submit"].input-lg, .input-group-lg > input.form-control[type="submit"],
	.input-group-lg > input.input-group-addon[type="submit"],
	.input-group-lg > .input-group-btn > input.btn[type="submit"] {
		height: 46px; }
	input[type="reset"].btn-sm, .btn-group-sm > input.btn[type="reset"], input[type="reset"].input-sm, .input-group-sm > input.form-control[type="reset"],
	.input-group-sm > input.input-group-addon[type="reset"],
	.input-group-sm > .input-group-btn > input.btn[type="reset"], input[type="button"].btn-sm, .btn-group-sm > input.btn[type="button"], input[type="button"].input-sm, .input-group-sm > input.form-control[type="button"],
	.input-group-sm > input.input-group-addon[type="button"],
	.input-group-sm > .input-group-btn > input.btn[type="button"], input[type="submit"].btn-sm, .btn-group-sm > input.btn[type="submit"], input[type="submit"].input-sm, .input-group-sm > input.form-control[type="submit"],
	.input-group-sm > input.input-group-addon[type="submit"],
	.input-group-sm > .input-group-btn > input.btn[type="submit"] {
		height: 33px; }
	input[type="reset"].btn-xs, .btn-group-xs > input.btn[type="reset"], input[type="button"].btn-xs, .btn-group-xs > input.btn[type="button"], input[type="submit"].btn-xs, .btn-group-xs > input.btn[type="submit"] {
		height: 25px; }

/*
 *  Form control width
 *
 *  Default should be representative of the expected length of input.
 *  Full width should be only for cases when the expected length of input is
 *  greater than the available width.
 *  height:37px; rule of Bootstrap was overwritten by height: auto; first
 *  then a min-height specified, in order to address the issue #8492. July 2019.
 */
input[type=button], input[type=reset], input[type=submit] {
	height: auto;
	min-height: 37px; }

.form-control {
	height: auto;
	max-width: 100%;
	min-height: 37px;
	width: auto; }

/*
 * Explicit labels for checkbox and radio button inputs
 *
 * Allow the use of horizontal explicit labels instead of the default implicit
 * labelling pattern for checkbox and radio button inputs provided by Bootstrap.
 */
.form-inline .label-inline {
	position: relative;
	vertical-align: middle; }
	.form-inline .label-inline label {
		font-weight: 400;
		margin-bottom: 0px;
		padding-left: 2px; }

/*
 *  Fieldset/legend border position
 *
 *  Bootstrap puts the border below the legend which creates a visual
 *  separation between the legend and the fields to which it relates. Putting
 *  the border above eliminates that visual separation. Putting it on the
 *  fieldset element instead ensures that all fieldsets will have a separation
 *  even when no legend is used.
 */
legend {
	border-bottom: 0;
	float: left; }

fieldset {
	border-top: 1px solid #e5e5e5;
	padding-top: 10px;
	/*
	 *  Allows fieldSet/legend to have a bottom border under legend title
	 *  https://github.com/wet-boew/wet-boew/issues/7766
	 */
	/*
	 *  Fieldset/legend as a label for a group of checkboxes or radio buttons
	 *  https://github.com/wet-boew/wet-boew/issues/5797
	 */ }
	fieldset:first-child {
		border-top: 0; }
	fieldset.legend-brdr-bttm {
		border-top: 0; }
		fieldset.legend-brdr-bttm legend {
			border-bottom: 1px solid #e5e5e5;
			float: none;
			margin-bottom: 10px; }
	fieldset.chkbxrdio-grp {
		border-top: 0;
		padding-top: 0; }
		fieldset.chkbxrdio-grp legend {
			font-size: 16px;
			font-weight: bold;
			margin-bottom: 5px; }

/*
  WET-BOEW
  @title: Form additions to WET-BOEW
 */
label.required:before,
legend.required:before,
.checkbox.required:before, label.required strong.required,
legend.required strong.required,
.checkbox.required strong.required {
	color: #d3080c;
	font-weight: 700; }

label.required:before,
legend.required:before,
.checkbox.required:before {
	content: "* ";
	margin-left: -0.87em;
	vertical-align: top; }

.form-group.has-error .checkbox {
	color: #333333; }

.form-group .checkbox.checkbox-standalone label {
	font-weight: 700; }

[dir=rtl] label.required:before,
[dir=rtl] legend.required:before {
	margin-left: auto;
	margin-right: -0.87em; }

/*
 *
 * Web Experience Toolkit (WET) / Boîte à outils de l'expérience Web (BOEW)
 * wet-boew.github.io/wet-boew/License-en.html / wet-boew.github.io/wet-boew/Licence-fr.html
 *
 * @title: Forms
 *
 */
input[placeholder],
[placeholder],
*[placeholder] {
	color: #5c5c5c !important; }

.input-group .form-control,
.input-group .input-group-addon,
.input-group .input-group-btn input,
.input-group .input-group-btn button {
	min-height: 39px; }

/* Exclude temporary the form element from the font update, keep same style as before
 * - Rational: More testing and various adjustment need to be completed before to apply it
 * - Fieldflow is brought to speed with the visual update with a clearly defined temporary class .gc-font-2019, but the class can be tried out on other forms
 */
:not(#wb-srch) form, .checkbox, .checkbox-inline, .radio, .radio-inline, form .btn:not(.btn-call-to-action) {
	font-size: 16px;
	line-height: 23px; }

form .btn:not(.btn-call-to-action), .form-control {
	padding: 6px 12px; }

legend {
	line-height: 1.65em; }

.gc-font-2019, .gc-font-2019 label, .gc-font-2019 fieldset legend, .gc-font-2019 input[type="submit"], .gc-font-2019 select, .gc-font-2019 .wb-fieldflow-label ~ p, .gc-font-2019 + div, .gc-font-2019 + div label, .gc-font-2019 + div fieldset legend, .gc-font-2019 + div input[type="submit"], .gc-font-2019 + div select, .gc-font-2019 + div .wb-fieldflow-label ~ p {
	font-size: 20px;
	line-height: 1.65em; }

.gc-font-2019 fieldset legend, .gc-font-2019 + div fieldset legend {
	margin-bottom: 11.5px; }

.gc-font-2019 input[type="checkbox"], .gc-font-2019 input[type="radio"], .gc-font-2019 + div input[type="checkbox"], .gc-font-2019 + div input[type="radio"] {
	margin-top: 11px; }

.gc-font-2019 [type="submit"], .gc-font-2019 select, .gc-font-2019 + div [type="submit"], .gc-font-2019 + div select {
	padding: .54em 1em; }

.btn {
	display: inline-block;
	margin-bottom: 0;
	font-weight: normal;
	text-align: center;
	white-space: nowrap;
	vertical-align: middle;
	-ms-touch-action: manipulation;
	    touch-action: manipulation;
	cursor: pointer;
	background-image: none;
	border: 1px solid transparent;
	padding: 10px 14px;
	font-size: 16px;
	line-height: 1.4375;
	border-radius: 4px;
	-webkit-user-select: none;
	-moz-user-select: none;
	-ms-user-select: none;
	user-select: none; }
	.btn:focus, .btn.focus, .btn:active:focus, .btn:active.focus, .btn.active:focus, .btn.active.focus {
		outline: 5px auto -webkit-focus-ring-color;
		outline-offset: -2px; }
	.btn:hover, .btn:focus, .btn.focus {
		color: #335075;
		text-decoration: none; }
	.btn:active, .btn.active {
		background-image: none;
		outline: 0;
		-webkit-box-shadow: inset 0 3px 5px rgba(0, 0, 0, 0.125);
		box-shadow: inset 0 3px 5px rgba(0, 0, 0, 0.125); }
	.btn.disabled, .btn[disabled],
	fieldset[disabled] .btn {
		cursor: not-allowed;
		filter: alpha(opacity=65);
		opacity: 0.65;
		-webkit-box-shadow: none;
		box-shadow: none; }

a.btn.disabled,
fieldset[disabled] a.btn {
	pointer-events: none; }

.btn-default {
	color: #335075;
	background-color: #eaebed;
	border-color: #dcdee1; }
	.btn-default:focus, .btn-default.focus {
		color: #335075;
		background-color: #cfd1d5;
		border-color: #989da6; }
	.btn-default:hover {
		color: #335075;
		background-color: #cfd1d5;
		border-color: #bbbfc5; }
	.btn-default:active, .btn-default.active,
	.open > .btn-default.dropdown-toggle {
		color: #335075;
		background-color: #cfd1d5;
		background-image: none;
		border-color: #bbbfc5; }
		.btn-default:active:hover, .btn-default:active:focus, .btn-default:active.focus, .btn-default.active:hover, .btn-default.active:focus, .btn-default.active.focus,
		.open > .btn-default.dropdown-toggle:hover,
		.open > .btn-default.dropdown-toggle:focus,
		.open > .btn-default.dropdown-toggle.focus {
			color: #335075;
			background-color: #bbbfc5;
			border-color: #989da6; }
	.btn-default.disabled:hover, .btn-default.disabled:focus, .btn-default.disabled.focus, .btn-default[disabled]:hover, .btn-default[disabled]:focus, .btn-default[disabled].focus,
	fieldset[disabled] .btn-default:hover,
	fieldset[disabled] .btn-default:focus,
	fieldset[disabled] .btn-default.focus {
		background-color: #eaebed;
		border-color: #dcdee1; }
	.btn-default .badge {
		color: #eaebed;
		background-color: #335075; }

.btn-primary {
	color: #fff;
	background-color: #2572b4;
	border-color: #143c5f; }
	.btn-primary:focus, .btn-primary.focus {
		color: #fff;
		background-color: #1c578a;
		border-color: black; }
	.btn-primary:hover {
		color: #fff;
		background-color: #1c578a;
		border-color: #091c2d; }
	.btn-primary:active, .btn-primary.active,
	.open > .btn-primary.dropdown-toggle {
		color: #fff;
		background-color: #1c578a;
		background-image: none;
		border-color: #091c2d; }
		.btn-primary:active:hover, .btn-primary:active:focus, .btn-primary:active.focus, .btn-primary.active:hover, .btn-primary.active:focus, .btn-primary.active.focus,
		.open > .btn-primary.dropdown-toggle:hover,
		.open > .btn-primary.dropdown-toggle:focus,
		.open > .btn-primary.dropdown-toggle.focus {
			color: #fff;
			background-color: #16446c;
			border-color: black; }
	.btn-primary.disabled:hover, .btn-primary.disabled:focus, .btn-primary.disabled.focus, .btn-primary[disabled]:hover, .btn-primary[disabled]:focus, .btn-primary[disabled].focus,
	fieldset[disabled] .btn-primary:hover,
	fieldset[disabled] .btn-primary:focus,
	fieldset[disabled] .btn-primary.focus {
		background-color: #2572b4;
		border-color: #143c5f; }
	.btn-primary .badge {
		color: #2572b4;
		background-color: #fff; }

.btn-success {
	color: #fff;
	background-color: #1b6c1c;
	border-color: #071a07; }
	.btn-success:focus, .btn-success.focus {
		color: #fff;
		background-color: #114311;
		border-color: black; }
	.btn-success:hover {
		color: #fff;
		background-color: #114311;
		border-color: black; }
	.btn-success:active, .btn-success.active,
	.open > .btn-success.dropdown-toggle {
		color: #fff;
		background-color: #114311;
		background-image: none;
		border-color: black; }
		.btn-success:active:hover, .btn-success:active:focus, .btn-success:active.focus, .btn-success.active:hover, .btn-success.active:focus, .btn-success.active.focus,
		.open > .btn-success.dropdown-toggle:hover,
		.open > .btn-success.dropdown-toggle:focus,
		.open > .btn-success.dropdown-toggle.focus {
			color: #fff;
			background-color: #0a270a;
			border-color: black; }
	.btn-success.disabled:hover, .btn-success.disabled:focus, .btn-success.disabled.focus, .btn-success[disabled]:hover, .btn-success[disabled]:focus, .btn-success[disabled].focus,
	fieldset[disabled] .btn-success:hover,
	fieldset[disabled] .btn-success:focus,
	fieldset[disabled] .btn-success.focus {
		background-color: #1b6c1c;
		border-color: #071a07; }
	.btn-success .badge {
		color: #1b6c1c;
		background-color: #fff; }

.btn-info {
	color: #fff;
	background-color: #4d4d4d;
	border-color: #1a1a1a; }
	.btn-info:focus, .btn-info.focus {
		color: #fff;
		background-color: #343333;
		border-color: black; }
	.btn-info:hover {
		color: #fff;
		background-color: #343333;
		border-color: black; }
	.btn-info:active, .btn-info.active,
	.open > .btn-info.dropdown-toggle {
		color: #fff;
		background-color: #343333;
		background-image: none;
		border-color: black; }
		.btn-info:active:hover, .btn-info:active:focus, .btn-info:active.focus, .btn-info.active:hover, .btn-info.active:focus, .btn-info.active.focus,
		.open > .btn-info.dropdown-toggle:hover,
		.open > .btn-info.dropdown-toggle:focus,
		.open > .btn-info.dropdown-toggle.focus {
			color: #fff;
			background-color: #222222;
			border-color: black; }
	.btn-info.disabled:hover, .btn-info.disabled:focus, .btn-info.disabled.focus, .btn-info[disabled]:hover, .btn-info[disabled]:focus, .btn-info[disabled].focus,
	fieldset[disabled] .btn-info:hover,
	fieldset[disabled] .btn-info:focus,
	fieldset[disabled] .btn-info.focus {
		background-color: #4d4d4d;
		border-color: #1a1a1a; }
	.btn-info .badge {
		color: #4d4d4d;
		background-color: #fff; }

.btn-warning {
	color: #000;
	background-color: #f2d40d;
	border-color: #917f08; }
	.btn-warning:focus, .btn-warning.focus {
		color: #000;
		background-color: #c2aa0a;
		border-color: #181501; }
	.btn-warning:hover {
		color: #000;
		background-color: #c2aa0a;
		border-color: #574c05; }
	.btn-warning:active, .btn-warning.active,
	.open > .btn-warning.dropdown-toggle {
		color: #000;
		background-color: #c2aa0a;
		background-image: none;
		border-color: #574c05; }
		.btn-warning:active:hover, .btn-warning:active:focus, .btn-warning:active.focus, .btn-warning.active:hover, .btn-warning.active:focus, .btn-warning.active.focus,
		.open > .btn-warning.dropdown-toggle:hover,
		.open > .btn-warning.dropdown-toggle:focus,
		.open > .btn-warning.dropdown-toggle.focus {
			color: #000;
			background-color: #a08c09;
			border-color: #181501; }
	.btn-warning.disabled:hover, .btn-warning.disabled:focus, .btn-warning.disabled.focus, .btn-warning[disabled]:hover, .btn-warning[disabled]:focus, .btn-warning[disabled].focus,
	fieldset[disabled] .btn-warning:hover,
	fieldset[disabled] .btn-warning:focus,
	fieldset[disabled] .btn-warning.focus {
		background-color: #f2d40d;
		border-color: #917f08; }
	.btn-warning .badge {
		color: #f2d40d;
		background-color: #000; }

.btn-danger {
	color: #fff;
	background-color: #bc3331;
	border-color: #6b1d1c; }
	.btn-danger:focus, .btn-danger.focus {
		color: #fff;
		background-color: #942826;
		border-color: #060202; }
	.btn-danger:hover {
		color: #fff;
		background-color: #942826;
		border-color: #3b100f; }
	.btn-danger:active, .btn-danger.active,
	.open > .btn-danger.dropdown-toggle {
		color: #fff;
		background-color: #942826;
		background-image: none;
		border-color: #3b100f; }
		.btn-danger:active:hover, .btn-danger:active:focus, .btn-danger:active.focus, .btn-danger.active:hover, .btn-danger.active:focus, .btn-danger.active.focus,
		.open > .btn-danger.dropdown-toggle:hover,
		.open > .btn-danger.dropdown-toggle:focus,
		.open > .btn-danger.dropdown-toggle.focus {
			color: #fff;
			background-color: #77201f;
			border-color: #060202; }
	.btn-danger.disabled:hover, .btn-danger.disabled:focus, .btn-danger.disabled.focus, .btn-danger[disabled]:hover, .btn-danger[disabled]:focus, .btn-danger[disabled].focus,
	fieldset[disabled] .btn-danger:hover,
	fieldset[disabled] .btn-danger:focus,
	fieldset[disabled] .btn-danger.focus {
		background-color: #bc3331;
		border-color: #6b1d1c; }
	.btn-danger .badge {
		color: #bc3331;
		background-color: #fff; }

.btn-link {
	font-weight: 400;
	color: #295376;
	border-radius: 0; }
	.btn-link, .btn-link:active, .btn-link.active, .btn-link[disabled],
	fieldset[disabled] .btn-link {
		background-color: transparent;
		-webkit-box-shadow: none;
		box-shadow: none; }
	.btn-link, .btn-link:hover, .btn-link:focus, .btn-link:active {
		border-color: transparent; }
	.btn-link:hover, .btn-link:focus {
		color: #0535d2;
		text-decoration: underline;
		background-color: transparent; }
	.btn-link[disabled]:hover, .btn-link[disabled]:focus,
	fieldset[disabled] .btn-link:hover,
	fieldset[disabled] .btn-link:focus {
		color: #6f6f6f;
		text-decoration: none; }

.btn-lg, .btn-group-lg > .btn {
	padding: 10px 16px;
	font-size: 18px;
	line-height: 1.3333333;
	border-radius: 6px; }

.btn-sm, .btn-group-sm > .btn {
	padding: 5px 10px;
	font-size: 14px;
	line-height: 1.5;
	border-radius: 3px; }

.btn-xs, .btn-group-xs > .btn {
	padding: 1px 5px;
	font-size: 14px;
	line-height: 1.5;
	border-radius: 3px; }

.btn-block {
	display: block;
	width: 100%; }

.btn-block + .btn-block {
	margin-top: 5px; }

input[type="submit"].btn-block,
input[type="reset"].btn-block,
input[type="button"].btn-block {
	width: 100%; }

/*
	WET-BOEW
	@title: Bootstrap overrides for WET-BOEW - Core CSS - button
 */
.btn-default:visited {
	color: #335075; }

.btn-primary:visited {
	color: #fff; }

.btn-success:visited {
	color: #fff; }

.btn-info:visited {
	color: #fff; }

.btn-warning:visited {
	color: #000; }

.btn-danger:visited {
	color: #fff; }

/*
 *  Use button border style 'outset' to give buttons depth, except when disabled
 */
.btn {
	border-style: outset;
	/*
	 * These two property overrides should be recommended upstream to
	 * Bootstrap as a fix for button wrapping (see wet-boew/wet-boew#4454)
	 */
	height: auto;
	min-height: 36px;
	min-width: 36px;
	white-space: normal; }

/*
 WET button overwrites
 */
body .btn-primary {
	background-color: #26374a;
	border-color: #26374a; }

.btn {
	font-family: Lato, sans-serif; }

/* Call-to-action button style - new with GCWeb v5 */
.btn-call-to-action {
	color: #fff;
	background-color: #318000;
	border-color: #458259;
	font-size: 1.1em;
	margin-bottom: 25px;
	margin-top: 15px;
	padding: .58em 1em;
	text-shadow: 1px 2px #333; }
	.btn-call-to-action:focus, .btn-call-to-action.focus {
		color: #fff;
		background-color: #1d4d00;
		border-color: #192f20; }
	.btn-call-to-action:hover {
		color: #fff;
		background-color: #1d4d00;
		border-color: #305a3e; }
	.btn-call-to-action:active, .btn-call-to-action.active,
	.open > .btn-call-to-action.dropdown-toggle {
		color: #fff;
		background-color: #1d4d00;
		background-image: none;
		border-color: #305a3e; }
		.btn-call-to-action:active:hover, .btn-call-to-action:active:focus, .btn-call-to-action:active.focus, .btn-call-to-action.active:hover, .btn-call-to-action.active:focus, .btn-call-to-action.active.focus,
		.open > .btn-call-to-action.dropdown-toggle:hover,
		.open > .btn-call-to-action.dropdown-toggle:focus,
		.open > .btn-call-to-action.dropdown-toggle.focus {
			color: #fff;
			background-color: #102900;
			border-color: #192f20; }
	.btn-call-to-action.disabled:hover, .btn-call-to-action.disabled:focus, .btn-call-to-action.disabled.focus, .btn-call-to-action[disabled]:hover, .btn-call-to-action[disabled]:focus, .btn-call-to-action[disabled].focus,
	fieldset[disabled] .btn-call-to-action:hover,
	fieldset[disabled] .btn-call-to-action:focus,
	fieldset[disabled] .btn-call-to-action.focus {
		background-color: #318000;
		border-color: #458259; }
	.btn-call-to-action .badge {
		color: #318000;
		background-color: #fff; }

.btn-call-to-action:visited {
	color: #fff; }

input.btn.btn-call-to-action {
	padding-bottom: 2em; }

/*
 *
 * Web Experience Toolkit (WET) / Boîte à outils de l'expérience Web (BOEW)
 * wet-boew.github.io/wet-boew/License-en.html / wet-boew.github.io/wet-boew/Licence-fr.html
 *
 * @title: Obselete style
 *
 */
/* Force GCWeb release 4.0.29 font style
 *
 * This undo the font style introduced with gcweb v5 new look
 *
 * - Rational: This is to help the adoption of the new desing by allowing adopter to use
 * a special CSS class on content like the one optimized for a desktop at 100% view port
 * Example of content: high profile pages, campaign, application, .....
 *
 * This CSS are going to be removed in a future version
 * Using this CSS hack should be temporary and be used to get some time to adapt the content
 * as per the new font size parameter
 *
 */
.force-style-gcweb-4-0-29 h1 {
	margin-top: 1.25em; }

.force-style-gcweb-4-0-29 h1,
.force-style-gcweb-4-0-29 .h1 {
	font-family: Helvetica, Arial, sans-serif;
	font-size: 34px; }

.force-style-gcweb-4-0-29 h2,
.force-style-gcweb-4-0-29 .h2 {
	font-family: Helvetica, Arial, sans-serif;
	font-size: 26px; }

.force-style-gcweb-4-0-29 h3,
.force-style-gcweb-4-0-29 .h3 {
	font-family: Helvetica, Arial, sans-serif;
	font-size: 22px; }

.force-style-gcweb-4-0-29 h4,
.force-style-gcweb-4-0-29 .h4 {
	font-family: Helvetica, Arial, sans-serif;
	font-size: 18px; }

.force-style-gcweb-4-0-29 h5,
.force-style-gcweb-4-0-29 .h5 {
	font-family: Helvetica, Arial, sans-serif;
	font-size: 16px; }

.force-style-gcweb-4-0-29 h6,
.force-style-gcweb-4-0-29 .h6 {
	font-family: Helvetica, Arial, sans-serif;
	font-size: 14px;
	font-weight: 700; }

.force-style-gcweb-4-0-29 .glyphicon {
	top: 1px; }

.force-style-gcweb-4-0-29 main,
main.force-style-gcweb-4-0-29 {
	font-family: Helvetica, Arial, sans-serif;
	font-size: 16px;
	line-height: 1.4375em; }

main .force-style-gcweb-4-0-29,
.force-style-gcweb-4-0-29 .btn {
	font-family: Helvetica, Arial, sans-serif;
	font-size: 16px;
	line-height: 23px; }

/*
 * END - Force GCWeb release 4.0.29 font style
 *
 */
form .btn.btn-lg, form .btn-group-lg > .btn,
.force-style-gcweb-4-0-29 .btn.btn-lg,
.force-style-gcweb-4-0-29 .btn-group-lg > .btn {
	padding: 10px 16px;
	font-size: 18px;
	line-height: 1.3333333;
	border-radius: 6px; }

form .btn.btn-sm, form .btn-group-sm > .btn,
.force-style-gcweb-4-0-29 .btn.btn-sm,
.force-style-gcweb-4-0-29 .btn-group-sm > .btn {
	padding: 5px 10px;
	font-size: 14px;
	line-height: 1.5;
	border-radius: 3px; }

form .btn.btn-xs, form .btn-group-xs > .btn,
.force-style-gcweb-4-0-29 .btn.btn-xs,
.force-style-gcweb-4-0-29 .btn-group-xs > .btn {
	padding: 1px 5px;
	font-size: 14px;
	line-height: 1.5;
	border-radius: 3px; }

/*
 Polyfills
 */
/*
 * Web Experience Toolkit (WET) / Boîte à outils de l'expérience Web (BOEW)
 * wet-boew.github.io/wet-boew/License-en.html / wet-boew.github.io/wet-boew/Licence-fr.html
 */
datalist {
	display: none; }

/*
  WET-BOEW
  @title: Details/summary polyfill pre-Modernizr CSS
 */
summary {
	display: list-item !important;
	list-style-type: none;
	list-style-type: disclosure-closed;
	visibility: visible !important; }

details:not([open]) details summary, details .out details summary {
	display: none !important; }

details {
	margin-bottom: .25em; }
	details summary {
		border: 1px solid #ddd;
		border-radius: 4px;
		color: #295376;
		padding: 5px 15px; }
		details summary:focus, details summary:hover {
			background-color: transparent;
			color: #0535d2;
			text-decoration: underline; }
		details summary:focus {
			outline-style: dotted;
			outline-width: 1px; }
	details[open] {
		border: 1px solid #ddd;
		border-radius: 4px; }
		details[open] > summary {
			border: 0;
			border-bottom: 1px solid #ddd;
			border-bottom-left-radius: 0;
			border-bottom-right-radius: 0;
			list-style-type: disclosure-open;
			margin-bottom: .25em; }
	details:not([open]) {
		visibility: hidden; }
		details:not([open]) > details,
		details:not([open]) > * {
			display: none; }
	details.alert:not([open]) {
		visibility: visible; }

.tabpanels > details:not([open]) {
	visibility: visible; }

.wb-disable details {
	visibility: visible !important; }
	.wb-disable details > *:not(summary) {
		display: block !important; }

/*
 * Web Experience Toolkit (WET) / Boîte à outils de l'expérience Web (BOEW)
 * wet-boew.github.io/wet-boew/License-en.html / wet-boew.github.io/wet-boew/Licence-fr.html
 */
.datepicker-format {
	display: none; }

.picker-overlay {
	width: 19em; }

/*! Base Site */
/*
	WET-BOEW
	@title: Accessibility Additions to WET-BOEW - Site template
 */
.wb-sl, #wb-lng h2, #wb-glb-mn h2, #wb-srch h2, #wb-srch label, #wb-sm h2, #wb-bc h2, #wb-sec h2, #wb-info h2, #mb-pnl h3, .wb-calevt-cal .cal-days td ul, .wb-fnote dt, #mb-pnl .srch-pnl label, .wb-invisible, .wb-inv, .wb-show-onfocus {
	clip: rect(1px, 1px, 1px, 1px);
	height: 1px;
	margin: 0;
	overflow: hidden;
	position: absolute;
	width: 1px; }

.wb-sl:focus, .wb-disable .wb-slc .wb-sl, .wb-show-onfocus:focus {
	clip: rect(auto, auto, auto, auto);
	height: inherit;
	margin: inherit;
	overflow: inherit;
	position: static;
	width: inherit; }

#wb-tphp {
	list-style-type: none;
	margin-bottom: 0; }

.wb-slc {
	left: 0;
	position: absolute;
	text-align: center;
	top: 10px;
	width: 100%;
	z-index: 3; }

.wb-sl {
	padding: 5px;
	z-index: 501; }

.wb-disable #wb-tphp {
	background: #fff; }

.wb-disable .wb-slc {
	position: static; }
	.wb-disable .wb-slc .wb-sl {
		background: none;
		color: #295376;
		display: block !important;
		font-weight: 400; }
		.wb-disable .wb-slc .wb-sl:hover, .wb-disable .wb-slc .wb-sl:focus {
			color: #0535d2; }

.wb-disable #wb-dtmd {
	float: none !important; }

.wb-disable #wb-tphp + section h2 {
	margin-left: 1.3em; }
	.wb-disable #wb-tphp + section h2::before {
		color: #f90;
		content: "\e107";
		display: inline-block;
		font-family: "Glyphicons Halflings";
		margin-left: -1.3em;
		position: absolute; }

/*
  WET-BOEW
  @title: Breadcrumb CSS
 */
#wb-bc ol {
	border-radius: 0;
	margin-bottom: 0;
	padding: 1px 13px; }

#wb-bc li {
	max-width: 100%;
	overflow: hidden;
	padding: 7px 2px;
	text-overflow: ellipsis;
	white-space: nowrap; }
	#wb-bc li:before {
		color: #333;
		content: ">";
		font-family: "Glyphicons Halflings";
		font-size: 0.7em; }

[dir=rtl] #wb-bc li:before {
	content: "<";
	display: inline-block; }

/*
 WET breadcrumb overwrites
 for: GCWeb v5
 */
#wb-bc ol {
	margin-top: 15px;
	padding-left: 0px;
	padding-right: 0px; }

#wb-bc li:before {
	position: relative;
	top: -2px; }

#wb-bc li:first-child a {
	padding-left: 0; }

#wb-bc a {
	padding: 5px 10px; }

/*
  WET-BOEW
  @title: Language selector
 */
.wb-lng-lnks-horiz .wb-lng-lnk {
	display: inline-block; }

.wb-lng-lnks-vert .wb-lng-lnk {
	display: block; }

.wb-lng-lnks-rtl .wb-lng-lnk {
	float: right; }

.wb-lng-lnks-rtl:after {
	clear: both;
	content: "";
	display: table; }

#wb-so {
	text-align: right; }
	#wb-so .row {
		padding: 1em 0 0; }

#archived-bnr {
	background-color: #fd0; }
	#archived-bnr p {
		margin: 0;
		text-align: center; }
	#archived-bnr a {
		color: #000;
		display: block;
		font-weight: 700;
		padding: .75em 44px;
		text-decoration: none; }
		#archived-bnr a:hover, #archived-bnr a:focus {
			text-decoration: underline; }
	#archived-bnr .overlay-close {
		color: #000; }

/*
 Banner
 */
header {
	position: relative; }
	header .brand {
		margin-bottom: 10px;
		padding-bottom: 0;
		padding-top: 10px; }
		header .brand a {
			display: block;
			height: auto;
			padding-bottom: 0;
			position: relative;
			text-decoration: none;
			width: auto; }
			header .brand a:after {
				bottom: 0;
				content: "";
				left: 0;
				position: absolute;
				right: 0;
				top: 0; }
		header .brand img,
		header .brand object {
			height: auto;
			max-height: 40px; }
		header .brand img {
			margin-bottom: .375em; }

/*
 * Mobile Chevron
 */
#wb-glb-mn {
	margin-top: 20px; }
	#wb-glb-mn ul {
		min-width: 150px; }
		#wb-glb-mn ul.chvrn {
			background: #26374a;
			display: inline-block;
			float: right;
			height: 2.75em; }
			#wb-glb-mn ul.chvrn li {
				display: block;
				padding-right: 0; }
				#wb-glb-mn ul.chvrn li a {
					color: #fff;
					display: block;
					font-size: 1.9em;
					padding: 5px 20px 0 0; }
			#wb-glb-mn ul.chvrn span .glyphicon-th-list {
				padding-left: 12px;
				top: 0; }
			#wb-glb-mn ul.chvrn:before {
				border-bottom: 1.375em solid transparent;
				border-left: .6875em solid #f8f8f8;
				border-top: 1.375em solid transparent;
				content: " ";
				display: block;
				float: left;
				height: 0;
				position: relative;
				width: 0; }

/* IE Tweaks */
.lt-ie9 header .brand a {
	margin-top: 0; }

.lt-ie9 header .brand img {
	height: 40px; }

[dir=rtl] header .brand {
	float: right; }

[dir=rtl] #wb-glb-mn ul.chvrn {
	padding-left: 1.5em;
	padding-right: 0;
	text-align: left; }
	[dir=rtl] #wb-glb-mn ul.chvrn span .glyphicon-th-list {
		padding-left: 0;
		padding-right: 10px; }
	[dir=rtl] #wb-glb-mn ul.chvrn:before {
		border-left: 0;
		border-right: 11px solid #f8f8f8;
		float: right; }

/* Home page banner */
#hme-banner {
	background-image: url(../assets/your-gov2.jpg);
	background-repeat: no-repeat;
	background-size: cover;
	height: auto;
	padding-top: 1.25%;
	width: 100%; }

#hme-banner-bg {
	background-color: #002b92;
	color: #fff;
	margin-left: 5%;
	min-height: 150px;
	padding: 8px;
	width: 225px; }

h2.hme-banner-bg {
	border: none; }

/*
 Site information
*/
#wb-info {
	position: relative;
	z-index: 5; }
	#wb-info h3 {
		margin-bottom: 1em;
		margin-top: 0; }
	#wb-info a {
		font-size: .875em;
		text-decoration: none; }
	#wb-info nav {
		padding-bottom: 1em;
		padding-top: 1.4em;
		position: relative; }
		#wb-info nav ul[class*="colcount-"] {
			-webkit-column-gap: 0;
			   -moz-column-gap: 0;
			        column-gap: 0; }
		#wb-info nav li {
			margin-bottom: .75em; }
	#wb-info .gc-contextual {
		background-color: #33465c;
		color: #fff; }
		#wb-info .gc-contextual nav {
			padding-bottom: 0; }
		#wb-info .gc-contextual a {
			color: #fff; }
			#wb-info .gc-contextual a:hover {
				text-decoration: underline; }
	#wb-info .gc-main-footer, #wb-info .landscape {
		background: #26374a url(../assets/landscape.png) no-repeat right bottom;
		color: #fff;
		/* Start: to support footer version 2.0 (with gcweb v4.0.22) */
		/* END */ }
		#wb-info .gc-main-footer nav h2.wb-inv + ul, #wb-info .landscape nav h2.wb-inv + ul {
			padding-bottom: 1em;
			padding-top: .6em; }
		#wb-info .gc-main-footer h4, #wb-info .landscape h4 {
			margin-top: 2em;
			position: relative; }
			#wb-info .gc-main-footer h4::before, #wb-info .landscape h4::before {
				border-bottom: 4px solid #fff;
				content: "";
				display: block;
				left: 0;
				position: absolute;
				top: -1.5em;
				width: 2.25em; }
				[dir=rtl] #wb-info .gc-main-footer h4::before, [dir=rtl] #wb-info .landscape h4::before {
					left: auto;
					right: 0; }
		#wb-info .gc-main-footer a, #wb-info .landscape a {
			color: #fff; }
			#wb-info .gc-main-footer a:hover, #wb-info .landscape a:hover {
				text-decoration: underline; }
	#wb-info .gc-sub-footer, #wb-info .brand {
		background: #f8f8f8;
		color: #333;
		padding: 1.5em 0 2em;
		/* START: To support footer <= v2.0 */
		/* END */ }
		#wb-info .gc-sub-footer object,
		#wb-info .gc-sub-footer img, #wb-info .brand object,
		#wb-info .brand img {
			height: 40px;
			width: auto; }
		#wb-info .gc-sub-footer nav, #wb-info .brand nav {
			-webkit-box-flex: 1;
			    -ms-flex: 1 1 auto;
			        flex: 1 1 auto;
			padding-bottom: 0;
			padding-top: 0;
			/* START: To support footer v3.0 */
			/* END */ }
			#wb-info .gc-sub-footer nav ul, #wb-info .brand nav ul {
				display: inline-block;
				list-style-type: none;
				margin: 0;
				padding: 0; }
				#wb-info .gc-sub-footer nav ul li, #wb-info .brand nav ul li {
					display: inline-block;
					margin-bottom: 0;
					margin-right: .5em; }
					[dir=rtl] #wb-info .gc-sub-footer nav ul li, [dir=rtl] #wb-info .brand nav ul li {
						margin-left: .5em;
						margin-right: 0; }
					#wb-info .gc-sub-footer nav ul li:not(:first-child)::before, #wb-info .brand nav ul li:not(:first-child)::before {
						content: "\2022";
						margin-right: .7em; }
						[dir=rtl] #wb-info .gc-sub-footer nav ul li:not(:first-child)::before, [dir=rtl] #wb-info .brand nav ul li:not(:first-child)::before {
							margin-left: .7em;
							margin-right: 0; }
			#wb-info .gc-sub-footer nav h4, #wb-info .brand nav h4 {
				margin: 0; }
			#wb-info .gc-sub-footer nav ul + h4, #wb-info .brand nav ul + h4 {
				display: inline-block;
				margin: 0; }
				#wb-info .gc-sub-footer nav ul + h4::before, #wb-info .brand nav ul + h4::before {
					border: 1px solid #333;
					border-width: 0 0 0 1px;
					content: "";
					display: block;
					height: 1em;
					margin: 0 .75em 0 .4em;
					position: relative;
					top: .1875em; }
		#wb-info .gc-sub-footer .wtrmrk, #wb-info .brand .wtrmrk {
			text-align: right; }
			[dir=rtl] #wb-info .gc-sub-footer .wtrmrk, [dir=rtl] #wb-info .brand .wtrmrk {
				text-align: left; }
		#wb-info .gc-sub-footer .row ul, #wb-info .brand .row ul {
			list-style-type: none;
			margin-bottom: 0;
			padding: 0;
			padding-top: 1em; }
			#wb-info .gc-sub-footer .row ul li, #wb-info .brand .row ul li {
				display: inline-block;
				margin-right: .5em; }
				[dir=rtl] #wb-info .gc-sub-footer .row ul li, [dir=rtl] #wb-info .brand .row ul li {
					margin-left: .5em;
					margin-right: 0; }
				#wb-info .gc-sub-footer .row ul li:not(:first-child):before, #wb-info .brand .row ul li:not(:first-child):before {
					content: "\2022";
					margin-right: .75em; }
					[dir=rtl] #wb-info .gc-sub-footer .row ul li:not(:first-child):before, [dir=rtl] #wb-info .brand .row ul li:not(:first-child):before {
						margin-left: .75em;
						margin-right: 0; }
		#wb-info .gc-sub-footer .row nav, #wb-info .brand .row nav {
			padding-bottom: 0;
			padding-top: 0; }
		#wb-info .gc-sub-footer .tofpg, #wb-info .brand .tofpg {
			line-height: 40px; }
			#wb-info .gc-sub-footer .tofpg a, #wb-info .brand .tofpg a {
				color: #000; }
				#wb-info .gc-sub-footer .tofpg a span, #wb-info .brand .tofpg a span {
					margin-left: 25px; }
				#wb-info .gc-sub-footer .tofpg a:hover, #wb-info .brand .tofpg a:hover {
					text-decoration: none; }
			[dir=rtl] #wb-info .gc-sub-footer .tofpg, [dir=rtl] #wb-info .brand .tofpg {
				float: right; }
				[dir=rtl] #wb-info .gc-sub-footer .tofpg a span, [dir=rtl] #wb-info .brand .tofpg a span {
					margin-left: 0;
					margin-right: 10px; }

#wb-lng {
	padding-top: 10px; }
	#wb-lng li {
		padding-right: 0; }

[dir=rtl] #wb-lng {
	text-align: left; }
	[dir=rtl] #wb-lng ul {
		padding-right: 0; }

/*
 * Search
 */
#wb-srch,
.srchbox {
	padding-top: 1em; }
	#wb-srch .submit,
	.srchbox .submit {
		position: absolute;
		right: 15px;
		top: 1em; }
	#wb-srch input,
	#wb-srch button,
	.srchbox input,
	.srchbox button {
		border-radius: 0; }
	#wb-srch button,
	.srchbox button {
		background-color: #26374a;
		border: 0;
		border-bottom: #26374a solid 1px;
		font-size: 17px; }
		#wb-srch button:hover, #wb-srch button:focus, #wb-srch button:active,
		.srchbox button:hover,
		.srchbox button:focus,
		.srchbox button:active {
			background: #444; }
	#wb-srch .glyphicon,
	.srchbox .glyphicon {
		top: auto;
		vertical-align: middle; }
	#wb-srch input,
	.srchbox input {
		border-color: #e0e0e0;
		border-style: solid;
		-webkit-box-shadow: none;
		        box-shadow: none;
		color: #555;
		position: relative; }
	#wb-srch .wb-srch-qry,
	.srchbox .wb-srch-qry {
		width: 100%; }
		#wb-srch .wb-srch-qry input,
		.srchbox .wb-srch-qry input {
			max-width: inherit;
			width: 100%; }

#wb-srch-sub {
	margin-left: 5px; }

[dir=rtl] #wb-srch {
	text-align: left; }
	[dir=rtl] #wb-srch input {
		margin-left: -4px;
		margin-right: auto; }

[dir=rtl] #wb-srch-sub {
	margin-left: 0;
	margin-right: 5px; }

input#wb-srch-q {
	width: 100%; }

/*
 Secondary Navigation
*/
#wb-sec h3 a:hover, #wb-sec .list-group a.list-group-item.wb-navcurr, #wb-sec .list-group a.list-group-item[href]:hover, #wb-sec .list-group a.list-group-item[href]:focus, #wb-sec .list-group .list-group .list-group .list-group-item.wb-navcurr {
	background-color: #243850;
	color: #fff; }

#wb-sec {
	margin-top: 20px;
	padding-bottom: 2em; }
	#wb-sec h3 {
		border: 1px solid #ddd;
		border-bottom: 5px solid #26374a;
		font-size: 1.1em;
		margin: 15px 0 1px;
		padding: 15px; }
		#wb-sec h3 a {
			color: #333;
			display: block;
			margin: -15px;
			padding: 15px;
			text-decoration: none; }
	#wb-sec .list-group {
		margin-bottom: 0;
		margin-left: 10px; }
		#wb-sec .list-group a.list-group-item {
			background-color: #fff;
			border-radius: 0;
			color: #555;
			margin-top: -1px;
			text-decoration: none; }
			#wb-sec .list-group a.list-group-item.wb-navcurr {
				cursor: text; }
				#wb-sec .list-group a.list-group-item.wb-navcurr[href]:hover {
					background-color: #26374a; }
		#wb-sec .list-group .list-group .list-group-item {
			background-color: #e6e5e5;
			color: black;
			padding-left: 1.8em; }
		#wb-sec .list-group .list-group .list-group .list-group-item {
			background-color: #fff; }
			#wb-sec .list-group .list-group .list-group .list-group-item.wb-navcurr {
				cursor: text; }

[dir=rtl] #wb-sec .list-group .list-group .list-group-item {
	padding-left: 15px;
	padding-right: 1.8em; }

/*
 * Share/feedback-specific overrides
 */
a.shr-opn, a.shr-opn:hover {
	text-decoration: none; }

.pagedetails .row div:first-child a, .pagedetails .row div:first-child details, .pagedetails div + .wb-share-inited {
	margin-top: .5em; }

.pagedetails.text-right .shr-pg {
	text-align: left; }

main .pagedetails {
	font-size: 16px; }

.pagedetails {
	padding-bottom: 2em;
	padding-top: 2em; }
	.pagedetails.row details {
		margin-bottom: .25em;
		margin-left: 1.1em;
		margin-right: 1.1em; }
	.pagedetails .datemod {
		padding-bottom: 7px;
		padding-top: 7px; }
		.pagedetails .datemod #wb-dtmd {
			margin-top: 0; }
	.pagedetails .well {
		margin-left: -1.1em;
		margin-right: -1.1em; }
	.pagedetails details {
		margin-bottom: 0; }

/*
 * Site menu
 */
/*
 * Special style for the home page - GCWeb v5 (gcweb-menu)
 */
.home .gcweb-menu {
	color: #284162; }
	.home .gcweb-menu button[aria-haspopup=true] {
		background-color: #fff;
		border-color: #fff;
		color: #284162; }
		.home .gcweb-menu button[aria-haspopup=true]:hover {
			background-color: #444;
			color: #fff; }

.home #wb-bnr + .gcweb-menu {
	margin-left: 0px; }

/*
 * ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
 *
 * GCWeb v5 (gcweb-menu)
 *
 */
#wb-bnr + .gcweb-menu {
	/*
	 * Level 0 - button menu
	*/
	border-top: 3px solid #38414d;
	font-size: 20px;
	margin-top: 5px; }
	#wb-bnr + .gcweb-menu .container {
		padding: 0px; }

.gcweb-menu {
	/*
	 * Level 1
	 */
	/*
	 * Level 2
	 */
	/* The rest of items */
	/* First menu item (represent the home link */
	/* Undo for lower level */
	/* SubSubMenu (MostRequested) for more iteroperability, use CSS class */
	/* Grid of the submenu panel */ }
	.gcweb-menu button[aria-haspopup=true] {
		background-color: #26374a;
		border: 1px solid #26374a;
		color: #fff;
		margin-left: 0;
		padding: .5em 1em;
		text-transform: uppercase; }
	.gcweb-menu button[aria-haspopup=true]:hover,
	.gcweb-menu button[aria-haspopup=true][aria-expanded=true] {
		background-color: #444;
		border-color: #444;
		color: #fff; }
	.gcweb-menu button[aria-haspopup=true]:focus {
		background-color: #fff;
		border: 1px dotted #555;
		color: #333; }
	.gcweb-menu [aria-haspopup=true][aria-expanded=false] + [role=menu] {
		display: none; }
	.gcweb-menu button[aria-haspopup=true][aria-expanded=true] + [role=menu] {
		z-index: 9999; }
	.gcweb-menu [role=menu] {
		background-color: #444;
		color: #fff;
		list-style: none;
		padding: 0;
		position: absolute; }
	.gcweb-menu [role=menu] > li {
		border-left: #444 solid 1px; }
	.gcweb-menu [role=menu] > li:first-child {
		border-top: #444 solid 1px; }
	.gcweb-menu [role=menu] > li:last-child {
		border-bottom: #444 solid 1px; }
	.gcweb-menu [role=menu] > li [role=menu] > li {
		border: none; }
	.gcweb-menu [role=menuitem] {
		display: block;
		padding: 14px 30px;
		width: 360px; }
	.gcweb-menu [role=menuitem],
	.gcweb-menu [role=menuitem]:visited {
		border-bottom: 1px solid #555;
		color: #fff;
		font-size: 18px;
		text-decoration: none; }
	.gcweb-menu li:last-child [role=menuitem] {
		border-bottom: none; }
	.gcweb-menu [role=menuitem]:hover,
	.gcweb-menu [role=menuitem][aria-expanded=true] + [role=menu] [role=menuitem]:focus,
	.gcweb-menu [role=menuitem][aria-expanded=true] {
		background-color: #fff;
		color: #333; }
	.gcweb-menu [role=menu] [role=menu] {
		background-color: #fff;
		border-top: #eee solid 1px;
		-webkit-box-shadow: 10px 10px 10px 5px rgba(0, 0, 0, 0.1);
		        box-shadow: 10px 10px 10px 5px rgba(0, 0, 0, 0.1);
		color: #000;
		left: 360px;
		margin-bottom: 25px;
		min-height: 815px;
		padding: 0px 39px 24px 39px;
		top: 0;
		width: 810px; }
	.gcweb-menu [role=menu] [role=menu] [role=menu] {
		border-top: none;
		min-height: auto; }
	.gcweb-menu [role=menu] [role=menu] [role=menuitem] {
		border-bottom: none;
		color: #000;
		width: auto; }
	.gcweb-menu [role=menu] [role=menu] [role=menu] {
		left: auto;
		top: auto; }
	.gcweb-menu [role=menu] [role=menu] li [role=menuitem] {
		color: #284162;
		padding: 6px 0;
		text-decoration: underline; }
	.gcweb-menu [role=menu] [role=menu] li [role=menuitem]:hover {
		color: #0535d2; }
	.gcweb-menu [role=menu] [role=menu] li:first-child [role=menuitem] {
		font-size: 32px;
		font-weight: 700;
		text-decoration: underline; }
	.gcweb-menu [role=menu] [role=menu] [role=menu] li:first-child [role=menuitem] {
		font-size: 18px;
		font-weight: 400;
		text-decoration: underline;
		width: auto; }
	.gcweb-menu [role=menu] [role=menu] li:last-child [role=menu] {
		list-style: disc;
		padding-top: 0px; }
	.gcweb-menu [role=menu] [role=menu] [role=menu] {
		-webkit-box-shadow: none;
		        box-shadow: none;
		width: auto; }
	.gcweb-menu [role=menu] [role=menu] li {
		width: 45%; }
	.gcweb-menu [role=menu] [role=menu] li:first-child {
		margin-bottom: 1.5em;
		width: 100%; }
	.gcweb-menu [role=menu] [role=menu] [role=menu] li:first-child {
		margin-bottom: 0px; }
	.gcweb-menu [role=menu] [role=menu] li:last-child {
		left: 400px;
		position: absolute;
		top: 4.5em; }
	.gcweb-menu [role=menu] [role=menu] [role=menu] li:last-child {
		left: auto;
		position: relative;
		top: auto; }
	.gcweb-menu [role=menu] [role=menu] [role=menu] li {
		width: 100%; }

.wb-disable .gcweb-menu [role=menu] {
	position: static; }

.wb-disable .gcweb-menu [aria-haspopup=true][aria-expanded=false] + [role=menu] {
	display: block; }

.wb-disable .gcweb-menu [role=menu] > li {
	float: left;
	padding-right: 5px;
	width: 50%; }
	.wb-disable .gcweb-menu [role=menu] > li:nth-child(2n+2) {
		clear: right; }
	.wb-disable .gcweb-menu [role=menu] > li:nth-child(2n+3) {
		clear: left; }

.wb-disable .gcweb-menu [role=menu] > li a {
	width: auto; }

.wb-disable .gcweb-menu [role=menu]:before, .wb-disable .gcweb-menu [role=menu]:after {
	content: " ";
	display: table; }

.wb-disable .gcweb-menu [role=menu]:after {
	clear: both; }

/*
 *
 * GCWeb v5 (gcweb-menu) - END
 *
 * ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
 */
/* GCWeb version 1.0 megamenu */
#wb-sm {
	background: #26374a; }
	#wb-sm .menu {
		display: table;
		margin-bottom: 0;
		text-shadow: 1px 1px 1px #222;
		width: 100%; }
		#wb-sm .menu .active,
		#wb-sm .menu .selected,
		#wb-sm .menu .wb-navcurr {
			background: #243850 !important;
			color: #fff !important; }
		#wb-sm .menu > li {
			border-left: 1px solid #999;
			display: table-cell;
			float: none; }
			#wb-sm .menu > li:last-child {
				border-right: 1px solid #999; }
			#wb-sm .menu > li a {
				color: #fff; }
				#wb-sm .menu > li a:hover, #wb-sm .menu > li a:focus {
					background: #243850 !important;
					text-shadow: none; }
	#wb-sm .sm.open {
		background: #ccc;
		border-bottom: 5px solid #243850; }
		#wb-sm .sm.open li a,
		#wb-sm .sm.open li summary {
			color: #444;
			padding: 5px 10px;
			text-shadow: none; }
			#wb-sm .sm.open li a:hover, #wb-sm .sm.open li a:focus, #wb-sm .sm.open li a:active,
			#wb-sm .sm.open li summary:hover,
			#wb-sm .sm.open li summary:focus,
			#wb-sm .sm.open li summary:active {
				background: #243850;
				color: #fff; }
		#wb-sm .sm.open .slflnk a {
			background: #bbb; }
	#wb-sm .sm .row {
		background: transparent; }
		#wb-sm .sm .row a {
			color: #6e6e6e; }

.wb-disable #wb-sm .nvbar {
	display: block !important; }

/*
 * Mobile panel
 */
#mb-pnl {
	background: url("data:image/gif;base64,R0lGODlh6AMBAIAAABk0UQAAACH/C1hNUCBEYXRhWE1QPD94cGFja2V0IGJlZ2luPSLvu78iIGlkPSJXNU0wTXBDZWhpSHpyZVN6TlRjemtjOWQiPz4gPHg6eG1wbWV0YSB4bWxuczp4PSJhZG9iZTpuczptZXRhLyIgeDp4bXB0az0iQWRvYmUgWE1QIENvcmUgNS4zLWMwMTEgNjYuMTQ1NjYxLCAyMDEyLzAyLzA2LTE0OjU2OjI3ICAgICAgICAiPiA8cmRmOlJERiB4bWxuczpyZGY9Imh0dHA6Ly93d3cudzMub3JnLzE5OTkvMDIvMjItcmRmLXN5bnRheC1ucyMiPiA8cmRmOkRlc2NyaXB0aW9uIHJkZjphYm91dD0iIiB4bWxuczp4bXA9Imh0dHA6Ly9ucy5hZG9iZS5jb20veGFwLzEuMC8iIHhtbG5zOnhtcE1NPSJodHRwOi8vbnMuYWRvYmUuY29tL3hhcC8xLjAvbW0vIiB4bWxuczpzdFJlZj0iaHR0cDovL25zLmFkb2JlLmNvbS94YXAvMS4wL3NUeXBlL1Jlc291cmNlUmVmIyIgeG1wOkNyZWF0b3JUb29sPSJBZG9iZSBQaG90b3Nob3AgQ1M2IChNYWNpbnRvc2gpIiB4bXBNTTpJbnN0YW5jZUlEPSJ4bXAuaWlkOkMxRUQ2ODczNUEyODExRTNBODM4OUNCRUJBOUJGN0REIiB4bXBNTTpEb2N1bWVudElEPSJ4bXAuZGlkOkMxRUQ2ODc0NUEyODExRTNBODM4OUNCRUJBOUJGN0REIj4gPHhtcE1NOkRlcml2ZWRGcm9tIHN0UmVmOmluc3RhbmNlSUQ9InhtcC5paWQ6QzFFRDY4NzE1QTI4MTFFM0E4Mzg5Q0JFQkE5QkY3REQiIHN0UmVmOmRvY3VtZW50SUQ9InhtcC5kaWQ6QzFFRDY4NzI1QTI4MTFFM0E4Mzg5Q0JFQkE5QkY3REQiLz4gPC9yZGY6RGVzY3JpcHRpb24+IDwvcmRmOlJERj4gPC94OnhtcG1ldGE+IDw/eHBhY2tldCBlbmQ9InIiPz4B//79/Pv6+fj39vX08/Lx8O/u7ezr6uno5+bl5OPi4eDf3t3c29rZ2NfW1dTT0tHQz87NzMvKycjHxsXEw8LBwL++vby7urm4t7a1tLOysbCvrq2sq6qpqKempaSjoqGgn56dnJuamZiXlpWUk5KRkI+OjYyLiomIh4aFhIOCgYB/fn18e3p5eHd2dXRzcnFwb25tbGtqaWhnZmVkY2JhYF9eXVxbWllYV1ZVVFNSUVBPTk1MS0pJSEdGRURDQkFAPz49PDs6OTg3NjU0MzIxMC8uLSwrKikoJyYlJCMiISAfHh0cGxoZGBcWFRQTEhEQDw4NDAsKCQgHBgUEAwIBAAAh+QQAAAAAACwAAAAA6AMBAAACHoSPqcvtD6OctNqLs968+w+G4kiW5omm6sq27gs7BQA7");
	background-position: 15px 0;
	background-repeat: repeat-y;
	-webkit-box-shadow: none;
	        box-shadow: none;
	padding-left: 15px; }
	#mb-pnl a[href$="#wb-cont"] {
		display: none !important; }
	#mb-pnl .modal-header {
		background: #2e5274;
		border-bottom: 1px solid #2e5274;
		-webkit-box-shadow: 0 3px 3px -2px rgba(0, 0, 0, 0.3), 3px 3px 3px -2px rgba(0, 0, 0, 0.3), -3px 3px 3px -2px rgba(0, 0, 0, 0.3);
		        box-shadow: 0 3px 3px -2px rgba(0, 0, 0, 0.3), 3px 3px 3px -2px rgba(0, 0, 0, 0.3), -3px 3px 3px -2px rgba(0, 0, 0, 0.3);
		color: #fff;
		margin-left: 0;
		padding: 0 44px 0 1em;
		position: relative;
		text-align: left;
		text-decoration: none;
		top: 1em;
		z-index: 1045; }
		#mb-pnl .modal-header:before {
			border-bottom: 1.45em solid #2e5274;
			border-left: 1em solid rgba(0, 0, 0, 0);
			border-top: 1.45em solid #2e5274;
			content: "";
			left: -1em;
			position: absolute;
			top: 0; }
		#mb-pnl .modal-header h2 {
			border: 0;
			margin-bottom: 0;
			margin-top: 1px;
			padding: 9px; }
	#mb-pnl .modal-body {
		background: #0e4164;
		margin-left: 0;
		padding-bottom: 0;
		padding-left: 0;
		padding-right: 0;
		padding-top: 5em;
		position: relative;
		top: -3em; }
		#mb-pnl .modal-body summary {
			color: #fff; }
			#mb-pnl .modal-body summary:hover, #mb-pnl .modal-body summary:focus {
				background: transparent;
				color: #fff; }
		#mb-pnl .modal-body a {
			color: #fff;
			text-decoration: none; }
		#mb-pnl .modal-body ul {
			list-style-type: none; }
		#mb-pnl .modal-body li {
			line-height: 2;
			list-style-type: none; }
	#mb-pnl .modal-footer {
		background: #0e4164; }
	#mb-pnl .mfp-close {
		top: .55em; }
	#mb-pnl .srch-pnl form button {
		background-color: #26374a;
		border: 0;
		border-color: #26374a;
		border-radius: 0;
		position: relative; }
		#mb-pnl .srch-pnl form button:hover, #mb-pnl .srch-pnl form button:focus, #mb-pnl .srch-pnl form button:active {
			background: #243850; }
	#mb-pnl .srch-pnl form input {
		background-color: #e0e0e0;
		border-color: #e0e0e0;
		border-radius: 0;
		border-right: 0;
		border-style: solid;
		-webkit-box-shadow: none;
		        box-shadow: none;
		color: #555;
		margin-right: -4px;
		position: relative; }
	#mb-pnl .srch-pnl .btn {
		line-height: 1.65;
		margin-top: -1px; }
	#mb-pnl .srch-pnl .form-group {
		float: left;
		margin-left: 15px;
		width: 75%; }
		#mb-pnl .srch-pnl .form-group.submit {
			margin-left: 0;
			width: 15%; }
	#mb-pnl .lng-ofr {
		padding-right: 30px;
		text-align: right; }
	#mb-pnl .sm-pnl {
		background: #0e4164;
		padding-left: 15px; }
	#mb-pnl .info-pnl {
		background: #193451;
		border-top: 2px solid #061e38;
		color: #325375 !important;
		padding-left: 15px; }
	#mb-pnl .active > a {
		font-weight: 800; }
	#mb-pnl .sec-pnl {
		background: #cdd4da !important;
		display: none !important;
		padding-left: 15px; }
		#mb-pnl .sec-pnl a,
		#mb-pnl .sec-pnl summary {
			color: #2e5576 !important; }

[dir=rtl] #wb-sm .menu > li {
	border-right: 1px solid #999; }

[dir=rtl] #mb-pnl {
	background: transparent;
	padding-left: 0;
	padding-right: 15px; }
	[dir=rtl] #mb-pnl .srch-pnl .form-group {
		float: right;
		margin-left: 0;
		margin-right: 15px; }
		[dir=rtl] #mb-pnl .srch-pnl .form-group input {
			margin-left: 0;
			margin-right: -4px; }
		[dir=rtl] #mb-pnl .srch-pnl .form-group.submit {
			margin-right: 0; }
	[dir=rtl] #mb-pnl .modal-header {
		text-align: right; }
		[dir=rtl] #mb-pnl .modal-header:before {
			border-left: 0;
			border-right: 1em solid rgba(0, 0, 0, 0);
			left: auto;
			right: -1em; }

/*
 * Specific classes for authentication section which include Sign-on/Sign-off button and the Contextual Sign-in button.
 */
#wb-so .btn {
	border-radius: 0px;
	margin-top: 5px; }

#wb-so a.btn:hover {
	background-color: #444; }

/*
 * Site header
 */
#wb-bnr + hr {
	border-top: 3px solid #38414d;
	margin-bottom: 0px;
	margin-top: 5px; }
	#wb-bnr + hr + .container {
		font-size: 20px; }

/*! Components (CSS type only) */
.fade {
	opacity: 0;
	-webkit-transition: opacity 0.15s linear;
	transition: opacity 0.15s linear; }
	.fade.in {
		opacity: 1; }

.collapse {
	display: none; }
	.collapse.in {
		display: block; }

tr.collapse.in {
	display: table-row; }

tbody.collapse.in {
	display: table-row-group; }

.collapsing {
	position: relative;
	height: 0;
	overflow: hidden;
	-webkit-transition-property: height, visibility;
	transition-property: height, visibility;
	-webkit-transition-duration: 0.35s;
	transition-duration: 0.35s;
	-webkit-transition-timing-function: ease;
	transition-timing-function: ease; }

/*
* Based upon jQuery Mobile Transitions (https://jquerymobile.com)
*
* Copyright 2010, 2013 jQuery Foundation, Inc. and other contributors
* Released under the MIT license.
* https://jquery.org/license
*
*/
/*! Placeholders */
.pop.in, .fade.in, .fade.reverse.out {
	opacity: 1;
	visibility: visible; }

.pop.out, .fade.out, .fade.reverse.in {
	opacity: 0;
	visibility: hidden; }

@keyframes spin {
	from {
		-webkit-transform: rotate(0);
		        transform: rotate(0); }
	to {
		-webkit-transform: rotate(360deg);
		        transform: rotate(360deg); } }

.out {
	display: none !important; }

.csstransitions .out {
	display: block !important; }

.pop {
	-webkit-transform-origin: 50% 50%;
	        transform-origin: 50% 50%; }
	.pop.in {
		-webkit-animation-duration: 350ms;
		        animation-duration: 350ms;
		-webkit-animation-name: popin;
		        animation-name: popin;
		-webkit-transform: scale(1);
		        transform: scale(1);
		visibility: visible; }
	.pop.out {
		-webkit-animation-duration: 100ms;
		        animation-duration: 100ms;
		-webkit-animation-name: fadeout;
		        animation-name: fadeout;
		visibility: hidden; }
	.pop.reverse.in {
		-webkit-animation-name: fadein;
		        animation-name: fadein; }
	.pop.reverse.out {
		-webkit-animation-name: popout;
		        animation-name: popout;
		-webkit-transform: scale(0.8);
		        transform: scale(0.8); }

@-webkit-keyframes popin {
	0% {
		opacity: 1;
		visibility: visible;
		-webkit-transform: scale(0.8);
		        transform: scale(0.8); }
	100% {
		opacity: 0;
		visibility: hidden;
		-webkit-transform: scale(1);
		        transform: scale(1); } }

@keyframes popin {
	0% {
		opacity: 1;
		visibility: visible;
		-webkit-transform: scale(0.8);
		        transform: scale(0.8); }
	100% {
		opacity: 0;
		visibility: hidden;
		-webkit-transform: scale(1);
		        transform: scale(1); } }

@-webkit-keyframes popout {
	0% {
		opacity: 1;
		visibility: visible;
		-webkit-transform: scale(1);
		        transform: scale(1); }
	100% {
		opacity: 0;
		visibility: hidden;
		-webkit-transform: scale(0.8);
		        transform: scale(0.8); } }

@keyframes popout {
	0% {
		opacity: 1;
		visibility: visible;
		-webkit-transform: scale(1);
		        transform: scale(1); }
	100% {
		opacity: 0;
		visibility: hidden;
		-webkit-transform: scale(0.8);
		        transform: scale(0.8); } }

.fade {
	-webkit-transition: all 0 ease 0;
	transition: all 0 ease 0; }
	.fade.in {
		-webkit-animation-duration: 225ms;
		        animation-duration: 225ms;
		-webkit-animation-name: fadein;
		        animation-name: fadein; }
	.fade.out {
		-webkit-animation-duration: 125ms;
		        animation-duration: 125ms;
		-webkit-animation-name: fadeout;
		        animation-name: fadeout;
		z-index: -1; }
		.fade.out.noheight {
			-webkit-animation-name: fadeoutnoheight;
			        animation-name: fadeoutnoheight;
			max-height: 0; }
	.fade.reverse.in {
		-webkit-animation-name: fadeout;
		        animation-name: fadeout; }
	.fade.reverse.out {
		-webkit-animation-name: fadein;
		        animation-name: fadein; }

@-webkit-keyframes fadein {
	0% {
		opacity: 0;
		visibility: hidden; }
	100% {
		opacity: 1;
		visibility: visible; } }

@keyframes fadein {
	0% {
		opacity: 0;
		visibility: hidden; }
	100% {
		opacity: 1;
		visibility: visible; } }

@-webkit-keyframes fadeout {
	0% {
		opacity: 1;
		visibility: visible; }
	100% {
		opacity: 0;
		visibility: hidden; } }

@keyframes fadeout {
	0% {
		opacity: 1;
		visibility: visible; }
	100% {
		opacity: 0;
		visibility: hidden; } }

@-webkit-keyframes fadeoutnoheight {
	0% {
		opacity: 1;
		visibility: visible;
		max-height: 100%; }
	99.9999% {
		max-height: 100%; }
	100% {
		opacity: 0;
		visibility: hidden;
		max-height: 0; } }

@keyframes fadeoutnoheight {
	0% {
		opacity: 1;
		visibility: visible;
		max-height: 100%; }
	99.9999% {
		max-height: 100%; }
	100% {
		opacity: 0;
		visibility: hidden;
		max-height: 0; } }

.slide.out, .slide.in {
	-webkit-animation-duration: 350ms;
	        animation-duration: 350ms;
	-webkit-animation-timing-function: ease-out;
	        animation-timing-function: ease-out; }

.slide.out {
	-webkit-animation-name: slideouttoleft;
	        animation-name: slideouttoleft;
	-webkit-transform: translateX(-100%);
	        transform: translateX(-100%);
	visibility: hidden; }

.slide.in {
	-webkit-animation-name: slideinfromright;
	        animation-name: slideinfromright;
	-webkit-transform: translateX(0);
	        transform: translateX(0);
	visibility: visible; }

.slide.reverse.out {
	-webkit-animation-name: slideouttoright;
	        animation-name: slideouttoright;
	-webkit-transform: translateX(100%);
	        transform: translateX(100%); }

.slide.reverse.in {
	-webkit-animation-name: slideinfromleft;
	        animation-name: slideinfromleft; }

/* keyframes for slidein from sides */
@-webkit-keyframes slideinfromright {
	0% {
		-webkit-transform: translateX(100%);
		        transform: translateX(100%); }
	100% {
		-webkit-transform: translateX(0);
		        transform: translateX(0); } }
@keyframes slideinfromright {
	0% {
		-webkit-transform: translateX(100%);
		        transform: translateX(100%); }
	100% {
		-webkit-transform: translateX(0);
		        transform: translateX(0); } }

@-webkit-keyframes slideinfromleft {
	0% {
		-webkit-transform: translateX(-100%);
		        transform: translateX(-100%); }
	100% {
		-webkit-transform: translateX(0);
		        transform: translateX(0); } }

@keyframes slideinfromleft {
	0% {
		-webkit-transform: translateX(-100%);
		        transform: translateX(-100%); }
	100% {
		-webkit-transform: translateX(0);
		        transform: translateX(0); } }

/* keyframes for slideout to sides */
@-webkit-keyframes slideouttoleft {
	0% {
		-webkit-transform: translateX(0);
		        transform: translateX(0);
		visibility: visible; }
	99% {
		visibility: visible; }
	100% {
		-webkit-transform: translateX(-100%);
		        transform: translateX(-100%);
		visibility: hidden; } }
@keyframes slideouttoleft {
	0% {
		-webkit-transform: translateX(0);
		        transform: translateX(0);
		visibility: visible; }
	99% {
		visibility: visible; }
	100% {
		-webkit-transform: translateX(-100%);
		        transform: translateX(-100%);
		visibility: hidden; } }

@-webkit-keyframes slideouttoright {
	0% {
		-webkit-transform: translateX(0);
		        transform: translateX(0);
		visibility: visible; }
	99% {
		visibility: visible; }
	100% {
		-webkit-transform: translateX(100%);
		        transform: translateX(100%);
		visibility: hidden; } }

@keyframes slideouttoright {
	0% {
		-webkit-transform: translateX(0);
		        transform: translateX(0);
		visibility: visible; }
	99% {
		visibility: visible; }
	100% {
		-webkit-transform: translateX(100%);
		        transform: translateX(100%);
		visibility: hidden; } }

.slidefade.out {
	-webkit-animation-duration: 225ms;
	        animation-duration: 225ms;
	-webkit-animation-name: slideouttoleft;
	        animation-name: slideouttoleft;
	-webkit-transform: translateX(-100%);
	        transform: translateX(-100%); }

.slidefade.in {
	-webkit-animation-duration: 200ms;
	        animation-duration: 200ms;
	-webkit-animation-name: fadein;
	        animation-name: fadein;
	-webkit-transform: translateX(0);
	        transform: translateX(0); }

.slidefade.reverse.out {
	-webkit-animation-name: slideouttoright;
	        animation-name: slideouttoright;
	-webkit-transform: translateX(100%);
	        transform: translateX(100%); }

/* slide up/down */
.slidevert.out, .slidevert.in {
	-webkit-animation-duration: 350ms;
	        animation-duration: 350ms;
	-webkit-animation-timing-function: ease-out;
	        animation-timing-function: ease-out; }

.slidevert.out {
	-webkit-animation-name: slideouttobottom;
	        animation-name: slideouttobottom;
	-webkit-transform: translateY(100%);
	        transform: translateY(100%);
	visibility: hidden; }

.slidevert.in {
	-webkit-animation-name: slideinfromtop;
	        animation-name: slideinfromtop;
	-webkit-transform: translateY(0);
	        transform: translateY(0);
	visibility: visible; }

.slidevert.reverse.out {
	-webkit-animation-name: slideouttotop;
	        animation-name: slideouttotop;
	-webkit-transform: translateY(-100%);
	        transform: translateY(-100%); }

.slidevert.reverse.in {
	-webkit-animation-name: slideinfrombottom;
	        animation-name: slideinfrombottom; }

@-webkit-keyframes slideinfromtop {
	0% {
		-webkit-transform: translateY(-100%);
		        transform: translateY(-100%); }
	100% {
		-webkit-transform: translateY(0);
		        transform: translateY(0); } }

@keyframes slideinfromtop {
	0% {
		-webkit-transform: translateY(-100%);
		        transform: translateY(-100%); }
	100% {
		-webkit-transform: translateY(0);
		        transform: translateY(0); } }

@-webkit-keyframes slideouttotop {
	0% {
		-webkit-transform: translateY(0);
		        transform: translateY(0);
		visibility: visible; }
	99% {
		visibility: visible; }
	100% {
		-webkit-transform: translateY(-100%);
		        transform: translateY(-100%);
		visibility: hidden; } }

@keyframes slideouttotop {
	0% {
		-webkit-transform: translateY(0);
		        transform: translateY(0);
		visibility: visible; }
	99% {
		visibility: visible; }
	100% {
		-webkit-transform: translateY(-100%);
		        transform: translateY(-100%);
		visibility: hidden; } }

@-webkit-keyframes slideinfrombottom {
	0% {
		-webkit-transform: translateY(100%);
		        transform: translateY(100%); }
	100% {
		-webkit-transform: translateY(0);
		        transform: translateY(0); } }

@keyframes slideinfrombottom {
	0% {
		-webkit-transform: translateY(100%);
		        transform: translateY(100%); }
	100% {
		-webkit-transform: translateY(0);
		        transform: translateY(0); } }

@-webkit-keyframes slideouttobottom {
	0% {
		-webkit-transform: translateY(0);
		        transform: translateY(0);
		visibility: visible; }
	99% {
		visibility: visible; }
	100% {
		-webkit-transform: translateY(100%);
		        transform: translateY(100%);
		visibility: hidden; } }

@keyframes slideouttobottom {
	0% {
		-webkit-transform: translateY(0);
		        transform: translateY(0);
		visibility: visible; }
	99% {
		visibility: visible; }
	100% {
		-webkit-transform: translateY(100%);
		        transform: translateY(100%);
		visibility: hidden; } }

.caret {
	display: inline-block;
	width: 0;
	height: 0;
	margin-left: 2px;
	vertical-align: middle;
	border-top: 4px dashed;
	border-top: 4px solid \9;
	border-right: 4px solid transparent;
	border-left: 4px solid transparent; }

.dropup,
.dropdown {
	position: relative; }

.dropdown-toggle:focus {
	outline: 0; }

.dropdown-menu {
	position: absolute;
	top: 100%;
	left: 0;
	z-index: 1000;
	display: none;
	float: left;
	min-width: 160px;
	padding: 5px 0;
	margin: 2px 0 0;
	font-size: 16px;
	text-align: left;
	list-style: none;
	background-color: #fff;
	background-clip: padding-box;
	border: 1px solid #ccc;
	border: 1px solid rgba(0, 0, 0, 0.15);
	border-radius: 4px;
	-webkit-box-shadow: 0 6px 12px rgba(0, 0, 0, 0.175);
	box-shadow: 0 6px 12px rgba(0, 0, 0, 0.175); }
	.dropdown-menu.pull-right {
		right: 0;
		left: auto; }
	.dropdown-menu .divider {
		height: 1px;
		margin: 10.5px 0;
		overflow: hidden;
		background-color: #e5e5e5; }
	.dropdown-menu > li > a {
		display: block;
		padding: 3px 20px;
		clear: both;
		font-weight: 400;
		line-height: 1.4375;
		color: #333333;
		white-space: nowrap; }
		.dropdown-menu > li > a:hover, .dropdown-menu > li > a:focus {
			color: #262626;
			text-decoration: none;
			background-color: #f5f5f5; }

.dropdown-menu > .active > a, .dropdown-menu > .active > a:hover, .dropdown-menu > .active > a:focus {
	color: #fff;
	text-decoration: none;
	background-color: #2572b4;
	outline: 0; }

.dropdown-menu > .disabled > a, .dropdown-menu > .disabled > a:hover, .dropdown-menu > .disabled > a:focus {
	color: #6f6f6f; }

.dropdown-menu > .disabled > a:hover, .dropdown-menu > .disabled > a:focus {
	text-decoration: none;
	cursor: not-allowed;
	background-color: transparent;
	background-image: none;
	filter: progid:DXImageTransform.Microsoft.gradient(enabled = false); }

.open > .dropdown-menu {
	display: block; }

.open > a {
	outline: 0; }

.dropdown-menu-right {
	right: 0;
	left: auto; }

.dropdown-menu-left {
	right: auto;
	left: 0; }

.dropdown-header {
	display: block;
	padding: 3px 20px;
	font-size: 14px;
	line-height: 1.4375;
	color: #6f6f6f;
	white-space: nowrap; }

.dropdown-backdrop {
	position: fixed;
	top: 0;
	right: 0;
	bottom: 0;
	left: 0;
	z-index: 990; }

.pull-right > .dropdown-menu {
	right: 0;
	left: auto; }

.dropup .caret,
.navbar-fixed-bottom .dropdown .caret {
	content: "";
	border-top: 0;
	border-bottom: 4px dashed;
	border-bottom: 4px solid \9; }

.dropup .dropdown-menu,
.navbar-fixed-bottom .dropdown .dropdown-menu {
	top: auto;
	bottom: 100%;
	margin-bottom: 2px; }

@media (min-width: 768px) {
	.navbar-right .dropdown-menu {
		right: 0;
		left: auto; }
	.navbar-right .dropdown-menu-left {
		left: 0;
		right: auto; } }

.btn-group,
.btn-group-vertical {
	position: relative;
	display: inline-block;
	vertical-align: middle; }
	.btn-group > .btn,
	.btn-group-vertical > .btn {
		position: relative;
		float: left; }
		.btn-group > .btn:hover, .btn-group > .btn:focus, .btn-group > .btn:active, .btn-group > .btn.active,
		.btn-group-vertical > .btn:hover,
		.btn-group-vertical > .btn:focus,
		.btn-group-vertical > .btn:active,
		.btn-group-vertical > .btn.active {
			z-index: 2; }

.btn-group .btn + .btn,
.btn-group .btn + .btn-group,
.btn-group .btn-group + .btn,
.btn-group .btn-group + .btn-group {
	margin-left: -1px; }

.btn-toolbar {
	margin-left: -5px; }
	.btn-toolbar:before, .btn-toolbar:after {
		display: table;
		content: " "; }
	.btn-toolbar:after {
		clear: both; }
	.btn-toolbar .btn,
	.btn-toolbar .btn-group,
	.btn-toolbar .input-group {
		float: left; }
	.btn-toolbar > .btn,
	.btn-toolbar > .btn-group,
	.btn-toolbar > .input-group {
		margin-left: 5px; }

.btn-group > .btn:not(:first-child):not(:last-child):not(.dropdown-toggle) {
	border-radius: 0; }

.btn-group > .btn:first-child {
	margin-left: 0; }
	.btn-group > .btn:first-child:not(:last-child):not(.dropdown-toggle) {
		border-top-right-radius: 0;
		border-bottom-right-radius: 0; }

.btn-group > .btn:last-child:not(:first-child),
.btn-group > .dropdown-toggle:not(:first-child) {
	border-top-left-radius: 0;
	border-bottom-left-radius: 0; }

.btn-group > .btn-group {
	float: left; }

.btn-group > .btn-group:not(:first-child):not(:last-child) > .btn {
	border-radius: 0; }

.btn-group > .btn-group:first-child:not(:last-child) > .btn:last-child,
.btn-group > .btn-group:first-child:not(:last-child) > .dropdown-toggle {
	border-top-right-radius: 0;
	border-bottom-right-radius: 0; }

.btn-group > .btn-group:last-child:not(:first-child) > .btn:first-child {
	border-top-left-radius: 0;
	border-bottom-left-radius: 0; }

.btn-group .dropdown-toggle:active,
.btn-group.open .dropdown-toggle {
	outline: 0; }

.btn-group > .btn + .dropdown-toggle {
	padding-right: 8px;
	padding-left: 8px; }

.btn-group > .btn-lg + .dropdown-toggle, .btn-group-lg.btn-group > .btn + .dropdown-toggle {
	padding-right: 12px;
	padding-left: 12px; }

.btn-group.open .dropdown-toggle {
	-webkit-box-shadow: inset 0 3px 5px rgba(0, 0, 0, 0.125);
	box-shadow: inset 0 3px 5px rgba(0, 0, 0, 0.125); }
	.btn-group.open .dropdown-toggle.btn-link {
		-webkit-box-shadow: none;
		box-shadow: none; }

.btn .caret {
	margin-left: 0; }

.btn-lg .caret, .btn-group-lg > .btn .caret {
	border-width: 5px 5px 0;
	border-bottom-width: 0; }

.dropup .btn-lg .caret, .dropup .btn-group-lg > .btn .caret {
	border-width: 0 5px 5px; }

.btn-group-vertical > .btn,
.btn-group-vertical > .btn-group,
.btn-group-vertical > .btn-group > .btn {
	display: block;
	float: none;
	width: 100%;
	max-width: 100%; }

.btn-group-vertical > .btn-group:before, .btn-group-vertical > .btn-group:after {
	display: table;
	content: " "; }

.btn-group-vertical > .btn-group:after {
	clear: both; }

.btn-group-vertical > .btn-group > .btn {
	float: none; }

.btn-group-vertical > .btn + .btn,
.btn-group-vertical > .btn + .btn-group,
.btn-group-vertical > .btn-group + .btn,
.btn-group-vertical > .btn-group + .btn-group {
	margin-top: -1px;
	margin-left: 0; }

.btn-group-vertical > .btn:not(:first-child):not(:last-child) {
	border-radius: 0; }

.btn-group-vertical > .btn:first-child:not(:last-child) {
	border-top-left-radius: 4px;
	border-top-right-radius: 4px;
	border-bottom-right-radius: 0;
	border-bottom-left-radius: 0; }

.btn-group-vertical > .btn:last-child:not(:first-child) {
	border-top-left-radius: 0;
	border-top-right-radius: 0;
	border-bottom-right-radius: 4px;
	border-bottom-left-radius: 4px; }

.btn-group-vertical > .btn-group:not(:first-child):not(:last-child) > .btn {
	border-radius: 0; }

.btn-group-vertical > .btn-group:first-child:not(:last-child) > .btn:last-child,
.btn-group-vertical > .btn-group:first-child:not(:last-child) > .dropdown-toggle {
	border-bottom-right-radius: 0;
	border-bottom-left-radius: 0; }

.btn-group-vertical > .btn-group:last-child:not(:first-child) > .btn:first-child {
	border-top-left-radius: 0;
	border-top-right-radius: 0; }

.btn-group-justified {
	display: table;
	width: 100%;
	table-layout: fixed;
	border-collapse: separate; }
	.btn-group-justified > .btn,
	.btn-group-justified > .btn-group {
		display: table-cell;
		float: none;
		width: 1%; }
	.btn-group-justified > .btn-group .btn {
		width: 100%; }
	.btn-group-justified > .btn-group .dropdown-menu {
		left: auto; }

[data-toggle="buttons"] > .btn input[type="radio"],
[data-toggle="buttons"] > .btn input[type="checkbox"],
[data-toggle="buttons"] > .btn-group > .btn input[type="radio"],
[data-toggle="buttons"] > .btn-group > .btn input[type="checkbox"] {
	position: absolute;
	clip: rect(0, 0, 0, 0);
	pointer-events: none; }

.input-group {
	position: relative;
	display: table;
	border-collapse: separate; }
	.input-group[class*="col-"] {
		float: none;
		padding-right: 0;
		padding-left: 0; }
	.input-group .form-control {
		position: relative;
		z-index: 2;
		float: left;
		width: 100%;
		margin-bottom: 0; }
		.input-group .form-control:focus {
			z-index: 3; }

.input-group-addon,
.input-group-btn,
.input-group .form-control {
	display: table-cell; }
	.input-group-addon:not(:first-child):not(:last-child),
	.input-group-btn:not(:first-child):not(:last-child),
	.input-group .form-control:not(:first-child):not(:last-child) {
		border-radius: 0; }

.input-group-addon,
.input-group-btn {
	width: 1%;
	white-space: nowrap;
	vertical-align: middle; }

.input-group-addon {
	padding: 10px 14px;
	font-size: 16px;
	font-weight: 400;
	line-height: 1;
	color: #555555;
	text-align: center;
	background-color: #eeeeee;
	border: 1px solid #ccc;
	border-radius: 4px; }
	.input-group-addon.input-sm,
	.input-group-sm > .input-group-addon,
	.input-group-sm > .input-group-btn > .input-group-addon.btn {
		padding: 5px 10px;
		font-size: 14px;
		border-radius: 3px; }
	.input-group-addon.input-lg,
	.input-group-lg > .input-group-addon,
	.input-group-lg > .input-group-btn > .input-group-addon.btn {
		padding: 10px 16px;
		font-size: 18px;
		border-radius: 6px; }
	.input-group-addon input[type="radio"],
	.input-group-addon input[type="checkbox"] {
		margin-top: 0; }

.input-group .form-control:first-child,
.input-group-addon:first-child,
.input-group-btn:first-child > .btn,
.input-group-btn:first-child > .btn-group > .btn,
.input-group-btn:first-child > .dropdown-toggle,
.input-group-btn:last-child > .btn:not(:last-child):not(.dropdown-toggle),
.input-group-btn:last-child > .btn-group:not(:last-child) > .btn {
	border-top-right-radius: 0;
	border-bottom-right-radius: 0; }

.input-group-addon:first-child {
	border-right: 0; }

.input-group .form-control:last-child,
.input-group-addon:last-child,
.input-group-btn:last-child > .btn,
.input-group-btn:last-child > .btn-group > .btn,
.input-group-btn:last-child > .dropdown-toggle,
.input-group-btn:first-child > .btn:not(:first-child),
.input-group-btn:first-child > .btn-group:not(:first-child) > .btn {
	border-top-left-radius: 0;
	border-bottom-left-radius: 0; }

.input-group-addon:last-child {
	border-left: 0; }

.input-group-btn {
	position: relative;
	font-size: 0;
	white-space: nowrap; }
	.input-group-btn > .btn {
		position: relative; }
		.input-group-btn > .btn + .btn {
			margin-left: -1px; }
		.input-group-btn > .btn:hover, .input-group-btn > .btn:focus, .input-group-btn > .btn:active {
			z-index: 2; }
	.input-group-btn:first-child > .btn,
	.input-group-btn:first-child > .btn-group {
		margin-right: -1px; }
	.input-group-btn:last-child > .btn,
	.input-group-btn:last-child > .btn-group {
		z-index: 2;
		margin-left: -1px; }

.nav {
	padding-left: 0;
	margin-bottom: 0;
	list-style: none; }
	.nav:before, .nav:after {
		display: table;
		content: " "; }
	.nav:after {
		clear: both; }
	.nav > li {
		position: relative;
		display: block; }
		.nav > li > a {
			position: relative;
			display: block;
			padding: 10px 15px; }
			.nav > li > a:hover, .nav > li > a:focus {
				text-decoration: none;
				background-color: #eeeeee; }
		.nav > li.disabled > a {
			color: #6f6f6f; }
			.nav > li.disabled > a:hover, .nav > li.disabled > a:focus {
				color: #6f6f6f;
				text-decoration: none;
				cursor: not-allowed;
				background-color: transparent; }
	.nav .open > a, .nav .open > a:hover, .nav .open > a:focus {
		background-color: #eeeeee;
		border-color: #295376; }
	.nav .nav-divider {
		height: 1px;
		margin: 10.5px 0;
		overflow: hidden;
		background-color: #e5e5e5; }
	.nav > li > a > img {
		max-width: none; }

.nav-tabs {
	border-bottom: 1px solid #ddd; }
	.nav-tabs > li {
		float: left;
		margin-bottom: -1px; }
		.nav-tabs > li > a {
			margin-right: 2px;
			line-height: 1.4375;
			border: 1px solid transparent;
			border-radius: 4px 4px 0 0; }
			.nav-tabs > li > a:hover {
				border-color: #eeeeee #eeeeee #ddd; }
		.nav-tabs > li.active > a, .nav-tabs > li.active > a:hover, .nav-tabs > li.active > a:focus {
			color: #555555;
			cursor: default;
			background-color: #fff;
			border: 1px solid #ddd;
			border-bottom-color: transparent; }

.nav-pills > li {
	float: left; }
	.nav-pills > li > a {
		border-radius: 4px; }
	.nav-pills > li + li {
		margin-left: 2px; }
	.nav-pills > li.active > a, .nav-pills > li.active > a:hover, .nav-pills > li.active > a:focus {
		color: #fff;
		background-color: #2572b4; }

.nav-stacked > li {
	float: none; }
	.nav-stacked > li + li {
		margin-top: 2px;
		margin-left: 0; }

.nav-justified, .nav-tabs.nav-justified {
	width: 100%; }
	.nav-justified > li, .nav-tabs.nav-justified > li {
		float: none; }
		.nav-justified > li > a, .nav-tabs.nav-justified > li > a {
			margin-bottom: 5px;
			text-align: center; }
	.nav-justified > .dropdown .dropdown-menu {
		top: auto;
		left: auto; }
	@media (min-width: 768px) {
		.nav-justified > li, .nav-tabs.nav-justified > li {
			display: table-cell;
			width: 1%; }
			.nav-justified > li > a, .nav-tabs.nav-justified > li > a {
				margin-bottom: 0; } }

.nav-tabs-justified, .nav-tabs.nav-justified {
	border-bottom: 0; }
	.nav-tabs-justified > li > a, .nav-tabs.nav-justified > li > a {
		margin-right: 0;
		border-radius: 4px; }
	.nav-tabs-justified > .active > a, .nav-tabs.nav-justified > .active > a,
	.nav-tabs-justified > .active > a:hover,
	.nav-tabs.nav-justified > .active > a:hover,
	.nav-tabs-justified > .active > a:focus,
	.nav-tabs.nav-justified > .active > a:focus {
		border: 1px solid #ddd; }
	@media (min-width: 768px) {
		.nav-tabs-justified > li > a, .nav-tabs.nav-justified > li > a {
			border-bottom: 1px solid #ddd;
			border-radius: 4px 4px 0 0; }
		.nav-tabs-justified > .active > a, .nav-tabs.nav-justified > .active > a,
		.nav-tabs-justified > .active > a:hover,
		.nav-tabs.nav-justified > .active > a:hover,
		.nav-tabs-justified > .active > a:focus,
		.nav-tabs.nav-justified > .active > a:focus {
			border-bottom-color: #fff; } }

.tab-content > .tab-pane {
	display: none; }

.tab-content > .active {
	display: block; }

.nav-tabs .dropdown-menu {
	margin-top: -1px;
	border-top-left-radius: 0;
	border-top-right-radius: 0; }

.navbar {
	position: relative;
	min-height: 50px;
	margin-bottom: 23px;
	border: 1px solid transparent; }
	.navbar:before, .navbar:after {
		display: table;
		content: " "; }
	.navbar:after {
		clear: both; }
	@media (min-width: 768px) {
		.navbar {
			border-radius: 4px; } }

.navbar-header:before, .navbar-header:after {
	display: table;
	content: " "; }

.navbar-header:after {
	clear: both; }

@media (min-width: 768px) {
	.navbar-header {
		float: left; } }

.navbar-collapse {
	padding-right: 15px;
	padding-left: 15px;
	overflow-x: visible;
	border-top: 1px solid transparent;
	-webkit-box-shadow: inset 0 1px 0 rgba(255, 255, 255, 0.1);
	        box-shadow: inset 0 1px 0 rgba(255, 255, 255, 0.1);
	-webkit-overflow-scrolling: touch; }
	.navbar-collapse:before, .navbar-collapse:after {
		display: table;
		content: " "; }
	.navbar-collapse:after {
		clear: both; }
	.navbar-collapse.in {
		overflow-y: auto; }
	@media (min-width: 768px) {
		.navbar-collapse {
			width: auto;
			border-top: 0;
			-webkit-box-shadow: none;
			        box-shadow: none; }
			.navbar-collapse.collapse {
				display: block !important;
				height: auto !important;
				padding-bottom: 0;
				overflow: visible !important; }
			.navbar-collapse.in {
				overflow-y: visible; }
			.navbar-fixed-top .navbar-collapse,
			.navbar-static-top .navbar-collapse,
			.navbar-fixed-bottom .navbar-collapse {
				padding-right: 0;
				padding-left: 0; } }

.navbar-fixed-top,
.navbar-fixed-bottom {
	position: fixed;
	right: 0;
	left: 0;
	z-index: 1030; }
	.navbar-fixed-top .navbar-collapse,
	.navbar-fixed-bottom .navbar-collapse {
		max-height: 340px; }
		@media (max-device-width: 480px) and (orientation: landscape) {
			.navbar-fixed-top .navbar-collapse,
			.navbar-fixed-bottom .navbar-collapse {
				max-height: 200px; } }
	@media (min-width: 768px) {
		.navbar-fixed-top,
		.navbar-fixed-bottom {
			border-radius: 0; } }

.navbar-fixed-top {
	top: 0;
	border-width: 0 0 1px; }

.navbar-fixed-bottom {
	bottom: 0;
	margin-bottom: 0;
	border-width: 1px 0 0; }

.container > .navbar-header,
.container > .navbar-collapse,
.container-fluid > .navbar-header,
.container-fluid > .navbar-collapse {
	margin-right: -15px;
	margin-left: -15px; }
	@media (min-width: 768px) {
		.container > .navbar-header,
		.container > .navbar-collapse,
		.container-fluid > .navbar-header,
		.container-fluid > .navbar-collapse {
			margin-right: 0;
			margin-left: 0; } }

.navbar-static-top {
	z-index: 1000;
	border-width: 0 0 1px; }
	@media (min-width: 768px) {
		.navbar-static-top {
			border-radius: 0; } }

.navbar-brand {
	float: left;
	height: 50px;
	padding: 13.5px 15px;
	font-size: 18px;
	line-height: 23px; }
	.navbar-brand:hover, .navbar-brand:focus {
		text-decoration: none; }
	.navbar-brand > img {
		display: block; }
	@media (min-width: 768px) {
		.navbar > .container .navbar-brand,
		.navbar > .container-fluid .navbar-brand {
			margin-left: -15px; } }

.navbar-toggle {
	position: relative;
	float: right;
	padding: 9px 10px;
	margin-right: 15px;
	margin-top: 8px;
	margin-bottom: 8px;
	background-color: transparent;
	background-image: none;
	border: 1px solid transparent;
	border-radius: 4px; }
	.navbar-toggle:focus {
		outline: 0; }
	.navbar-toggle .icon-bar {
		display: block;
		width: 22px;
		height: 2px;
		border-radius: 1px; }
	.navbar-toggle .icon-bar + .icon-bar {
		margin-top: 4px; }
	@media (min-width: 768px) {
		.navbar-toggle {
			display: none; } }

.navbar-nav {
	margin: 6.75px -15px; }
	.navbar-nav > li > a {
		padding-top: 10px;
		padding-bottom: 10px;
		line-height: 23px; }
	@media (max-width: 767px) {
		.navbar-nav .open .dropdown-menu {
			position: static;
			float: none;
			width: auto;
			margin-top: 0;
			background-color: transparent;
			border: 0;
			-webkit-box-shadow: none;
			        box-shadow: none; }
			.navbar-nav .open .dropdown-menu > li > a,
			.navbar-nav .open .dropdown-menu .dropdown-header {
				padding: 5px 15px 5px 25px; }
			.navbar-nav .open .dropdown-menu > li > a {
				line-height: 23px; }
				.navbar-nav .open .dropdown-menu > li > a:hover, .navbar-nav .open .dropdown-menu > li > a:focus {
					background-image: none; } }
	@media (min-width: 768px) {
		.navbar-nav {
			float: left;
			margin: 0; }
			.navbar-nav > li {
				float: left; }
				.navbar-nav > li > a {
					padding-top: 13.5px;
					padding-bottom: 13.5px; } }

.navbar-form {
	padding: 10px 15px;
	margin-right: -15px;
	margin-left: -15px;
	border-top: 1px solid transparent;
	border-bottom: 1px solid transparent;
	-webkit-box-shadow: inset 0 1px 0 rgba(255, 255, 255, 0.1), 0 1px 0 rgba(255, 255, 255, 0.1);
	box-shadow: inset 0 1px 0 rgba(255, 255, 255, 0.1), 0 1px 0 rgba(255, 255, 255, 0.1);
	margin-top: 6.5px;
	margin-bottom: 6.5px; }
	@media (min-width: 768px) {
		.navbar-form .form-group {
			display: inline-block;
			margin-bottom: 0;
			vertical-align: middle; }
		.navbar-form .form-control {
			display: inline-block;
			width: auto;
			vertical-align: middle; }
		.navbar-form .form-control-static {
			display: inline-block; }
		.navbar-form .input-group {
			display: inline-table;
			vertical-align: middle; }
			.navbar-form .input-group .input-group-addon,
			.navbar-form .input-group .input-group-btn,
			.navbar-form .input-group .form-control {
				width: auto; }
		.navbar-form .input-group > .form-control {
			width: 100%; }
		.navbar-form .control-label {
			margin-bottom: 0;
			vertical-align: middle; }
		.navbar-form .radio,
		.navbar-form .checkbox {
			display: inline-block;
			margin-top: 0;
			margin-bottom: 0;
			vertical-align: middle; }
			.navbar-form .radio label,
			.navbar-form .checkbox label {
				padding-left: 0; }
		.navbar-form .radio input[type="radio"],
		.navbar-form .checkbox input[type="checkbox"] {
			position: relative;
			margin-left: 0; }
		.navbar-form .has-feedback .form-control-feedback {
			top: 0; } }
	@media (max-width: 767px) {
		.navbar-form .form-group {
			margin-bottom: 5px; }
			.navbar-form .form-group:last-child {
				margin-bottom: 0; } }
	@media (min-width: 768px) {
		.navbar-form {
			width: auto;
			padding-top: 0;
			padding-bottom: 0;
			margin-right: 0;
			margin-left: 0;
			border: 0;
			-webkit-box-shadow: none;
			box-shadow: none; } }

.navbar-nav > li > .dropdown-menu {
	margin-top: 0;
	border-top-left-radius: 0;
	border-top-right-radius: 0; }

.navbar-fixed-bottom .navbar-nav > li > .dropdown-menu {
	margin-bottom: 0;
	border-top-left-radius: 4px;
	border-top-right-radius: 4px;
	border-bottom-right-radius: 0;
	border-bottom-left-radius: 0; }

.navbar-btn {
	margin-top: 6.5px;
	margin-bottom: 6.5px; }
	.navbar-btn.btn-sm, .btn-group-sm > .navbar-btn.btn {
		margin-top: 8.5px;
		margin-bottom: 8.5px; }
	.navbar-btn.btn-xs, .btn-group-xs > .navbar-btn.btn {
		margin-top: 14px;
		margin-bottom: 14px; }

.navbar-text {
	margin-top: 13.5px;
	margin-bottom: 13.5px; }
	@media (min-width: 768px) {
		.navbar-text {
			float: left;
			margin-right: 15px;
			margin-left: 15px; } }

@media (min-width: 768px) {
	.navbar-left {
		float: left !important; }
	.navbar-right {
		float: right !important;
		margin-right: -15px; }
		.navbar-right ~ .navbar-right {
			margin-right: 0; } }

.navbar-default {
	background-color: #f8f8f8;
	border-color: #e7e7e7; }
	.navbar-default .navbar-brand {
		color: #777; }
		.navbar-default .navbar-brand:hover, .navbar-default .navbar-brand:focus {
			color: #5e5d5d;
			background-color: transparent; }
	.navbar-default .navbar-text {
		color: #777; }
	.navbar-default .navbar-nav > li > a {
		color: #777; }
		.navbar-default .navbar-nav > li > a:hover, .navbar-default .navbar-nav > li > a:focus {
			color: #333;
			background-color: transparent; }
	.navbar-default .navbar-nav > .active > a, .navbar-default .navbar-nav > .active > a:hover, .navbar-default .navbar-nav > .active > a:focus {
		color: #555;
		background-color: #e7e7e7; }
	.navbar-default .navbar-nav > .disabled > a, .navbar-default .navbar-nav > .disabled > a:hover, .navbar-default .navbar-nav > .disabled > a:focus {
		color: #ccc;
		background-color: transparent; }
	.navbar-default .navbar-nav > .open > a, .navbar-default .navbar-nav > .open > a:hover, .navbar-default .navbar-nav > .open > a:focus {
		color: #555;
		background-color: #e7e7e7; }
	@media (max-width: 767px) {
		.navbar-default .navbar-nav .open .dropdown-menu > li > a {
			color: #777; }
			.navbar-default .navbar-nav .open .dropdown-menu > li > a:hover, .navbar-default .navbar-nav .open .dropdown-menu > li > a:focus {
				color: #333;
				background-color: transparent; }
		.navbar-default .navbar-nav .open .dropdown-menu > .active > a, .navbar-default .navbar-nav .open .dropdown-menu > .active > a:hover, .navbar-default .navbar-nav .open .dropdown-menu > .active > a:focus {
			color: #555;
			background-color: #e7e7e7; }
		.navbar-default .navbar-nav .open .dropdown-menu > .disabled > a, .navbar-default .navbar-nav .open .dropdown-menu > .disabled > a:hover, .navbar-default .navbar-nav .open .dropdown-menu > .disabled > a:focus {
			color: #ccc;
			background-color: transparent; } }
	.navbar-default .navbar-toggle {
		border-color: #ddd; }
		.navbar-default .navbar-toggle:hover, .navbar-default .navbar-toggle:focus {
			background-color: #ddd; }
		.navbar-default .navbar-toggle .icon-bar {
			background-color: #888; }
	.navbar-default .navbar-collapse,
	.navbar-default .navbar-form {
		border-color: #e7e7e7; }
	.navbar-default .navbar-link {
		color: #777; }
		.navbar-default .navbar-link:hover {
			color: #333; }
	.navbar-default .btn-link {
		color: #777; }
		.navbar-default .btn-link:hover, .navbar-default .btn-link:focus {
			color: #333; }
		.navbar-default .btn-link[disabled]:hover, .navbar-default .btn-link[disabled]:focus,
		fieldset[disabled] .navbar-default .btn-link:hover,
		fieldset[disabled] .navbar-default .btn-link:focus {
			color: #ccc; }

.navbar-inverse {
	background-color: #222;
	border-color: #090808; }
	.navbar-inverse .navbar-brand {
		color: #959595; }
		.navbar-inverse .navbar-brand:hover, .navbar-inverse .navbar-brand:focus {
			color: #fff;
			background-color: transparent; }
	.navbar-inverse .navbar-text {
		color: #959595; }
	.navbar-inverse .navbar-nav > li > a {
		color: #959595; }
		.navbar-inverse .navbar-nav > li > a:hover, .navbar-inverse .navbar-nav > li > a:focus {
			color: #fff;
			background-color: transparent; }
	.navbar-inverse .navbar-nav > .active > a, .navbar-inverse .navbar-nav > .active > a:hover, .navbar-inverse .navbar-nav > .active > a:focus {
		color: #fff;
		background-color: #090808; }
	.navbar-inverse .navbar-nav > .disabled > a, .navbar-inverse .navbar-nav > .disabled > a:hover, .navbar-inverse .navbar-nav > .disabled > a:focus {
		color: #444;
		background-color: transparent; }
	.navbar-inverse .navbar-nav > .open > a, .navbar-inverse .navbar-nav > .open > a:hover, .navbar-inverse .navbar-nav > .open > a:focus {
		color: #fff;
		background-color: #090808; }
	@media (max-width: 767px) {
		.navbar-inverse .navbar-nav .open .dropdown-menu > .dropdown-header {
			border-color: #090808; }
		.navbar-inverse .navbar-nav .open .dropdown-menu .divider {
			background-color: #090808; }
		.navbar-inverse .navbar-nav .open .dropdown-menu > li > a {
			color: #959595; }
			.navbar-inverse .navbar-nav .open .dropdown-menu > li > a:hover, .navbar-inverse .navbar-nav .open .dropdown-menu > li > a:focus {
				color: #fff;
				background-color: transparent; }
		.navbar-inverse .navbar-nav .open .dropdown-menu > .active > a, .navbar-inverse .navbar-nav .open .dropdown-menu > .active > a:hover, .navbar-inverse .navbar-nav .open .dropdown-menu > .active > a:focus {
			color: #fff;
			background-color: #090808; }
		.navbar-inverse .navbar-nav .open .dropdown-menu > .disabled > a, .navbar-inverse .navbar-nav .open .dropdown-menu > .disabled > a:hover, .navbar-inverse .navbar-nav .open .dropdown-menu > .disabled > a:focus {
			color: #444;
			background-color: transparent; } }
	.navbar-inverse .navbar-toggle {
		border-color: #333; }
		.navbar-inverse .navbar-toggle:hover, .navbar-inverse .navbar-toggle:focus {
			background-color: #333; }
		.navbar-inverse .navbar-toggle .icon-bar {
			background-color: #fff; }
	.navbar-inverse .navbar-collapse,
	.navbar-inverse .navbar-form {
		border-color: #101010; }
	.navbar-inverse .navbar-link {
		color: #959595; }
		.navbar-inverse .navbar-link:hover {
			color: #fff; }
	.navbar-inverse .btn-link {
		color: #959595; }
		.navbar-inverse .btn-link:hover, .navbar-inverse .btn-link:focus {
			color: #fff; }
		.navbar-inverse .btn-link[disabled]:hover, .navbar-inverse .btn-link[disabled]:focus,
		fieldset[disabled] .navbar-inverse .btn-link:hover,
		fieldset[disabled] .navbar-inverse .btn-link:focus {
			color: #444; }

.breadcrumb {
	padding: 8px 15px;
	margin-bottom: 23px;
	list-style: none;
	background-color: transparent;
	border-radius: 4px; }
	.breadcrumb > li {
		display: inline-block; }
		.breadcrumb > li + li:before {
			padding: 0 5px;
			color: #ccc;
			content: "/ "; }
	.breadcrumb > .active {
		color: #6f6f6f; }

.pagination {
	display: inline-block;
	padding-left: 0;
	margin: 23px 0;
	border-radius: 4px; }
	.pagination > li {
		display: inline; }
		.pagination > li > a,
		.pagination > li > span {
			position: relative;
			float: left;
			padding: 10px 14px;
			margin-left: -1px;
			line-height: 1.4375;
			color: #335075;
			text-decoration: none;
			background-color: #eaebed;
			border: 1px solid #dcdee1; }
			.pagination > li > a:hover, .pagination > li > a:focus,
			.pagination > li > span:hover,
			.pagination > li > span:focus {
				z-index: 2;
				color: #335075;
				background-color: #d4d6da;
				border-color: #bbbfc5; }
		.pagination > li:first-child > a,
		.pagination > li:first-child > span {
			margin-left: 0;
			border-top-left-radius: 4px;
			border-bottom-left-radius: 4px; }
		.pagination > li:last-child > a,
		.pagination > li:last-child > span {
			border-top-right-radius: 4px;
			border-bottom-right-radius: 4px; }
	.pagination > .active > a, .pagination > .active > a:hover, .pagination > .active > a:focus,
	.pagination > .active > span,
	.pagination > .active > span:hover,
	.pagination > .active > span:focus {
		z-index: 3;
		color: #fff;
		cursor: default;
		background-color: #2572b4;
		border-color: #2572b4; }
	.pagination > .disabled > span,
	.pagination > .disabled > span:hover,
	.pagination > .disabled > span:focus,
	.pagination > .disabled > a,
	.pagination > .disabled > a:hover,
	.pagination > .disabled > a:focus {
		color: #6f6f6f;
		cursor: not-allowed;
		background-color: #fff;
		border-color: #ddd; }

.pagination-lg > li > a,
.pagination-lg > li > span {
	padding: 10px 16px;
	font-size: 18px;
	line-height: 1.3333333; }

.pagination-lg > li:first-child > a,
.pagination-lg > li:first-child > span {
	border-top-left-radius: 6px;
	border-bottom-left-radius: 6px; }

.pagination-lg > li:last-child > a,
.pagination-lg > li:last-child > span {
	border-top-right-radius: 6px;
	border-bottom-right-radius: 6px; }

.pagination-sm > li > a,
.pagination-sm > li > span {
	padding: 5px 10px;
	font-size: 14px;
	line-height: 1.5; }

.pagination-sm > li:first-child > a,
.pagination-sm > li:first-child > span {
	border-top-left-radius: 3px;
	border-bottom-left-radius: 3px; }

.pagination-sm > li:last-child > a,
.pagination-sm > li:last-child > span {
	border-top-right-radius: 3px;
	border-bottom-right-radius: 3px; }

.pager {
	padding-left: 0;
	margin: 23px 0;
	text-align: center;
	list-style: none; }
	.pager:before, .pager:after {
		display: table;
		content: " "; }
	.pager:after {
		clear: both; }
	.pager li {
		display: inline; }
		.pager li > a,
		.pager li > span {
			display: inline-block;
			padding: 5px 14px;
			background-color: #eaebed;
			border: 1px solid #dcdee1;
			border-radius: 4px; }
		.pager li > a:hover,
		.pager li > a:focus {
			text-decoration: none;
			background-color: #d4d6da; }
	.pager .next > a,
	.pager .next > span {
		float: right; }
	.pager .previous > a,
	.pager .previous > span {
		float: left; }
	.pager .disabled > a,
	.pager .disabled > a:hover,
	.pager .disabled > a:focus,
	.pager .disabled > span {
		color: #6f6f6f;
		cursor: not-allowed;
		background-color: #eaebed; }

.label {
	display: inline;
	padding: .2em .6em .3em;
	font-size: 75%;
	font-weight: 700;
	line-height: 1;
	color: #fff;
	text-align: center;
	white-space: nowrap;
	vertical-align: baseline;
	border-radius: .25em; }
	.label:empty {
		display: none; }
	.btn .label {
		position: relative;
		top: -1px; }

a.label:hover, a.label:focus {
	color: #fff;
	text-decoration: none;
	cursor: pointer; }

.label-default {
	background-color: #6f6f6f; }
	.label-default[href]:hover, .label-default[href]:focus {
		background-color: #565555; }

.label-primary {
	background-color: #2572b4; }
	.label-primary[href]:hover, .label-primary[href]:focus {
		background-color: #1c578a; }

.label-success {
	background-color: #1b6c1c; }
	.label-success[href]:hover, .label-success[href]:focus {
		background-color: #114311; }

.label-info {
	background-color: #4d4d4d; }
	.label-info[href]:hover, .label-info[href]:focus {
		background-color: #343333; }

.label-warning {
	background-color: #f2d40d; }
	.label-warning[href]:hover, .label-warning[href]:focus {
		background-color: #c2aa0a; }

.label-danger {
	background-color: #bc3331; }
	.label-danger[href]:hover, .label-danger[href]:focus {
		background-color: #942826; }

.alert {
	padding: 15px;
	margin-bottom: 23px;
	border: 1px solid transparent;
	border-radius: 4px; }
	.alert h4 {
		margin-top: 0;
		color: inherit; }
	.alert .alert-link {
		font-weight: bold; }
	.alert > p,
	.alert > ul {
		margin-bottom: 0; }
	.alert > p + p {
		margin-top: 5px; }

.alert-dismissable,
.alert-dismissible {
	padding-right: 35px; }
	.alert-dismissable .close,
	.alert-dismissible .close {
		position: relative;
		top: -2px;
		right: -21px;
		color: inherit; }

.alert-success {
	color: #3c763d;
	background-color: #dff0d8;
	border-color: #d6e9c6; }
	.alert-success hr {
		border-top-color: #c9e2b3; }
	.alert-success .alert-link {
		color: #2b542c; }

.alert-info {
	color: #31708f;
	background-color: #d9edf7;
	border-color: #bce8f1; }
	.alert-info hr {
		border-top-color: #a6e1ec; }
	.alert-info .alert-link {
		color: #245269; }

.alert-warning {
	color: #8a6d3b;
	background-color: #fcf8e3;
	border-color: #faebcc; }
	.alert-warning hr {
		border-top-color: #f7e1b5; }
	.alert-warning .alert-link {
		color: #66512c; }

.alert-danger {
	color: #a94442;
	background-color: #f2dede;
	border-color: #ebccd1; }
	.alert-danger hr {
		border-top-color: #e4b9c0; }
	.alert-danger .alert-link {
		color: #843534; }

/*
	WET-BOEW
	@title: Bootstrap overrides for WET-BOEW - Helper - Placeholders
 */
/*
 *  Alerts and labels
 */
.alert, .label {
	border-radius: 0;
	border-style: solid;
	border-width: 0 0 0 4px; }

.alert-success, .alert-info, .alert-warning, .alert-danger, .label-default, .label-default[href]:hover, .label-default[href]:focus, .label-default[href]:active, .label-primary, .label-primary[href]:hover, .label-primary[href]:focus, .label-primary[href]:active, .label-success, .label-success[href]:hover, .label-success[href]:focus, .label-success[href]:active, .label-info, .label-info[href]:hover, .label-info[href]:focus, .label-info[href]:active, .label-warning, .label-warning[href]:hover, .label-warning[href]:focus, .label-warning[href]:active, .label-danger, .label-danger[href]:hover, .label-danger[href]:focus, .label-danger[href]:active {
	color: #000; }

.label-default[href]:hover, .label-default[href]:focus, .label-default[href]:active, .label-primary[href]:hover, .label-primary[href]:focus, .label-primary[href]:active, .label-success[href]:hover, .label-success[href]:focus, .label-success[href]:active, .label-info[href]:hover, .label-info[href]:focus, .label-info[href]:active, .label-warning[href]:hover, .label-warning[href]:focus, .label-warning[href]:active, .label-danger[href]:hover, .label-danger[href]:focus, .label-danger[href]:active {
	text-decoration: underline; }

.label-default, .label-default[href]:hover, .label-default[href]:focus, .label-default[href]:active {
	background: #eee;
	border-color: #acacac; }

.label-primary, .label-primary[href]:hover, .label-primary[href]:focus, .label-primary[href]:active {
	background: #e8f2f4;
	border-color: #083c6c; }

.alert-success, .label-success, .label-success[href]:hover, .label-success[href]:focus, .label-success[href]:active, details.alert.alert-success, details.alert.alert-success[open] {
	background: #d8eeca;
	border-color: #278400; }

.alert-info, .label-info, .label-info[href]:hover, .label-info[href]:focus, .label-info[href]:active, details.alert.alert-info, details.alert.alert-info[open] {
	background: #d7faff;
	border-color: #269abc; }

.alert-warning, .label-warning, .label-warning[href]:hover, .label-warning[href]:focus, .label-warning[href]:active, details.alert.alert-warning, details.alert.alert-warning[open] {
	background: #f9f4d4;
	border-color: #f90; }

.alert-danger, .label-danger, .label-danger[href]:hover, .label-danger[href]:focus, .label-danger[href]:active, details.alert.alert-danger, details.alert.alert-danger[open] {
	background: #f3e9e8;
	border-color: #d3080c; }

/*
  WET-BOEW
  @title: Bootstrap overrides for WET-BOEW - Components - Alert
 */
/*
 *	Override the design of alerts and labels
 */
.alert > :first-child {
	margin-left: 1.2em;
	margin-top: auto; }
	.alert > :first-child:before {
		display: inline-block;
		font-family: "Glyphicons Halflings";
		margin-left: -1.3em;
		position: absolute; }

.alert > strong:first-child,
.alert > em:first-child,
.alert > span:first-child {
	display: inline-block; }

.alert-success > :first-child:before {
	color: #278400;
	content: "\e084"; }

.alert-info > :first-child:before {
	color: #269abc;
	content: "\e086"; }

.alert-warning > :first-child:before {
	color: #f90;
	content: "\e107"; }

.alert-danger > :first-child:before {
	color: #d3080c;
	content: "\e101"; }

/*
 *  Right-to-left support
 */
[dir=rtl] .alert > :first-child {
	margin-left: auto;
	margin-right: 1.2em; }
	[dir=rtl] .alert > :first-child:before {
		margin-left: auto;
		margin-right: -1.3em; }

[dir=rtl] details.alert {
	padding-right: 45px; }
	[dir=rtl] details.alert:before {
		margin-right: -1.3em; }
	[dir=rtl] details.alert > * {
		margin-right: .7em; }
	[dir=rtl] details.alert > :first-child {
		margin-right: .4em; }

/*
  WET-BOEW
  @title: Bootstrap overrides for WET-BOEW - Components - Alert
 */
/*
 *	Override the design of alerts and labels
 */
.badge {
	display: inline-block;
	min-width: 10px;
	padding: 3px 7px;
	font-size: 14px;
	font-weight: bold;
	line-height: 1;
	color: #fff;
	text-align: center;
	white-space: nowrap;
	vertical-align: middle;
	background-color: #6f6f6f;
	border-radius: 10px; }
	.badge:empty {
		display: none; }
	.btn .badge {
		position: relative;
		top: -1px; }
	.btn-xs .badge, .btn-group-xs > .btn .badge,
	.btn-group-xs > .btn .badge {
		top: 0;
		padding: 1px 5px; }
	.list-group-item.active > .badge,
	.nav-pills > .active > a > .badge {
		color: #295376;
		background-color: #fff; }
	.list-group-item > .badge {
		float: right; }
	.list-group-item > .badge + .badge {
		margin-right: 5px; }
	.nav-pills > li > a > .badge {
		margin-left: 3px; }

a.badge:hover, a.badge:focus {
	color: #fff;
	text-decoration: none;
	cursor: pointer; }

/*
	special badges
*/
.badge.badge-dept {
	background-color: #eee;
	color: #333;
	font-size: 2em;
	margin: 20px 10px 0; }

.jumbotron {
	padding-top: 30px;
	padding-bottom: 30px;
	margin-bottom: 30px;
	color: inherit;
	background-color: #eeeeee; }
	.jumbotron h1,
	.jumbotron .h1 {
		color: inherit; }
	.jumbotron p {
		margin-bottom: 15px;
		font-size: 24px;
		font-weight: 200; }
	.jumbotron > hr {
		border-top-color: #d5d5d5; }
	.container .jumbotron,
	.container-fluid .jumbotron {
		padding-right: 15px;
		padding-left: 15px;
		border-radius: 6px; }
	.jumbotron .container {
		max-width: 100%; }
	@media screen and (min-width: 768px) {
		.jumbotron {
			padding-top: 48px;
			padding-bottom: 48px; }
			.container .jumbotron,
			.container-fluid .jumbotron {
				padding-right: 60px;
				padding-left: 60px; }
			.jumbotron h1,
			.jumbotron .h1 {
				font-size: 72px; } }

.thumbnail {
	display: block;
	padding: 4px;
	margin-bottom: 23px;
	line-height: 1.4375;
	background-color: #fff;
	border: 1px solid #ddd;
	border-radius: 4px;
	-webkit-transition: border 0.2s ease-in-out;
	transition: border 0.2s ease-in-out; }
	.thumbnail > img,
	.thumbnail a > img {
		display: block;
		max-width: 100%;
		height: auto;
		margin-right: auto;
		margin-left: auto; }
	.thumbnail .caption {
		padding: 9px;
		color: #333333; }

a.thumbnail:hover,
a.thumbnail:focus,
a.thumbnail.active {
	border-color: #295376; }

/*
 *
 * Web Experience Toolkit (WET) / Boîte à outils de l'expérience Web (BOEW)
 * wet-boew.github.io/wet-boew/License-en.html / wet-boew.github.io/wet-boew/Licence-fr.html
 *
 * @title: Thumbnail
 *
 */
/* Thumbnail Treatments */
.thumbnail {
	background: #eaebed;
	border-color: #eee;
	border-radius: 0;
	padding: 5px; }
	.thumbnail:hover img {
		-webkit-box-shadow: 1px 1px 5px #999;
		        box-shadow: 1px 1px 5px #999; }

@-webkit-keyframes progress-bar-stripes {
	from {
		background-position: 40px 0; }
	to {
		background-position: 0 0; } }

@keyframes progress-bar-stripes {
	from {
		background-position: 40px 0; }
	to {
		background-position: 0 0; } }

.progress {
	height: 23px;
	margin-bottom: 23px;
	overflow: hidden;
	background-color: #f5f5f5;
	border-radius: 4px;
	-webkit-box-shadow: inset 0 1px 2px rgba(0, 0, 0, 0.1);
	box-shadow: inset 0 1px 2px rgba(0, 0, 0, 0.1); }

.progress-bar {
	float: left;
	width: 0%;
	height: 100%;
	font-size: 14px;
	line-height: 23px;
	color: #fff;
	text-align: center;
	background-color: #2572b4;
	-webkit-box-shadow: inset 0 -1px 0 rgba(0, 0, 0, 0.15);
	box-shadow: inset 0 -1px 0 rgba(0, 0, 0, 0.15);
	-webkit-transition: width 0.6s ease;
	transition: width 0.6s ease; }

.progress-striped .progress-bar,
.progress-bar-striped {
	background-image: linear-gradient(45deg, rgba(255, 255, 255, 0.15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.15) 50%, rgba(255, 255, 255, 0.15) 75%, transparent 75%, transparent);
	background-size: 40px 40px; }

.progress.active .progress-bar,
.progress-bar.active {
	-webkit-animation: progress-bar-stripes 2s linear infinite;
	animation: progress-bar-stripes 2s linear infinite; }

.progress-bar-success {
	background-color: #1b6c1c; }
	.progress-striped .progress-bar-success {
		background-image: linear-gradient(45deg, rgba(255, 255, 255, 0.15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.15) 50%, rgba(255, 255, 255, 0.15) 75%, transparent 75%, transparent); }

.progress-bar-info {
	background-color: #4d4d4d; }
	.progress-striped .progress-bar-info {
		background-image: linear-gradient(45deg, rgba(255, 255, 255, 0.15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.15) 50%, rgba(255, 255, 255, 0.15) 75%, transparent 75%, transparent); }

.progress-bar-warning {
	background-color: #f2d40d; }
	.progress-striped .progress-bar-warning {
		background-image: linear-gradient(45deg, rgba(255, 255, 255, 0.15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.15) 50%, rgba(255, 255, 255, 0.15) 75%, transparent 75%, transparent); }

.progress-bar-danger {
	background-color: #bc3331; }
	.progress-striped .progress-bar-danger {
		background-image: linear-gradient(45deg, rgba(255, 255, 255, 0.15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.15) 50%, rgba(255, 255, 255, 0.15) 75%, transparent 75%, transparent); }

.media {
	margin-top: 15px; }
	.media:first-child {
		margin-top: 0; }

.media,
.media-body {
	overflow: hidden;
	zoom: 1; }

.media-body {
	width: 10000px; }

.media-object {
	display: block; }
	.media-object.img-thumbnail {
		max-width: none; }

.media-right,
.media > .pull-right {
	padding-left: 10px; }

.media-left,
.media > .pull-left {
	padding-right: 10px; }

.media-left,
.media-right,
.media-body {
	display: table-cell;
	vertical-align: top; }

.media-middle {
	vertical-align: middle; }

.media-bottom {
	vertical-align: bottom; }

.media-heading {
	margin-top: 0;
	margin-bottom: 5px; }

.media-list {
	padding-left: 0;
	list-style: none; }

.list-group {
	padding-left: 0;
	margin-bottom: 20px; }

.list-group-item {
	position: relative;
	display: block;
	padding: 10px 15px;
	margin-bottom: -1px;
	background-color: #fff;
	border: 1px solid #ddd; }
	.list-group-item:first-child {
		border-top-left-radius: 4px;
		border-top-right-radius: 4px; }
	.list-group-item:last-child {
		margin-bottom: 0;
		border-bottom-right-radius: 4px;
		border-bottom-left-radius: 4px; }
	.list-group-item.disabled, .list-group-item.disabled:hover, .list-group-item.disabled:focus {
		color: #6f6f6f;
		cursor: not-allowed;
		background-color: #eeeeee; }
		.list-group-item.disabled .list-group-item-heading, .list-group-item.disabled:hover .list-group-item-heading, .list-group-item.disabled:focus .list-group-item-heading {
			color: inherit; }
		.list-group-item.disabled .list-group-item-text, .list-group-item.disabled:hover .list-group-item-text, .list-group-item.disabled:focus .list-group-item-text {
			color: #6f6f6f; }
	.list-group-item.active, .list-group-item.active:hover, .list-group-item.active:focus {
		z-index: 2;
		color: #fff;
		background-color: #2572b4;
		border-color: #2572b4; }
		.list-group-item.active .list-group-item-heading,
		.list-group-item.active .list-group-item-heading > small,
		.list-group-item.active .list-group-item-heading > .small, .list-group-item.active:hover .list-group-item-heading,
		.list-group-item.active:hover .list-group-item-heading > small,
		.list-group-item.active:hover .list-group-item-heading > .small, .list-group-item.active:focus .list-group-item-heading,
		.list-group-item.active:focus .list-group-item-heading > small,
		.list-group-item.active:focus .list-group-item-heading > .small {
			color: inherit; }
		.list-group-item.active .list-group-item-text, .list-group-item.active:hover .list-group-item-text, .list-group-item.active:focus .list-group-item-text {
			color: #b5d5f0; }

a.list-group-item,
button.list-group-item {
	color: #555; }
	a.list-group-item .list-group-item-heading,
	button.list-group-item .list-group-item-heading {
		color: #333; }
	a.list-group-item:hover, a.list-group-item:focus,
	button.list-group-item:hover,
	button.list-group-item:focus {
		color: #555;
		text-decoration: none;
		background-color: #f5f5f5; }

button.list-group-item {
	width: 100%;
	text-align: left; }

.list-group-item-success {
	color: #3c763d;
	background-color: #dff0d8; }

a.list-group-item-success,
button.list-group-item-success {
	color: #3c763d; }
	a.list-group-item-success .list-group-item-heading,
	button.list-group-item-success .list-group-item-heading {
		color: inherit; }
	a.list-group-item-success:hover, a.list-group-item-success:focus,
	button.list-group-item-success:hover,
	button.list-group-item-success:focus {
		color: #3c763d;
		background-color: #d0e9c6; }
	a.list-group-item-success.active, a.list-group-item-success.active:hover, a.list-group-item-success.active:focus,
	button.list-group-item-success.active,
	button.list-group-item-success.active:hover,
	button.list-group-item-success.active:focus {
		color: #fff;
		background-color: #3c763d;
		border-color: #3c763d; }

.list-group-item-info {
	color: #31708f;
	background-color: #d9edf7; }

a.list-group-item-info,
button.list-group-item-info {
	color: #31708f; }
	a.list-group-item-info .list-group-item-heading,
	button.list-group-item-info .list-group-item-heading {
		color: inherit; }
	a.list-group-item-info:hover, a.list-group-item-info:focus,
	button.list-group-item-info:hover,
	button.list-group-item-info:focus {
		color: #31708f;
		background-color: #c4e3f3; }
	a.list-group-item-info.active, a.list-group-item-info.active:hover, a.list-group-item-info.active:focus,
	button.list-group-item-info.active,
	button.list-group-item-info.active:hover,
	button.list-group-item-info.active:focus {
		color: #fff;
		background-color: #31708f;
		border-color: #31708f; }

.list-group-item-warning {
	color: #8a6d3b;
	background-color: #fcf8e3; }

a.list-group-item-warning,
button.list-group-item-warning {
	color: #8a6d3b; }
	a.list-group-item-warning .list-group-item-heading,
	button.list-group-item-warning .list-group-item-heading {
		color: inherit; }
	a.list-group-item-warning:hover, a.list-group-item-warning:focus,
	button.list-group-item-warning:hover,
	button.list-group-item-warning:focus {
		color: #8a6d3b;
		background-color: #faf2cc; }
	a.list-group-item-warning.active, a.list-group-item-warning.active:hover, a.list-group-item-warning.active:focus,
	button.list-group-item-warning.active,
	button.list-group-item-warning.active:hover,
	button.list-group-item-warning.active:focus {
		color: #fff;
		background-color: #8a6d3b;
		border-color: #8a6d3b; }

.list-group-item-danger {
	color: #a94442;
	background-color: #f2dede; }

a.list-group-item-danger,
button.list-group-item-danger {
	color: #a94442; }
	a.list-group-item-danger .list-group-item-heading,
	button.list-group-item-danger .list-group-item-heading {
		color: inherit; }
	a.list-group-item-danger:hover, a.list-group-item-danger:focus,
	button.list-group-item-danger:hover,
	button.list-group-item-danger:focus {
		color: #a94442;
		background-color: #ebcccc; }
	a.list-group-item-danger.active, a.list-group-item-danger.active:hover, a.list-group-item-danger.active:focus,
	button.list-group-item-danger.active,
	button.list-group-item-danger.active:hover,
	button.list-group-item-danger.active:focus {
		color: #fff;
		background-color: #a94442;
		border-color: #a94442; }

.list-group-item-heading {
	margin-top: 0;
	margin-bottom: 5px; }

.list-group-item-text {
	margin-bottom: 0;
	line-height: 1.3; }

.panel {
	margin-bottom: 23px;
	background-color: #fff;
	border: 1px solid transparent;
	border-radius: 4px;
	-webkit-box-shadow: 0 1px 1px rgba(0, 0, 0, 0.05);
	box-shadow: 0 1px 1px rgba(0, 0, 0, 0.05); }

.panel-body {
	padding: 15px; }
	.panel-body:before, .panel-body:after {
		display: table;
		content: " "; }
	.panel-body:after {
		clear: both; }

.panel-heading {
	padding: 10px 15px;
	border-bottom: 1px solid transparent;
	border-top-left-radius: 3px;
	border-top-right-radius: 3px; }
	.panel-heading > .dropdown .dropdown-toggle {
		color: inherit; }

.panel-title {
	margin-top: 0;
	margin-bottom: 0;
	font-size: 18px;
	color: inherit; }
	.panel-title > a,
	.panel-title > small,
	.panel-title > .small,
	.panel-title > small > a,
	.panel-title > .small > a {
		color: inherit; }

.panel-footer {
	padding: 10px 15px;
	background-color: #f5f5f5;
	border-top: 1px solid #8e8e8e;
	border-bottom-right-radius: 3px;
	border-bottom-left-radius: 3px; }

.panel > .list-group,
.panel > .panel-collapse > .list-group {
	margin-bottom: 0; }
	.panel > .list-group .list-group-item,
	.panel > .panel-collapse > .list-group .list-group-item {
		border-width: 1px 0;
		border-radius: 0; }
	.panel > .list-group:first-child .list-group-item:first-child,
	.panel > .panel-collapse > .list-group:first-child .list-group-item:first-child {
		border-top: 0;
		border-top-left-radius: 3px;
		border-top-right-radius: 3px; }
	.panel > .list-group:last-child .list-group-item:last-child,
	.panel > .panel-collapse > .list-group:last-child .list-group-item:last-child {
		border-bottom: 0;
		border-bottom-right-radius: 3px;
		border-bottom-left-radius: 3px; }

.panel > .panel-heading + .panel-collapse > .list-group .list-group-item:first-child {
	border-top-left-radius: 0;
	border-top-right-radius: 0; }

.panel-heading + .list-group .list-group-item:first-child {
	border-top-width: 0; }

.list-group + .panel-footer {
	border-top-width: 0; }

.panel > .table,
.panel > .table-responsive > .table,
.panel > .panel-collapse > .table {
	margin-bottom: 0; }
	.panel > .table caption,
	.panel > .table-responsive > .table caption,
	.panel > .panel-collapse > .table caption {
		padding-right: 15px;
		padding-left: 15px; }

.panel > .table:first-child,
.panel > .table-responsive:first-child > .table:first-child {
	border-top-left-radius: 3px;
	border-top-right-radius: 3px; }
	.panel > .table:first-child > thead:first-child > tr:first-child,
	.panel > .table:first-child > tbody:first-child > tr:first-child,
	.panel > .table-responsive:first-child > .table:first-child > thead:first-child > tr:first-child,
	.panel > .table-responsive:first-child > .table:first-child > tbody:first-child > tr:first-child {
		border-top-left-radius: 3px;
		border-top-right-radius: 3px; }
		.panel > .table:first-child > thead:first-child > tr:first-child td:first-child,
		.panel > .table:first-child > thead:first-child > tr:first-child th:first-child,
		.panel > .table:first-child > tbody:first-child > tr:first-child td:first-child,
		.panel > .table:first-child > tbody:first-child > tr:first-child th:first-child,
		.panel > .table-responsive:first-child > .table:first-child > thead:first-child > tr:first-child td:first-child,
		.panel > .table-responsive:first-child > .table:first-child > thead:first-child > tr:first-child th:first-child,
		.panel > .table-responsive:first-child > .table:first-child > tbody:first-child > tr:first-child td:first-child,
		.panel > .table-responsive:first-child > .table:first-child > tbody:first-child > tr:first-child th:first-child {
			border-top-left-radius: 3px; }
		.panel > .table:first-child > thead:first-child > tr:first-child td:last-child,
		.panel > .table:first-child > thead:first-child > tr:first-child th:last-child,
		.panel > .table:first-child > tbody:first-child > tr:first-child td:last-child,
		.panel > .table:first-child > tbody:first-child > tr:first-child th:last-child,
		.panel > .table-responsive:first-child > .table:first-child > thead:first-child > tr:first-child td:last-child,
		.panel > .table-responsive:first-child > .table:first-child > thead:first-child > tr:first-child th:last-child,
		.panel > .table-responsive:first-child > .table:first-child > tbody:first-child > tr:first-child td:last-child,
		.panel > .table-responsive:first-child > .table:first-child > tbody:first-child > tr:first-child th:last-child {
			border-top-right-radius: 3px; }

.panel > .table:last-child,
.panel > .table-responsive:last-child > .table:last-child {
	border-bottom-right-radius: 3px;
	border-bottom-left-radius: 3px; }
	.panel > .table:last-child > tbody:last-child > tr:last-child,
	.panel > .table:last-child > tfoot:last-child > tr:last-child,
	.panel > .table-responsive:last-child > .table:last-child > tbody:last-child > tr:last-child,
	.panel > .table-responsive:last-child > .table:last-child > tfoot:last-child > tr:last-child {
		border-bottom-right-radius: 3px;
		border-bottom-left-radius: 3px; }
		.panel > .table:last-child > tbody:last-child > tr:last-child td:first-child,
		.panel > .table:last-child > tbody:last-child > tr:last-child th:first-child,
		.panel > .table:last-child > tfoot:last-child > tr:last-child td:first-child,
		.panel > .table:last-child > tfoot:last-child > tr:last-child th:first-child,
		.panel > .table-responsive:last-child > .table:last-child > tbody:last-child > tr:last-child td:first-child,
		.panel > .table-responsive:last-child > .table:last-child > tbody:last-child > tr:last-child th:first-child,
		.panel > .table-responsive:last-child > .table:last-child > tfoot:last-child > tr:last-child td:first-child,
		.panel > .table-responsive:last-child > .table:last-child > tfoot:last-child > tr:last-child th:first-child {
			border-bottom-left-radius: 3px; }
		.panel > .table:last-child > tbody:last-child > tr:last-child td:last-child,
		.panel > .table:last-child > tbody:last-child > tr:last-child th:last-child,
		.panel > .table:last-child > tfoot:last-child > tr:last-child td:last-child,
		.panel > .table:last-child > tfoot:last-child > tr:last-child th:last-child,
		.panel > .table-responsive:last-child > .table:last-child > tbody:last-child > tr:last-child td:last-child,
		.panel > .table-responsive:last-child > .table:last-child > tbody:last-child > tr:last-child th:last-child,
		.panel > .table-responsive:last-child > .table:last-child > tfoot:last-child > tr:last-child td:last-child,
		.panel > .table-responsive:last-child > .table:last-child > tfoot:last-child > tr:last-child th:last-child {
			border-bottom-right-radius: 3px; }

.panel > .panel-body + .table,
.panel > .panel-body + .table-responsive,
.panel > .table + .panel-body,
.panel > .table-responsive + .panel-body {
	border-top: 1px solid #ddd; }

.panel > .table > tbody:first-child > tr:first-child th,
.panel > .table > tbody:first-child > tr:first-child td {
	border-top: 0; }

.panel > .table-bordered,
.panel > .table-responsive > .table-bordered {
	border: 0; }
	.panel > .table-bordered > thead > tr > th:first-child,
	.panel > .table-bordered > thead > tr > td:first-child,
	.panel > .table-bordered > tbody > tr > th:first-child,
	.panel > .table-bordered > tbody > tr > td:first-child,
	.panel > .table-bordered > tfoot > tr > th:first-child,
	.panel > .table-bordered > tfoot > tr > td:first-child,
	.panel > .table-responsive > .table-bordered > thead > tr > th:first-child,
	.panel > .table-responsive > .table-bordered > thead > tr > td:first-child,
	.panel > .table-responsive > .table-bordered > tbody > tr > th:first-child,
	.panel > .table-responsive > .table-bordered > tbody > tr > td:first-child,
	.panel > .table-responsive > .table-bordered > tfoot > tr > th:first-child,
	.panel > .table-responsive > .table-bordered > tfoot > tr > td:first-child {
		border-left: 0; }
	.panel > .table-bordered > thead > tr > th:last-child,
	.panel > .table-bordered > thead > tr > td:last-child,
	.panel > .table-bordered > tbody > tr > th:last-child,
	.panel > .table-bordered > tbody > tr > td:last-child,
	.panel > .table-bordered > tfoot > tr > th:last-child,
	.panel > .table-bordered > tfoot > tr > td:last-child,
	.panel > .table-responsive > .table-bordered > thead > tr > th:last-child,
	.panel > .table-responsive > .table-bordered > thead > tr > td:last-child,
	.panel > .table-responsive > .table-bordered > tbody > tr > th:last-child,
	.panel > .table-responsive > .table-bordered > tbody > tr > td:last-child,
	.panel > .table-responsive > .table-bordered > tfoot > tr > th:last-child,
	.panel > .table-responsive > .table-bordered > tfoot > tr > td:last-child {
		border-right: 0; }
	.panel > .table-bordered > thead > tr:first-child > td,
	.panel > .table-bordered > thead > tr:first-child > th,
	.panel > .table-bordered > tbody > tr:first-child > td,
	.panel > .table-bordered > tbody > tr:first-child > th,
	.panel > .table-responsive > .table-bordered > thead > tr:first-child > td,
	.panel > .table-responsive > .table-bordered > thead > tr:first-child > th,
	.panel > .table-responsive > .table-bordered > tbody > tr:first-child > td,
	.panel > .table-responsive > .table-bordered > tbody > tr:first-child > th {
		border-bottom: 0; }
	.panel > .table-bordered > tbody > tr:last-child > td,
	.panel > .table-bordered > tbody > tr:last-child > th,
	.panel > .table-bordered > tfoot > tr:last-child > td,
	.panel > .table-bordered > tfoot > tr:last-child > th,
	.panel > .table-responsive > .table-bordered > tbody > tr:last-child > td,
	.panel > .table-responsive > .table-bordered > tbody > tr:last-child > th,
	.panel > .table-responsive > .table-bordered > tfoot > tr:last-child > td,
	.panel > .table-responsive > .table-bordered > tfoot > tr:last-child > th {
		border-bottom: 0; }

.panel > .table-responsive {
	margin-bottom: 0;
	border: 0; }

.panel-group {
	margin-bottom: 23px; }
	.panel-group .panel {
		margin-bottom: 0;
		border-radius: 4px; }
		.panel-group .panel + .panel {
			margin-top: 5px; }
	.panel-group .panel-heading {
		border-bottom: 0; }
		.panel-group .panel-heading + .panel-collapse > .panel-body,
		.panel-group .panel-heading + .panel-collapse > .list-group {
			border-top: 1px solid #8e8e8e; }
	.panel-group .panel-footer {
		border-top: 0; }
		.panel-group .panel-footer + .panel-collapse .panel-body {
			border-bottom: 1px solid #8e8e8e; }

.panel-default {
	border-color: #8e8e8e; }
	.panel-default > .panel-heading {
		color: #333333;
		background-color: #f5f5f5;
		border-color: #8e8e8e; }
		.panel-default > .panel-heading + .panel-collapse > .panel-body {
			border-top-color: #8e8e8e; }
		.panel-default > .panel-heading .badge {
			color: #f5f5f5;
			background-color: #333333; }
	.panel-default > .panel-footer + .panel-collapse > .panel-body {
		border-bottom-color: #8e8e8e; }

.panel-primary {
	border-color: #2572b4; }
	.panel-primary > .panel-heading {
		color: #fff;
		background-color: #2572b4;
		border-color: #2572b4; }
		.panel-primary > .panel-heading + .panel-collapse > .panel-body {
			border-top-color: #2572b4; }
		.panel-primary > .panel-heading .badge {
			color: #2572b4;
			background-color: #fff; }
	.panel-primary > .panel-footer + .panel-collapse > .panel-body {
		border-bottom-color: #2572b4; }

.panel-success {
	border-color: #629339; }
	.panel-success > .panel-heading {
		color: #3c763d;
		background-color: #dff0d8;
		border-color: #629339; }
		.panel-success > .panel-heading + .panel-collapse > .panel-body {
			border-top-color: #629339; }
		.panel-success > .panel-heading .badge {
			color: #dff0d8;
			background-color: #3c763d; }
	.panel-success > .panel-footer + .panel-collapse > .panel-body {
		border-bottom-color: #629339; }

.panel-info {
	border-color: #2392A9; }
	.panel-info > .panel-heading {
		color: #31708f;
		background-color: #d9edf7;
		border-color: #2392A9; }
		.panel-info > .panel-heading + .panel-collapse > .panel-body {
			border-top-color: #2392A9; }
		.panel-info > .panel-heading .badge {
			color: #d9edf7;
			background-color: #31708f; }
	.panel-info > .panel-footer + .panel-collapse > .panel-body {
		border-bottom-color: #2392A9; }

.panel-warning {
	border-color: #BA8312; }
	.panel-warning > .panel-heading {
		color: #8a6d3b;
		background-color: #fcf8e3;
		border-color: #BA8312; }
		.panel-warning > .panel-heading + .panel-collapse > .panel-body {
			border-top-color: #BA8312; }
		.panel-warning > .panel-heading .badge {
			color: #fcf8e3;
			background-color: #8a6d3b; }
	.panel-warning > .panel-footer + .panel-collapse > .panel-body {
		border-bottom-color: #BA8312; }

.panel-danger {
	border-color: #C16171; }
	.panel-danger > .panel-heading {
		color: #a94442;
		background-color: #f2dede;
		border-color: #C16171; }
		.panel-danger > .panel-heading + .panel-collapse > .panel-body {
			border-top-color: #C16171; }
		.panel-danger > .panel-heading .badge {
			color: #f2dede;
			background-color: #a94442; }
	.panel-danger > .panel-footer + .panel-collapse > .panel-body {
		border-bottom-color: #C16171; }

.embed-responsive {
	position: relative;
	display: block;
	height: 0;
	padding: 0;
	overflow: hidden; }
	.embed-responsive .embed-responsive-item,
	.embed-responsive iframe,
	.embed-responsive embed,
	.embed-responsive object,
	.embed-responsive video {
		position: absolute;
		top: 0;
		bottom: 0;
		left: 0;
		width: 100%;
		height: 100%;
		border: 0; }

.embed-responsive-16by9 {
	padding-bottom: 56.25%; }

.embed-responsive-4by3 {
	padding-bottom: 75%; }

.well {
	min-height: 20px;
	padding: 19px;
	margin-bottom: 20px;
	background-color: #f5f5f5;
	border: 1px solid #e3e3e3;
	border-radius: 4px;
	-webkit-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.05);
	box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.05); }
	.well blockquote {
		border-color: #ddd;
		border-color: rgba(0, 0, 0, 0.15); }

.well-lg {
	padding: 24px;
	border-radius: 6px; }

.well-sm {
	padding: 9px;
	border-radius: 3px; }

.close {
	float: right;
	font-size: 24px;
	font-weight: bold;
	line-height: 1;
	color: #000;
	text-shadow: 0 1px 0 #fff;
	filter: alpha(opacity=20);
	opacity: 0.2; }
	.close:hover, .close:focus {
		color: #000;
		text-decoration: none;
		cursor: pointer;
		filter: alpha(opacity=50);
		opacity: 0.5; }

button.close {
	padding: 0;
	cursor: pointer;
	background: transparent;
	border: 0;
	-webkit-appearance: none;
	-moz-appearance: none;
	     appearance: none; }

/*
	WET-BOEW
	@title: Bootstrap overrides for WET-BOEW - Components
 */
/*! Placeholders */
.pagination > li:first-child [rel="prev"]:before,
.pager > li:first-child [rel="prev"]:before, [dir=rtl] .pagination [rel="next"]:before,
[dir=rtl] .pager [rel="next"]:before, .dataTables_wrapper .dataTables_paginate .paginate_button.previous:before, [dir=rtl] .dataTables_wrapper .dataTables_paginate .paginate_button.next:before, .pagination > li:last-child [rel="next"]:after,
.pager > li:last-child [rel="next"]:after, [dir=rtl] .pagination [rel="prev"]:after,
[dir=rtl] .pager [rel="prev"]:after, .dataTables_wrapper .dataTables_paginate .paginate_button.next:after, [dir=rtl] .dataTables_wrapper .dataTables_paginate .paginate_button.previous:after, table.dataTable thead .sorting-icons:before, table.dataTable thead .sorting-icons:after {
	content: " ";
	font-family: "Glyphicons Halflings";
	font-weight: 400;
	line-height: 1em;
	position: relative;
	top: .1em; }

.pagination > li:first-child [rel="prev"]:before,
.pager > li:first-child [rel="prev"]:before, [dir=rtl] .pagination [rel="next"]:before,
[dir=rtl] .pager [rel="next"]:before, .dataTables_wrapper .dataTables_paginate .paginate_button.previous:before, [dir=rtl] .dataTables_wrapper .dataTables_paginate .paginate_button.next:before {
	content: "\e091";
	margin-right: .5em; }

.pagination > li:last-child [rel="next"]:after,
.pager > li:last-child [rel="next"]:after, [dir=rtl] .pagination [rel="prev"]:after,
[dir=rtl] .pager [rel="prev"]:after, .dataTables_wrapper .dataTables_paginate .paginate_button.next:after, [dir=rtl] .dataTables_wrapper .dataTables_paginate .paginate_button.previous:after {
	content: "\e092";
	margin-left: .5em; }

/*
 * btn-xs should be equal to btn-sm in >v4.0.*
*/
.btn-group-xs .btn,
.btn.btn-xs,
.btn-group-xs > .btn {
	min-height: 0; }

.dropdown-menu > li > a:visited {
	color: #333333; }

.nav > li > a:visited {
	color: #295376; }

.nav-pills > li.active > a:visited {
	color: #fff; }

.navbar-default .navbar-nav > li > a:visited {
	color: #777; }

@media (max-width: 767px) {
	.navbar-default .open .dropdown-menu > li > a {
		color: #777; } }

.navbar-default .navbar-link:visited {
	color: #777; }

.navbar-inverse .navbar-nav > li > a:visited {
	color: #959595; }

@media (max-width: 767px) {
	.navbar-inverse .open .dropdown-menu > li > a:visited {
		color: #959595; } }

.navbar-inverse .navbar-link:visited {
	color: #959595; }

/*
 *  Pagination
 *    * Add left/right arrows to previous/next buttons
 *    * Increase size of the pagination buttons
 *    * Prevent contrast ratio issues on active placeholder links
 */
.pagination > li > a,
.pager > li > a {
	cursor: pointer;
	display: inline-block;
	margin-bottom: .5em;
	padding: 10px 16px; }

.pagination > li.active > a,
.pager > li.active > a {
	cursor: default; }

.pagination > li.disabled + li > a,
.pager > li.disabled + li > a {
	border-top-left-radius: 4px;
	border-bottom-left-radius: 4px; }

.pager > li > a {
	text-decoration: none; }

.pager > li > a:hover, .pager > li > a:focus,
.pager > li > span:hover,
.pager > li > span:focus {
	border-color: #bbbfc5;
	color: #335075; }

.pagination > .active {
	color: #fff; }

/*
 *  Right-to-left support
 */
[dir=rtl] .pagination [rel="prev"],
[dir=rtl] .pager [rel="prev"] {
	border-top-left-radius: 0;
	border-bottom-left-radius: 0;
	border-top-right-radius: 4px;
	border-bottom-right-radius: 4px; }

[dir=rtl] .pagination [rel="next"],
[dir=rtl] .pager [rel="next"] {
	border-top-left-radius: 4px;
	border-bottom-left-radius: 4px;
	border-top-right-radius: 0;
	border-bottom-right-radius: 0; }

[dir=rtl] .pagination > li,
[dir=rtl] .pager > li {
	float: right; }
	[dir=rtl] .pagination > li.disabled + li > a,
	[dir=rtl] .pager > li.disabled + li > a {
		border-top-left-radius: 0;
		border-bottom-left-radius: 0;
		border-top-right-radius: 4px;
		border-bottom-right-radius: 4px; }

/*
  WET-BOEW
  @title: Ellipsis
 */
.wb-elps {
	overflow: hidden;
	text-overflow: ellipsis;
	white-space: nowrap; }

/*
 *
 * Web Experience Toolkit (WET) / Boîte à outils de l'expérience Web (BOEW)
 * wet-boew.github.io/wet-boew/License-en.html / wet-boew.github.io/wet-boew/Licence-fr.html
 *
 */
/*
.provisional {
	// Add provisional CSS here
}
*/
.modal-open {
	overflow: hidden; }

.modal {
	position: fixed;
	top: 0;
	right: 0;
	bottom: 0;
	left: 0;
	z-index: 1050;
	display: none;
	overflow: hidden;
	-webkit-overflow-scrolling: touch;
	outline: 0; }
	.modal.fade .modal-dialog {
		-webkit-transform: translate(0, -25%);
		transform: translate(0, -25%);
		-webkit-transition: -webkit-transform 0.3s ease-out;
		transition: -webkit-transform 0.3s ease-out;
		transition: transform 0.3s ease-out;
		transition: transform 0.3s ease-out, -webkit-transform 0.3s ease-out; }
	.modal.in .modal-dialog {
		-webkit-transform: translate(0, 0);
		transform: translate(0, 0); }

.modal-open .modal {
	overflow-x: hidden;
	overflow-y: auto; }

.modal-dialog {
	position: relative;
	width: auto;
	margin: 10px; }

.modal-content {
	position: relative;
	background-color: #fff;
	background-clip: padding-box;
	border: 1px solid #999;
	border: 1px solid rgba(0, 0, 0, 0.2);
	border-radius: 6px;
	-webkit-box-shadow: 0 3px 9px rgba(0, 0, 0, 0.5);
	box-shadow: 0 3px 9px rgba(0, 0, 0, 0.5);
	outline: 0; }

.modal-backdrop {
	position: fixed;
	top: 0;
	right: 0;
	bottom: 0;
	left: 0;
	z-index: 1040;
	background-color: #000; }
	.modal-backdrop.fade {
		filter: alpha(opacity=0);
		opacity: 0; }
	.modal-backdrop.in {
		filter: alpha(opacity=50);
		opacity: 0.5; }

.modal-header {
	padding: 15px;
	border-bottom: 1px solid #e5e5e5; }
	.modal-header:before, .modal-header:after {
		display: table;
		content: " "; }
	.modal-header:after {
		clear: both; }

.modal-header .close {
	margin-top: -2px; }

.modal-title {
	margin: 0;
	line-height: 1.4375; }

.modal-body {
	position: relative;
	padding: 15px; }

.modal-footer {
	padding: 15px;
	text-align: right;
	border-top: 1px solid #e5e5e5; }
	.modal-footer:before, .modal-footer:after {
		display: table;
		content: " "; }
	.modal-footer:after {
		clear: both; }
	.modal-footer .btn + .btn {
		margin-bottom: 0;
		margin-left: 5px; }
	.modal-footer .btn-group .btn + .btn {
		margin-left: -1px; }
	.modal-footer .btn-block + .btn-block {
		margin-left: 0; }

.modal-scrollbar-measure {
	position: absolute;
	top: -9999px;
	width: 50px;
	height: 50px;
	overflow: scroll; }

@media (min-width: 768px) {
	.modal-dialog {
		width: 600px;
		margin: 30px auto; }
	.modal-content {
		-webkit-box-shadow: 0 5px 15px rgba(0, 0, 0, 0.5);
		box-shadow: 0 5px 15px rgba(0, 0, 0, 0.5); }
	.modal-sm {
		width: 300px; } }

@media (min-width: 992px) {
	.modal-lg {
		width: 900px; } }

.tooltip {
	position: absolute;
	z-index: 1070;
	display: block;
	font-family: "Noto Sans", sans-serif;
	font-style: normal;
	font-weight: 400;
	line-height: 1.4375;
	line-break: auto;
	text-align: left;
	text-align: start;
	text-decoration: none;
	text-shadow: none;
	text-transform: none;
	letter-spacing: normal;
	word-break: normal;
	word-spacing: normal;
	word-wrap: normal;
	white-space: normal;
	font-size: 14px;
	filter: alpha(opacity=0);
	opacity: 0; }
	.tooltip.in {
		filter: alpha(opacity=90);
		opacity: 0.9; }
	.tooltip.top {
		padding: 5px 0;
		margin-top: -3px; }
	.tooltip.right {
		padding: 0 5px;
		margin-left: 3px; }
	.tooltip.bottom {
		padding: 5px 0;
		margin-top: 3px; }
	.tooltip.left {
		padding: 0 5px;
		margin-left: -3px; }
	.tooltip.top .tooltip-arrow {
		bottom: 0;
		left: 50%;
		margin-left: -5px;
		border-width: 5px 5px 0;
		border-top-color: #000; }
	.tooltip.top-left .tooltip-arrow {
		right: 5px;
		bottom: 0;
		margin-bottom: -5px;
		border-width: 5px 5px 0;
		border-top-color: #000; }
	.tooltip.top-right .tooltip-arrow {
		bottom: 0;
		left: 5px;
		margin-bottom: -5px;
		border-width: 5px 5px 0;
		border-top-color: #000; }
	.tooltip.right .tooltip-arrow {
		top: 50%;
		left: 0;
		margin-top: -5px;
		border-width: 5px 5px 5px 0;
		border-right-color: #000; }
	.tooltip.left .tooltip-arrow {
		top: 50%;
		right: 0;
		margin-top: -5px;
		border-width: 5px 0 5px 5px;
		border-left-color: #000; }
	.tooltip.bottom .tooltip-arrow {
		top: 0;
		left: 50%;
		margin-left: -5px;
		border-width: 0 5px 5px;
		border-bottom-color: #000; }
	.tooltip.bottom-left .tooltip-arrow {
		top: 0;
		right: 5px;
		margin-top: -5px;
		border-width: 0 5px 5px;
		border-bottom-color: #000; }
	.tooltip.bottom-right .tooltip-arrow {
		top: 0;
		left: 5px;
		margin-top: -5px;
		border-width: 0 5px 5px;
		border-bottom-color: #000; }

.tooltip-inner {
	max-width: 200px;
	padding: 3px 8px;
	color: #fff;
	text-align: center;
	background-color: #000;
	border-radius: 4px; }

.tooltip-arrow {
	position: absolute;
	width: 0;
	height: 0;
	border-color: transparent;
	border-style: solid; }

.popover {
	position: absolute;
	top: 0;
	left: 0;
	z-index: 1060;
	display: none;
	max-width: 276px;
	padding: 1px;
	font-family: "Noto Sans", sans-serif;
	font-style: normal;
	font-weight: 400;
	line-height: 1.4375;
	line-break: auto;
	text-align: left;
	text-align: start;
	text-decoration: none;
	text-shadow: none;
	text-transform: none;
	letter-spacing: normal;
	word-break: normal;
	word-spacing: normal;
	word-wrap: normal;
	white-space: normal;
	font-size: 16px;
	background-color: #fff;
	background-clip: padding-box;
	border: 1px solid #ccc;
	border: 1px solid rgba(0, 0, 0, 0.2);
	border-radius: 6px;
	-webkit-box-shadow: 0 5px 10px rgba(0, 0, 0, 0.2);
	box-shadow: 0 5px 10px rgba(0, 0, 0, 0.2); }
	.popover.top {
		margin-top: -10px; }
	.popover.right {
		margin-left: 10px; }
	.popover.bottom {
		margin-top: 10px; }
	.popover.left {
		margin-left: -10px; }
	.popover > .arrow {
		border-width: 11px; }
		.popover > .arrow, .popover > .arrow:after {
			position: absolute;
			display: block;
			width: 0;
			height: 0;
			border-color: transparent;
			border-style: solid; }
		.popover > .arrow:after {
			content: "";
			border-width: 10px; }
	.popover.top > .arrow {
		bottom: -11px;
		left: 50%;
		margin-left: -11px;
		border-top-color: #999999;
		border-top-color: rgba(0, 0, 0, 0.25);
		border-bottom-width: 0; }
		.popover.top > .arrow:after {
			bottom: 1px;
			margin-left: -10px;
			content: " ";
			border-top-color: #fff;
			border-bottom-width: 0; }
	.popover.right > .arrow {
		top: 50%;
		left: -11px;
		margin-top: -11px;
		border-right-color: #999999;
		border-right-color: rgba(0, 0, 0, 0.25);
		border-left-width: 0; }
		.popover.right > .arrow:after {
			bottom: -10px;
			left: 1px;
			content: " ";
			border-right-color: #fff;
			border-left-width: 0; }
	.popover.bottom > .arrow {
		top: -11px;
		left: 50%;
		margin-left: -11px;
		border-top-width: 0;
		border-bottom-color: #999999;
		border-bottom-color: rgba(0, 0, 0, 0.25); }
		.popover.bottom > .arrow:after {
			top: 1px;
			margin-left: -10px;
			content: " ";
			border-top-width: 0;
			border-bottom-color: #fff; }
	.popover.left > .arrow {
		top: 50%;
		right: -11px;
		margin-top: -11px;
		border-right-width: 0;
		border-left-color: #999999;
		border-left-color: rgba(0, 0, 0, 0.25); }
		.popover.left > .arrow:after {
			right: 1px;
			bottom: -10px;
			content: " ";
			border-right-width: 0;
			border-left-color: #fff; }

.popover-title {
	padding: 8px 14px;
	margin: 0;
	font-size: 16px;
	background-color: #f7f7f7;
	border-bottom: 1px solid #ebebeb;
	border-radius: 5px 5px 0 0; }

.popover-content {
	padding: 9px 14px; }

.carousel {
	position: relative; }

.carousel-inner {
	position: relative;
	width: 100%;
	overflow: hidden; }
	.carousel-inner > .item {
		position: relative;
		display: none;
		-webkit-transition: 0.6s ease-in-out left;
		transition: 0.6s ease-in-out left; }
		.carousel-inner > .item > img,
		.carousel-inner > .item > a > img {
			display: block;
			max-width: 100%;
			height: auto;
			line-height: 1; }
		@media all and (transform-3d), (-webkit-transform-3d) {
			.carousel-inner > .item {
				-webkit-transition: -webkit-transform 0.6s ease-in-out;
				transition: -webkit-transform 0.6s ease-in-out;
				transition: transform 0.6s ease-in-out;
				transition: transform 0.6s ease-in-out, -webkit-transform 0.6s ease-in-out;
				-webkit-backface-visibility: hidden;
				backface-visibility: hidden;
				-webkit-perspective: 1000px;
				perspective: 1000px; }
				.carousel-inner > .item.next, .carousel-inner > .item.active.right {
					-webkit-transform: translate3d(100%, 0, 0);
					transform: translate3d(100%, 0, 0);
					left: 0; }
				.carousel-inner > .item.prev, .carousel-inner > .item.active.left {
					-webkit-transform: translate3d(-100%, 0, 0);
					transform: translate3d(-100%, 0, 0);
					left: 0; }
				.carousel-inner > .item.next.left, .carousel-inner > .item.prev.right, .carousel-inner > .item.active {
					-webkit-transform: translate3d(0, 0, 0);
					transform: translate3d(0, 0, 0);
					left: 0; } }
	.carousel-inner > .active,
	.carousel-inner > .next,
	.carousel-inner > .prev {
		display: block; }
	.carousel-inner > .active {
		left: 0; }
	.carousel-inner > .next,
	.carousel-inner > .prev {
		position: absolute;
		top: 0;
		width: 100%; }
	.carousel-inner > .next {
		left: 100%; }
	.carousel-inner > .prev {
		left: -100%; }
	.carousel-inner > .next.left,
	.carousel-inner > .prev.right {
		left: 0; }
	.carousel-inner > .active.left {
		left: -100%; }
	.carousel-inner > .active.right {
		left: 100%; }

.carousel-control {
	position: absolute;
	top: 0;
	bottom: 0;
	left: 0;
	width: 15%;
	font-size: 20px;
	color: #fff;
	text-align: center;
	text-shadow: 0 1px 2px rgba(0, 0, 0, 0.6);
	background-color: rgba(0, 0, 0, 0);
	filter: alpha(opacity=50);
	opacity: 0.5; }
	.carousel-control.left {
		background-image: -webkit-gradient(linear, left top, right top, from(rgba(0, 0, 0, 0.5)), to(rgba(0, 0, 0, 0.0001)));
		background-image: linear-gradient(to right, rgba(0, 0, 0, 0.5) 0%, rgba(0, 0, 0, 0.0001) 100%);
		filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#80000000', endColorstr='#00000000', GradientType=1);
		background-repeat: repeat-x; }
	.carousel-control.right {
		right: 0;
		left: auto;
		background-image: -webkit-gradient(linear, left top, right top, from(rgba(0, 0, 0, 0.0001)), to(rgba(0, 0, 0, 0.5)));
		background-image: linear-gradient(to right, rgba(0, 0, 0, 0.0001) 0%, rgba(0, 0, 0, 0.5) 100%);
		filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#00000000', endColorstr='#80000000', GradientType=1);
		background-repeat: repeat-x; }
	.carousel-control:hover, .carousel-control:focus {
		color: #fff;
		text-decoration: none;
		outline: 0;
		filter: alpha(opacity=90);
		opacity: 0.9; }
	.carousel-control .icon-prev,
	.carousel-control .icon-next,
	.carousel-control .glyphicon-chevron-left,
	.carousel-control .glyphicon-chevron-right {
		position: absolute;
		top: 50%;
		z-index: 5;
		display: inline-block;
		margin-top: -10px; }
	.carousel-control .icon-prev,
	.carousel-control .glyphicon-chevron-left {
		left: 50%;
		margin-left: -10px; }
	.carousel-control .icon-next,
	.carousel-control .glyphicon-chevron-right {
		right: 50%;
		margin-right: -10px; }
	.carousel-control .icon-prev,
	.carousel-control .icon-next {
		width: 20px;
		height: 20px;
		font-family: serif;
		line-height: 1; }
	.carousel-control .icon-prev:before {
		content: "\2039"; }
	.carousel-control .icon-next:before {
		content: "\203a"; }

.carousel-indicators {
	position: absolute;
	bottom: 10px;
	left: 50%;
	z-index: 15;
	width: 60%;
	padding-left: 0;
	margin-left: -30%;
	text-align: center;
	list-style: none; }
	.carousel-indicators li {
		display: inline-block;
		width: 10px;
		height: 10px;
		margin: 1px;
		text-indent: -999px;
		cursor: pointer;
		background-color: #000 \9;
		background-color: rgba(0, 0, 0, 0);
		border: 1px solid #fff;
		border-radius: 10px; }
	.carousel-indicators .active {
		width: 12px;
		height: 12px;
		margin: 0;
		background-color: #fff; }

.carousel-caption {
	position: absolute;
	right: 15%;
	bottom: 20px;
	left: 15%;
	z-index: 10;
	padding-top: 20px;
	padding-bottom: 20px;
	color: #fff;
	text-align: center;
	text-shadow: 0 1px 2px rgba(0, 0, 0, 0.6); }
	.carousel-caption .btn {
		text-shadow: none; }

@media screen and (min-width: 768px) {
	.carousel-control .glyphicon-chevron-left,
	.carousel-control .glyphicon-chevron-right,
	.carousel-control .icon-prev,
	.carousel-control .icon-next {
		width: 30px;
		height: 30px;
		margin-top: -10px;
		font-size: 30px; }
	.carousel-control .glyphicon-chevron-left,
	.carousel-control .icon-prev {
		margin-left: -10px; }
	.carousel-control .glyphicon-chevron-right,
	.carousel-control .icon-next {
		margin-right: -10px; }
	.carousel-caption {
		right: 20%;
		left: 20%;
		padding-bottom: 30px; }
	.carousel-indicators {
		bottom: 20px; } }

/*
 Plugins
 */
/*
 * Web Experience Toolkit (WET) / Boîte à outils de l'expérience Web (BOEW)
 * wet-boew.github.io/wet-boew/License-en.html / wet-boew.github.io/wet-boew/Licence-fr.html
 */
.wb-calevt-cal .cal-days td ul.ev-details, .wb-calevt-cal .cal-days td:hover ul {
	background-color: #fff;
	border: 1px solid #333;
	clip: rect(auto, auto, auto, auto);
	color: #000;
	height: inherit;
	list-style-type: none;
	margin: 0;
	margin-top: -.5em;
	overflow: inherit;
	padding: 0;
	position: absolute;
	width: 10em;
	z-index: 5; }
	.wb-calevt-cal .cal-days td ul.ev-details a:hover, .wb-calevt-cal .cal-days td:hover ul a:hover, .wb-calevt-cal .cal-days td ul.ev-details a:focus, .wb-calevt-cal .cal-days td:hover ul a:focus {
		color: #fff; }

.wb-calevt-cal {
	width: 19em; }
	.wb-calevt-cal .cal-days .cal-evt {
		background: #176ca7;
		color: #fff; }
	.wb-calevt-cal .cal-evt-lnk {
		display: block;
		padding: .5em; }
	.wb-calevt-cal.cal-cnt-fluid {
		width: 100%; }

/*
 * Web Experience Toolkit (WET) / Boîte à outils de l'expérience Web (BOEW)
 * wet-boew.github.io/wet-boew/License-en.html / wet-boew.github.io/wet-boew/Licence-fr.html
 */
.wb-clndr td > a {
	display: block;
	height: 100%;
	width: 100%; }

.wb-clndr th abbr, .wb-clndr td > time, .wb-clndr td > a, .wb-clndr td div {
	color: #000;
	padding: 20% 0;
	text-align: center; }

.wb-clndr .cal-curr-day, .wb-clndr .cal-curr-day a,
.wb-clndr .cal-curr-day div {
	color: #000; }

.wb-clndr {
	background: #fff;
	position: relative;
	width: 100%; }
	.wb-clndr .cal-nav {
		background: #333;
		padding: .5em;
		text-align: center; }
	.wb-clndr .form-group {
		margin: 0;
		padding: 10px 14px; }
	.wb-clndr .btn {
		background: none;
		color: #fff; }
		.wb-clndr .btn[disabled] {
			color: #ccc; }
	.wb-clndr option[disabled] {
		color: #aaa; }
	.wb-clndr table {
		width: 100%; }
	.wb-clndr th {
		background: #555;
		border: 1px solid #333; }
		.wb-clndr th abbr {
			color: #fff;
			display: block; }
	.wb-clndr td {
		background: #fff;
		border: 1px solid #aaa;
		padding: 0;
		text-align: center; }
		.wb-clndr td > time {
			display: block; }
		.wb-clndr td a:hover, .wb-clndr td a:focus {
			background: #333;
			color: #fff; }
	.wb-clndr .cal-curr-day {
		background: #ccc;
		font-weight: bolder; }

/*
 * Web Experience Toolkit (WET) / Boîte à outils de l'expérience Web (BOEW)
 * wet-boew.github.io/wet-boew/License-en.html / wet-boew.github.io/wet-boew/Licence-fr.html
 */
figure .pieLabel {
	background-color: #fff;
	border: solid #000 1px;
	color: #000;
	padding: 1px; }

details.alert, details.alert[open] {
	border-radius: 0;
	border-width: 0 0 0 4px;
	padding-left: 45px;
	padding-right: 0;
	position: relative; }
	details.alert:before, details.alert[open]:before {
		display: inline-block;
		font-family: "Glyphicons Halflings";
		font-size: 24px;
		margin-left: -1.3em;
		margin-top: -3px;
		position: absolute;
		top: 15px; }
	details.alert summary, details.alert[open] summary {
		border-width: 0;
		margin-right: 15px;
		padding-left: 5px; }
		details.alert summary:focus, details.alert summary:hover, details.alert[open] summary:focus, details.alert[open] summary:hover {
			text-decoration: none; }
			details.alert summary:focus h2,
			details.alert summary:focus h3,
			details.alert summary:focus h4,
			details.alert summary:focus h5,
			details.alert summary:focus h6, details.alert summary:hover h2,
			details.alert summary:hover h3,
			details.alert summary:hover h4,
			details.alert summary:hover h5,
			details.alert summary:hover h6, details.alert[open] summary:focus h2,
			details.alert[open] summary:focus h3,
			details.alert[open] summary:focus h4,
			details.alert[open] summary:focus h5,
			details.alert[open] summary:focus h6, details.alert[open] summary:hover h2,
			details.alert[open] summary:hover h3,
			details.alert[open] summary:hover h4,
			details.alert[open] summary:hover h5,
			details.alert[open] summary:hover h6 {
				text-decoration: underline; }
	details.alert > *, details.alert[open] > * {
		margin-left: .7em; }
	details.alert > :first-child, details.alert[open] > :first-child {
		margin-left: .2em; }
		details.alert > :first-child:before, details.alert[open] > :first-child:before {
			color: #000;
			content: ""; }
	details.alert.alert-success:before, details.alert[open].alert-success:before {
		color: #278400;
		content: "\e084"; }
	details.alert.alert-info:before, details.alert[open].alert-info:before {
		color: #269abc;
		content: "\e086"; }
	details.alert.alert-warning:before, details.alert[open].alert-warning:before {
		color: #f90;
		content: "\e107"; }
	details.alert.alert-danger:before, details.alert[open].alert-danger:before {
		color: #d3080c;
		content: "\e101"; }

.wb-enable.no-details details.alert > summary {
	margin-left: 1.2em; }
	.wb-enable.no-details details.alert > summary:before {
		content: "\25BA\a0"; }

.wb-enable.no-details details.alert[open] > summary:before {
	content: "\25BC\a0"; }

.wb-enable.no-details[dir="rtl"] details.alert > summary {
	margin-right: 1.2em; }

/*
 * Web Experience Toolkit (WET) / Boîte à outils de l'expérience Web (BOEW)
 * wet-boew.github.io/wet-boew/License-en.html / wet-boew.github.io/wet-boew/Licence-fr.html
 */
/*
 *	Dismissable content container
 */
.wb-dismissable-container {
	background-color: #eee;
	display: table;
	margin: 10px 0;
	padding: 10px;
	width: 100%; }
	.wb-dismissable-container .mfp-close {
		color: #555;
		display: table-cell;
		position: static; }

/*
 *	Dismissable content wrapper
 */
.wb-dismissable-wrapper {
	display: table-cell;
	width: 100%; }

.wb-eqht-grd {
	-webkit-box-align: stretch;
	    -ms-flex-align: stretch;
	        align-items: stretch;
	display: -webkit-box;
	display: -ms-flexbox;
	display: flex;
	-ms-flex-wrap: wrap;
	    flex-wrap: wrap;
	height: 100%; }
	.wb-eqht-grd > [class*="col-"] {
		display: -webkit-box;
		display: -ms-flexbox;
		display: flex;
		-webkit-box-orient: vertical;
		-webkit-box-direction: normal;
		    -ms-flex-direction: column;
		        flex-direction: column; }
		.wb-eqht-grd > [class*="col-"] > section, .wb-eqht-grd > [class*="col-"] .hght-inhrt {
			display: -webkit-box;
			display: -ms-flexbox;
			display: flex;
			-webkit-box-flex: 1;
			    -ms-flex: 1 1 auto;
			        flex: 1 1 auto;
			-webkit-box-orient: vertical;
			-webkit-box-direction: normal;
			    -ms-flex-direction: column;
			        flex-direction: column; }
	.wb-eqht-grd.grow > [class*="col-"] {
		-webkit-box-flex: 1;
		    -ms-flex-positive: 1;
		        flex-grow: 1; }

/*
 * Web Experience Toolkit (WET) / Boîte à outils de l'expérience Web (BOEW)
 * wet-boew.github.io/wet-boew/License-en.html / wet-boew.github.io/wet-boew/Licence-fr.html
 */
.hght-inhrt {
	min-height: inherit; }

/*
 * Equal Heights overrides
 */
.sect-lnks {
	display: inline-block;
	width: 100%; }

.sect-lnks h2 a,
.sect-lnks h3 a,
.sect-lnks h4 a {
	font-size: 20px; }

.wb-fltr-out {
	display: none !important; }

.wb-filter .input-group {
	max-width: 100%; }

/*
 * Web Experience Toolkit (WET) / Boîte à outils de l'expérience Web (BOEW)
 * wet-boew.github.io/wet-boew/License-en.html / wet-boew.github.io/wet-boew/Licence-fr.html
 */
/*
 * Web Experience Toolkit (WET) / Boîte à outils de l'expérience Web (BOEW)
 * wet-boew.github.io/wet-boew/License-en.html / wet-boew.github.io/wet-boew/Licence-fr.html
 */
/*
 * HOW TO USE THIS FILE
 * Use this file to override Bootstrap variables and WET custom variables.
 * If there is a Bootstrap variable not shown here that you want to override, go to "../node_modules/bootstrap-sass/assets/stylesheets/bootstrap/variables" to view the variables that you can override. Simply copy and paste the variable and its applicable section (if applicable) from the Bootstrap file into this override file and override the variables as applicable.
 */
.fn-lnk:hover, .fn-lnk:focus, .wb-fnote dd:focus .fn-rtn a, .wb-fnote .fn-rtn a:hover, .wb-fnote .fn-rtn a:focus {
	background-color: #555;
	border-color: #555;
	color: #fff !important; }

.fn-lnk, .wb-fnote .fn-rtn a {
	background-color: #eee;
	border: 1px solid #ccc;
	display: inline-block;
	padding: 1px 10px 2px;
	white-space: nowrap; }

.wb-fnote h2, .wb-fnote dd > ul:first-child,
.wb-fnote dd > ol:first-child, .wb-fnote table:first-child {
	margin-top: 0.375em; }

.fn-lnk {
	line-height: 1.15;
	margin-left: 5px; }

.wb-fnote {
	border-color: #ccc;
	border-style: solid;
	border-width: 1px 0;
	margin: 2em 0 0; }
	.wb-fnote h2 {
		margin-left: 0;
		margin-right: 0; }
	.wb-fnote dl {
		margin: 0; }
	.wb-fnote dd {
		border: 1px solid transparent;
		margin: 0.375em 0;
		position: relative; }
		.wb-fnote dd:focus {
			background-color: #eee;
			border-color: #555; }
		.wb-fnote dd > ul,
		.wb-fnote dd > ol {
			margin: 0 0.375em 0.375em 4.25em; }
	.wb-fnote p {
		margin: 0 0 0 3.875em;
		padding: 0 0.375em 0.375em; }
		.wb-fnote p:first-child {
			margin-top: .11em;
			padding-top: 0.375em; }
	.wb-fnote ul,
	.wb-fnote ol {
		margin-bottom: 0.375em; }
	.wb-fnote table {
		margin: 0 0.375em 0.375em 4.25em; }
	.wb-fnote .fn-rtn {
		margin: 0;
		overflow: hidden;
		padding-right: 0;
		padding-top: 0.375em;
		position: absolute;
		top: 0;
		width: 3.5em; }
		.wb-fnote .fn-rtn a {
			display: inline-block;
			margin-top: 0;
			padding-bottom: 0; }

/* Right to left (RTL) SCSS */
[dir="rtl"] sup .fn-lnk {
	margin-left: 0;
	margin-right: 5px; }

[dir="rtl"] .wb-fnote p {
	margin: 0 3.875em 0 0; }

[dir="rtl"] .wb-fnote .fn-rtn {
	margin-right: 0;
	padding-right: 0; }

/*
 * Web Experience Toolkit (WET) / Boîte à outils de l'expérience Web (BOEW)
 * wet-boew.github.io/wet-boew/License-en.html / wet-boew.github.io/wet-boew/Licence-fr.html
 */
.wb-frmvld label strong.error,
.wb-frm label strong.error, .wb-frmvld legend .error,
.wb-frm legend .error {
	display: inline-block;
	width: 100%; }

.wb-frmvld label strong.error .label,
.wb-frm label strong.error .label, .wb-frmvld legend .error .label,
.wb-frm legend .error .label {
	font-size: 100%;
	white-space: normal; }

.wb-server-error {
	display: block !important;
	font-size: 100% !important;
	text-align: left !important;
	white-space: normal !important; }

.css-implicite-input {
	font-weight: 400;
	margin-top: 5px; }

/*
 * Web Experience Toolkit (WET) / Boîte à outils de l'expérience Web (BOEW)
 * wet-boew.github.io/wet-boew/License-en.html / wet-boew.github.io/wet-boew/Licence-fr.html
 */
/*
 * Web Experience Toolkit (WET) / Boîte à outils de l'expérience Web (BOEW)
 * wet-boew.github.io/wet-boew/License-en.html / wet-boew.github.io/wet-boew/Licence-fr.html
 */
/*
 * HOW TO USE THIS FILE
 * Use this file to override Bootstrap variables and WET custom variables.
 * If there is a Bootstrap variable not shown here that you want to override, go to "../node_modules/bootstrap-sass/assets/stylesheets/bootstrap/variables" to view the variables that you can override. Simply copy and paste the variable and its applicable section (if applicable) from the Bootstrap file into this override file and override the variables as applicable.
 */
/* Magnific Popup CSS */
.mfp-bg {
	top: 0;
	left: 0;
	width: 100%;
	height: 100%;
	z-index: 1042;
	overflow: hidden;
	position: fixed;
	background: #0b0b0b;
	opacity: 0.8;
	filter: alpha(opacity=80); }

.mfp-wrap {
	top: 0;
	left: 0;
	width: 100%;
	height: 100%;
	z-index: 1043;
	position: fixed;
	outline: none !important;
	-webkit-backface-visibility: hidden; }

.mfp-container {
	text-align: center;
	position: absolute;
	width: 100%;
	height: 100%;
	left: 0;
	top: 0;
	padding: 0 8px;
	-webkit-box-sizing: border-box;
	box-sizing: border-box; }

.mfp-container:before {
	content: '';
	display: inline-block;
	height: 100%;
	vertical-align: middle; }

.mfp-align-top .mfp-container:before {
	display: none; }

.mfp-content {
	position: relative;
	display: inline-block;
	vertical-align: middle;
	margin: 0 auto;
	text-align: left;
	z-index: 1045; }

.mfp-inline-holder .mfp-content,
.mfp-ajax-holder .mfp-content {
	width: 100%;
	cursor: auto; }

.mfp-ajax-cur {
	cursor: progress; }

.mfp-zoom-out-cur, .mfp-zoom-out-cur .mfp-image-holder .mfp-close {
	cursor: -webkit-zoom-out;
	cursor: zoom-out; }

.mfp-zoom {
	cursor: pointer;
	cursor: -webkit-zoom-in;
	cursor: zoom-in; }

.mfp-auto-cursor .mfp-content {
	cursor: auto; }

.mfp-close,
.mfp-arrow,
.mfp-preloader,
.mfp-counter {
	-webkit-user-select: none;
	-moz-user-select: none;
	-ms-user-select: none;
	    user-select: none; }

.mfp-loading.mfp-figure {
	display: none; }

.mfp-hide {
	display: none !important; }

.mfp-preloader {
	color: #CCC;
	position: absolute;
	top: 50%;
	width: auto;
	text-align: center;
	margin-top: -0.8em;
	left: 8px;
	right: 8px;
	z-index: 1044; }
	.mfp-preloader a {
		color: #CCC; }
		.mfp-preloader a:hover {
			color: #FFF; }

.mfp-s-ready .mfp-preloader {
	display: none; }

.mfp-s-error .mfp-content {
	display: none; }

button.mfp-close, button.mfp-arrow {
	overflow: visible;
	cursor: pointer;
	background: transparent;
	border: 0;
	-webkit-appearance: none;
	display: block;
	outline: none;
	padding: 0;
	z-index: 1046;
	-webkit-box-shadow: none;
	box-shadow: none; }

button::-moz-focus-inner {
	padding: 0;
	border: 0; }

.mfp-close {
	width: 44px;
	height: 44px;
	line-height: 44px;
	position: absolute;
	right: 0;
	top: 0;
	text-decoration: none;
	text-align: center;
	opacity: 0.65;
	filter: alpha(opacity=65);
	padding: 0 0 18px 10px;
	color: #FFF;
	font-style: normal;
	font-size: 28px;
	font-family: Arial, Baskerville, monospace; }
	.mfp-close:hover, .mfp-close:focus {
		opacity: 1;
		filter: alpha(opacity=100); }
	.mfp-close:active {
		top: 1px; }

.mfp-close-btn-in .mfp-close {
	color: #333; }

.mfp-image-holder .mfp-close,
.mfp-iframe-holder .mfp-close {
	color: #FFF;
	right: -6px;
	text-align: right;
	padding-right: 6px;
	width: 100%; }

.mfp-counter {
	position: absolute;
	top: 0;
	right: 0;
	color: #CCC;
	font-size: 12px;
	line-height: 18px;
	white-space: nowrap; }

.mfp-arrow {
	position: absolute;
	opacity: 0.65;
	filter: alpha(opacity=65);
	margin: 0;
	top: 50%;
	margin-top: -55px;
	padding: 0;
	width: 90px;
	height: 110px;
	-webkit-tap-highlight-color: rgba(0, 0, 0, 0); }
	.mfp-arrow:active {
		margin-top: -54px; }
	.mfp-arrow:hover, .mfp-arrow:focus {
		opacity: 1;
		filter: alpha(opacity=100); }
	.mfp-arrow:before, .mfp-arrow:after,
	.mfp-arrow .mfp-b,
	.mfp-arrow .mfp-a {
		content: '';
		display: block;
		width: 0;
		height: 0;
		position: absolute;
		left: 0;
		top: 0;
		margin-top: 35px;
		margin-left: 35px;
		border: medium inset transparent; }
	.mfp-arrow:after,
	.mfp-arrow .mfp-a {
		border-top-width: 13px;
		border-bottom-width: 13px;
		top: 8px; }
	.mfp-arrow:before,
	.mfp-arrow .mfp-b {
		border-top-width: 21px;
		border-bottom-width: 21px;
		opacity: 0.7; }

.mfp-arrow-left {
	left: 0; }
	.mfp-arrow-left:after,
	.mfp-arrow-left .mfp-a {
		border-right: 17px solid #FFF;
		margin-left: 31px; }
	.mfp-arrow-left:before,
	.mfp-arrow-left .mfp-b {
		margin-left: 25px;
		border-right: 27px solid #3F3F3F; }

.mfp-arrow-right {
	right: 0; }
	.mfp-arrow-right:after,
	.mfp-arrow-right .mfp-a {
		border-left: 17px solid #FFF;
		margin-left: 39px; }
	.mfp-arrow-right:before,
	.mfp-arrow-right .mfp-b {
		border-left: 27px solid #3F3F3F; }

.mfp-iframe-holder {
	padding-top: 40px;
	padding-bottom: 40px; }
	.mfp-iframe-holder .mfp-content {
		line-height: 0;
		width: 100%;
		max-width: 900px; }
	.mfp-iframe-holder .mfp-close {
		top: -40px; }

.mfp-iframe-scaler {
	width: 100%;
	height: 0;
	overflow: hidden;
	padding-top: 56.25%; }
	.mfp-iframe-scaler iframe {
		position: absolute;
		display: block;
		top: 0;
		left: 0;
		width: 100%;
		height: 100%;
		-webkit-box-shadow: 0 0 8px rgba(0, 0, 0, 0.6);
		        box-shadow: 0 0 8px rgba(0, 0, 0, 0.6);
		background: #000; }

/* Main image in popup */
img.mfp-img {
	width: auto;
	max-width: 100%;
	height: auto;
	display: block;
	line-height: 0;
	-webkit-box-sizing: border-box;
	box-sizing: border-box;
	padding: 40px 0 40px;
	margin: 0 auto; }

/* The shadow behind the image */
.mfp-figure {
	line-height: 0; }
	.mfp-figure:after {
		content: '';
		position: absolute;
		left: 0;
		top: 40px;
		bottom: 40px;
		display: block;
		right: 0;
		width: auto;
		height: auto;
		z-index: -1;
		-webkit-box-shadow: 0 0 8px rgba(0, 0, 0, 0.6);
		        box-shadow: 0 0 8px rgba(0, 0, 0, 0.6);
		background: #444; }
	.mfp-figure small {
		color: #BDBDBD;
		display: block;
		font-size: 12px;
		line-height: 14px; }
	.mfp-figure figure {
		margin: 0; }

.mfp-bottom-bar {
	margin-top: -36px;
	position: absolute;
	top: 100%;
	left: 0;
	width: 100%;
	cursor: auto; }

.mfp-title {
	text-align: left;
	line-height: 18px;
	color: #F3F3F3;
	word-wrap: break-word;
	padding-right: 36px; }

.mfp-image-holder .mfp-content {
	max-width: 100%; }

.mfp-gallery .mfp-image-holder .mfp-figure {
	cursor: pointer; }

@media screen and (max-width: 800px) and (orientation: landscape), screen and (max-height: 300px) {
	/**
       * Remove all paddings around the image on small screen
       */
	.mfp-img-mobile .mfp-image-holder {
		padding-left: 0;
		padding-right: 0; }
	.mfp-img-mobile img.mfp-img {
		padding: 0; }
	.mfp-img-mobile .mfp-figure:after {
		top: 0;
		bottom: 0; }
	.mfp-img-mobile .mfp-figure small {
		display: inline;
		margin-left: 5px; }
	.mfp-img-mobile .mfp-bottom-bar {
		background: rgba(0, 0, 0, 0.6);
		bottom: 0;
		margin: 0;
		top: auto;
		padding: 3px 5px;
		position: fixed;
		-webkit-box-sizing: border-box;
		box-sizing: border-box; }
		.mfp-img-mobile .mfp-bottom-bar:empty {
			padding: 0; }
	.mfp-img-mobile .mfp-counter {
		right: 5px;
		top: 3px; }
	.mfp-img-mobile .mfp-close {
		top: 0;
		right: 0;
		width: 35px;
		height: 35px;
		line-height: 35px;
		background: rgba(0, 0, 0, 0.6);
		position: fixed;
		text-align: center;
		padding: 0; } }

@media all and (max-width: 900px) {
	.mfp-arrow {
		-webkit-transform: scale(0.75);
		transform: scale(0.75); }
	.mfp-arrow-left {
		-webkit-transform-origin: 0;
		transform-origin: 0; }
	.mfp-arrow-right {
		-webkit-transform-origin: 100%;
		transform-origin: 100%; }
	.mfp-container {
		padding-left: 6px;
		padding-right: 6px; } }

.mfp-ie7 .mfp-img {
	padding: 0; }

.mfp-ie7 .mfp-bottom-bar {
	width: 600px;
	left: 50%;
	margin-left: -300px;
	margin-top: 5px;
	padding-bottom: 5px; }

.mfp-ie7 .mfp-container {
	padding: 0; }

.mfp-ie7 .mfp-content {
	padding-top: 44px; }

.mfp-ie7 .mfp-close {
	top: 0;
	right: 0;
	padding-top: 0; }

.mfp-close:focus, .mfp-arrow:focus {
	outline: 1px dotted #fff;
	outline-offset: -2px; }

body.wb-modal > #wb-tphp,
body.wb-modal > header,
body.wb-modal > main,
body.wb-modal > footer, body.wb-modal summary {
	visibility: hidden !important; }

.lbx-hide-gal li {
	display: none;
	list-style-type: none; }
	.lbx-hide-gal li:first-child {
		display: block; }

body.wb-modal .modal-dialog summary {
	visibility: visible !important; }

.modal-dialog {
	left: auto;
	padding: 0;
	position: relative; }

.modal-content {
	background: transparent; }

.modal-body {
	background: #fff; }

.modal-footer {
	background: #fff;
	margin-top: 0; }

.mfp-gallery .modal-body {
	padding: 20px 30px; }

.mfp-close {
	cursor: pointer !important;
	font-weight: 700;
	/* Should fix upstream in Magnific Popup rather than overriding in WET */ }

/* Should fix upstream in Magnific Popup rather than overriding in WET */
.mfp-arrow {
	opacity: 1; }

.mfp-arrow-left:before,
.mfp-arrow-left .mfp-b {
	border-right: 27px solid #000000; }

.mfp-arrow-right:before,
.mfp-arrow-right .mfp-b {
	border-left: 27px solid #000000; }

/* Should fix upstream in Magnific Popup rather than overriding in WET */
.mfp-bottom-bar .mfp-title {
	padding-right: 5px;
	width: 75%; }

.mfp-bottom-bar .mfp-counter {
	font-size: 1em;
	text-align: right;
	width: 25%; }

.wb-modal dialog {
	background-color: transparent;
	border: none; }

/*
 * Web Experience Toolkit (WET) / Boîte à outils de l'expérience Web (BOEW)
 * wet-boew.github.io/wet-boew/License-en.html / wet-boew.github.io/wet-boew/Licence-fr.html
 */
/*
 * Menu Sass
 */
.expicon {
	font-size: .7em;
	margin: 0 -.35em 0 .7em; }

.wb-menu .sm {
	display: none;
	max-height: 0;
	overflow: hidden;
	position: relative; }
	.wb-menu .sm.open {
		display: inline;
		max-height: 1000px;
		min-width: 12.5em;
		position: absolute;
		text-transform: none;
		top: auto;
		z-index: 500; }
		.wb-menu .sm.open li a {
			text-align: left; }
	.wb-menu .sm details > * {
		margin-left: auto;
		margin-right: auto; }

.wb-menu .menu {
	margin-left: 0;
	position: relative; }
	.wb-menu .menu > li {
		float: left;
		margin: 0;
		padding: 0; }
		.wb-menu .menu > li a {
			display: block;
			padding: 1em;
			text-align: center; }
			.wb-menu .menu > li a[aria-haspopup]:hover, .wb-menu .menu > li a[aria-haspopup]:focus {
				cursor: default; }

.wb-menu .sm-open .expicon {
	z-index: -1; }

.wb-menu details, .wb-menu details[open] {
	border: 0;
	margin-bottom: 0; }
	.wb-menu details summary, .wb-menu details[open] summary {
		border: 0;
		color: inherit; }
		.wb-menu details summary:focus, .wb-menu details summary:hover, .wb-menu details[open] summary:focus, .wb-menu details[open] summary:hover {
			text-decoration: none; }

#mb-pnl nav a.wb-navcurr, #mb-pnl nav summary.wb-navcurr {
	outline: 1px solid; }

#mb-pnl nav a.wb-navcurr:focus, #mb-pnl nav summary.wb-navcurr:focus {
	outline-style: dotted; }

#mb-pnl .srch-pnl, #mb-pnl nav {
	padding: 10px 20px 8px; }

#mb-pnl .srch-pnl form {
	white-space: nowrap; }

#mb-pnl .lng-ofr {
	padding: 7px 15px 0;
	text-align: right; }
	#mb-pnl .lng-ofr ul {
		margin-bottom: 0; }
	#mb-pnl .lng-ofr li {
		line-height: normal;
		padding-left: 10px;
		padding-right: 0; }
		#mb-pnl .lng-ofr li a {
			padding: 5px; }

#mb-pnl nav ul li.no-sect {
	padding-left: 1.27em; }
	#mb-pnl nav ul li.no-sect .list-group {
		margin-bottom: 0; }
	#mb-pnl nav ul li.no-sect a {
		margin: 0 0 0 -6px; }

#mb-pnl nav .mb-menu > li {
	padding: 10px 0 2px; }

#mb-pnl nav a {
	display: inline-block;
	margin: 6px 0 6px -6px;
	padding: 0 6px;
	width: 100%; }

#mb-pnl nav summary {
	padding-left: 3px; }
	#mb-pnl nav summary.wb-navcurr:focus {
		outline-offset: -2px; }

#mb-pnl details[open] {
	padding-bottom: 0; }

#mb-pnl details ul {
	padding-left: 1.2em; }

#mb-pnl details details {
	margin: 6px 0 6px -1.28em; }

.wb-disable #wb-glb-mn {
	display: none !important; }

.wb-disable #wb-sm .menu {
	background: #0e4164; }

[dir=rtl] .wb-menu .menu {
	padding-right: 0; }
	[dir=rtl] .wb-menu .menu > li {
		float: right; }

[dir=rtl] .wb-menu .sm.open li a {
	text-align: right; }

[dir=rtl] .expicon {
	margin: 0 .7em 0 -.35em; }

[dir=rtl] #mb-pnl .lng-ofr {
	text-align: left; }
	[dir=rtl] #mb-pnl .lng-ofr li {
		padding-left: 0;
		padding-right: 10px; }

[dir=rtl] #mb-pnl nav ul li.no-sect {
	padding-left: 0;
	padding-right: 1.27em; }

[dir=rtl] #mb-pnl nav a {
	margin-left: 0;
	margin-right: -6px; }

[dir=rtl] #mb-pnl nav summary {
	margin-left: 0;
	margin-right: -3px;
	padding-left: 0;
	padding-right: 3px; }

[dir=rtl] #mb-pnl details ul {
	padding-left: 0;
	padding-right: .7em; }

/*
  Multimedia Player Code
 */
.wb-mltmd.audio .lastpnl, .wb-mltmd.youtube.cc_on .wb-mm-cc {
	display: none; }

.wb-mm-ctrls .btn:focus, .wb-mm-ctrls progress:focus, .wb-mm-ctrls input:focus[type=range] {
	outline: 1px solid #4aafff; }

.wb-mm-ctrls .fd-slider-bar, .wb-mm-ctrls .fd-slider-range {
	background: #aaa;
	border: 0; }

.xxsmallview .wb-mm-ctrls .frstpnl, .xxsmallview .wb-mm-ctrls .lastpnl {
	padding-top: 2em; }

.wb-mltmd video, .wb-mltmd object,
.wb-mltmd iframe {
	display: block;
	width: 100%; }

.wb-mm-cc {
	max-height: 0;
	padding: 0; }

.wb-mm-cc:before, .wb-mm-cc div {
	display: table-cell;
	height: 2.875em;
	vertical-align: middle; }

.wb-mltmd {
	display: block;
	position: relative;
	/*
	  Light Skinning of mediacontrols
	 */ }
	.wb-mltmd.video:not(.playing):not(.waiting) .display {
		cursor: pointer;
		position: relative; }
	.wb-mltmd.video:not(.playing):not(.waiting) .display:before {
		text-align: center; }
	.wb-mltmd.video:not(.playing):not(.waiting) .display:after {
		color: #fff;
		content: "";
		font-family: "Glyphicons Halflings";
		font-size: 65px;
		text-align: center; }
	.wb-mltmd.video.waiting .display {
		position: relative; }
		.wb-mltmd.video.waiting .display:before, .wb-mltmd.video.waiting .display:after {
			display: block; }
	.wb-mltmd.audio object {
		position: absolute; }
	.wb-mltmd video {
		height: auto;
		width: 100%; }
	.wb-mltmd.cc_on .wb-mm-cc {
		display: table;
		height: calc(2.875em + 1em);
		padding: 0.5em; }
	.wb-mltmd.cc_on:not(.errmsg) .cc:after {
		border-bottom: 3px solid #4aafff;
		content: " ";
		display: block;
		margin-left: -2px;
		width: 1.2em; }
	.wb-mltmd.youtube.video:not(.playing):not(.waiting) .display:before {
		background: #3e3e3e; }
	.wb-mltmd.skn-lt {
		border-bottom: 1px solid #ddd;
		color: #000; }
		.wb-mltmd.skn-lt .wb-mm-ctrls {
			background: #fff;
			color: #000; }
			.wb-mltmd.skn-lt .wb-mm-ctrls .btn {
				background: #fff;
				border: 0;
				color: #000; }
				.wb-mltmd.skn-lt .wb-mm-ctrls .btn[disabled]:active:hover {
					color: #000; }
	.wb-mltmd .wb-share {
		text-align: right; }
	.wb-mltmd summary,
	.wb-mltmd details[open] {
		border-top-left-radius: 0;
		border-top-right-radius: 0; }

.wb-mm-cc {
	background-color: #000;
	color: #fff;
	text-align: center;
	-webkit-transition: all .26s ease;
	transition: all .26s ease;
	width: 100%; }
	.wb-mm-cc:before {
		content: " "; }

.wb-mm-ctrls .frstpnl, .wb-mm-ctrls .lastpnl, .wb-mm-ctrls .tline {
	display: table-cell;
	vertical-align: middle; }

.wb-mm-ctrls {
	background: #3e3e3e;
	color: #fff;
	display: table;
	padding-top: 2em;
	position: relative;
	width: 100%;
	/* Progress Bar */
	/* Slider polyfill styles */ }
	.wb-mm-ctrls .btn {
		background: transparent;
		border: 0;
		border-top-left-radius: 0 !important;
		border-top-right-radius: 0 !important;
		color: #fff;
		font-size: 130%; }
		.wb-mm-ctrls .btn[disabled]:active:hover {
			color: #fff; }
		.wb-mm-ctrls .btn[disabled]:hover {
			background-color: transparent; }
	.wb-mm-ctrls .frstpnl {
		text-align: center;
		width: 13em; }
	.wb-mm-ctrls .lastpnl {
		text-align: center;
		width: 3em; }
	.wb-mm-ctrls .tline .wb-mm-tmln-crrnt:after {
		content: " / ";
		padding: 0 .5em; }
	.wb-mm-ctrls .wb-mm-txtonly {
		padding: 0 1em; }
		.wb-mm-ctrls .wb-mm-txtonly p {
			display: inline; }
	.wb-mm-ctrls .wb-mm-txtonly,
	.wb-mm-ctrls .wb-mm-prgrss {
		display: table-cell;
		vertical-align: middle; }
	.wb-mm-ctrls progress {
		/* Important Thing */
		-webkit-appearance: none;
		background: #fff;
		background-clip: padding-box;
		border: 7px solid #3e3e3e;
		border-radius: 14px;
		color: #176ca7;
		display: block;
		height: 30px;
		left: 0;
		padding: 2px;
		position: absolute;
		top: 0;
		width: 100%; }
		.wb-mm-ctrls progress.wb-progress-inited {
			overflow: hidden;
			padding: 0; }
		.wb-mm-ctrls progress::-webkit-progress-bar {
			background: #fff; }
		.wb-mm-ctrls progress::-webkit-progress-value {
			background: #176ca7;
			border-radius: 7px; }
		.wb-mm-ctrls progress::-moz-progress-bar {
			background: #176ca7;
			border-radius: 7px; }
	.wb-mm-ctrls .progress {
		height: 22px; }
	.wb-mm-ctrls input[type=range] {
		-webkit-appearance: none;
		background: transparent;
		display: inline-block;
		height: 2.5em;
		padding: 0;
		width: 7em; }
		.wb-mm-ctrls input[type=range]:focus {
			/* Prevent Webkit/Blink browsers from defaulting to a -2px outline offset. */
			outline-offset: 0; }
		.wb-mm-ctrls input[type=range]::-webkit-slider-runnable-track {
			background: #aaa;
			height: 4px; }
		.wb-mm-ctrls input[type=range]::-webkit-slider-thumb {
			-webkit-appearance: none;
			background: #fff;
			border: 1px solid #707070;
			-webkit-box-sizing: content-box;
			        box-sizing: content-box;
			height: 1.3em;
			margin-top: -9px;
			width: 10px; }
		.wb-mm-ctrls input[type=range]::-moz-range-track {
			background: #aaa;
			border: 0; }
		.wb-mm-ctrls input[type=range]::-moz-range-thumb {
			background: #fff;
			border: 1px solid #707070;
			border-radius: 0;
			height: 1.3em;
			width: 10px; }
		.wb-mm-ctrls input[type=range]::-ms-track {
			border: 0;
			color: transparent;
			height: 4px; }
		.wb-mm-ctrls input[type=range]::-ms-fill-upper {
			background: #aaa; }
		.wb-mm-ctrls input[type=range]::-ms-fill-lower {
			background: #aaa; }
		.wb-mm-ctrls input[type=range]::-ms-thumb {
			background: #fff;
			border: 1px solid #707070;
			height: 1.3em;
			width: 10px; }
	.wb-mm-ctrls .fd-slider {
		display: inline-block;
		height: 100%;
		margin-top: 10px;
		width: 7em; }
	.wb-mm-ctrls .fd-slider-handle {
		background: #fff;
		border: 1px solid #707070;
		-webkit-box-sizing: content-box;
		        box-sizing: content-box;
		width: 10px; }

.xxsmallview .wb-mm-ctrls .wb-mm-txtonly {
	left: 0;
	margin-top: -2em;
	position: absolute; }

/*
 *
 * Web Experience Toolkit (WET) / Boîte à outils de l'expérience Web (BOEW)
 * wet-boew.github.io/wet-boew/License-en.html / wet-boew.github.io/wet-boew/Licence-fr.html
 *
 * @title: Multimedia player overrides
 *
 */
.wb-mltmd {
	margin-bottom: 10px;
	margin-top: 10px; }
	.wb-mltmd.cc_on .wb-mm-cc {
		height: calc(3.3em + 1em); }

.wb-mltmd.video:not(.playing):not(.waiting) .display::after {
	line-height: 1.5em; }

.wb-mm-cc:before,
.wb-mm-cc div {
	height: 3.3em; }

.wb-mm-ctrls .wb-mm-txtonly p {
	white-space: nowrap; }

/*
 * Web Experience Toolkit (WET) / Boîte à outils de l'expérience Web (BOEW)
 * wet-boew.github.io/wet-boew/License-en.html / wet-boew.github.io/wet-boew/Licence-fr.html
 */
/*
 *	Overlay base
 */
.wb-overlay {
	background-clip: border-box;
	background-color: #fff;
	border: 0;
	border-radius: 0;
	display: none;
	-webkit-transform: translateZ(0);
	        transform: translateZ(0);
	z-index: 1050; }
	.wb-overlay.wb-inview {
		display: block; }
	.wb-overlay.open {
		display: inline-block;
		position: fixed; }

.wb-panel-l, .wb-panel-r {
	height: 100%;
	max-width: 90%;
	top: 0; }

.wb-bar-t, .wb-bar-b {
	border-bottom: 0;
	left: 0;
	max-height: 90%;
	min-width: 100%; }

.wb-popup-mid {
	max-height: 90%;
	max-width: 90%; }

/*
 *	Overlay styles
 */
.wb-panel-l {
	left: 0; }

.wb-panel-r {
	right: 0; }

.wb-bar-t {
	top: 0; }

.wb-bar-b {
	bottom: 0; }

.wb-popup-mid {
	border-radius: 6px;
	bottom: 0;
	left: 0;
	margin: auto;
	right: 0;
	top: 0;
	width: 90%; }

.wb-popup-full {
	height: 100%;
	left: 0;
	top: 0;
	width: 100%; }

.mfp-bg {
	opacity: .97; }

.wb-overlay-dlg {
	overflow: hidden; }
	.wb-overlay-dlg .overlay-bg {
		-webkit-box-shadow: 0 0 1000px 1000px black;
		        box-shadow: 0 0 1000px 1000px black; }

/*
 *	Overlay parts
 */
.overlay-def {
	overflow-y: auto; }
	.overlay-def header {
		background-color: #2e5274;
		color: #fff;
		display: block;
		padding: 0 44px 0 1em; }
	.overlay-def .modal-title {
		font-size: 1.15em;
		padding: 10px 0; }
	.overlay-def.wb-bar-t, .overlay-def.wb-bar-b {
		background-color: #000; }
		.overlay-def.wb-bar-t header, .overlay-def.wb-bar-b header {
			background-color: #000; }
	.overlay-def .mfp-close {
		color: #fff; }

.hidden-hd .modal-body {
	padding-top: 50px; }

.hidden-hd .overlay-close:not(.btn) {
	background-color: #000;
	border-radius: 999px;
	height: 1em;
	line-height: 1em;
	margin-right: 20px;
	margin-top: 10px;
	width: 1em; }

[dir=rtl] .mfp-close {
	left: 0;
	right: auto; }

[dir=rtl] .wb-panel-l {
	left: auto;
	right: 0; }

[dir=rtl] .wb-panel-r {
	left: 0;
	right: auto; }

[dir=rtl] .overlay-def header {
	padding: 0 1em 0 44px; }

/*
 * Overlay-specific overrides
 */
.overlay-def header {
	background: #26374a; }

/*
 * Web Experience Toolkit (WET) / Boîte à outils de l'expérience Web (BOEW)
 * wet-boew.github.io/wet-boew/License-en.html / wet-boew.github.io/wet-boew/Licence-fr.html
 */
/* Pretty printing styles. Used with prettify.js. */
/* SPAN elements with the classes below are added by prettyprint. */
/* plain text */
.pln {
	color: #000; }

pre.prettyprint {
	background-color: #f5f5f5;
	border: 1px solid #ddd;
	color: #707070;
	font-size: 95%;
	padding: 8px;
	/* Specify class=linenums on a pre to get line numbering */ }
	pre.prettyprint.linenums {
		-webkit-box-shadow: 40px 0 0 #fbfbfc inset, 41px 0 0 #eee inset;
		        box-shadow: 40px 0 0 #fbfbfc inset, 41px 0 0 #eee inset; }
	pre.prettyprint code {
		-moz-tab-size: 20px;
		  -o-tab-size: 20px;
		     tab-size: 20px; }
		pre.prettyprint code ins {
			font-weight: bold;
			text-decoration: none; }

ol.linenums {
	margin: 0 !important; }
	ol.linenums li {
		padding-left: 10px;
		text-shadow: 0 1px 0 #fff; }

/* Right to left (RTL) CSS */
[dir="rtl"] pre.prettyprint {
	direction: ltr; }

/*
 * Web Experience Toolkit (WET) / Boîte à outils de l'expérience Web (BOEW)
 * wet-boew.github.io/wet-boew/License-en.html / wet-boew.github.io/wet-boew/Licence-fr.html
 */
#wb-rsz {
	clip: rect(1px, 1px, 1px, 1px);
	margin: 0;
	overflow: hidden;
	position: absolute;
	top: -1000px; }

/*
 * Web Experience Toolkit (WET) / Boîte à outils de l'expérience Web (BOEW)
 * wet-boew.github.io/wet-boew/License-en.html / wet-boew.github.io/wet-boew/Licence-fr.html
 */
.shr-opn span {
	padding-right: .2em; }

.shr-pg .shr-lnk {
	font-size: 115%;
	line-height: 32px;
	margin-bottom: 8px;
	min-height: 32px;
	text-align: left;
	text-decoration: none;
	width: 100%; }
	.shr-pg .shr-lnk:before {
		content: " ";
		display: inline-block;
		height: 32px;
		margin-right: .6em;
		vertical-align: middle;
		width: 32px; }

.shr-pg .blogger:before {
	background-image: url(../../wet-boew/assets/sprites_share.png);
	background-position: 0px 0px;
	width: 32px;
	height: 32px; }

.shr-pg .diigo:before {
	background-image: url(../../wet-boew/assets/sprites_share.png);
	background-position: -32px 0px;
	width: 32px;
	height: 32px; }

.shr-pg .facebook:before {
	background-image: url(../../wet-boew/assets/sprites_share.png);
	background-position: 0px -32px;
	width: 32px;
	height: 32px; }

.shr-pg .feed:before {
	background-image: url(../../wet-boew/assets/sprites_share.png);
	background-position: -32px -32px;
	width: 32px;
	height: 32px; }

.shr-pg .gmail:before {
	background-image: url(../../wet-boew/assets/sprites_share.png);
	background-position: -64px 0px;
	width: 32px;
	height: 32px; }

.shr-pg .linkedin:before {
	background-image: url(../../wet-boew/assets/sprites_share.png);
	background-position: -64px -32px;
	width: 32px;
	height: 32px; }

.shr-pg .myspace:before {
	background-image: url(../../wet-boew/assets/sprites_share.png);
	background-position: 0px -64px;
	width: 32px;
	height: 32px; }

.shr-pg .pinterest:before {
	background-image: url(../../wet-boew/assets/sprites_share.png);
	background-position: -32px -64px;
	width: 32px;
	height: 32px; }

.shr-pg .reddit:before {
	background-image: url(../../wet-boew/assets/sprites_share.png);
	background-position: -64px -64px;
	width: 32px;
	height: 32px; }

.shr-pg .tinyurl:before {
	background-image: url(../../wet-boew/assets/sprites_share.png);
	background-position: -96px 0px;
	width: 32px;
	height: 32px; }

.shr-pg .tumblr:before {
	background-image: url(../../wet-boew/assets/sprites_share.png);
	background-position: -96px -32px;
	width: 32px;
	height: 32px; }

.shr-pg .twitter:before {
	background-image: url(../../wet-boew/assets/sprites_share.png);
	background-position: -96px -64px;
	width: 32px;
	height: 32px; }

.shr-pg .whatsapp:before {
	background-image: url(../../wet-boew/assets/sprites_share.png);
	background-position: 0px -96px;
	width: 32px;
	height: 32px; }

.shr-pg .yahoomail:before {
	background-image: url(../../wet-boew/assets/sprites_share.png);
	background-position: -32px -96px;
	width: 32px;
	height: 32px; }

.shr-pg .shr-dscl {
	padding-bottom: 0; }

.shr-pg .email:before {
	content: "\2709";
	display: inline-block;
	font-family: "Glyphicons Halflings";
	font-size: 32px;
	margin-right: .3em; }

.shr-pg .shr-pg {
	text-align: left; }

.shr-pg ul {
	list-style-type: none;
	margin: 10px;
	padding: 0; }

[dir=rtl] .shr-opn span {
	padding-left: .2em;
	padding-right: 0; }

[dir=rtl] .shr-pg {
	text-align: right; }
	[dir=rtl] .shr-pg .shr-lnk {
		text-align: right; }
		[dir=rtl] .shr-pg .shr-lnk:before {
			margin-left: .4em;
			margin-right: auto; }

[dir=rtl] .email:before {
	margin-left: .6em;
	margin-right: auto; }

/*
* Web Experience Toolkit (WET) / Boîte à outils de l'expérience Web (BOEW)
* wet-boew.github.io/wet-boew/License-en.html / wet-boew.github.io/wet-boew/Licence-fr.html
*/
.provisional.wb-steps {
	counter-reset: fieldset_counter; }
	.provisional.wb-steps .wb-tggle-fildst > legend:before {
		content: counter(fieldset_counter) ". ";
		counter-increment: fieldset_counter; }
	.provisional.wb-steps .wb-tggle-fildst > legend.wb-steps-active {
		color: #1c578a; }
	.provisional.wb-steps .wb-tggle-fildst > legend.wb-steps-error {
		color: #942826; }
	.provisional.wb-steps .steps-wrapper {
		border-bottom: 1px solid #c0c0c0; }
	.provisional.wb-steps .subfields {
		border: 0; }

/*
 * Web Experience Toolkit (WET) / Boîte à outils de l'expérience Web (BOEW)
 * wet-boew.github.io/wet-boew/License-eng.html / wet-boew.github.io/wet-boew/Licence-fra.html
 */
table.dataTable, .dataTables_wrapper .dataTables_scroll {
	clear: both; }

table.dataTable thead th:active, table.dataTable thead td:active {
	outline: none; }

.dataTables_wrapper .dataTables_filter, .dataTables_wrapper .dataTables_length {
	font-weight: 400; }

table.dataTable thead th, table.dataTable tfoot th {
	font-weight: 700; }

table.dataTable thead th, table.dataTable thead td, table.dataTable tfoot th, table.dataTable tfoot td, table.dataTable.no-footer, .dataTables_wrapper.no-footer .dataTables_scrollBody {
	border-bottom: 1px solid #111; }

table.dataTable th.right, table.dataTable td.right {
	text-align: right; }

table.dataTable th.center, table.dataTable td.center, table.dataTable td.dataTables_empty {
	text-align: center; }

table.dataTable.rowborder tbody th,
table.dataTable.rowborder tbody td, table.dataTable.display tbody th,
table.dataTable.display tbody td {
	border-top: 1px solid #ddd; }

table.dataTable.rowborder tbody tr:first-child th,
table.dataTable.rowborder tbody tr:first-child td, table.dataTable.display tbody tr:first-child th,
table.dataTable.display tbody tr:first-child td, table.dataTable.cell-border tbody tr:first-child th,
table.dataTable.cell-border tbody tr:first-child td {
	border-top: 0; }

table.dataTable.cell-border tbody th,
table.dataTable.cell-border tbody td {
	border-right: 1px solid #ddd;
	border-top: 1px solid #ddd; }

table.dataTable.cell-border tbody tr th:first-child,
table.dataTable.cell-border tbody tr td:first-child {
	border-left: 1px solid #ddd; }

.dataTables_wrapper .dataTables_filter, .dataTables_wrapper .dataTables_length, .dataTables_wrapper .dataTables_info, .dataTables_wrapper .dataTables_processing {
	color: #333; }

table.dataTable.display tbody tr:hover.selected > .sorting_1, table.dataTable.display tbody tr.odd:hover.selected > .sorting_1, table.dataTable.display tbody tr.even:hover.selected > .sorting_1, table.dataTable.order-column.hover tbody tr:hover.selected > .sorting_1, table.dataTable.order-column.hover tbody tr.odd:hover.selected > .sorting_1, table.dataTable.order-column.hover tbody tr.even:hover.selected > .sorting_1 {
	background-color: #a1aec7; }

table.dataTable.display tbody tr:hover.selected > .sorting_2, table.dataTable.display tbody tr.odd:hover.selected > .sorting_2, table.dataTable.display tbody tr.even:hover.selected > .sorting_2, table.dataTable.order-column.hover tbody tr:hover.selected > .sorting_2, table.dataTable.order-column.hover tbody tr.odd:hover.selected > .sorting_2, table.dataTable.order-column.hover tbody tr.even:hover.selected > .sorting_2 {
	background-color: #a2afc8; }

table.dataTable.display tbody tr:hover.selected > .sorting_3, table.dataTable.display tbody tr.odd:hover.selected > .sorting_3, table.dataTable.display tbody tr.even:hover.selected > .sorting_3, table.dataTable.order-column.hover tbody tr:hover.selected > .sorting_3, table.dataTable.order-column.hover tbody tr.odd:hover.selected > .sorting_3, table.dataTable.order-column.hover tbody tr.even:hover.selected > .sorting_3 {
	background-color: #a4b2cb; }

table.dataTable.display tbody tr.odd.selected > .sorting_1, table.dataTable.order-column.stripe tbody tr.odd.selected > .sorting_1 {
	background-color: #a6b3cd; }

table.dataTable.display tbody tr.odd.selected > .sorting_2, table.dataTable.order-column.stripe tbody tr.odd.selected > .sorting_2 {
	background-color: #a7b5ce; }

table.dataTable.display tbody tr.odd.selected > .sorting_3, table.dataTable.order-column.stripe tbody tr.odd.selected > .sorting_3 {
	background-color: #a9b6d0; }

table.dataTable.display tbody tr.selected:hover, table.dataTable.display tbody tr.odd.selected:hover, table.dataTable.display tbody tr.even.selected:hover, table.dataTable.hover tbody tr.selected:hover, table.dataTable.hover tbody tr.odd.selected:hover, table.dataTable.hover tbody tr.even.selected:hover {
	background-color: #a9b7d1; }

table.dataTable.display tbody tr.odd.selected, table.dataTable.stripe tbody tr.odd.selected {
	background-color: #abb9d3; }

table.dataTable.display tbody tr.even.selected > .sorting_1, table.dataTable.display tbody tr.selected > .sorting_1, table.dataTable.display tbody tr.selected > .sorting_2, table.dataTable.display tbody tr.selected > .sorting_3, table.dataTable.order-column tbody tr.selected > .sorting_1, table.dataTable.order-column tbody tr.selected > .sorting_2, table.dataTable.order-column tbody tr.selected > .sorting_3, table.dataTable.order-column.stripe tbody tr.even.selected > .sorting_1 {
	background-color: #acbad4; }

table.dataTable.display tbody tr.even.selected > .sorting_2, table.dataTable.order-column.stripe tbody tr.even.selected > .sorting_2 {
	background-color: #adbbd6; }

table.dataTable.display tbody tr.even.selected > .sorting_3, table.dataTable.order-column.stripe tbody tr.even.selected > .sorting_3 {
	background-color: #afbdd8; }

table.dataTable thead .sorting_asc, table.dataTable thead .sorting_desc {
	background-color: #e7e7e7; }

table.dataTable.display tbody tr:hover > .sorting_1, table.dataTable.display tbody tr.odd:hover > .sorting_1, table.dataTable.display tbody tr.even:hover > .sorting_1, table.dataTable.order-column.hover tbody tr:hover > .sorting_1, table.dataTable.order-column.hover tbody tr.odd:hover > .sorting_1, table.dataTable.order-column.hover tbody tr.even:hover > .sorting_1 {
	background-color: #eaeaea; }

table.dataTable.display tbody tr:hover > .sorting_2, table.dataTable.display tbody tr.odd:hover > .sorting_2, table.dataTable.display tbody tr.even:hover > .sorting_2, table.dataTable.order-column.hover tbody tr:hover > .sorting_2, table.dataTable.order-column.hover tbody tr.odd:hover > .sorting_2, table.dataTable.order-column.hover tbody tr.even:hover > .sorting_2 {
	background-color: #ebebeb; }

table.dataTable.display tbody tr:hover > .sorting_3, table.dataTable.display tbody tr.odd:hover > .sorting_3, table.dataTable.display tbody tr.even:hover > .sorting_3, table.dataTable.order-column.hover tbody tr:hover > .sorting_3, table.dataTable.order-column.hover tbody tr.odd:hover > .sorting_3, table.dataTable.order-column.hover tbody tr.even:hover > .sorting_3 {
	background-color: #eee; }

table.dataTable.display tbody tr.odd > .sorting_1, table.dataTable.order-column.stripe tbody tr.odd > .sorting_1 {
	background-color: #f1f1f1; }

table.dataTable.display tbody tr.odd > .sorting_2, table.dataTable.order-column.stripe tbody tr.odd > .sorting_2 {
	background-color: #f3f3f3; }

table.dataTable.display tbody tr:hover, table.dataTable.display tbody tr.odd:hover, table.dataTable.display tbody tr.odd > .sorting_3, table.dataTable.display tbody tr.even:hover, table.dataTable.hover tbody tr:hover, table.dataTable.hover tbody tr.odd:hover, table.dataTable.hover tbody tr.even:hover, table.dataTable.order-column.stripe tbody tr.odd > .sorting_3 {
	background-color: #f5f5f5; }

table.dataTable.display tbody tr.odd, table.dataTable.display tbody tr.even > .sorting_1, table.dataTable.display tbody tr > .sorting_1, table.dataTable.display tbody tr > .sorting_2, table.dataTable.display tbody tr > .sorting_3, table.dataTable.stripe tbody tr.odd, table.dataTable.order-column tbody tr > .sorting_1, table.dataTable.order-column tbody tr > .sorting_2, table.dataTable.order-column tbody tr > .sorting_3, table.dataTable.order-column.stripe tbody tr.even > .sorting_1 {
	background-color: #f9f9f9; }

table.dataTable.display tbody tr.even > .sorting_2, table.dataTable.order-column.stripe tbody tr.even > .sorting_2 {
	background-color: #fbfbfb; }

table.dataTable.display tbody tr.even > .sorting_3, table.dataTable.order-column.stripe tbody tr.even > .sorting_3 {
	background-color: #fdfdfd; }

table.dataTable, table.dataTable th, table.dataTable td {
	-webkit-box-sizing: content-box;
	        box-sizing: content-box; }

table.dataTable thead .sorting .sorting-icons:before, table.dataTable thead .sorting .sorting-icons:after, table.dataTable thead .sorting_asc .sorting-icons:after, table.dataTable thead .sorting_desc .sorting-icons:before {
	background: #fff;
	border: 1px solid #aaa;
	color: #757575; }

table.dataTable thead .sorting_asc .sorting-icons:before, table.dataTable thead .sorting_desc .sorting-icons:after {
	background: #ccc;
	border: 1px solid #111;
	color: #000; }

table.dataTable thead .sorting, table.dataTable thead .sorting_asc, table.dataTable thead .sorting_desc {
	cursor: pointer; }

table.dataTable thead .sorting .sorting-icons, table.dataTable thead .sorting_asc .sorting-icons, table.dataTable thead .sorting_desc .sorting-icons, table.dataTable thead .sorting_asc_disabled .sorting-icons, table.dataTable thead .sorting_desc_disabled .sorting-icons {
	display: inline-block; }

/*
 * Table styles
 */
table.dataTable {
	border-collapse: separate;
	border-spacing: 0;
	margin: 0 auto;
	width: 100% !important; }
	table.dataTable thead button {
		-webkit-appearance: none;
		   -moz-appearance: none;
		        appearance: none;
		background: transparent;
		border: 0;
		font-family: inherit;
		padding: 0;
		text-align: left; }
	table.dataTable thead .sorting-cnt {
		white-space: nowrap; }
		table.dataTable thead .sorting-cnt:before {
			content: " "; }
	table.dataTable thead .sorting-icons {
		margin-top: 2px; }
		table.dataTable thead .sorting-icons:before {
			content: "\e093";
			padding: 0 .1em 0 0; }
		table.dataTable thead .sorting-icons:after {
			content: "\e094";
			padding: 0 .04em 0 .06em; }
	table.dataTable tbody tr {
		background-color: #fff; }
		table.dataTable tbody tr.selected {
			background-color: #b0bed9; }

/*
 * Control feature layout
 */
.dataTables_wrapper .dataTables_scroll div.dataTables_scrollBody th > div.dataTables_sizing,
.dataTables_wrapper .dataTables_scroll div.dataTables_scrollBody td > div.dataTables_sizing {
	height: 0;
	margin: 0 !important;
	overflow: hidden;
	padding: 0 !important; }

.dataTables_wrapper .dataTables_paginate .paginate_button.previous, .dataTables_wrapper .dataTables_paginate .paginate_button.current:first-child {
	border-top-left-radius: 4px;
	border-bottom-left-radius: 4px;
	margin-left: 0; }

.dataTables_wrapper .dataTables_paginate .paginate_button.next, .dataTables_wrapper .dataTables_paginate .paginate_button.current:last-child {
	border-top-right-radius: 4px;
	border-bottom-right-radius: 4px; }

.dataTables_wrapper {
	clear: both;
	position: relative;
	zoom: 1; }
	.dataTables_wrapper .dataTables_filter {
		float: left;
		margin-right: 15px; }
		.dataTables_wrapper .dataTables_filter input {
			margin-left: .5em; }
	.dataTables_wrapper .dataTables_length {
		display: inline-block;
		margin-top: 5px; }
	.dataTables_wrapper .dataTables_info {
		display: inline-block; }
	.dataTables_wrapper .dataTables_paginate {
		padding-top: 1.25em;
		text-align: center; }
		.dataTables_wrapper .dataTables_paginate .paginate_button {
			background-color: #eaebed;
			border: 1px solid #dcdee1;
			color: #335075;
			cursor: pointer;
			display: inline-block;
			line-height: 1.4375;
			margin-bottom: .5em;
			margin-left: -1px;
			padding: 10px 16px;
			position: relative;
			text-decoration: none; }
			.dataTables_wrapper .dataTables_paginate .paginate_button.current {
				background-color: #2572b4;
				border-color: #2572b4;
				color: #fff;
				cursor: default;
				z-index: 2; }
			.dataTables_wrapper .dataTables_paginate .paginate_button:hover, .dataTables_wrapper .dataTables_paginate .paginate_button:focus, .dataTables_wrapper .dataTables_paginate .paginate_button:active {
				background-color: #d4d6da;
				border-color: #bbbfc5;
				color: #335075; }
	.dataTables_wrapper .dataTables_processing {
		background: -webkit-gradient(linear, left top, right top, from(rgba(255, 255, 255, 0)), color-stop(25%, rgba(255, 255, 255, 0.9)), color-stop(75%, rgba(255, 255, 255, 0.9)), to(rgba(255, 255, 255, 0)));
		background: linear-gradient(to right, rgba(255, 255, 255, 0) 0%, rgba(255, 255, 255, 0.9) 25%, rgba(255, 255, 255, 0.9) 75%, rgba(255, 255, 255, 0) 100%);
		background-color: #fff;
		font-size: 1.2em;
		height: 40px;
		left: 50%;
		margin-left: -50%;
		margin-top: -25px;
		padding-top: 20px;
		position: absolute;
		text-align: center;
		top: 50%;
		width: 100%; }
	.dataTables_wrapper .dataTables_scroll div.dataTables_scrollBody {
		-webkit-overflow-scrolling: touch; }
	.dataTables_wrapper.no-footer div.dataTables_scrollHead table, .dataTables_wrapper.no-footer div.dataTables_scrollBody table {
		border-bottom: 0; }
	.dataTables_wrapper:after {
		clear: both;
		content: "";
		display: block;
		height: 0;
		visibility: hidden; }

[dir=rtl] table.dataTable thead .sorting,
[dir=rtl] table.dataTable thead .sorting_asc,
[dir=rtl] table.dataTable thead .sorting_desc,
[dir=rtl] table.dataTable thead .sorting_asc_disabled,
[dir=rtl] table.dataTable thead .sorting_desc_disabled {
	text-align: right; }

[dir=rtl] table.dataTable thead .sorting:after,
[dir=rtl] table.dataTable thead .sorting_asc:after,
[dir=rtl] table.dataTable thead .sorting_desc:after,
[dir=rtl] table.dataTable thead .sorting_asc_disabled:after,
[dir=rtl] table.dataTable thead .sorting_desc_disabled:after {
	margin-left: 0;
	margin-right: 5px; }

[dir=rtl] .dataTables_wrapper .dataTables_paginate .paginate_button.previous, [dir=rtl] .dataTables_wrapper .dataTables_paginate .paginate_button.current:first-child {
	border-top-left-radius: 0;
	border-bottom-left-radius: 0;
	border-top-right-radius: 4px;
	border-bottom-right-radius: 4px; }

[dir=rtl] .dataTables_wrapper .dataTables_paginate .paginate_button.next, [dir=rtl] .dataTables_wrapper .dataTables_paginate .paginate_button.current:last-child {
	border-top-left-radius: 4px;
	border-bottom-left-radius: 4px;
	border-top-right-radius: 0;
	border-bottom-right-radius: 0; }

[dir=rtl] .dataTables_wrapper .dataTables_info,
[dir=rtl] .dataTables_wrapper .dataTables_length {
	float: right; }

[dir=rtl] .dataTables_wrapper .dataTables_filter {
	float: left;
	text-align: left; }
	[dir=rtl] .dataTables_wrapper .dataTables_filter input {
		margin-left: auto;
		margin-right: .5em; }

/*
 *
 * Web Experience Toolkit (WET) / Boîte à outils de l'expérience Web (BOEW)
 * wet-boew.github.io/wet-boew/License-en.html / wet-boew.github.io/wet-boew/Licence-fr.html
 *
 * @title: Data table overrides
 *
 */
.dataTables_wrapper .top {
	font-size: 17px; }

.dataTables_wrapper .top [type=search] {
	max-width: 205px; }

/*
 * Web Experience Toolkit (WET) / Boîte à outils de l'expérience Web (BOEW)
 * wet-boew.github.io/wet-boew/License-en.html / wet-boew.github.io/wet-boew/Licence-fr.html
 */
.wb-tabs [role="tablist"].allow-wrap li, .wb-tabs.carousel-s1 [role="tablist"] > li, .wb-tabs.carousel-s2 [role="tablist"] > li {
	margin: 0 10px 0 0; }

.wb-tabs, .wb-tabs.carousel-s1 figure, .wb-tabs.carousel-s2 figure {
	position: relative; }

.wb-tabs.carousel-s1 [role="tablist"] > li, .wb-tabs.carousel-s2 [role="tablist"] > li {
	z-index: 100; }

.wb-tabs.carousel-s1 figure, .wb-tabs.carousel-s2 figure {
	background: #243850;
	background: rgba(36, 56, 80, 0.9); }
	.wb-tabs.carousel-s1 figure img, .wb-tabs.carousel-s2 figure img {
		height: auto;
		width: 100%; }

.wb-tabs.carousel-s1 figcaption, .wb-tabs.carousel-s2 figcaption {
	bottom: 0;
	color: #fff;
	left: 0;
	padding: .5em 1em;
	position: relative;
	right: 0;
	z-index: 101; }

.wb-tabs.carousel-s1 [role="tabpanel"] a figure::before, .wb-tabs.carousel-s2 [role="tabpanel"] a figure::before, .wb-tabs.carousel-s1 [role="tabpanel"] a figure::after, .wb-tabs.carousel-s2 [role="tabpanel"] a figure::after {
	content: "";
	outline: inherit;
	position: absolute; }

.wb-tabs.carousel-s1 [role="tabpanel"] a, .wb-tabs.carousel-s2 [role="tabpanel"] a {
	color: #000;
	outline-offset: 0; }
	.wb-tabs.carousel-s1 [role="tabpanel"] a figure, .wb-tabs.carousel-s2 [role="tabpanel"] a figure {
		outline: inherit; }
		.wb-tabs.carousel-s1 [role="tabpanel"] a figure::before, .wb-tabs.carousel-s2 [role="tabpanel"] a figure::before {
			height: calc(100% - 4px);
			margin: 2px;
			outline-color: #fff;
			width: calc(100% - 4px); }
		.wb-tabs.carousel-s1 [role="tabpanel"] a figure::after, .wb-tabs.carousel-s2 [role="tabpanel"] a figure::after {
			height: calc(100% - 2px);
			margin: 1px;
			top: 0;
			width: calc(100% - 2px); }
	.wb-tabs.carousel-s1 [role="tabpanel"] a figcaption, .wb-tabs.carousel-s2 [role="tabpanel"] a figcaption {
		color: #fff;
		text-decoration: underline; }

.wb-tabs.carousel-s1 [role="tabpanel"] figure a, .wb-tabs.carousel-s2 [role="tabpanel"] figure a {
	color: #fff; }

.wb-tabs.carousel-s1 .display:focus-within, .wb-tabs.carousel-s2 .display:focus-within {
	outline: 1px dotted #fff;
	outline-offset: -2px; }

.wb-tabs.carousel-s1 video:focus, .wb-tabs.carousel-s2 video:focus {
	outline-offset: -1px; }

.wb-tabs.carousel-s2 [role="tablist"] > li.prv, .wb-tabs.carousel-s2 [role="tablist"] > li.nxt {
	background: none;
	margin: 0;
	padding: 0; }

.wb-tabs.carousel-s2 [role="tablist"] > li.prv a, .wb-tabs.carousel-s2 [role="tablist"] > li.nxt a {
	border: 0;
	padding: 10px 5px;
	width: 100%; }

.wb-tabs.carousel-s2 [role="tablist"] > li.prv a .glyphicon, .wb-tabs.carousel-s2 [role="tablist"] > li.nxt a .glyphicon, .wb-tabs.carousel-s2 [role="tablist"] > li.plypause a {
	background: #fff;
	border-radius: 999px;
	-webkit-box-shadow: 0 0 4px #243850;
	        box-shadow: 0 0 4px #243850; }

.wb-tabs.carousel-s2 [role="tablist"] > li.prv a, .wb-tabs.carousel-s2 [role="tablist"] > li.nxt a, .wb-tabs.carousel-s2 [role="tablist"] > li.plypause a {
	color: #243850; }

.wb-tabs.carousel-s2 [role="tablist"] > li.prv a .glyphicon, .wb-tabs.carousel-s2 [role="tablist"] > li.nxt a .glyphicon {
	font-size: 1.75em;
	height: 1.75em;
	line-height: 1.75em;
	margin: auto 0;
	text-align: center;
	width: 1.75em; }

.wb-tabs.carousel-s2 [role="tablist"] > li.prv a:focus, .wb-tabs.carousel-s2 [role="tablist"] > li.prv a:hover, .wb-tabs.carousel-s2 [role="tablist"] > li.nxt a:focus, .wb-tabs.carousel-s2 [role="tablist"] > li.nxt a:hover {
	background: transparent; }

.wb-tabs.carousel-s2 [role="tablist"] > li.prv a:focus .glyphicon, .wb-tabs.carousel-s2 [role="tablist"] > li.prv a:hover .glyphicon, .wb-tabs.carousel-s2 [role="tablist"] > li.nxt a:focus .glyphicon, .wb-tabs.carousel-s2 [role="tablist"] > li.nxt a:hover .glyphicon, .wb-tabs.carousel-s2 [role="tablist"] > li.plypause a:focus, .wb-tabs.carousel-s2 [role="tablist"] > li.plypause a:hover {
	-webkit-box-shadow: none;
	        box-shadow: none; }

.wb-tabs.carousel-s1 [role="tablist"] > li.active a, .wb-tabs.carousel-s1 [role="tablist"] > li:focus a, .wb-tabs.carousel-s1 [role="tablist"] > li:hover a {
	border-top: 0;
	padding-top: 10px; }

.wb-tabs [role="tablist"] > li, .wb-tabs [role="tablist"] > li a, .wb-tabs.carousel-s1 [role="tablist"] > li.control, .wb-tabs.carousel-s2 [role="tablist"] > li.control {
	display: inline-block; }

.wb-tabs.carousel-s1 figcaption p, .wb-tabs.carousel-s2 figcaption p {
	margin-bottom: 0; }

.wb-tabs > details, .wb-tabs > .tabpanels > details {
	padding: 6px 12px; }
	.wb-tabs > details > summary, .wb-tabs > .tabpanels > details > summary {
		margin: -6px -12px;
		padding: 6px 12px; }

.csstransitions .wb-tabs [role="tabpanel"].out {
	position: absolute;
	top: 0;
	width: 100%;
	z-index: 0; }

.wb-tabs {
	/**
	 * Default, minimal, shared style
	 */
	/* For backwards compatibility. Should be removed in v4.1 */
	/**
	 * Style 1 - Basic carousel style
	 */
	/**
	 * Style 2 - Slider-like carousel style
	 */ }
	.wb-tabs details[open] {
		border-top-left-radius: 0; }
	.wb-tabs > .tabpanels {
		overflow: hidden;
		position: relative; }
	.wb-tabs [role="tablist"] {
		border-spacing: 10px 0;
		display: table;
		list-style: none;
		margin: 0;
		padding: 0;
		position: relative; }
		.wb-tabs [role="tablist"] > li {
			background: #ebf2fc;
			border-color: #ccc;
			border-style: solid;
			border-width: 1px;
			color: #000;
			cursor: pointer;
			display: table-cell;
			left: -10px;
			position: relative;
			text-align: center; }
			.wb-tabs [role="tablist"] > li a {
				color: #000;
				padding: 10px;
				text-decoration: none; }
			.wb-tabs [role="tablist"] > li:focus, .wb-tabs [role="tablist"] > li:hover {
				background: #ccc;
				background: rgba(204, 204, 204, 0.9); }
			.wb-tabs [role="tablist"] > li.active {
				background: #fff;
				border-bottom: 0;
				cursor: default;
				padding-bottom: 1px;
				z-index: 2; }
				.wb-tabs [role="tablist"] > li.active a {
					border-color: #666;
					border-style: solid;
					border-width: 4px 0 0 0;
					cursor: default;
					padding-top: 6px; }
			.wb-tabs [role="tablist"] > li.tab-count {
				line-height: normal; }
				.wb-tabs [role="tablist"] > li.tab-count > div {
					position: relative;
					top: 0; }
				.wb-tabs [role="tablist"] > li.tab-count .curr-count {
					font-size: 1.5em; }
				.wb-tabs [role="tablist"] > li.tab-count:focus, .wb-tabs [role="tablist"] > li.tab-count:hover {
					background: transparent;
					cursor: default; }
		.wb-tabs [role="tablist"].generated li {
			border-bottom: 0;
			top: 1px; }
		.wb-tabs [role="tablist"].allow-wrap {
			border-spacing: 0;
			display: block; }
			.wb-tabs [role="tablist"].allow-wrap li {
				display: inline-block;
				left: auto; }
	.wb-tabs [role="tabpanel"] {
		overflow-x: auto;
		position: relative;
		z-index: 1; }
	.wb-tabs.carousel-s1 {
		border-top: 0; }
		.wb-tabs.carousel-s1 [role="tablist"] {
			bottom: 1em;
			left: 1em;
			position: static; }
			.wb-tabs.carousel-s1 [role="tablist"] > li.prv {
				margin-right: 5px; }
			.wb-tabs.carousel-s1 [role="tablist"] > li.tab-count {
				background: none;
				border: 0;
				font-size: .9em;
				padding: 0 .1em;
				top: .55em; }
				.wb-tabs.carousel-s1 [role="tablist"] > li.tab-count.active, .wb-tabs.carousel-s1 [role="tablist"] > li.tab-count:focus, .wb-tabs.carousel-s1 [role="tablist"] > li.tab-count:hover {
					cursor: default; }
	.wb-tabs.carousel-s2 {
		background: #eee; }
		.wb-tabs.carousel-s2 [role="tablist"] {
			bottom: 0;
			position: absolute;
			width: 100%; }
			.wb-tabs.carousel-s2 [role="tablist"] > li {
				background: transparent;
				border: 0; }
				.wb-tabs.carousel-s2 [role="tablist"] > li.prv a {
					padding-left: 1em; }
				.wb-tabs.carousel-s2 [role="tablist"] > li.plypause {
					background: none;
					border: 0;
					float: right;
					margin-right: 0;
					padding: 2px 0; }
					.wb-tabs.carousel-s2 [role="tablist"] > li.plypause a {
						font-size: 1.5em;
						margin-right: .65em;
						margin-top: .4em;
						padding: 8px 10px 4px; }
			.wb-tabs.carousel-s2 [role="tablist"] a:focus {
				outline-offset: 0; }

.wb-disable.csstransitions .wb-tabs [role="tabpanel"].out {
	position: static;
	width: auto; }

.wb-disable .wb-tabs.carousel-s2 {
	background: transparent; }

.wb-disable .wb-tabs > details[open] > summary {
	display: list-item !important; }

.wb-disable .wb-tabs > .tabpanels > details[open] > summary {
	display: list-item !important; }

.wb-disable .wb-tabs .out {
	visibility: visible; }

.wb-disable .wb-tabs [role="tablist"] {
	display: none; }

.wb-disable .wb-tabs [role="tabpanel"] {
	-webkit-animation: none;
	        animation: none;
	display: block;
	margin-bottom: .5em;
	opacity: 1;
	-webkit-transform: none;
	        transform: none; }

/*
Carousel
*/
.carousel-s1,
.carousel-s2 {
	margin-bottom: 15px; }
	.carousel-s1 .wb-mltmd,
	.carousel-s2 .wb-mltmd {
		margin-top: 0; }

/*
 * Web Experience Toolkit (WET) / Boîte à outils de l'expérience Web (BOEW)
 * wet-boew.github.io/wet-boew/License-en.html / wet-boew.github.io/wet-boew/Licence-fr.html
 */
.wb-disable .wb-twitter .twitter-timeline {
	text-indent: 0 !important; }

.wb-twitter .twitter-timeline {
	display: block; }

.wb-twitter iframe[style] {
	width: 100% !important; }

.wb-enable .wb-twitter .twitter-timeline {
	min-height: 100px;
	min-width: 100px;
	position: relative; }

/*
 * Web Experience Toolkit (WET) / Boîte à outils de l'expérience Web (BOEW)
 * wet-boew.github.io/wet-boew/License-en.html / wet-boew.github.io/wet-boew/Licence-fr.html
 */
/*
 * Web Experience Toolkit (WET) / Boîte à outils de l'expérience Web (BOEW)
 * wet-boew.github.io/wet-boew/License-eng.html / wet-boew.github.io/wet-boew/Licence-fra.html
*/
.ol-overlay-container {
	z-index: 1000; }

.ol-popup {
	-moz-box-shadow: 0 1px 4px rgba(0, 0, 0, 0.2);
	-webkit-filter: drop-shadow(0 1px 4px rgba(0, 0, 0, 0.2));
	background-color: white;
	border: 1px solid #cccccc;
	border-radius: 3px;
	bottom: 12px;
	-webkit-box-shadow: 0 1px 4px rgba(0, 0, 0, 0.2);
	        box-shadow: 0 1px 4px rgba(0, 0, 0, 0.2);
	display: block;
	filter: drop-shadow(0 1px 4px rgba(0, 0, 0, 0.2));
	font-size: .75em;
	left: -50px;
	min-width: 250px;
	padding: 15px;
	position: absolute; }

.ol-popup:after, .ol-popup:before {
	border: solid transparent;
	content: " ";
	height: 0;
	pointer-events: none;
	position: absolute;
	top: 100%;
	width: 0; }

.ol-popup:after {
	border-top-color: white;
	border-width: 10px;
	left: 48px;
	margin-left: -10px; }

.ol-popup:before {
	border-top-color: #cccccc;
	border-width: 11px;
	left: 48px;
	margin-left: -11px; }

.ol-popup-closer {
	color: #333;
	font-family: Arial, Baskerville, monospace;
	font-size: 24px;
	font-weight: 700;
	height: 28px;
	line-height: 28px;
	position: absolute;
	right: 0;
	text-align: center;
	text-decoration: none;
	top: 0;
	width: 28px; }

.ol-popup-closer:link, .ol-popup-closer:visited, .ol-popup-closer:hover, .ol-popup-closer:active {
	color: #333;
	text-decoration: none; }

.popup-content h5 {
	border-bottom: solid 1px #999;
	color: #999;
	font-size: 1.0em;
	margin: -5px 0px 5px 0px;
	padding-bottom: 3px; }

.popup-content table th, .popup-content table td {
	padding: 2px; }

/**
 * GeoMap
 */
.wb-geomap-map {
	outline: 1px solid #ccc;
	overflow: hidden;
	position: relative; }
	.wb-geomap-map.active {
		-webkit-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075), 0 0 8px rgba(102, 175, 233, 0.6);
		box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075), 0 0 8px rgba(102, 175, 233, 0.6);
		outline-color: #66afe9; }

.geomap-legend-detail {
	padding-top: 10px; }

.geomap-legend-element {
	overflow: hidden;
	width: 100%; }

.geomap-legend-symbol {
	float: left;
	margin-right: 5px; }

.geomap-legend-symbol-text {
	display: inline-block;
	line-height: 30px;
	vertical-align: middle; }

.geomap-clear-format {
	clear: both; }

.geomap-legend-label {
	display: inline; }

.geomap-lgnd-layer {
	margin-bottom: 10px;
	margin-top: 0px !important; }

.geomap-lgnd > :last-child {
	margin-bottom: 0px; }

.geomap-geoloc {
	background: transparent;
	left: .25em;
	top: .25em; }
	.geomap-geoloc input[type="text"] {
		border-color: #fff;
		border-radius: 2px;
		-webkit-box-shadow: 1px 2px 4px #999;
		        box-shadow: 1px 2px 4px #999;
		width: 100%; }

.geomap-aoi legend {
	border: 0;
	font-size: 1em;
	margin-bottom: 1em; }

.geomap-aoi button.geomap-geoloc-aoi-btn {
	position: absolute;
	right: 15px;
	top: auto; }

.geoloc-progress {
	-webkit-animation-duration: 500ms;
	        animation-duration: 500ms;
	-webkit-animation-iteration-count: infinite;
	        animation-iteration-count: infinite;
	-webkit-animation-name: spin;
	        animation-name: spin;
	-webkit-animation-timing-function: linear;
	        animation-timing-function: linear;
	color: #333;
	content: "\e031";
	font-family: "Glyphicons Halflings";
	font-size: 1em;
	height: 1em;
	line-height: 1.03;
	width: 1em;
	z-index: 2; }

/* OL3 */
.ol-geolocate {
	bottom: 8em;
	right: 1em; }

.ol-touch .ol-geolocate {
	bottom: 1.5em;
	right: .5em; }

.ol-mouse-position {
	background: #fff;
	background: rgba(255, 255, 255, 0.7);
	border-radius: 2px;
	bottom: 3em;
	font-size: .75em;
	left: .6666em;
	min-width: 100px;
	padding: 2px 6px 2px 6px;
	position: absolute;
	will-change: contents, width; }

.ol-mouse-position:before {
	content: "\e062";
	font-family: "Glyphicons Halflings";
	margin-right: 3px; }

.ol-mouse-position-inner {
	padding: 10px; }

.ol-mouse-position:empty {
	display: none; }

.ol-touch .ol-mouse-position {
	display: none; }

.ol-scale-line {
	background: #fff;
	background: rgba(255, 255, 255, 0.7);
	border-radius: 2px;
	bottom: .5em;
	left: .5em;
	padding: 2px;
	position: absolute; }

.ol-touch .ol-scale-line {
	display: none; }

.ol-scale-line-inner {
	border: 1px solid #000;
	border-top: none;
	color: #000;
	font-size: .75em;
	margin: 1px;
	text-align: center;
	will-change: contents, width; }

.ol-overlay-container {
	will-change: left, right, top, bottom; }

.ol-unsupported {
	display: none; }

.ol-viewport .ol-unselectable {
	-moz-user-select: none;
	-ms-user-select: none;
	-webkit-tap-highlight-color: transparent;
	-webkit-user-select: none;
	user-select: none; }

.ol-control {
	background-color: rgba(255, 255, 255, 0.4);
	border-radius: 4px;
	padding: 2px;
	position: absolute; }

.ol-control:hover {
	background-color: rgba(255, 255, 255, 0.4); }

.ol-zoom {
	bottom: 1.5em;
	right: 1em; }

.ol-touch .ol-zoom {
	display: none; }

.ol-rotate {
	bottom: 1.5em;
	right: 3.25em;
	-webkit-transition: opacity .25s linear, visibility 0s linear;
	transition: opacity .25s linear, visibility 0s linear; }

.ol-rotate.ol-hidden {
	opacity: 0;
	-webkit-transition: opacity .25s linear, visibility 0s linear .25s;
	transition: opacity .25s linear, visibility 0s linear .25s;
	visibility: hidden; }

.ol-zoom-extent {
	bottom: 6em;
	right: 1em; }

.ol-touch .ol-zoom-extent {
	display: none; }

.ol-zoom-extent span.glyphicon {
	top: 3px; }

.ol-full-screen {
	right: .5em;
	top: .5em; }

@media print {
	.ol-control {
		display: none; } }

.ol-control button {
	background-color: white;
	border: none;
	border-radius: 2px;
	-webkit-box-shadow: 1px 2px 4px #999;
	        box-shadow: 1px 2px 4px #999;
	color: #333;
	display: block;
	font-size: 1.14em;
	font-weight: 700;
	height: 1.5em;
	line-height: .4em;
	margin: 0;
	padding: 0;
	text-align: center;
	text-decoration: none;
	width: 1.5em; }

.ol-control button::-moz-focus-inner {
	border: none;
	padding: 0; }

.ol-zoom-extent button {
	line-height: 1.4em; }

ol-geolocate button {
	line-height: 1em; }

.ol-compass {
	display: block;
	font-size: 1.2em;
	font-weight: 400;
	will-change: transform; }

.ol-touch .ol-control button {
	font-size: 1.5em; }

.ol-control button:focus, .ol-control button:hover {
	text-decoration: none; }

.ol-zoom .ol-zoom-in {
	border-bottom: solid 1px #999;
	border-radius: 2px 2px 0 0; }

.ol-zoom .ol-zoom-out {
	border-radius: 0 0 2px 2px; }

.ol-attribution {
	background: rgba(255, 255, 255, 0.7);
	border-radius: 2px 0 0;
	bottom: 0;
	line-height: .75em;
	max-width: calc(80% - 1.3em);
	right: 0;
	text-align: right; }

.ol-attribution ul {
	color: #333;
	font-size: .75em;
	margin: 0;
	padding: .15em .25em;
	text-shadow: 0 0 2px #fff; }

.ol-attribution li {
	display: inline;
	line-height: inherit;
	list-style: none; }
	.ol-attribution li :after {
		content: " "; }
	.ol-attribution li :last-child:after {
		content: ""; }

.ol-attribution img {
	max-height: 2em;
	max-width: inherit; }

.ol-attribution a {
	color: #333;
	text-decoration: none; }

.ol-attribution a:visited, .ol-attribution a:active {
	color: #333; }

.ol-attribution button, .ol-attribution ul {
	display: inline-block; }

.ol-attribution.ol-collapsed ul {
	display: none; }

.ol-attribution.ol-logo-only ul {
	display: block; }

.ol-attribution.ol-uncollapsible {
	border-radius: 4px 0 0;
	bottom: 0;
	height: 1.3em;
	line-height: .75em;
	right: 0; }

.ol-attribution.ol-logo-only {
	background: 0 0;
	bottom: .4em;
	height: 1.1em;
	line-height: 1em; }

.ol-attribution.ol-uncollapsible img {
	margin-top: -.2em;
	max-height: 1.6em; }

.ol-attribution.ol-logo-only button, .ol-attribution.ol-uncollapsible button {
	display: none; }

.ol-box {
	border: 2px solid #2572b4;
	border-radius: 2px;
	-webkit-box-sizing: border-box;
	        box-sizing: border-box; }

.ol-dragbox {
	border: 2px solid #ff0033;
	border-radius: 2px;
	-webkit-box-sizing: border-box;
	        box-sizing: border-box; }

.ol-overviewmap {
	bottom: .5em;
	left: .5em; }

.ol-overviewmap.ol-uncollapsible {
	border-radius: 0 4px 0 0;
	bottom: 0;
	left: 0; }

.ol-overviewmap .ol-overviewmap-map, .ol-overviewmap button {
	display: inline-block; }

.ol-overviewmap .ol-overviewmap-map {
	border: 1px solid #7b98bc;
	height: 150px;
	margin: 2px;
	width: 150px; }

.ol-overviewmap:not(.ol-collapsed) button {
	bottom: 1px;
	left: 2px;
	position: absolute; }

.ol-overviewmap.ol-collapsed .ol-overviewmap-map, .ol-overviewmap.ol-uncollapsible button {
	display: none; }

.ol-overviewmap:not(.ol-collapsed) {
	background: rgba(255, 255, 255, 0.8); }

.ol-overviewmap-box {
	border: 2px dotted rgba(0, 60, 136, 0.7); }

.geomap-help-btn {
	background-color: transparent;
	right: .5em;
	top: .5em; }

.geomap-help-btn:focus, .geomap-help-btn:hover {
	background-color: transparent; }

.geomap-help-btn button {
	background-color: #333;
	border-radius: 50%;
	color: #fff; }

.ol-touch .geomap-help-btn {
	display: none; }

.geomap-help-dialog {
	background-color: white;
	height: auto;
	margin: 10px;
	right: 0;
	top: 0;
	width: auto; }
	.geomap-help-dialog header {
		position: static; }
	.geomap-help-dialog a.btn {
		color: #333;
		font-family: Arial, Baskerville, monospace;
		font-size: 28px;
		font-weight: 700;
		height: 44px;
		line-height: 44px;
		padding: 0;
		position: absolute;
		right: 0;
		text-align: center;
		text-decoration: none;
		top: 0;
		width: 44px; }

.geomap-help-dialog:hover {
	background-color: white; }

.tooltip-txt::after {
	border-color: silver transparent transparent transparent;
	border-style: solid;
	border-width: 5px;
	content: " ";
	left: 50%;
	margin-left: -5px;
	position: absolute;
	top: 100%; }

.tooltip-txt {
	-moz-box-shadow: 0 1px 4px rgba(0, 0, 0, 0.2);
	-webkit-filter: drop-shadow(0 1px 4px rgba(0, 0, 0, 0.2));
	background: silver;
	border: solid 1px silver;
	border-radius: 5px;
	bottom: 100%;
	-webkit-box-shadow: 0 1px 4px rgba(0, 0, 0, 0.2);
	        box-shadow: 0 1px 4px rgba(0, 0, 0, 0.2);
	color: #333333;
	cursor: default;
	filter: drop-shadow(0 1px 4px rgba(0, 0, 0, 0.2));
	font-size: .80em;
	left: 50%;
	margin-left: -60px;
	padding: 5px 0;
	position: absolute;
	text-align: center;
	width: 120px; }

.wb-geomap-geoloc-al-cnt, .wb-geomap-geoloc-al-cnt .wb-geomap-geoloc-al {
	max-height: 15em; }

.wb-geomap-geoloc-al-cnt {
	border: 1px solid transparent;
	left: 0;
	margin-top: 0;
	position: absolute;
	z-index: 50; }
	.wb-geomap-geoloc-al-cnt .wb-geomap-geoloc-al {
		-webkit-overflow-scrolling: touch;
		background: #fff;
		border: solid 1px #ccc;
		border-top: 0;
		font-size: .9em;
		list-style-type: none;
		overflow-y: scroll;
		padding: 0; }
		.wb-geomap-geoloc-al-cnt .wb-geomap-geoloc-al li {
			border-bottom: solid 1px #ccc; }
		.wb-geomap-geoloc-al-cnt .wb-geomap-geoloc-al li:last-of-type {
			border-bottom: 0; }
		.wb-geomap-geoloc-al-cnt .wb-geomap-geoloc-al a {
			color: #333;
			display: block;
			padding: 5px 5px;
			text-decoration: none; }
			.wb-geomap-geoloc-al-cnt .wb-geomap-geoloc-al a:hover, .wb-geomap-geoloc-al-cnt .wb-geomap-geoloc-al a:focus {
				background: #666;
				color: #fff; }
			.wb-geomap-geoloc-al-cnt .wb-geomap-geoloc-al a span.glyphicon {
				color: #ccc;
				margin-right: 5px; }

.glyphicon-spin {
	-webkit-animation: spin 1000ms infinite linear;
	animation: spin 1000ms infinite linear; }

@-webkit-keyframes spin {
	0% {
		-webkit-transform: rotate(0deg);
		transform: rotate(0deg); }
	100% {
		-webkit-transform: rotate(359deg);
		transform: rotate(359deg); } }

@keyframes spin {
	0% {
		-webkit-transform: rotate(0deg);
		transform: rotate(0deg); }
	100% {
		-webkit-transform: rotate(359deg);
		transform: rotate(359deg); } }

.skeleton-lgnd-1 {
	background-color: #f5f5f5;
	height: 25px;
	margin-top: 10px;
	width: 100%; }

.skeleton-lgnd-2 {
	background-color: #f5f5f5;
	height: 25px;
	margin: 20px 0 20px 0;
	width: 100%; }

.skeleton-lgnd-3 {
	background-color: #fff;
	display: block;
	height: 25px;
	margin-left: 25px;
	width: 15px; }

/*
 * Web Experience Toolkit (WET) / Boîte à outils de l'expérience Web (BOEW)
 * wet-boew.github.io/wet-boew/License-en.html / wet-boew.github.io/wet-boew/Licence-fr.html
 */
.wb-zebra-col-hover .wb-group-summary col.table-hover, .table-hover .wb-group-summary tr:hover td,
.table-hover .wb-group-summary tr:hover th {
	background-color: #fafaff; }

.wb-cell-layout {
	background-color: transparent; }

.wb-cell-key, .wb-cell-desc {
	font-style: italic; }

.wb-zebra > colgroup + colgroup {
	border-left: 2px solid #ddd; }

.wb-group-summary {
	background-color: #f0f2f4; }

.wb-zebra-col-hover col.table-hover {
	background-color: #f0f0f0; }

/*
 * Web Experience Toolkit (WET) / Boîte à outils de l'expérience Web (BOEW)
 * wet-boew.github.io/wet-boew/License-en.html / wet-boew.github.io/wet-boew/Licence-fr.html
 */
.feeds-cont.waiting:after, .feeds-cont.waiting:before {
	bottom: 0;
	content: " ";
	height: 50px;
	left: 0;
	margin: auto;
	position: absolute;
	right: 0;
	top: 0;
	width: 50px; }

.feeds-cont.waiting {
	min-height: 100px;
	min-width: 100px; }
	.feeds-cont.waiting:after {
		-webkit-animation-duration: 1000ms;
		        animation-duration: 1000ms;
		-webkit-animation-iteration-count: infinite;
		        animation-iteration-count: infinite;
		-webkit-animation-name: spin;
		        animation-name: spin;
		-webkit-animation-timing-function: linear;
		        animation-timing-function: linear;
		background: url("../../wet-boew/assets/loading.png") center center no-repeat;
		background-size: 30px 30px;
		z-index: 2; }
	.feeds-cont.waiting:before {
		background: rgba(0, 0, 0, 0);
		z-index: 1; }

.feeds-cont .feeds-date:before {
	content: "["; }

.feeds-cont .feeds-date:after {
	content: "]"; }

.feeds-cont button[data-youtube] {
	border: none;
	padding: 0; }

/*
 *
 * Web Experience Toolkit (WET) / Boîte à outils de l'expérience Web (BOEW)
 * wet-boew.github.io/wet-boew/License-en.html / wet-boew.github.io/wet-boew/Licence-fr.html
 *
 * @title: Shared style between multiple components
 *
 */
.gc-srvinfo p, .gc-drmt p, .gc-features p {
	font-size: 17px;
	line-height: 1.5em; }

.gc-srvinfo h3, .gc-srvinfo h4, .gc-srvinfo h5, .gc-srvinfo h6, .gc-drmt h3, .gc-drmt h4, .gc-drmt h5, .gc-drmt h6, .gc-features h3, .gc-features h4, .gc-features h5, .gc-features h6 {
	font-size: 1em;
	margin-bottom: 5px;
	margin-top: 23px; }

/*
 * Components styles
 */
.gc-dwnld .gc-dwnld-txt {
	text-decoration: underline; }
	.gc-dwnld .gc-dwnld-txt:hover {
		text-decoration: none; }
	.gc-dwnld .gc-dwnld-txt span {
		display: block; }

.gc-dwnld .gc-dwnld-img {
	margin-bottom: 0; }

.gc-dwnld p {
	margin-bottom: 0; }

.gc-stp-stp {
	border-bottom: solid 1px #ccc;
	margin-bottom: 30px;
	margin-top: 15px; }

.bg-gctheme {
	background-color: #355688; }

/* H1 short bold red underline */
h1.gc-thickline {
	border-bottom: none; }
	h1.gc-thickline::after {
		border-bottom: .18em solid #af3c43;
		content: "";
		display: block;
		padding-bottom: 8px;
		width: 70px; }

/*
* Panel title
*/
.panel-title {
	font-size: 1.2em; }

/*
 * Components
 */
.alert-info > :first-child::before, .alert-success > :first-child::before, .alert-warning > :first-child::before, .alert-danger > :first-child::before {
	color: inherit;
	content: none; }

.alert {
	background-clip: content-box;
	background-color: inherit;
	border-left: 6px solid #000;
	margin-bottom: 23px;
	margin-left: 10px;
	padding: 0 0 0 15px; }
	.alert > p, .alert > ul, .alert > ol {
		margin-bottom: 0px; }
	.alert > * {
		margin-left: 15px; }
	.alert details {
		margin-left: .5em;
		padding-top: 15px; }
	.alert > :first-child:not(details) {
		margin-top: auto;
		padding-top: 15px; }
	.alert > :last-child {
		padding-bottom: 25px; }
	.alert::before {
		display: -webkit-box;
		display: -ms-flexbox;
		display: flex;
		font-family: "Glyphicons Halflings";
		font-size: 26px;
		line-height: 2.3em;
		margin-left: -1.27em;
		padding: 2px;
		position: absolute; }
	.alert > :first-child {
		margin-left: 15px; }

.alert-info {
	border-color: #269abc;
	-o-border-image: linear-gradient(to bottom, #269abc 16px, #269abc 16px, transparent 16px, transparent 48px, #269abc 48px, #269abc 48px) 1 100%;
	   border-image: linear-gradient(to bottom, #269abc 16px, #269abc 16px, transparent 16px, transparent 48px, #269abc 48px, #269abc 48px) 1 100%; }
	.alert-info::before {
		color: #269abc;
		content: ""; }

.alert-success {
	border-color: #278400;
	-o-border-image: linear-gradient(to bottom, #278400 16px, #278400 16px, transparent 16px, transparent 48px, #278400 48px, #278400 48px) 1 100%;
	   border-image: linear-gradient(to bottom, #278400 16px, #278400 16px, transparent 16px, transparent 48px, #278400 48px, #278400 48px) 1 100%; }
	.alert-success::before {
		color: #278400;
		content: ""; }

.alert-warning {
	border-color: #ee7100;
	-o-border-image: linear-gradient(to bottom, #ee7100 16px, #ee7100 16px, transparent 16px, transparent 48px, #ee7100 48px, #ee7100 48px) 1 100%;
	   border-image: linear-gradient(to bottom, #ee7100 16px, #ee7100 16px, transparent 16px, transparent 48px, #ee7100 48px, #ee7100 48px) 1 100%; }
	.alert-warning::before {
		color: #ee7100;
		content: ""; }

.alert-danger {
	border-color: #d3080c;
	-o-border-image: linear-gradient(to bottom, #d3080c 16px, #d3080c 16px, transparent 16px, transparent 48px, #d3080c 48px, #d3080c 48px) 1 100%;
	   border-image: linear-gradient(to bottom, #d3080c 16px, #d3080c 16px, transparent 16px, transparent 48px, #d3080c 48px, #d3080c 48px) 1 100%; }
	.alert-danger::before {
		color: #d3080c;
		content: ""; }

/*
* Template pages styles
*/
.whtwedo p {
	font-weight: 700;
	margin-bottom: 30px;
	margin-top: 15px; }

.whtwedo ul > li {
	margin-bottom: 10px; }

.lnkbx > ul > li {
	margin-bottom: 10px; }

.lnkbx dl a {
	overflow-wrap: break-word;
	word-break: break-all;
	word-wrap: break-word; }

.lnkbx dl dt {
	margin-top: 10px; }

.lnkbx dl dd {
	margin-bottom: 0; }

.gc-byline {
	font-weight: 700;
	margin-bottom: 30px; }

/*
 * Corporate information on Institution and Organization pages
*/
.gc-crprt ul:nth-child(1) {
	list-style: outside none none;
	margin: 0;
	padding: 0; }
	.gc-crprt ul:nth-child(1) > li {
		margin-bottom: 10px; }

.gc-crprt h3 {
	margin-top: 0; }

.gc-crprt .col-md-8 .col-md-4 {
	margin-bottom: 15px; }

/*
 * Institution pages
 */
.gc-instttn .gc-rms-lngth img,
.gc-orgnztn .gc-rms-lngth img {
	margin-bottom: 30px; }

/*
 * Theme template
 */
.gc-theme .profile {
	margin-bottom: 25px; }

/*
 * Service template
 */
.gc-cntct-lst dl dt,
.gc-cntct-lst dl dd,
.lnkbx dl dt,
.lnkbx dl dd {
	border: 0; }

/*
 * Advance Service template
 */
.gc-advnc-srvc .col-md-8 h2:first-child {
	margin-top: 0; }

/*
 * Archived template banner
 */
.gc-archv {
	background-color: #ffd700 !important;
	padding: 25px 50px; }
	.gc-archv h2 {
		margin-top: 0; }
	.gc-archv .mfp-close.overlay-close {
		color: #000; }

/* Embedding a Fluid Survey */
.gc-fld-srvy-container {
	-webkit-overflow-scrolling: touch;
	height: 0;
	overflow: hidden;
	overflow-y: scroll;
	padding-bottom: 70%;
	position: relative; }

.gc-fld-srvy-mbd {
	border: 0;
	height: 100%;
	left: 0;
	position: absolute;
	top: 0;
	width: 100%;
	zoom: 1; }

/*
 * Main content area
 */
main .subtitle {
	color: #555;
	font-size: 1em;
	font-weight: 300;
	margin-bottom: 1em; }

main .departments .learnmore {
	padding: 3em 0; }

main .priorities {
	padding-top: 2em; }
	main .priorities .thumbnail {
		margin-bottom: 1.5em;
		padding: 1em; }

main .gc-rms-lngth img {
	background-color: #fff;
	border: solid 1px #e1e4e7;
	padding: 18px; }

/* Heading with links inside of rows */
.departments a h2,
.departments a h3,
.departments a h4,
.priorities a h2,
.priorities a h3,
.priorities a h4 {
	font-size: 20px; }

/*
 *
 * Web Experience Toolkit (WET) / Boîte à outils de l'expérience Web (BOEW)
 * wet-boew.github.io/wet-boew/License-en.html / wet-boew.github.io/wet-boew/Licence-fr.html
 *
 */
/*
	Global Provisional styling
	- Provisional  CSSspecific for view port are defined in the "views/[view port]" theme CSS
*/
.provisional {
	/* ------------
	 * Background color
	 *
	 */
	/* ------------
	 * Background image for heading
	 *
	 */
	/* ------------
	 * Theme color
	 *
	 */
	/* Pink day - One day event in April
	 * (with a contrast conforming to Level AAA)
	 */
	/* Dark theme
	 */
	/* Theme/topic decorative image */
	/* Contributors */ }
	.provisional .bg-pnkDy {
		background-color: #AD005F; }
		.provisional .bg-pnkDy.well.header-rwd {
			background-color: #570030; }
	.provisional .bg-img-hdng {
		background-image: url("../assets/x-blue-line.png");
		background-position: right bottom;
		background-repeat: no-repeat;
		min-height: 60px;
		padding-bottom: 35px;
		padding-right: 80px; }
	.provisional.pnkDy-theme .gcweb-menu button[aria-haspopup=true],
	.provisional.pnkDy-theme #wb-srch button,
	.provisional.pnkDy-theme .srchbox button {
		background-color: #AD005F;
		border-color: #AD005F; }
	.provisional.pnkDy-theme .gcweb-menu button[aria-haspopup=true]:focus, .provisional.pnkDy-theme .gcweb-menu button[aria-haspopup=true]:hover,
	.provisional.pnkDy-theme #wb-srch button:focus, .provisional.pnkDy-theme #wb-srch button:hover,
	.provisional.pnkDy-theme .srchbox button:focus, .provisional.pnkDy-theme .srchbox button:hover {
		background-color: #570030;
		color: #fff; }
	.provisional.pnkDy-theme .gcweb-menu, .provisional.pnkDy-theme #wb-bnr + .gcweb-menu,
	.provisional.pnkDy-theme.home .gcweb-menu, .provisional.pnkDy-theme #wb-bnr + hr {
		border-top-color: #AD005F; }
	.provisional.pnkDy-theme.home .gcweb-menu button[aria-haspopup=true] {
		background-color: #ffffff;
		border-color: #ffffff; }
	.provisional.pnkDy-theme.home .gcweb-menu button[aria-haspopup=true] {
		color: #AD005F; }
	.provisional.pnkDy-theme.home .gcweb-menu button[aria-haspopup=true]:focus,
	.provisional.pnkDy-theme.home .gcweb-menu button[aria-haspopup=true]:hover {
		background-color: #AD005F;
		border-color: #AD005F;
		color: #ffffff; }
	.provisional.pnkDy-theme #wb-info .gc-contextual {
		background-color: #c40b71; }
	.provisional.pnkDy-theme #wb-info .landscape {
		background-color: #AD005F; }
	.provisional.dark-theme .gcweb-menu button[aria-haspopup=true],
	.provisional.dark-theme #wb-srch button,
	.provisional.dark-theme .srchbox button {
		background-color: #000;
		border-color: #000;
		color: #fff; }
	.provisional.dark-theme .gcweb-menu button[aria-haspopup=true]:focus, .provisional.dark-theme .gcweb-menu button[aria-haspopup=true]:hover,
	.provisional.dark-theme #wb-srch button:focus, .provisional.dark-theme #wb-srch button:hover,
	.provisional.dark-theme .srchbox button:focus, .provisional.dark-theme .srchbox button:hover {
		background-color: #000;
		color: #fff; }
	.provisional.dark-theme .gcweb-menu, .provisional.dark-theme #wb-bnr + .gcweb-menu,
	.provisional.dark-theme.home .gcweb-menu, .provisional.dark-theme #wb-bnr + hr {
		border-top-color: #000; }
	.provisional.dark-theme.home .gcweb-menu button[aria-haspopup=true] {
		background-color: #fff;
		border-color: #fff; }
	.provisional.dark-theme.home .gcweb-menu button[aria-haspopup=true] {
		color: #000; }
	.provisional.dark-theme.home .gcweb-menu button[aria-haspopup=true]:focus,
	.provisional.dark-theme.home .gcweb-menu button[aria-haspopup=true]:hover {
		background-color: #000;
		border-color: #000;
		color: #fff; }
	.provisional.dark-theme #wb-info .gc-contextual {
		background-color: #0a1015; }
	.provisional.dark-theme #wb-info .landscape {
		background-color: #000;
		color: #fff; }
	.provisional.icon-warning-light, .provisional .icon-warning-light {
		color: #DF7200; }
	.provisional.gc-topic-bg div {
		background: no-repeat;
		margin-left: -15px;
		min-height: 200px;
		overflow: hidden;
		width: calc(50vw - 15px); }
	.provisional.gc-contributors {
		margin-top: 38px; }
		.provisional.gc-contributors h2, .provisional.gc-contributors ul {
			display: inline;
			font-size: 87%;
			margin-top: 0; }
		.provisional.gc-contributors ul {
			-webkit-padding-start: 0;
			        padding-inline-start: 0; }
			.provisional.gc-contributors ul li {
				display: inline-block;
				font-weight: 700;
				margin-right: .7em; }

/*
 *
 * Web Experience Toolkit (WET) / Boîte à outils de l'expérience Web (BOEW)
 * wet-boew.github.io/wet-boew/License-en.html / wet-boew.github.io/wet-boew/Licence-fr.html
 *
 * @title: GC News
 *
 */
.gc-nws a h2,
.gc-nws a h3,
.gc-nws a h4 {
	font-size: 20px;
	margin-top: 15px; }

/*
 * Global small component style
 *
 * Use this style sheet to define style for small component
 */
/*
 * Redacted inline text style
 */
.redacted {
	display: inline-block;
	line-break: anywhere;
	overflow-wrap: break-word;
	word-break: break-all;
	word-wrap: break-word; }

/*
 Details Summary Styling

 There is no working example supporting those style
*/
.dshbrd .cntrls li {
	padding-right: 0; }

.dshbrd .cntrls a {
	background: #eee;
	border: 1px solid #ddd;
	color: #000;
	padding: 7px 5px; }

.dshbrd > details {
	display: inline;
	left: 0;
	position: relative;
	top: 0; }
	.dshbrd > details > summary {
		font-size: 0;
		max-height: 0; }

/*
 * Helper Classes
 */
#triangle-up {
	border-bottom: 10px solid #fff;
	border-left: 5px solid transparent;
	border-right: 5px solid transparent;
	height: 0;
	width: 0; }

/*
 Social Media Icons, follow-us
*/
.followus .foursquare, .followus .youtube, .followus .twitter, .followus .flickr, .followus .facebook, .followus .pinterest, .followus .linkedin, .followus .instagram, .followus .googleplus, .followus .reddit, .followus .rss, .followus .periscope, .followus .email {
	background-position: center center;
	background-repeat: no-repeat;
	display: inline;
	min-height: 27px;
	min-width: 27px;
	position: relative;
	vertical-align: text-bottom; }

.followus .foursquare, .icon.foursquare {
	background-image: url("data:image/png;base64,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"); }

.followus .youtube, .icon.youtube {
	background-image: url("data:image/png;base64, "); }

.followus .twitter, .icon.twitter {
	background-image: url("data:image/png;base64,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"); }

.followus .flickr, .icon.flickr {
	background-image: url("data:image/png;base64,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"); }

.followus .facebook, .icon.facebook {
	background-image: url("data:image/png;base64,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"); }

.followus .pinterest, .icon.pinterest {
	background-image: url("data:image/png;base64, "); }

.followus .linkedin, .icon.linkedin {
	background-image: url("data:image/png;base64, "); }

.followus .instagram, .icon.instagram {
	background-image: url("data:image/png;base64,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"); }

.followus .googleplus, .icon.googleplus {
	background-image: url("data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAC4AAAAuCAYAAABXuSs3AAAAAXNSR0IArs4c6QAAA9lJREFUaAXtmX9IU1EUx882tznnr0ynGREpFvRfkWZ/FCRSRGQWmEgU/VF/FNEPqD8LwiAoIUihfyMoSyywoP6oDCEtqUj6IWRIhKVu/pq2qU+39zrnuvt82x6Mt+3pgl04vHPPu+/cz/t6d3bvBPhPm0GFWy2mMmzJQ5JyRiUk+aaAka+8p3xmqX0CJvMHjL1AioLC9KayvCrPZm00GYyFiviyu35JHHTNzp3e/uLtU4TxEZAxQEXqmhMRmvhISEeqpYkY0dhKUIJbEk1pguYtwGbBfjg4H5TAV1Vw5XpPVHZiDFKcQFkgUYkDXDIjX+MJzhuOlwQP10TfSFJxffUNz55UPFwTfSMxfekY7HbIPlgH9i1bwZyP+zKssvPOIfB+6AZ36z2Qpqd1o48aPG1zGeSePAdmR0EQnHVtEZBl7KgAZ1MDCD0fg+7HqxMVuG1TKRRcvgYGw8IX2dyIC2a+9zIm24aNYMlzgOT3g2/wd7w4w/JoBjek2SHv1HkGLfp8MNZ8ByYfPwCDKLLkktEI6bv3wUx3J4jjo2ETxiugGTz7QK28PCYeNcNU6/2gTQ69gPd5W0S+4rZ2NqZ/f0XEsWoDNJdDe2k5yyPiB8/dclct55LENCtuLljNwISfP/AQRcfAxcZVXIwseJ7ODnBev8I6oWN4X6vymhWXJH7YlneYoZzhfROdwePbNCvuc/4B07oSsBaV4AkQj4Dz8zLRcGOD7JuysiDv6AnW942PyfG+qp3MX//kNbvyvilQoeSBERzNinvedbGURpsNcuqOBaX3vnwG3ExmOmUtNKH3C3fx4GtgxgOhfR6PdNWs+GRbC2RU7AJL/irIrj4EEpbEiYf4IcW6zVvm3mpYUXOYdYWBX+Dp6uC35Gu0SvMEmsGlmRlw3boBhfUNYMS1m1N7BDIr98Bsfx+AKOESKpbLpYilceT2zaCX4hNrXRr8OX7VDE4PCl97YPDSBXCcuciUT1mZC+loyuZzT4ALoYVvn5XhuPlRgdPsBD9w9jhkVtWAvWwbWAvXBDZZw+D99B4m8ctJ+jsVN9DQRFGDs0S4bKZwfZPxIglYLvkeJnSyePZjA1eQyFVdY1lTpNDkai6HmrLrODgJrqO4qqmTiqvKomMwqbiO4qqmTiquKouOQaXioiD6XTrOFVPqANvCTwmYiYPTVsPXPjR6VfD7R2KaQYeHienV8Fg9MaKxbRHfYtALpKPlo+WgpaLxe+guayPQWbRxNCeaB03kmyy6KaC5KYhG5y7+10B3WRvxzKHRHpkYgxTHPgOlf4ASNL1QIilOS4Tg6WTO1vk/yrUG/vk8ZeYAAAAASUVORK5CYII="); }

.followus .reddit, .icon.reddit {
	background-image: url("data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAABgAAAAYCAYAAADgdz34AAACAUlEQVRIS+2TTUhUURiGnxm1zJ9KQScVmxT/MlJQCFNQNyJBZLrSQPyBNokbwRKNRBdGCG1EWhg06kLd+L8RQRRJJNBKURyVURjFRJhSw4pJRw4HnWQu3rloO7/Vved8533Oed9zdI4sHPzH0l0A1NzVbpG3L3h6wc8fUjvAADod2L4psrQDntRAaBToPWDfDml5oNdDSQx833SBaAc8b4PGInA4IPAGmJbltwDYNs4B8KId3hQ6ha4HS8D21jlYZDDCg6dgeqmW7fG8ukV+AZCaA8Y7EH8fRMhfRsAyA5MDsGs7FeYKiEyE/CqwmsHrMuSUwRV/ZZFfu9DXDPbfcPM2dLwGy9cTva6AljkwxrttwYnGNTOUxqkA3s/L3RxVczlMDkJ9P0TclaMrs/DqEaQ8hLImZ+/aIpTGqgCEyLvP8p6LKoyAzVWoNEFWkRwbboXGYjDcgvYVOXawD8+SZDb/lHLIvdvgc9W52+VpyMyXmYiy/4HRTohKcp5qbwceX3OxVhlQ2w1pudpy+NgDdXluAoLC4e04iHsvHpFYmJgJ0clSYGkK5iegpkv+Cwsr0mHL6iZAtIVEQnUHxN6Dv3aYGYP1RSkQFgMJ6eB5CcyfoKEANiyKJ1Z/aAkZkF0C4XEQFi1F1pfAugBDHyT4lFIHaEtCg0VnFD5afnECVSMPAeyytmHDG1/pAAAAAElFTkSuQmCC"); }

.followus .rss, .icon.rss {
	background-image: url("data:image/png;base64,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"); }

.followus .periscope {
	background-image: url("data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAB0AAAAdCAIAAADZ8fBYAAAACXBIWXMAABJ0AAASdAHeZh94AAAAB3RJTUUH4gQVEAg4+eKAogAABDhJREFUSMedVk1oXGUUPfe+N/Mmk0x+GpM0TdOaBlOpSgXdtAoVhUrBuhGKK0EXrrpyIYi4KxQXrYhUcSFaEWtFpVJxI/5iKoVWa9pqUmObnza/k2Q6M3Ey8953j4sXqyGZJPZbPXjvO+9w7zn3XHnkgx+xjiMgIAAAcvFhtaNrfyECkhACBAgRcE1gf3WOhBgJkeaUf0c6cMap+XI+dLfe/n9ckiJC7utue7y7rasxXeurEYXQ9U3lT10ZuzCZBwkAsgK6rFxfEiKbM6mXdt21o6V+xf9+2j927PzVGHk5tL8cUQQU6axPHXnsvpZ0MjSKQAkzp76vQATA7Km7N2UC/3DvFRHhOuuQ8OTl3T0t6WTFzBNRILw5d+2NV8uT43X37mx78kC6o7Pi3N6u1j9mip8MjAvA1fUgACFPbGvd3pwpG31VJWmWbGxq2b3H9V/Kff7xwAvP5y6c8zwvcvbMzq0bUj4B0KrjkgQ8cH/PJiNUZe78WVcpi+dBJGhrD2pr000b/Pn88NFDldlZE80kvL1drQBUtCquqkBkW2N6S0ONCRhGY28dzX72IcsLlezU9Mn3ATByydoMJ25kv/pCFQQe3NQkoC3lu7S+BICuxloPqAALo8Nudnr2o+Pzvd9F80U3OyPJADQSvu+Xfr9ogE+016VSKiWLBS0r9o2AZIIERQhExYKSGgTl6yNQ0VSKZgSEEFUulGhwitpkIuV7pYoT+bd7uqxtiMwAGJBs2SjJJM00CMTzF10AiAqd85uaY3KRmTNbbT7E94bmigDEMdm+seae+6NiAepBhGTsQQBmrH/oUQoUmCguFEIHkqyGSwLonymOF8u+wojW5w5qa3t0c26xrb4Ps0p2OrN3f/3De6KIAvRN5CiqssR1S+sgIrQypXc064tEkQWbOzsPvZ56YJdzLirko0Le+X7D08+2H3yRBk9Qcfx6aAqAcVW/xSPqVP+Nfd0bEwl1oQVb79x86LXSlYFwfBTqBdt6Uh0dNERmdb5+M5z9M1f6rxKq+5g29lf45eDEgR0dBQEcBazp2Z7u2R73wCJH8TyVBeOJi0MQWY67bK5LXCeeuDwyNl8OPDGShEXmKpGrhBY6ika0GpXTA2ODN8swB9V15IUIyFzFjp0dTMo/+hOB58NLQNWRaU+H8qV3fxmqNt1XziECMHdmPHfyt+t1voakAQQJGuEBkdmRMwMlAqSorjvfRAmB2ds/X/vpxlxDQp0xNouRaV/fPHf10sw8zFWLoqq5GbMg5HDvwK/T+YaEhkaY1Sf0+MWR04OToEFkxRBaK49VQRZC98q3l78fyTYmtCbhvXNh+L2+UZgjAalOq+r+EEuHBA3q0WzPlubcQtiXLdI5iEh1sqvmcXxHBOLFE+eH63OxukVlUSG3tz8s8TegIAmuhbjefecWtBGssi3cLl8A60aMz9/uIDYzpseL+gAAAABJRU5ErkJggg=="); }

.followus .email {
	background-image: url("data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAACEAAAAWCAYAAABOm/V6AAAACXBIWXMAAAsTAAALEwEAmpwYAAAAB3RJTUUH4gQVECMqfCsMgwAAAshJREFUSMfF1s9P02AYwPFvyxwbHRuMrYOVVgS2BRNBDfHqxXDxz/Bq4sH/QA+e/B8MR+9e/QcUMk0IMBRho4R1g7LRbmPA6mFuqLAxfj9Jk6bv276fPHnep6+QnJ3xAq+Bl0CEm41PwBsX8AJ4y+3Ec2DYBbwCCClj7O1k6Q3KRO5OXNuqlVKRjVQSr6+PXSMDMCUCIwCylkCJTWHt5smuLV4LYL9ssZFK4g9GUMYnm8/Fvyd5fX1Exx7UIetXC6mWbTLLc/gHBpG1+D9jIuDUb51jyPgklpknu750NYBKifTSVwKhKOHhGCCcQJwIry+AEptizzQw0suXByx+oS+sEFLGEQThxByx1cseyc9w/BHFnSy5zAqO41wYEAgrDERHTwW0RQB4enpRE48pbG+S13/iOLVz1UADEIqOIoitlxLP+li314eWmKaQ09nWV3FqZ0P2Sxbp5TkC4SghZawtoCMEgNsroU1Ms5vTyW+uts1IpVQkk5rHHxxsWQMXQgC4PXVIIaeT11dPrZGKXUBPJekNRpC1eEeAcyGqlRJGOoUUCFHI6+QyKWpHh81xu7CNvvKd7h4fFbuImc10XD+uzgA2RjqFRwoQUkbZL9ts/vjG4UGVbq+PWu0Qy8zROxBBVuNU7CJGJgVAf0S9fCb+B9SLVUK7/wTXHTd2cYdq2SasxpDVeHN7y2qcPdNo/B8unoljgL8JaERXlwtZS9Cuz8hqrN5jgH5ZPX8mGjXgkfwMREcv1C09kp+wGsPaaZ8R8biRH1fywX4ZI71cBwzd67jKW2ZES7BnGpgtICJQBZpN6KBaIbu+hEfyExwaObPRdBLdPT5kLYFlGqfuGhGYB9haW+Do8ICtXwt1wKCGIAg4Tu1KLrenh7AaxzKzZNcWsXZzDUNJSM7OPPtz1nPf0hHvowv4DDwF3gEPAekGFnaADPABeP8bNrJaPIc3C6EAAAAASUVORK5CYII="); }

.provisional.gc-followus .facebook::before, .provisional.gc-followus .twitter::before, .provisional.gc-followus .youtube::before, .provisional.gc-followus .instagram::before, .provisional.gc-followus .linkedin::before {
	background-repeat: no-repeat;
	background-size: cover;
	content: "";
	height: 38px;
	margin-right: 10px;
	min-width: 38px; }

.provisional.gc-followus h2 {
	font-size: 1.1em; }

.provisional.gc-followus ul {
	display: block;
	font-size: 87%;
	font-weight: 700;
	list-style: none;
	-webkit-margin-before: 1em;
	        margin-block-start: 1em;
	-webkit-padding-start: calc(1em + 6px);
	        padding-inline-start: calc(1em + 6px); }
	.provisional.gc-followus ul li {
		margin-bottom: 21px; }
		.provisional.gc-followus ul li:last-child {
			margin-bottom: 15px; }
		.provisional.gc-followus ul li a {
			display: -webkit-box;
			display: -ms-flexbox;
			display: flex;
			line-height: 1.54;
			max-width: -webkit-max-content;
			max-width: -moz-max-content;
			max-width: max-content;
			text-decoration: none; }
			.provisional.gc-followus ul li a::before {
				margin-right: 10px;
				margin-top: -6px; }
			.provisional.gc-followus ul li a:hover, .provisional.gc-followus ul li a:focus, .provisional.gc-followus ul li a:active {
				text-decoration: underline; }
	.provisional.gc-followus ul.list-inline {
		-webkit-padding-start: 0;
		        padding-inline-start: 0; }
		.provisional.gc-followus ul.list-inline li {
			display: inline-block;
			padding-right: 0; }
			.provisional.gc-followus ul.list-inline li a {
				height: 38px;
				overflow: hidden;
				width: 38px; }
				.provisional.gc-followus ul.list-inline li a::before {
					margin-top: 0; }
				.provisional.gc-followus ul.list-inline li a:hover, .provisional.gc-followus ul.list-inline li a:focus, .provisional.gc-followus ul.list-inline li a:active {
					outline: solid 2px #0535d2; }

.provisional.gc-followus .facebook::before {
	background-image: url("../assets/gc-follow-us/facebook.svg"); }

.provisional.gc-followus .twitter::before {
	background-image: url("../assets/gc-follow-us/twitter.svg"); }

.provisional.gc-followus .youtube::before {
	background-image: url("../assets/gc-follow-us/youtube.svg"); }

.provisional.gc-followus .instagram::before {
	background-image: url("../assets/gc-follow-us/instagram.svg"); }

.provisional.gc-followus .linkedin::before {
	background-image: url("../assets/gc-follow-us/linkedin.svg"); }

.shr-pg a {
	background-image: none; }

.followus {
	background-color: #eaebed;
	display: inline-block;
	margin-bottom: 15px;
	padding: 10px 5px; }
	.followus h2 {
		display: inline;
		font-size: 16px;
		margin-left: 5px; }
	.followus ul {
		display: inline;
		margin-left: 5px;
		padding-left: 0; }
		.followus ul li {
			display: inline-block;
			margin: 5px 0;
			padding: 0; }
			.followus ul li a {
				border: solid 2px #eaebed;
				padding: 10px 17px; }
				.followus ul li a:hover, .followus ul li a:focus, .followus ul li a:active {
					border: solid 2px #0535d2; }
	.followus .youtube {
		min-width: 38px; }
	.followus .googleplus {
		background-repeat: no-repeat;
		background-size: 35px 35px; }

.icon {
	background-position: left center;
	background-repeat: no-repeat;
	display: inline-block;
	min-height: 32px;
	min-width: 32px;
	padding-left: 35px; }
	.icon.youtube {
		padding-left: 45px; }
	.icon.googleplus {
		height: 45px;
		padding-left: 48px; }

/*
	Github addition Widget Format
	Use in:
	+ Event page
	+ campaign
	+ widgets
*/
.fd-wdgt.panel {
	padding-left: 0;
	padding-right: 0; }

.fd-wdgt .panel-heading {
	border-bottom: 1px solid #ddd; }

.fd-wdgt .panel-body {
	max-height: 25em;
	overflow-y: scroll;
	padding: 0; }

.fd-wdgt .media {
	border-top: 1px solid #ddd;
	margin-top: 0;
	padding: 15px 15px 0 5px;
	position: relative; }
	.fd-wdgt .media:first-child {
		border-top: 0; }
	.fd-wdgt .media p {
		font-size: .9em; }

.fd-wdgt .panel-title {
	padding-right: 30px; }
	.fd-wdgt .panel-title .icon {
		position: absolute;
		right: 5px;
		top: 5px; }

.fd-wdgt .feeds-date {
	display: inline-block;
	float: none !important;
	padding-top: 10px; }
	.fd-wdgt .feeds-date:before {
		content: ""; }
	.fd-wdgt .feeds-date:after {
		content: ""; }

.fd-wdgt .media-body img {
	display: block;
	margin-left: auto;
	margin-right: auto;
	padding: 15px 10px 5px; }

/* IE Tweaks */
.lt-ie9 .fd-wdgt .panel-title {
	padding-right: 30px; }
	.lt-ie9 .fd-wdgt .panel-title .icon {
		padding-left: 0; }

/*
 * Pagination
 */
.pagntn-prv-nxt {
	margin-bottom: 15px; }
	.pagntn-prv-nxt .glyphicon-chevron-left,
	.pagntn-prv-nxt .glyphicon-chevron-right {
		font-size: 2em; }
	.pagntn-prv-nxt .glyphicon-chevron-left {
		float: left;
		margin: -4px 0 0 -32px; }
	.pagntn-prv-nxt .glyphicon-chevron-right {
		float: right;
		margin: -4px -32px 0 0; }
	.pagntn-prv-nxt li {
		font-size: 16px;
		font-weight: 300;
		list-style: none outside none; }
		.pagntn-prv-nxt li a {
			display: block;
			padding: 15px 40px;
			text-decoration: none; }
			.pagntn-prv-nxt li a:hover {
				background-color: #eaebed; }
			.pagntn-prv-nxt li a .pgntn-lbl {
				display: block;
				font-size: 27px;
				font-weight: 400; }

/*
* Table of Content styles for document navigation
*/
.toc li {
	display: inline;
	font-size: .85em;
	/* Expected 17px with 20px base font */ }
	.toc li .list-group-item:focus, .toc li .list-group-item:hover {
		background-color: #f5f5f5;
		text-decoration: none; }
	.toc li .list-group-item.active, .toc li .list-group-item.active:focus, .toc li .list-group-item.active:hover {
		background-color: #26374a;
		color: #fff;
		cursor: auto;
		text-decoration: none;
		z-index: 2; }

/*
 * Well header responsive
 */
.bg-gctheme.well.header-rwd {
	background-color: #26374a; }

.well.header-rwd {
	width: 100%; }

.bg-darker.well.header-rwd h1 {
	border-bottom-color: #6f6f6f; }

/*
 * tbl-floatcolumn
 */
.table-columnfloat th:first-child {
	float: left; }

.table-columnfloat td:nth-of-type(1) {
	clear: left;
	float: left; }

.table-columnfloat thead th:nth-child(2) {
	clip: rect(1px, 1px, 1px, 1px);
	height: 1px;
	margin: 0;
	overflow: hidden;
	position: absolute;
	width: 1px; }

.table-columnfloat th:first-child, .table-columnfloat td:nth-of-type(1) {
	border: none; }

.table-columnfloat tr, .table-columnfloat th:not(:first-of-type), .table-columnfloat td {
	border-bottom: 1px solid #ddd; }

/*
 *
 * Web Experience Toolkit (WET) / Boîte à outils de l'expérience Web (BOEW)
 * wet-boew.github.io/wet-boew/License-en.html / wet-boew.github.io/wet-boew/Licence-fr.html
 *
*/
.wb-fieldflow-form .input-group .form-control:last-child {
	border-radius: 4px 0 0 4px; }

/*
 *
 * Web Experience Toolkit (WET) / Boîte à outils de l'expérience Web (BOEW)
 * wet-boew.github.io/wet-boew/License-en.html / wet-boew.github.io/wet-boew/Licence-fr.html
 *
 *
 *	GC Checkboxes and radio buttons
*/
fieldset.gc-chckbxrdio {
	border-top: 0;
	padding-top: 0; }

.gc-chckbxrdio label {
	cursor: pointer;
	display: block;
	font-size: 20px; }

.gc-chckbxrdio legend {
	float: none;
	font-size: 22px;
	font-weight: 700;
	margin-bottom: 15px;
	margin-top: 0; }

.gc-chckbxrdio input[type="radio"],
.gc-chckbxrdio input[type="checkbox"] {
	border: 0;
	clip: rect(0 0 0 0);
	height: 1px;
	margin: -1px;
	overflow: hidden;
	padding: 0;
	position: absolute;
	width: 1px; }
	.gc-chckbxrdio input[type="radio"][disabled] + label,
	.gc-chckbxrdio input[type="checkbox"][disabled] + label {
		cursor: not-allowed;
		opacity: .5; }
	.gc-chckbxrdio input[type="radio"] + label,
	.gc-chckbxrdio input[type="checkbox"] + label {
		display: inline-block;
		line-height: 2;
		margin-left: 36px;
		width: auto; }
	.gc-chckbxrdio input[type="radio"] + label::before,
	.gc-chckbxrdio input[type="checkbox"] + label::before {
		border: 4px solid #fff;
		-webkit-box-shadow: 0 0 0 2px #000;
		        box-shadow: 0 0 0 2px #000;
		content: "";
		display: inline-block;
		height: 36px;
		left: 0;
		position: absolute;
		top: 2px;
		width: 36px; }
	.gc-chckbxrdio input[type="radio"] + label:hover::before,
	.gc-chckbxrdio input[type="checkbox"] + label:hover::before {
		background-image: -webkit-gradient(linear, left top, left bottom, from(#e6e5e5), color-stop(50%, white));
		background-image: linear-gradient(to bottom, #e6e5e5, white 50%); }
	.gc-chckbxrdio input[type="radio"]:focus + label::before,
	.gc-chckbxrdio input[type="checkbox"]:focus + label::before {
		-webkit-box-shadow: 0 0 0 2px #000, 0 0 8px 4px #3b99fc;
		        box-shadow: 0 0 0 2px #000, 0 0 8px 4px #3b99fc; }

.gc-chckbxrdio input[type="radio"] + label::before {
	border-radius: 50%; }

.gc-chckbxrdio input[type="radio"]:checked + label::before {
	background: #444; }

.gc-chckbxrdio.checkbox input[type="checkbox"] + label,
.gc-chckbxrdio.checkbox input[type="checkbox"] + label + ul {
	font-size: 17px;
	min-height: 23px; }

.gc-chckbxrdio.checkbox input[type="checkbox"] + label::before {
	height: 24px;
	left: 6px;
	top: 4px;
	width: 24px; }

.gc-chckbxrdio.checkbox input[type="checkbox"]:checked + label::after {
	border-width: 0 3px 3px 0;
	height: 16px;
	left: 14px;
	top: 6px;
	width: 9px; }

.gc-chckbxrdio input[type="checkbox"]:checked + label::after {
	border-color: #333;
	border-style: solid;
	border-width: 0 5px 5px 0;
	content: "";
	display: inline-block;
	height: 26px;
	left: 12px;
	position: absolute;
	top: 4px;
	-webkit-transform: rotate(45deg);
	        transform: rotate(45deg);
	width: 13px; }

.gc-chckbxrdio.form-inline .label-inline {
	padding-right: 20px; }
	.gc-chckbxrdio.form-inline .label-inline label {
		padding-left: 10px; }

/*
 *
 * Web Experience Toolkit (WET) / Boîte à outils de l'expérience Web (BOEW)
 * wet-boew.github.io/wet-boew/License-en.html / wet-boew.github.io/wet-boew/Licence-fr.html
 *
 * @title: GC Features component
 *
 */
.gc-features {
	margin-bottom: 15px; }
	.gc-features a:hover {
		text-decoration: none; }
	.gc-features img {
		width: 100%; }
	.gc-features .well {
		border-radius: 0;
		position: relative; }

aside.site-related h2 {
	font-size: 28px;
	margin-top: 0; }

aside.features {
	background-color: #eaebed;
	background-image: -webkit-gradient(linear, left top, left bottom, from(#eaebed), to(#eaebed));
	background-image: linear-gradient(to bottom, #eaebed 0%, #eaebed 100%);
	padding-bottom: 1.5em; }
	aside.features h2 {
		border: 0; }
	aside.features figcaption {
		font-weight: 700;
		margin-top: 3px; }
	aside.features .thumbnail {
		background-color: transparent;
		border: 0;
		border-radius: 0;
		margin-bottom: 1.5em;
		padding: 10px 10px 0; }
		aside.features .thumbnail img {
			border: solid 1px #eee;
			max-width: 100%; }

/* Deprecated as v4.0.28 */
.gc-nttvs {
	border-top: 1px solid #ccc; }

/*
 * Feature
 *
 * Deprecated as v4.0.28
 * - style applied for: h2, h3, h4
 * - class .gc-nttvs
 */
.gc-prtts a,
.gc-nttvs a {
	text-decoration: none; }
	.gc-prtts a h2,
	.gc-prtts a h3,
	.gc-prtts a h4,
	.gc-prtts a figcaption,
	.gc-nttvs a h2,
	.gc-nttvs a h3,
	.gc-nttvs a h4,
	.gc-nttvs a figcaption {
		font-size: 20px;
		font-weight: bold;
		margin-top: 23px;
		text-decoration: underline; }
	.gc-prtts a p:last-child,
	.gc-nttvs a p:last-child {
		color: black; }

/*
 * CSS used for the legacy/obselete code
 */
/* Report a problem Thank you message */
.gc-rprt-prblm-thnk {
	padding-bottom: 25px; }

/* Report a problem temporary fix for toggle : GH issue #1336 */
.gc-rprt-prblm-frm.gc-rprt-prblm-tggl.show {
	display: none !important; }

/* Hide RAP textarea and Other : GH issue #1336 */
.gc-rprt-prblm-frm .form-group {
	display: none !important; }

.gc-rprt-prblm-frm label[for=problem6] {
	display: none !important; }

/*
 * Web Experience Toolkit (WET) / Boîte à outils de l'expérience Web (BOEW)
 * wet-boew.github.io/wet-boew/License-en.html / wet-boew.github.io/wet-boew/Licence-fr.html
 * Chat wizard - Provisional CSS
 *
 * ++++++++
 * This is a Provisional CSS, once stabilized it's include should be done from the theme.scss instead of _provisional.scss
 * ++++++++
 *
 */
/* Animations */
@-webkit-keyframes slideInFromRight {
	0% {
		-webkit-transform: scale(0, 1);
		        transform: scale(0, 1); }
	95% {
		-webkit-transform: scale(0, 1);
		        transform: scale(0, 1); }
	100% {
		-webkit-transform: scale(1, 1);
		        transform: scale(1, 1); } }
@keyframes slideInFromRight {
	0% {
		-webkit-transform: scale(0, 1);
		        transform: scale(0, 1); }
	95% {
		-webkit-transform: scale(0, 1);
		        transform: scale(0, 1); }
	100% {
		-webkit-transform: scale(1, 1);
		        transform: scale(1, 1); } }

@-webkit-keyframes pulseIn {
	0% {
		-webkit-transform: scale(1, 1);
		        transform: scale(1, 1); }
	15% {
		-webkit-transform: scale(1.15, 1.15);
		        transform: scale(1.15, 1.15); }
	30% {
		-webkit-transform: scale(1, 1);
		        transform: scale(1, 1); }
	65% {
		-webkit-transform: scale(1.3, 1.3);
		        transform: scale(1.3, 1.3); }
	100% {
		-webkit-transform: scale(1, 1);
		        transform: scale(1, 1); } }

@keyframes pulseIn {
	0% {
		-webkit-transform: scale(1, 1);
		        transform: scale(1, 1); }
	15% {
		-webkit-transform: scale(1.15, 1.15);
		        transform: scale(1.15, 1.15); }
	30% {
		-webkit-transform: scale(1, 1);
		        transform: scale(1, 1); }
	65% {
		-webkit-transform: scale(1.3, 1.3);
		        transform: scale(1.3, 1.3); }
	100% {
		-webkit-transform: scale(1, 1);
		        transform: scale(1, 1); } }

@-webkit-keyframes grow {
	to {
		-webkit-transform: translateX(-50%) scale(0);
		        transform: translateX(-50%) scale(0); } }

@keyframes grow {
	to {
		-webkit-transform: translateX(-50%) scale(0);
		        transform: translateX(-50%) scale(0); } }

.trans-left {
	-webkit-animation-delay: 0s;
	        animation-delay: 0s;
	-webkit-animation-duration: 5s;
	        animation-duration: 5s;
	-webkit-animation-iteration-count: 1;
	        animation-iteration-count: 1;
	-webkit-animation-name: slideInFromRight;
	        animation-name: slideInFromRight;
	-webkit-animation-timing-function: ease-out;
	        animation-timing-function: ease-out;
	-webkit-transform-origin: 100% 50%;
	        transform-origin: 100% 50%;
	will-change: scroll-position; }

.trans-pulse {
	-webkit-animation: .5s linear 3.5s 1 pulseIn, .5s linear 15s 1 pulseIn, .5s linear 30s 1 pulseIn;
	        animation: .5s linear 3.5s 1 pulseIn, .5s linear 15s 1 pulseIn, .5s linear 30s 1 pulseIn;
	will-change: transform; }

.loader-typing {
	bottom: 30%;
	height: 6px;
	left: 30px;
	position: absolute;
	-webkit-transform: translateX(-50%) translateY(-50%);
	        transform: translateX(-50%) translateY(-50%);
	width: 26px; }

.loader-dot {
	-webkit-animation: grow .5s ease-in-out infinite alternate;
	        animation: grow .5s ease-in-out infinite alternate;
	background-color: #444;
	border-radius: 50%;
	height: 6px;
	position: absolute;
	width: 6px;
	will-change: transform; }

.loader-dot.dot1 {
	left: 0;
	-webkit-transform-origin: 100% 50%;
	        transform-origin: 100% 50%; }

.loader-dot.dot2 {
	-webkit-animation-delay: .1s;
	        animation-delay: .1s;
	left: 50%;
	margin-left: -3px;
	-webkit-transform: scale(0.99);
	        transform: scale(0.99); }

.loader-dot.dot3 {
	-webkit-animation-delay: .2s;
	        animation-delay: .2s;
	right: 0; }

/* Chat wizard Bubble */
.wb-chtwzrd-bubble-wrap {
	bottom: 30px;
	height: 60px;
	position: fixed;
	right: 30px;
	width: 60px;
	z-index: 1049; }

.wb-chtwzrd-bubble-wrap p {
	background: #335075;
	border-bottom-left-radius: 25px;
	border-top-left-radius: 25px;
	-webkit-box-shadow: 0 1px 3px rgba(0, 0, 0, 0.45);
	        box-shadow: 0 1px 3px rgba(0, 0, 0, 0.45);
	color: #fff;
	font-size: 14px;
	line-height: 20px;
	min-height: 50px;
	padding: 5px 37.5px 5px 27.5px;
	position: relative;
	right: 195px;
	top: 5px;
	width: 225px; }

.wb-chtwzrd-bubble-wrap p .notif-close {
	background: #333;
	border-radius: 50%;
	color: #fff;
	font-size: 19px;
	height: 1.25em;
	line-height: 21px;
	position: absolute;
	right: 92.5%;
	text-align: center;
	text-decoration: none;
	top: 0;
	width: 1.25em; }

.wb-chtwzrd-bubble-wrap .notif {
	cursor: pointer; }

.wb-chtwzrd-bubble-wrap .bubble {
	background: #fff url("../assets/wb-chtwzrd/default-avatar.png") center no-repeat;
	border-radius: 50%;
	bottom: 0;
	-webkit-box-shadow: 0 2px 4px rgba(0, 0, 0, 0.45);
	        box-shadow: 0 2px 4px rgba(0, 0, 0, 0.45);
	height: 100%;
	overflow: hidden;
	position: absolute;
	right: 0;
	text-indent: -9999px;
	white-space: nowrap;
	width: 100%;
	z-index: 1048; }

.wb-chtwzrd-bubble-wrap .bubble:focus {
	border: 1px solid rgba(0, 0, 0, 0.5);
	-webkit-box-shadow: 0 2px 3px rgba(0, 0, 0, 0.7);
	        box-shadow: 0 2px 3px rgba(0, 0, 0, 0.7); }

.wb-chtwzrd-btn-extrnl + .wb-chtwzrd-bubble-wrap {
	display: none !important; }

/* Chat Wizard */
.wb-disable .wb-chtwzrd.hidden {
	display: block !important; }

.wb-chtwzrd-container {
	background-color: #fff;
	bottom: 20px;
	display: none;
	font-size: .9em;
	min-height: 200px;
	overflow: hidden;
	position: fixed;
	right: 20px;
	width: 25%;
	z-index: 1050; }

.wb-chtwzrd-container .header {
	max-height: 70px;
	min-height: 39px;
	padding-right: 84px; }

.wb-chtwzrd-container .header .title {
	-webkit-box-orient: vertical;
	-webkit-line-clamp: 2;
	display: -webkit-box;
	font-size: 19px;
	line-height: 1.35;
	overflow: hidden;
	padding: 6px 0;
	text-overflow: ellipsis; }

.wb-chtwzrd-container .minimize, .wb-chtwzrd-container .reset {
	-webkit-appearance: none;
	background: transparent;
	border: 0;
	color: #fff;
	filter: alpha(opacity=65);
	font-size: 1em;
	font-weight: 700;
	height: 40px;
	line-height: 41px;
	margin: 0;
	opacity: .65;
	overflow: visible;
	padding: 0;
	position: absolute;
	right: 0;
	text-decoration: none;
	top: 0;
	width: 40px; }

.wb-chtwzrd-container .reset {
	right: 42px; }

.wb-chtwzrd-container .minimize:focus, .wb-chtwzrd-container .reset:focus {
	opacity: 1;
	outline: 1px dotted #fff;
	outline-offset: -2px; }

.wb-chtwzrd-container .conversation {
	margin-bottom: 15px;
	max-height: 45vh;
	min-height: 200px;
	overflow-x: hidden;
	overflow-y: auto; }

.wb-chtwzrd-container .history {
	padding-top: 15px; }

.wb-chtwzrd-container .history::before {
	background: -webkit-gradient(linear, left top, left bottom, color-stop(20%, #fff), to(rgba(255, 255, 255, 0)));
	background: linear-gradient(to bottom, #fff 20%, rgba(255, 255, 255, 0) 100%);
	content: "";
	height: 40px;
	left: 0;
	pointer-events: none;
	position: absolute;
	top: 0;
	width: 100%;
	z-index: 1054; }

.wb-chtwzrd-container .controls {
	height: 75px; }

.wb-chtwzrd-container .inputs-zone fieldset:first-child {
	border-top: 1px solid #e5e5e5; }

.wb-chtwzrd-container .inputs-zone ul:last-child {
	margin-bottom: 0; }

.wb-chtwzrd-container .choices input[type=radio]:checked + span {
	color: #333; }

.wb-chtwzrd-container h4,
.wb-chtwzrd-container legend,
.wb-chtwzrd-container h4 .question a {
	font-size: 1em;
	line-height: 1.4375; }

.wb-chtwzrd-container .question,
.wb-chtwzrd-container .message,
.wb-chtwzrd-container label,
.wb-chtwzrd-container .question {
	border-radius: 15px;
	color: #5a5a5a;
	font-weight: normal;
	padding: 8px 12px;
	width: auto; }

.wb-chtwzrd-container .question {
	background-color: #efefef;
	min-width: 60px;
	position: relative; }

.wb-chtwzrd-container .message:focus {
	-webkit-box-shadow: 0 0 4px #666;
	        box-shadow: 0 0 4px #666; }

.wb-chtwzrd-container .message,
.wb-chtwzrd-container label {
	background-color: #ddd; }

.wb-chtwzrd-container .message {
	margin-right: 15px; }

.wb-chtwzrd-container label {
	border: 1px solid #c1c1c1;
	font-weight: bold;
	padding: 6px 10px; }

.wb-chtwzrd-container .avatar,
.wb-chtwzrd-container .question {
	display: table-cell;
	vertical-align: middle; }

.wb-chtwzrd-container .avatar {
	background-color: #fff;
	background-image: url("../assets/default-avatar.png");
	background-position: center;
	background-repeat: no-repeat;
	background-size: 25px;
	height: 30px;
	width: 30px; }

.wb-chtwzrd-container .basic-link {
	min-height: inherit; }

.wb-chtwzrd-mrgn {
	margin-top: 80px; }

.wb-chtwzrd-container legend:focus {
	outline: 1px dotted #666; }

/* Chat wizard inline (full-screen) */
.wb-chtwzrd-contained {
	bottom: 0;
	-webkit-box-shadow: none;
	        box-shadow: none;
	margin: 30px auto;
	position: static;
	right: 0;
	width: 100%; }

.wb-chtwzrd-contained .conversation {
	max-height: 70vh; }

.wb-chtwzrd-contained .minimize {
	display: none; }

.wb-chtwzrd-contained .reset {
	right: 0; }

/* Chat wizard Media queries */
@media screen and (max-width: 1199px) {
	.wb-chtwzrd-container {
		width: 35%; } }

@media screen and (max-width: 992px) {
	.wb-chtwzrd-container {
		width: 45%; } }

@media screen and (max-width: 768px) {
	.wb-chtwzrd-bubble-wrap {
		right: 10px; }
	.wb-chtwzrd-container {
		bottom: 0;
		height: 100%;
		margin: 0;
		padding: 0;
		right: 0;
		width: 100%; }
	.wb-chtwzrd-container .body {
		-webkit-box-direction: normal;
		-webkit-box-orient: vertical;
		display: -webkit-box;
		display: -ms-flexbox;
		display: flex;
		-ms-flex-direction: column;
		    flex-direction: column;
		-ms-flex-wrap: nowrap;
		    flex-wrap: nowrap;
		height: 100%;
		padding-bottom: 75px;
		width: 100%; }
	.wb-chtwzrd-container .conversation {
		-ms-flex-positive: 1;
		-webkit-box-flex: 1;
		flex-grow: 1;
		max-height: none;
		min-height: 2em; }
	.wb-chtwzrd-container .controls {
		-ms-flex-negative: 0;
		flex-shrink: 0;
		height: 75px; }
	.wb-chtwzrd-noscroll {
		overflow: hidden !important; }
	.wb-chtwzrd-bubble-wrap p .notif-close {
		font-size: 2em;
		height: 35px;
		line-height: 1.1em;
		right: 90%;
		width: 35px; }
	.wb-chtwzrd-contained .body {
		padding-bottom: 10px; } }

/*
 *
 * Web Experience Toolkit (WET) / Boîte à outils de l'expérience Web (BOEW)
 * wet-boew.github.io/wet-boew/License-en.html / wet-boew.github.io/wet-boew/Licence-fr.html
 *
 *
 *	Provisional GC Subway map menu
*/
.provisional {
	/*** GC Subway mobile first styles ***/
	/* Double H1 */ }
	.provisional.gc-subway {
		border-radius: 0px 6px 6px 0px;
		border-right: 4px solid #26374a;
		border-top: 4px solid #26374a;
		margin-top: 38px; }
		.provisional.gc-subway ul,
		.provisional.gc-subway dl {
			clear: both;
			list-style: none;
			padding-left: .57em;
			padding-top: 10px;
			position: relative; }
			.provisional.gc-subway ul dt,
			.provisional.gc-subway dl dt {
				border-left: 4px solid #26374a;
				padding: 0px 20px 3px 1em;
				font-weight: normal; }
				.provisional.gc-subway ul dt a::before,
				.provisional.gc-subway dl dt a::before {
					background-color: #fff;
					border: 3px solid #26374a;
					border-radius: 50%;
					content: "";
					height: 1.2em;
					left: 0em;
					position: absolute;
					-webkit-transition: width .2s, height .2s, left .2s, margin-top .2s;
					transition: width .2s, height .2s, left .2s, margin-top .2s;
					width: 1.3em; }
				.provisional.gc-subway ul dt a.active,
				.provisional.gc-subway dl dt a.active {
					color: #333333;
					text-decoration: none; }
					.provisional.gc-subway ul dt a.active::before,
					.provisional.gc-subway dl dt a.active::before {
						background-color: #26374a; }
					.provisional.gc-subway ul dt a.active:hover, .provisional.gc-subway ul dt a.active:focus,
					.provisional.gc-subway dl dt a.active:hover,
					.provisional.gc-subway dl dt a.active:focus {
						color: #0535d2;
						text-decoration: underline; }
				.provisional.gc-subway ul dt a:not(.active):hover::before, .provisional.gc-subway ul dt a:not(.active):focus::before,
				.provisional.gc-subway dl dt a:not(.active):hover::before,
				.provisional.gc-subway dl dt a:not(.active):focus::before {
					height: 1.5em;
					left: -.1em;
					margin-top: -.1em;
					width: 1.5em; }
				.provisional.gc-subway ul dt:last-of-type,
				.provisional.gc-subway dl dt:last-of-type {
					border-left: 5px solid transparent;
					padding-bottom: 0; }
			.provisional.gc-subway ul dd,
			.provisional.gc-subway dl dd {
				border-left: 4px solid #26374a;
				line-height: inherit;
				margin-bottom: 0px;
				margin-top: -3px;
				padding: 0px 20px 20px 1em; }
				.provisional.gc-subway ul dd:last-child,
				.provisional.gc-subway dl dd:last-child {
					border-left: 5px solid transparent;
					padding-bottom: 0; }
			.provisional.gc-subway ul li,
			.provisional.gc-subway dl li {
				border-left: 4px solid #26374a;
				padding: 0px 20px 30px 1em; }
				.provisional.gc-subway ul li a::before,
				.provisional.gc-subway dl li a::before {
					background-color: #fff;
					border: 3px solid #26374a;
					border-radius: 50%;
					content: "";
					height: 1.2em;
					left: 0.05em;
					position: absolute;
					-webkit-transition: width .2s, height .2s, left .2s, margin-top .2s;
					transition: width .2s, height .2s, left .2s, margin-top .2s;
					width: 1.2em; }
				.provisional.gc-subway ul li a.active,
				.provisional.gc-subway dl li a.active {
					color: #333333;
					text-decoration: none; }
					.provisional.gc-subway ul li a.active::before,
					.provisional.gc-subway dl li a.active::before {
						background-color: #26374a; }
					.provisional.gc-subway ul li a.active:hover, .provisional.gc-subway ul li a.active:focus,
					.provisional.gc-subway dl li a.active:hover,
					.provisional.gc-subway dl li a.active:focus {
						color: #0535d2;
						text-decoration: underline; }
				.provisional.gc-subway ul li a:not(.active):hover::before, .provisional.gc-subway ul li a:not(.active):focus::before,
				.provisional.gc-subway dl li a:not(.active):hover::before,
				.provisional.gc-subway dl li a:not(.active):focus::before {
					height: 1.5em;
					left: -.1em;
					margin-top: -.1em;
					width: 1.5em; }
				.provisional.gc-subway ul li::first-line,
				.provisional.gc-subway dl li::first-line {
					line-height: 1; }
				.provisional.gc-subway ul li:last-child,
				.provisional.gc-subway dl li:last-child {
					border-bottom: 4px solid #26374a;
					border-bottom-left-radius: 6px;
					border-left: 4px solid #26374a; }
				.provisional.gc-subway ul li ul,
				.provisional.gc-subway dl li ul {
					margin-top: 20px;
					padding-left: .55em; }
					.provisional.gc-subway ul li ul li:last-child,
					.provisional.gc-subway dl li ul li:last-child {
						border-bottom-width: 0px;
						padding-bottom: 0px; }
		.provisional.gc-subway h1 {
			float: left; }
	.provisional.gc-subway h1,
	.provisional.gc-subway-section .gc-subway-h1 {
		background-color: #fff;
		border-bottom-width: 0px;
		color: #555;
		font-size: 1.3em;
		margin-right: 20px;
		margin-top: -19px;
		padding: 0px 20px 10px 0px; }

h1 ~ .provisional.gc-subway {
	border-right: none;
	border-top: none; }

/*
 * Web Experience Toolkit (WET) / Boîte à outils de l'expérience Web (BOEW)
 * wet-boew.github.io/wet-boew/License-en.html / wet-boew.github.io/wet-boew/Licence-fr.html
 *
 * GC Table provisional style
 * -- Responsive table - part of design, not responsive part --
 */
.provisional.gc-table caption {
	text-align: left; }

.provisional.gc-table td ul {
	-webkit-padding-start: 20px;
	        padding-inline-start: 20px; }

/* Provisional featured link component */
.gc-featured-link {
	background-color: #355688; }
	.gc-featured-link.provisional {
		font-family: Lato, sans-serif;
		opacity: .9;
		padding-bottom: 15px;
		padding-top: 15px; }
		.gc-featured-link.provisional p:first-of-type {
			font-weight: 700;
			margin-bottom: 0px; }
		.gc-featured-link.provisional p, .gc-featured-link.provisional a {
			color: #fff; }

/* Provisional most requested component */
.provisional.gc-most-requested {
	border: none; }
	.provisional.gc-most-requested h2 {
		font-size: 1.1em;
		margin-top: 15px; }
	.provisional.gc-most-requested ul {
		margin-bottom: 15px;
		margin-top: 15px; }
		.provisional.gc-most-requested ul li {
			font-family: "Lato", sans-serif;
			font-size: 87%;
			font-weight: 700;
			line-height: 1.5em; }

/* Well bold provisional */
.well.well-bold {
	font-weight: 700; }
	.well.well-bold strong {
		font-weight: 400; }

/* Feeds plugin GC override */
.provisional.gc-feeds {
	border: none; }
	.provisional.gc-feeds li {
		line-height: 1.65em;
		padding: 0px; }
		.provisional.gc-feeds li a {
			font-weight: 700; }

/* Profile on page-type-navigation pages
 * was: ".secondary" which are now deprecated */
.secondary .profile .thumbnail, .page-type-nav .profile .thumbnail {
	margin-top: 1.25em; }

.page-type-search label {
	font-weight: normal; }

.page-type-search .current, .page-type-search .current label {
	font-weight: 700; }

.page-type-search .location {
	color: #006621;
	padding-left: 0px; }
	.page-type-search .location li {
		display: inline-block; }
		.page-type-search .location li + li:before {
			content: "> "; }
	.page-type-search .location cite {
		font-style: normal; }

.page-type-search .context-labels {
	font-size: .8em;
	list-style: none;
	padding-left: 0px; }
	.page-type-search .context-labels li {
		background-color: #5e738b;
		color: #fff;
		display: inline-block;
		font-weight: 700;
		margin-bottom: 1px;
		padding: 0 5px; }

.page-type-search .results > section {
	border-bottom: solid 1px #000;
	margin-bottom: 1.5em;
	padding-bottom: 1.5em; }

.page-type-search .label li {
	background-color: #5e738b;
	color: white;
	font-size: .8em;
	font-weight: bold;
	margin-top: 5px;
	padding-left: 5px;
	padding-right: 5px; }

.page-type-search .expand-collapse-buttons {
	color: white;
	font-size: .8em;
	font-weight: bold;
	padding-left: 5px;
	padding-right: 5px; }

.page-type-search cite a {
	color: #006621;
	display: inline-block;
	font-size: 1em;
	margin-top: 10px; }

.page-type-search .search-description {
	line-height: 34px;
	padding-bottom: 8px;
	padding-top: 8px; }

/*
 *
 * Web Experience Toolkit (WET) / Boîte à outils de l'expérience Web (BOEW)
 * wet-boew.github.io/wet-boew/License-en.html / wet-boew.github.io/wet-boew/Licence-fr.html
 *
 * @title: Home page exclusive style
 *
 */
.home {
	/*
	 * GCWeb menu
	 */
	/* Home page banner
	 *
	 * Reference in:
	 * - components/_screen-xxs-max
	 * - components/_screen-xs-min-to-screen-xs-max
	 * - components/_screen-md-min-to-screen-md-max
	 * - components/_screen-md-max
	 * - components/_screen-lg-min
	 */
	/* Home page Most requested section
	 *
	 * Reference in:
	 * - views/_screen-sm-max
	 */
	/* Home page your gov
	 *
	 * Reference in:
	 * - views/_screen-sm-max
	 */ }
	.home h1 {
		border-bottom-width: 4px;
		font-weight: 500;
		margin-top: 10px; }
	.home h2 {
		font-size: 1.2em; }
	.home #wb-bnr + hr {
		border-top: 1px solid #ddd;
		color: #284162;
		margin-left: 0px; }
	.home #wb-bnr + .gcweb-menu {
		border-top: 1px solid #ddd;
		color: #284162;
		margin-left: 0px; }
		.home #wb-bnr + .gcweb-menu .container {
			padding: 0px; }
	.home #wb-so .btn {
		margin-top: 3px; }
	.home .header-rwd {
		margin: 2em 0px; }
	.home .home-most-requested li {
		font-family: Lato, sans-serif;
		font-size: 17px;
		font-weight: 700;
		line-height: 26px;
		margin-top: 0px; }
	.home .home-your-gov {
		background-image: url(https://www.canada.ca/content/dam/canada/carousel/bkg-home-yourgov.jpg), url(../assets/bkg-home-yourgov.jpg);
		background-position: right center;
		background-repeat: no-repeat;
		background-size: 38%; }

/* The blog page template was removed on Sep 27, 2016 and introduced in 2014
 *
 * Introduced commit: https://github.com/wet-boew/GCWeb/commit/9bf094b6b68413ceec05295644e7d82074754d50#diff-39233a6d1c9cb49f3a36b9e4884a205e719494c7f6cb415a1d358239a795de71
 * Removal commit: https://github.com/wet-boew/GCWeb/commit/0c80ed18fdc901cda4bd9a6128b422d3cf1fd5c3
 *
 * We can presume this code bellow are unused and was forgotten to be removed along with the demoed template
 * This style don't seem to be documented anywhere.
 *
 */
.blog article .col-md-3,
.blog article .col-md-9 {
	display: inline-block;
	float: none;
	margin-right: -4px;
	vertical-align: middle; }

.zbra section.brdr-tp:nth-child(odd) {
	background: #eee; }

.zbra section.brdr-tp .row {
	margin-left: -5px;
	margin-right: -5px; }

/*
 * Social media centre
 */
/* Re-usable rules */
.backgroundsize.csstransitions .product-name, .backgroundsize.csstransitions .product-platforms, .backgroundsize.csstransitions .product-department,
.backgroundsize.csstransitions .product-language,
.backgroundsize.csstransitions .product-link-container, #mobile-centre_wrapper .product-name, #mobile-centre_wrapper .product-platforms, #mobile-centre_wrapper .product-links, #mobile-centre_wrapper .product-shortdescription,
#mobile-centre_wrapper .product-longdescription, #mobile-centre_wrapper .product-department {
	border: 0;
	display: block; }

.backgroundsize.csstransitions #mobile-centre tbody tr .product-longdescription,
.backgroundsize.csstransitions #mobile-centre tbody tr td.product-link-container,
.backgroundsize.csstransitions #mobile-centre tbody tr .product-department, #mobile-centre_wrapper .record-close, #mobile-centre_wrapper table :target .product-data-compressed, #mobile-centre_wrapper .product-data-hidden, #mobile-centre_wrapper .product-data-expanded {
	display: none;
	visibility: hidden; }

.backgroundsize.csstransitions #mobile-centre tbody tr:target .product-longdescription,
.backgroundsize.csstransitions #mobile-centre tbody tr:target td.product-link-container,
.backgroundsize.csstransitions #mobile-centre tbody tr:target .product-department, #mobile-centre_wrapper table :target .record-close, #mobile-centre_wrapper table :target .product-data-expanded, #mobile-centre_wrapper .product-data-compressed {
	display: block;
	visibility: visible; }

.backgroundsize.csstransitions {
	/* Layout of fields */ }
	.backgroundsize.csstransitions #social-media-centre tbody {
		padding-top: 2em; }
		.backgroundsize.csstransitions #social-media-centre tbody tr {
			background-clip: content-box;
			background-color: #eee;
			background-image: url("data:image/gif;base64,R0lGODlhAQABAIAAAMLCwgAAACH5BAAAAAAALAAAAAABAAEAAAICRAEAOw=="), url("data:image/gif;base64,R0lGODlhAQABAIAAAMLCwgAAACH5BAAAAAAALAAAAAABAAEAAAICRAEAOw=="), url("data:image/gif;base64,R0lGODlhAQABAIAAAMLCwgAAACH5BAAAAAAALAAAAAABAAEAAAICRAEAOw=="), url("data:image/gif;base64,R0lGODlhAQABAIAAAMLCwgAAACH5BAAAAAAALAAAAAABAAEAAAICRAEAOw==");
			background-origin: content-box;
			background-position: top left, top left, bottom left, top right;
			background-repeat: repeat-x, repeat-y, repeat-x, repeat-y;
			border: 0;
			display: inline-block;
			margin-bottom: 20px;
			padding: 5px;
			text-align: center;
			vertical-align: middle;
			width: 100%; }
			@media (min-width: 768px) {
				.backgroundsize.csstransitions #social-media-centre tbody tr {
					width: 50%; } }
			@media (min-width: 1200px) {
				.backgroundsize.csstransitions #social-media-centre tbody tr {
					width: 33.333%; } }
			.backgroundsize.csstransitions #social-media-centre tbody tr .product-department {
				height: 3em;
				white-space: normal; }
	.backgroundsize.csstransitions .product-listing {
		border: 0;
		width: 100%; }
	.backgroundsize.csstransitions .product-record {
		display: inline-block;
		margin-bottom: 20px;
		width: 100%; }
		.backgroundsize.csstransitions .product-record:target {
			height: auto !important; }
	.backgroundsize.csstransitions .product-department,
	.backgroundsize.csstransitions .product-language,
	.backgroundsize.csstransitions .product-link-container {
		margin-top: 1em; }
	.backgroundsize.csstransitions .product-department,
	.backgroundsize.csstransitions .product-language {
		font-weight: bold;
		margin-top: 1em; }
	.backgroundsize.csstransitions .product-link {
		display: block;
		padding: 6px 12px !important;
		text-decoration: none;
		text-transform: none !important;
		white-space: normal; }
		.backgroundsize.csstransitions .product-link:hover, .backgroundsize.csstransitions .product-link:focus {
			text-decoration: none; }

#social-media-centre_wrapper .datatables_wrapper {
	margin-bottom: 3em; }

#social-media-centre_wrapper .product-listing {
	border: 1px solid #ddd; }
	#social-media-centre_wrapper .product-listing td {
		padding: 8px; }

/*
 * Mobile centre
 */
/* Re-usable rules */
.backgroundsize.csstransitions .product-name, .backgroundsize.csstransitions .product-platforms, .backgroundsize.csstransitions .product-department,
.backgroundsize.csstransitions .product-language,
.backgroundsize.csstransitions .product-link-container, #mobile-centre_wrapper .product-name, #mobile-centre_wrapper .product-platforms, #mobile-centre_wrapper .product-links, #mobile-centre_wrapper .product-shortdescription,
#mobile-centre_wrapper .product-longdescription, #mobile-centre_wrapper .product-department {
	border: 0;
	display: block; }

.backgroundsize.csstransitions #mobile-centre tbody tr .product-longdescription,
.backgroundsize.csstransitions #mobile-centre tbody tr td.product-link-container,
.backgroundsize.csstransitions #mobile-centre tbody tr .product-department, #mobile-centre_wrapper .record-close, #mobile-centre_wrapper table :target .product-data-compressed, #mobile-centre_wrapper .product-data-hidden, #mobile-centre_wrapper .product-data-expanded {
	display: none;
	visibility: hidden; }

.backgroundsize.csstransitions #mobile-centre tbody tr:target .product-longdescription,
.backgroundsize.csstransitions #mobile-centre tbody tr:target td.product-link-container,
.backgroundsize.csstransitions #mobile-centre tbody tr:target .product-department, #mobile-centre_wrapper table :target .record-close, #mobile-centre_wrapper table :target .product-data-expanded, #mobile-centre_wrapper .product-data-compressed {
	display: block;
	visibility: visible; }

.backgroundsize.csstransitions #mobile-centre tbody {
	padding-top: 2em; }
	.backgroundsize.csstransitions #mobile-centre tbody tr {
		background-clip: content-box;
		background-color: #eee;
		background-image: url("data:image/gif;base64,R0lGODlhAQABAIAAAMLCwgAAACH5BAAAAAAALAAAAAABAAEAAAICRAEAOw=="), url("data:image/gif;base64,R0lGODlhAQABAIAAAMLCwgAAACH5BAAAAAAALAAAAAABAAEAAAICRAEAOw=="), url("data:image/gif;base64,R0lGODlhAQABAIAAAMLCwgAAACH5BAAAAAAALAAAAAABAAEAAAICRAEAOw=="), url("data:image/gif;base64,R0lGODlhAQABAIAAAMLCwgAAACH5BAAAAAAALAAAAAABAAEAAAICRAEAOw==");
		background-origin: content-box;
		background-position: top left, top left, bottom left, top right;
		background-repeat: repeat-x, repeat-y, repeat-x, repeat-y;
		border: 0;
		display: inline-block;
		margin-bottom: 20px;
		min-height: 20em;
		padding: 5px;
		vertical-align: middle;
		width: 100%; }
		@media (min-width: 768px) {
			.backgroundsize.csstransitions #mobile-centre tbody tr {
				width: 50%; } }
		@media (min-width: 1200px) {
			.backgroundsize.csstransitions #mobile-centre tbody tr {
				width: 33.333%; } }
		.backgroundsize.csstransitions #mobile-centre tbody tr .product-platforms span {
			margin-right: 5px; }
		.backgroundsize.csstransitions #mobile-centre tbody tr:target {
			height: auto !important;
			width: 100%; }
			.backgroundsize.csstransitions #mobile-centre tbody tr:target .product-longdescription {
				float: none; }
			.backgroundsize.csstransitions #mobile-centre tbody tr:target .product-link-container {
				border: 0;
				float: none; }
		.backgroundsize.csstransitions #mobile-centre tbody tr:hover {
			background-color: #e8e8e8;
			border-color: #d6d6d6; }

.no-backgroundsize.no-csstransitions #mobile-centre tr,
.backgroundsize.no-csstransitions #mobile-centre tr {
	border-bottom: 1px solid #999 !important;
	border-top: 1px solid #999 !important; }

.no-backgroundsize.no-csstransitions #mobile-centre .product-name,
.no-backgroundsize.no-csstransitions #mobile-centre .product-platforms,
.no-backgroundsize.no-csstransitions #mobile-centre .product-shortdescription,
.no-backgroundsize.no-csstransitions #mobile-centre .product-longdescription,
.no-backgroundsize.no-csstransitions #mobile-centre .product-department,
.no-backgroundsize.no-csstransitions #mobile-centre .product-links,
.backgroundsize.no-csstransitions #mobile-centre .product-name,
.backgroundsize.no-csstransitions #mobile-centre .product-platforms,
.backgroundsize.no-csstransitions #mobile-centre .product-shortdescription,
.backgroundsize.no-csstransitions #mobile-centre .product-longdescription,
.backgroundsize.no-csstransitions #mobile-centre .product-department,
.backgroundsize.no-csstransitions #mobile-centre .product-links {
	float: left !important;
	margin-left: 10px;
	margin-right: 10px; }

.no-backgroundsize.no-csstransitions #mobile-centre .product-name,
.no-backgroundsize.no-csstransitions #mobile-centre .product-platforms,
.no-backgroundsize.no-csstransitions #mobile-centre .product-shortdescription,
.no-backgroundsize.no-csstransitions #mobile-centre .product-longdescription,
.no-backgroundsize.no-csstransitions #mobile-centre .product-department,
.backgroundsize.no-csstransitions #mobile-centre .product-name,
.backgroundsize.no-csstransitions #mobile-centre .product-platforms,
.backgroundsize.no-csstransitions #mobile-centre .product-shortdescription,
.backgroundsize.no-csstransitions #mobile-centre .product-longdescription,
.backgroundsize.no-csstransitions #mobile-centre .product-department {
	width: 96% !important; }

.no-backgroundsize.no-csstransitions #mobile-centre .product-name,
.no-backgroundsize.no-csstransitions #mobile-centre .product-platforms,
.backgroundsize.no-csstransitions #mobile-centre .product-name,
.backgroundsize.no-csstransitions #mobile-centre .product-platforms {
	margin-top: 10px; }

.no-backgroundsize.no-csstransitions #mobile-centre .product-name,
.backgroundsize.no-csstransitions #mobile-centre .product-name {
	padding-bottom: 0; }

.no-backgroundsize.no-csstransitions #mobile-centre .product-platforms,
.backgroundsize.no-csstransitions #mobile-centre .product-platforms {
	padding-top: 0; }

.no-backgroundsize.no-csstransitions #mobile-centre .product-platforms,
.no-backgroundsize.no-csstransitions #mobile-centre .product-shortdescription,
.no-backgroundsize.no-csstransitions #mobile-centre .product-longdescription,
.no-backgroundsize.no-csstransitions #mobile-centre .product-department,
.no-backgroundsize.no-csstransitions #mobile-centre .product-links,
.backgroundsize.no-csstransitions #mobile-centre .product-platforms,
.backgroundsize.no-csstransitions #mobile-centre .product-shortdescription,
.backgroundsize.no-csstransitions #mobile-centre .product-longdescription,
.backgroundsize.no-csstransitions #mobile-centre .product-department,
.backgroundsize.no-csstransitions #mobile-centre .product-links {
	clear: left;
	margin-top: 0; }

.no-backgroundsize.no-csstransitions #mobile-centre .product-shortdescription,
.no-backgroundsize.no-csstransitions #mobile-centre .record-close,
.backgroundsize.no-csstransitions #mobile-centre .product-shortdescription,
.backgroundsize.no-csstransitions #mobile-centre .record-close {
	display: none !important; }

.no-backgroundsize.no-csstransitions #mobile-centre .product-link-container,
.backgroundsize.no-csstransitions #mobile-centre .product-link-container {
	border: none !important; }

.no-backgroundsize.no-csstransitions #mobile-centre .product-link-list li,
.backgroundsize.no-csstransitions #mobile-centre .product-link-list li {
	display: inline;
	float: left; }

#mobile-centre_wrapper {
	/* Layout of fields */
	/* Expand/collapse record functionality */
	/* Data visibility */ }
	#mobile-centre_wrapper .product-record {
		display: inline-block;
		margin-bottom: 20px;
		width: 100%; }
		#mobile-centre_wrapper .product-record:target {
			height: auto !important; }
		#mobile-centre_wrapper .product-record:hover {
			background-color: #e8e8e8;
			border-color: #d6d6d6;
			cursor: pointer; }
	#mobile-centre_wrapper .product-icon {
		border: 0;
		float: left;
		height: 48px;
		margin-bottom: 10px;
		margin-right: 10px;
		padding-bottom: 3px;
		padding-right: 3px;
		width: 48px; }
	#mobile-centre_wrapper .product-shortdescription,
	#mobile-centre_wrapper .product-longdescription {
		margin-top: 1em; }
	#mobile-centre_wrapper .product-department {
		font-weight: bold;
		margin-top: 1em; }
	#mobile-centre_wrapper .product-link-list {
		list-style-type: none;
		margin-top: 1em;
		padding-left: 0; }
	#mobile-centre_wrapper .product-link-container {
		margin-bottom: 1em; }
	#mobile-centre_wrapper .product-link {
		display: block;
		padding: 6px 12px !important;
		text-align: left;
		text-decoration: none;
		text-transform: none !important;
		white-space: normal; }
		#mobile-centre_wrapper .product-link:hover, #mobile-centre_wrapper .product-link:focus {
			text-decoration: none; }
	#mobile-centre_wrapper .record-expand {
		color: inherit;
		text-decoration: none; }
		#mobile-centre_wrapper .record-expand:hover, #mobile-centre_wrapper .record-expand:focus {
			color: inherit;
			text-decoration: underline; }
	#mobile-centre_wrapper .record-close {
		float: right; }
	#mobile-centre_wrapper .product-listing {
		border: 1px solid #ddd; }
		#mobile-centre_wrapper .product-listing td {
			padding: 8px; }

@media (min-width: 768px) {
	#mobile-centre_wrapper .product-record {
		margin-left: 10px;
		margin-right: 10px;
		max-width: 47%; }
		#mobile-centre_wrapper .product-record:target {
			max-width: 100%; }
	#mobile-centre_wrapper .product-department,
	#mobile-centre_wrapper .product-links {
		margin-right: 10px;
		width: 30%; }
	#mobile-centre_wrapper .product-longdescription {
		float: right;
		margin-left: 10px;
		width: 67%; } }

@media (min-width: 1200px) {
	#mobile-centre_wrapper .product-record {
		max-width: 31.5%; } }

/*
 * Campaign
 *
 * Seem it was designed to support a specific unique use case.
 * Added by : https://github.com/wet-boew/GCWeb/commit/ac202aff53003b379cc616ae066fb9304be5e267#diff-f95a90ad02373165b1cb6349d5cde8c2d61ac3cd498631eefb562f5790ada4cf
 */
.infostripe .btn-cnt {
	bottom: 5px;
	padding-right: 30px;
	position: absolute;
	text-align: center;
	width: 100%; }

.infostripe .col-md-6 {
	min-height: 830px !important;
	vertical-align: top; }

#anti_infographic_4.modal-dialog {
	width: 50%; }

.secondary .infostripe .h1, .page-type-nav .infostripe .h1 {
	font-size: 1.5em; }

.secondary .infostripe.dbl .h1, .page-type-nav .infostripe.dbl .h1 {
	min-height: 3.1em; }

.secondary .infostripe.trpl .h1, .page-type-nav .infostripe.trpl .h1 {
	min-height: 4em; }

[lang=fr] .infostripe .col-md-6 {
	min-height: 870px !important; }

.gc-prtts.dbl .h5 {
	min-height: 2.2em; }

.cmpgn-sctns a {
	text-decoration: none; }
	.cmpgn-sctns a:hover strong, .cmpgn-sctns a:focus strong, .cmpgn-sctns a:active strong {
		text-decoration: underline; }

.cmpgn-sctns strong {
	display: block; }

/*
* News styles
*/
/*
* News filtered table
*/
table.nws-tbl td {
	display: block; }

table.nws-tbl .nws-tbl-ttl,
table.nws-tbl .nws-tbl-desc {
	margin-top: 15px; }

table.nws-tbl .nws-tbl-date,
table.nws-tbl .nws-tbl-dept,
table.nws-tbl .nws-tbl-type {
	color: #555;
	letter-spacing: .01em; }

table.nws-tbl tbody tr {
	background-color: #fff; }

table.nws-tbl > tbody > tr > td,
table.nws-tbl > tbody > tr > th,
table.nws-tbl > tfoot > tr > td,
table.nws-tbl > tfoot > tr > th,
table.nws-tbl > thead > tr > td,
table.nws-tbl > thead > tr > th {
	border-top: 0;
	padding-bottom: 0;
	padding-top: 0; }

.nws-tbl .tp-rail {
	display: inline-block; }

.nws-tbl details summary, .nws-tbl details[open] {
	border: 0; }

.nws-tbl .one-dot {
	-moz-border-radius: 50%;
	-webkit-border-radius: 50%;
	background: #000;
	border-radius: 50%;
	display: inline-block;
	height: .5em;
	vertical-align: middle;
	width: .5em; }

.nws-tbl .tp-rail.commit {
	font-size: 1.15em;
	font-weight: 600;
	max-width: 67%;
	min-width: 67%; }

.largeview .nws-tbl .tp-rail.commit, .xlargeview .nws-tbl .tp-rail.commit {
	max-width: 71%;
	min-width: 71%; }

table.dataTable.nws-tbl .label.label-success {
	padding: .6em .6em .3em; }

/*! Core - Utilities */
/*
 * Helper Classes
 */
.margin-bottom-none {
	margin-bottom: 0; }

.margin-bottom-small {
	margin-bottom: .25em; }

.margin-top-large {
	margin-top: 1.5em; }

.margin-top-medium {
	margin-top: .75em; }

.clearfix:before, .clearfix:after {
	display: table;
	content: " "; }

.clearfix:after {
	clear: both; }

.center-block {
	display: block;
	margin-right: auto;
	margin-left: auto; }

.pull-right {
	float: right !important; }

.pull-left {
	float: left !important; }

.hide {
	display: none !important; }

.show {
	display: block !important; }

.invisible {
	visibility: hidden; }

.text-hide {
	font: 0/0 a;
	color: transparent;
	text-shadow: none;
	background-color: transparent;
	border: 0; }

.hidden {
	display: none !important; }

.affix {
	position: fixed; }

@-ms-viewport {
	width: device-width; }

.visible-xs {
	display: none !important; }

.visible-sm {
	display: none !important; }

.visible-md {
	display: none !important; }

.visible-lg {
	display: none !important; }

.visible-xs-block,
.visible-xs-inline,
.visible-xs-inline-block,
.visible-sm-block,
.visible-sm-inline,
.visible-sm-inline-block,
.visible-md-block,
.visible-md-inline,
.visible-md-inline-block,
.visible-lg-block,
.visible-lg-inline,
.visible-lg-inline-block {
	display: none !important; }

@media (max-width: 767px) {
	.visible-xs {
		display: block !important; }
	table.visible-xs {
		display: table !important; }
	tr.visible-xs {
		display: table-row !important; }
	th.visible-xs,
	td.visible-xs {
		display: table-cell !important; } }

@media (max-width: 767px) {
	.visible-xs-block {
		display: block !important; } }

@media (max-width: 767px) {
	.visible-xs-inline {
		display: inline !important; } }

@media (max-width: 767px) {
	.visible-xs-inline-block {
		display: inline-block !important; } }

@media (min-width: 768px) and (max-width: 991px) {
	.visible-sm {
		display: block !important; }
	table.visible-sm {
		display: table !important; }
	tr.visible-sm {
		display: table-row !important; }
	th.visible-sm,
	td.visible-sm {
		display: table-cell !important; } }

@media (min-width: 768px) and (max-width: 991px) {
	.visible-sm-block {
		display: block !important; } }

@media (min-width: 768px) and (max-width: 991px) {
	.visible-sm-inline {
		display: inline !important; } }

@media (min-width: 768px) and (max-width: 991px) {
	.visible-sm-inline-block {
		display: inline-block !important; } }

@media (min-width: 992px) and (max-width: 1199px) {
	.visible-md {
		display: block !important; }
	table.visible-md {
		display: table !important; }
	tr.visible-md {
		display: table-row !important; }
	th.visible-md,
	td.visible-md {
		display: table-cell !important; } }

@media (min-width: 992px) and (max-width: 1199px) {
	.visible-md-block {
		display: block !important; } }

@media (min-width: 992px) and (max-width: 1199px) {
	.visible-md-inline {
		display: inline !important; } }

@media (min-width: 992px) and (max-width: 1199px) {
	.visible-md-inline-block {
		display: inline-block !important; } }

@media (min-width: 1200px) {
	.visible-lg {
		display: block !important; }
	table.visible-lg {
		display: table !important; }
	tr.visible-lg {
		display: table-row !important; }
	th.visible-lg,
	td.visible-lg {
		display: table-cell !important; } }

@media (min-width: 1200px) {
	.visible-lg-block {
		display: block !important; } }

@media (min-width: 1200px) {
	.visible-lg-inline {
		display: inline !important; } }

@media (min-width: 1200px) {
	.visible-lg-inline-block {
		display: inline-block !important; } }

@media (max-width: 767px) {
	.hidden-xs {
		display: none !important; } }

@media (min-width: 768px) and (max-width: 991px) {
	.hidden-sm {
		display: none !important; } }

@media (min-width: 992px) and (max-width: 1199px) {
	.hidden-md {
		display: none !important; } }

@media (min-width: 1200px) {
	.hidden-lg {
		display: none !important; } }

.visible-print {
	display: none !important; }

@media print {
	.visible-print {
		display: block !important; }
	table.visible-print {
		display: table !important; }
	tr.visible-print {
		display: table-row !important; }
	th.visible-print,
	td.visible-print {
		display: table-cell !important; } }

.visible-print-block {
	display: none !important; }
	@media print {
		.visible-print-block {
			display: block !important; } }

.visible-print-inline {
	display: none !important; }
	@media print {
		.visible-print-inline {
			display: inline !important; } }

.visible-print-inline-block {
	display: none !important; }
	@media print {
		.visible-print-inline-block {
			display: inline-block !important; } }

@media print {
	.hidden-print {
		display: none !important; } }

/*
  WET-BOEW
  @title: Accessibility Additions to WET-BOEW - Utilities
 */
/*
  WET-BOEW
  @title: Proximity CSS
 */
.opct-100 {
	opacity: 1; }

.opct-90 {
	opacity: .9; }

.opct-80 {
	opacity: .8; }

.opct-70 {
	opacity: .7; }

.opct-60 {
	opacity: .6; }

.opct-50 {
	opacity: .5; }

.opct-40 {
	opacity: .4; }

.opct-30 {
	opacity: .3; }

.opct-20 {
	opacity: .2; }

.opct-10 {
	opacity: .1; }

/*
 *	Removes bold from elements
 */
.fnt-nrml {
	font-weight: normal; }

/*
 *	Fix for missing bullets in Chrome and Safari
 */
[class*=clmn-] {
	list-style: outside;
	padding-left: 1.3em; }
	[class*=clmn-] > li {
		margin-left: 1.3em; }

.pstn-lft-xs,
.pstn-lft-sm,
.pstn-lft-md,
.pstn-lft-lg,
.pstn-rght-xs,
.pstn-rght-sm,
.pstn-rght-md,
.pstn-rght-lg,
.pstn-tp-xs,
.pstn-tp-sm,
.pstn-tp-md,
.pstn-tp-lg,
.pstn-bttm-xs,
.pstn-bttm-sm,
.pstn-bttm-md,
.pstn-bttm-lg {
	margin: 0; }

.pstn-lft-xs {
	position: absolute;
	left: 0;
	right: auto; }

.pstn-rght-xs {
	position: absolute;
	right: 0;
	left: auto; }

.pstn-tp-xs {
	position: absolute;
	top: 0;
	bottom: auto; }

.pstn-bttm-xs {
	position: absolute;
	bottom: 0;
	top: auto; }

.mrgn-lft-0 {
	margin-left: 0; }

.mrgn-lft-sm {
	margin-left: 5px; }

.mrgn-lft-md {
	margin-left: 15px; }

.mrgn-lft-lg {
	margin-left: 30px; }

.mrgn-lft-xl {
	margin-left: 50px; }

.mrgn-bttm-0 {
	margin-bottom: 0; }

.mrgn-bttm-sm {
	margin-bottom: 5px; }

.mrgn-bttm-md {
	margin-bottom: 15px; }

.mrgn-bttm-lg {
	margin-bottom: 30px; }

.mrgn-bttm-xl {
	margin-bottom: 50px; }

.mrgn-tp-0 {
	margin-top: 0; }

.mrgn-tp-sm {
	margin-top: 5px; }

.mrgn-tp-md {
	margin-top: 15px; }

.mrgn-tp-lg {
	margin-top: 30px; }

.mrgn-tp-xl {
	margin-top: 50px; }

.mrgn-rght-0 {
	margin-right: 0; }

.mrgn-rght-sm {
	margin-right: 5px; }

.mrgn-rght-md {
	margin-right: 15px; }

.mrgn-rght-lg {
	margin-right: 30px; }

.mrgn-rght-xl {
	margin-right: 50px; }

.brdr-lft, .brdr-rght, .brdr-tp, .brdr-bttm {
	border: solid 0 #ccc; }

.brdr-lft {
	border-left-width: 1px; }

.brdr-rght {
	border-right-width: 1px; }

.brdr-tp {
	border-top-width: 1px; }

.brdr-bttm {
	border-bottom-width: 1px; }

.brdr-0 {
	border: 0 !important; }

.brdr-rds-0 {
	border-radius: 0 !important; }

.tbl-gridify thead,
.tbl-gridify tfoot {
	display: none; }

.tbl-gridify tbody,
.tbl-gridify td,
.tbl-gridify td {
	display: block; }

/*
 *	Fix for missing bullets in Chrome and Safari
 */
[class*=colcount-] {
	list-style-position: outside;
	padding-left: 1.3em; }
	[class*=colcount-] > li {
		margin-left: 1.3em; }
	[class*=colcount-].list-unstyled {
		list-style: none outside none;
		padding-left: 0; }
		[class*=colcount-].list-unstyled li {
			margin-left: 0; }

.colcount-xxs-2 {
	-webkit-column-count: 2;
	   -moz-column-count: 2;
	        column-count: 2; }

.colcount-xxs-3 {
	-webkit-column-count: 3;
	   -moz-column-count: 3;
	        column-count: 3; }

.colcount-xxs-4 {
	-webkit-column-count: 4;
	   -moz-column-count: 4;
	        column-count: 4; }

.full-width {
	width: 100%; }

/*
  WET-BOEW
  @title: Bootstrap 4 suplemental style for WET-BOEW
 */
/* Spacing */
.p-0 {
	padding: 0 !important; }

.pl-2,
.px-2 {
	padding-left: 5px !important; }

.pr-2,
.px-2 {
	padding-right: 5px !important; }

.pt-4,
.py-4 {
	padding-top: 30px !important; }

.pb-4,
.py-4 {
	padding-bottom: 30px !important; }

.mt-auto {
	margin-top: auto !important; }

/* Stretched link */
.stretched-link:after {
	background-color: rgba(0, 0, 0, 0);
	bottom: 0;
	content: "";
	left: 0;
	pointer-events: auto;
	position: absolute;
	right: 0;
	top: 0;
	z-index: 1; }

/* Sizing */
.h-100 {
	height: 100% !important; }

/* Positioning */
.position-relative {
	position: relative !important; }

/* Flexbox */
.d-flex {
	display: -webkit-box !important;
	display: -ms-flexbox !important;
	display: flex !important; }

.flex-column {
	-webkit-box-orient: vertical !important;
	-webkit-box-direction: normal !important;
	    -ms-flex-direction: column !important;
	        flex-direction: column !important; }

.align-items-center {
	-webkit-box-align: center !important;
	    -ms-flex-align: center !important;
	        align-items: center !important; }

.align-self-center {
	-ms-flex-item-align: center !important;
	    align-self: center !important; }

.align-self-end {
	-ms-flex-item-align: end !important;
	    align-self: flex-end !important; }

/* Vertical alignment */
.align-top {
	vertical-align: top !important; }

.align-middle {
	vertical-align: middle !important; }

.align-bottom {
	vertical-align: bottom !important; }

/* Color scheme */
.text-white, a.text-white:visited {
	color: #fff; }

a.text-white:hover, a.text-white:focus {
	color: #b3ffff; }

.btn.text-white:hover, .btn.text-white:focus {
	color: #b3ffff; }

/*
 *
 * Web Experience Toolkit (WET) / Boîte à outils de l'expérience Web (BOEW)
 * wet-boew.github.io/wet-boew/License-en.html / wet-boew.github.io/wet-boew/Licence-fr.html
 *
 * Components and helpers style for WET-BOEW
 */
/*
 Background Utility CSS
 */
.bg-cover {
	background-size: cover; }

.bg-center {
	background-position: center; }

.bg-norepeat {
	background-repeat: no-repeat; }

/*
 Additional color
 */
.bg-darker {
	background-color: #000; }

.bg-dark {
	background-color: #343a40; }

button.bg-dark:hover, button.bg-dark:focus {
	background-color: #1d2124; }

/*
Miscellaneous Utiliy CSS
 */
.max-content {
	max-width: -webkit-max-content;
	max-width: -moz-max-content;
	max-width: max-content; }

/*
 * GCWeb custom implementation
 *
 * Copy and rename the folder "variant-default" to "variant".
 * - the "variant" folder should not GIT conflict with your custom implementation when updating to the latest gcweb
 */
/*
  Variant - GCWeb custom implementation
  @title: Default SCSS
 */
/*
 Views
 */
/* All screen views */
@media screen {
	/*
  WET-BOEW
  @title: All screen views
 */
	.mathml body > div > math,
	.no-mathml body > div > math, .nojs-show, .wb-disable .nojs-hide {
		display: none !important; }
	/* Hide MathML check */
	#wb-dtmd {
		margin: 2em 0 0; }
		#wb-dtmd dt,
		#wb-dtmd dd {
			display: inline;
			font-weight: normal;
			margin-right: 0; }
	.nowrap {
		white-space: nowrap; }
	.wb-disable .nojs-show {
		display: block !important; }
	.col-xs-auto, .col-sm-auto, .col-md-auto, .col-lg-auto {
		min-height: 1px;
		padding-left: 15px;
		padding-right: 15px; }
	.col-xs-auto {
		width: auto; }
	/*
  WET-BOEW
  @title: All screen views
 */
	.overlay-def .modal-header {
		background: #2e5274; }
	.wb-sl {
		background: #26374a;
		color: #fff;
		font-weight: 700; }
		.wb-sl:focus {
			color: #fff;
			text-decoration: none; }
		.wb-sl:hover {
			background-color: #444;
			color: #fff; }
	/*
 * Web Experience Toolkit (WET) / Boîte à outils de l'expérience Web (BOEW)
 * wet-boew.github.io/wet-boew/License-en.html / wet-boew.github.io/wet-boew/Licence-fr.html
 */
	/* Pretty printing styles. Used with prettify.js. */
	.typ, .atn, .dec, .var {
		color: #606; }
	.pun, .opn, .clo {
		color: #660; }
	.str, .atv {
		color: #2f6d2f; }
	/* string content - from #080 */
	/* a keyword - from #008 */
	.kwd {
		color: #024b6e; }
	/* a comment */
	.com {
		color: #800; }
	/* a type name */
	/* a literal value */
	.lit {
		color: #066; }
	/* punctuation, lisp open bracket, lisp close bracket */
	/* a markup tag name - from #008 */
	.tag {
		color: #125b7e; }
	/* a markup attribute name */
	/* a markup attribute value - from #080 */
	/* a declaration */
	/* a variable name */
	/* a function name */
	.fun {
		color: #f00; }
	/*
 * Web Experience Toolkit (WET) / Boîte à outils de l'expérience Web (BOEW)
 * wet-boew.github.io/wet-boew/License-en.html / wet-boew.github.io/wet-boew/Licence-fr.html
 */
	/**
 * Screen-only styles
 */
	.wb-tabs.carousel-s2.wb-init {
		padding-bottom: 4.375em; }
	.wb-tabs.carousel-s2.exclude-controls {
		padding-bottom: 0; }
	/*
 * Carousel-specific overrides
 */
	.prm-flpr {
		background-color: #eee;
		margin-top: 1px; }
		.prm-flpr .wb-tabs.carousel-s2 [role="tablist"] li.plypause {
			font-size: 1.3em; }
			.prm-flpr .wb-tabs.carousel-s2 [role="tablist"] li.plypause a {
				margin-top: .15em; }
		.prm-flpr .wb-tabs.carousel-s2 figure figcaption {
			font-size: 1.3em; }
			.prm-flpr .wb-tabs.carousel-s2 figure figcaption a {
				text-decoration: none; }
				.prm-flpr .wb-tabs.carousel-s2 figure figcaption a:hover {
					text-decoration: underline; }
	.wb-tabs.carousel-s2 [role="tablist"] li.tab-count .curr-count, .wb-tabs.carousel-s2 [role="tablist"] li.plypause a {
		font-size: 1.2em; }
	.wb-tabs.carousel-s2 [role="tablist"] li.nxt a .glyphicon, .wb-tabs.carousel-s2 [role="tablist"] li.prv a .glyphicon {
		font-size: 1.65em; }
	/*
 * Priorities (Government of Canada activities and initiatives) (all screen views)
 */
	.gc-nttvs a:active h3,
	.gc-nttvs a:active img, .gc-nttvs a:focus h3,
	.gc-nttvs a:focus img {
		outline: thin dotted; }
	.gc-nttvs h3 {
		float: left;
		text-decoration: underline; }
	.gc-nttvs img {
		float: left;
		margin-right: 100%; }
	.gc-nttvs p {
		clear: both; }
	[dir=rtl] .gc-nttvs h3 {
		float: right; }
	[dir=rtl] .gc-nttvs img {
		float: right;
		margin-left: 100%;
		margin-right: 0; }
	/* Deprecated as v4.0.28 */
	/*
  Variant - GCWeb custom implementation
  @title: All screen views
 */ }

/* Extra-small view and under */
@media screen and (max-width: 767px) {
	/*
  WET-BOEW
  @title: Extra-small view and under (screen only)
 */
	/*
  WET-BOEW
  @title: Extra-small view and under (screen only)
  @desc:  Variable $screen-xs-max <= 767px
 */
	/* Make a simple list multi-column and responsive (overide _defaults.scss) */
	.list-responsive > li {
		clear: right;
		width: 100%; }
	/*
 Banner (small view and under)
 */
	header .brand img {
		margin-top: 15px; }
	header .brand object,
	header .brand img {
		max-height: 30px; }
	#wb-glb-mn {
		margin-top: 20px; }
		#wb-glb-mn ul.chvrn li a {
			font-size: 1.7em; }
	/*
  WET-BOEW
  @title: Extra-small view and under (screen only)
 */
	.gcweb-menu > [role=menu] {
		margin-left: -15px;
		margin-right: -15px; }
	#wb-bnr + .gcweb-menu button[aria-haspopup="true"] {
		margin-left: 15px !important; }
	#wb-bnr + .gcweb-menu > [role=menu] {
		margin-left: 0;
		margin-right: 0; }
	/*
 * Share/feedback-specific overrides (extra-small view and under)
 */
	.pagedetails .pull-right {
		float: none !important; }
	/*
  WET-BOEW
  @title: Footer extra-small view and under (screen only)
 */
	#wb-info .gc-sub-footer, #wb-info .brand {
		/* START: To support footer v3.0 */
		/* END */
		/* START: To support footer <= v2.0 */
		/* END */ }
		#wb-info .gc-sub-footer nav ul + h4, #wb-info .brand nav ul + h4 {
			margin-top: 0; }
			#wb-info .gc-sub-footer nav ul + h4::before, #wb-info .brand nav ul + h4::before {
				border-width: 0 0 1px 0;
				display: block !important;
				height: 0;
				margin: 1em 0;
				position: static;
				width: 1.5em; }
		#wb-info .gc-sub-footer .row nav ul li:first-child::before, #wb-info .brand .row nav ul li:first-child::before {
			display: inline; }
	.wb-eqht-grd > [class*="col-"] {
		width: 100%; }
	/*
  WET-BOEW
  @title: Extra-small view and under (screen only)
 */
	/*
 * Well header responsive
 */
	[class*=col-] .well.header-rwd[class*=pstn-] {
		left: 15px;
		right: 15px;
		width: inherit; }
	/*
  Pagination
  @title: Extra-small view and under (screen only)
 */
	.pager {
		margin-bottom: 50px; }
	/*
  TOC
  @title: Extra-small view and under (screen only)
 */
	.toc li {
		display: block;
		margin-bottom: 0; }
		.toc li .list-group-item {
			border-bottom: 0;
			border-radius: 0;
			padding: 4px 10px; }
		.toc li:last-child .list-group-item {
			border-bottom: 1px solid #ddd; }
	/*
  Campaign
  @title: Extra-small view and under (screen only)
 */
	.cmpgn-sctns {
		margin-top: 0; }
		.cmpgn-sctns li {
			margin-top: 20px; }
		.cmpgn-sctns .h4 {
			margin-top: 0;
			padding-top: 15px; }
		.cmpgn-sctns .sctn-desc {
			margin-bottom: 10px; }
	/*
  Variant - GCWeb custom implementation
  @title: Extra-small view and under (screen only)
 */ }

/* Small view and under */
@media screen and (max-width: 991px) {
	/*
  WET-BOEW
  @title: Small view and under (screen only)
 */
	/*
  WET-BOEW
  @title: Small view and under (screen only)
  @desc:  Variable $screen-sm-max <= 991 px
 */
	h1, .h1 {
		font-size: 1.7em;
		margin-top: .75em; }
	h2, .h2 {
		font-size: 1.6em; }
	.gc-srvinfo p, .gc-drmt p, .gc-features p {
		font-size: 19px; }
	.home .home-most-requested li {
		font-size: 19px; }
	.home .home-your-gov {
		background-image: none; }
	/* PROVISIONAL features */
	.provisional {
		/* Contributors */ }
		.provisional.gc-contributors h2, .provisional.gc-contributors ul {
			display: block; }
		.provisional.gc-contributors ul {
			-webkit-padding-start: 20px;
			        padding-inline-start: 20px; }
			.provisional.gc-contributors ul li {
				display: list-item;
				margin-right: 0; }
	/*
 Banner (small view and under)
 */
	header .brand img {
		margin-top: 10px; }
	/*
  WET-BOEW
  @title: Small view and under (screen only)
 */
	#wb-bnr + .gcweb-menu button[aria-haspopup="true"] {
		margin-left: calc( 50% - 360px); }
	.gcweb-menu {
		/*
	 * Mobile - first level
	 */
		/*
	 * Mobile - Second level
	 */
		/* Reset the style set by the panel */
		/* Arrow for menu item with submenu */
		/* Menu text style */
		/* Mobile - Third level */ }
		.gcweb-menu .container {
			padding: 0;
			width: 100%; }
		.gcweb-menu [role=menu] {
			position: static; }
		.gcweb-menu button[aria-haspopup=true][aria-expanded=true] + [role=menu] {
			border-right: #eee solid 1px; }
		.gcweb-menu [role=menuitem] {
			width: auto; }
		.gcweb-menu [role=menu] [role=menu] li:first-child [role=menuitem] {
			font-size: 18px;
			font-weight: 400;
			text-decoration: underline;
			width: auto; }
		.gcweb-menu [role=menu] {
			width: auto; }
		.gcweb-menu [role=menu] [role=menu] {
			border-top: none;
			-webkit-box-shadow: none;
			        box-shadow: none;
			margin-bottom: 0;
			min-height: auto;
			padding: 0;
			width: auto; }
		.gcweb-menu [role=menu] [role=menu] li {
			width: auto; }
		.gcweb-menu button:hover {
			text-decoration: underline; }
		.gcweb-menu button + [role=menu] [role="menuitem"][aria-expanded=false]:hover,
		.gcweb-menu button + [role=menu] [role="menuitem"][aria-expanded=false]:focus {
			background: transparent;
			color: #fff; }
		.gcweb-menu button + [role=menu] [role=menu] [role="menuitem"][aria-expanded=false]:hover,
		.gcweb-menu button + [role=menu] [role=menu] [role="menuitem"][aria-expanded=false]:focus {
			color: #000; }
		.gcweb-menu [role=menu] [role=menu] li:first-child {
			margin-bottom: 0px; }
		.gcweb-menu [role=menu] [role=menu] li [role=menuitem] {
			padding-bottom: 14px;
			padding-left: 0;
			padding-right: 30px;
			padding-top: 14px; }
		.gcweb-menu [aria-expanded=true]:not(button) + [role=menu] li {
			margin-left: 65px; }
		.gcweb-menu [aria-expanded=true]:not(button) + [role=menu] li:first-child [role=menuitem],
		.gcweb-menu [aria-expanded=true]:not(button) + [role=menu] li:last-child [role=menuitem] {
			padding-left: 65px; }
		.gcweb-menu [aria-expanded=true]:not(button) + [role=menu] li:first-child,
		.gcweb-menu [aria-expanded=true]:not(button) + [role=menu] li:last-child {
			margin-left: 0px; }
		.gcweb-menu [aria-haspopup]:not(button)::before,
		.gcweb-menu [role=treegrid] > [role=row] > [role=rowheader]::before {
			content: "\25BA\a0"; }
		.gcweb-menu [aria-haspopup][aria-expanded=true]:not(button)::before,
		.gcweb-menu [role=treegrid] > [role=row][aria-expanded=true] > [role=rowheader]::before {
			content: "\25BC\a0"; }
		.gcweb-menu [role=menu] [role=menu] [role=menuitem],
		.gcweb-menu [role=menu] [role=menu] li:first-child [role=menuitem] {
			border-bottom: 1px solid #ccc;
			color: #000; }
		.gcweb-menu [role=menu] [role=menu] [role=menuitem],
		.gcweb-menu [role=menu] [role=menu] li:last-child [role=menuitem],
		.gcweb-menu [role=menu] [role=menu] [role=menu] li:first-child [role=menuitem] {
			color: #284162;
			text-decoration: none; }
		.gcweb-menu [role=menu] [role=menu] [role=menuitem]:hover,
		.gcweb-menu [role=menu] [role=menu] [role=menuitem]:focus,
		.gcweb-menu [role=menu] [role=menu] li:first-child [role=menuitem]:hover,
		.gcweb-menu [role=menu] [role=menu] li:first-child [role=menuitem]:focus,
		.gcweb-menu [role=menu] [role=menu] li:last-child [role=menuitem]:hover,
		.gcweb-menu [role=menu] [role=menu] li:last-child [role=menuitem]:focus {
			color: #000;
			text-decoration: underline; }
		.gcweb-menu [role=menu] [role=menu] li:first-child [role=menuitem],
		.gcweb-menu [role=menu] [role=menu] li:last-child [role=menuitem] {
			background-color: #e1e1e1; }
		.gcweb-menu [role=menu] [role=menu] li:last-child {
			left: auto;
			position: static;
			top: auto; }
		.gcweb-menu [role=menu] [role=menu] li:last-child [role=menu] {
			list-style: none; }
		.gcweb-menu [aria-expanded=true] + [role=menu] [role=menu] [role=menu] {
			background-color: #e1e1e1; }
		.gcweb-menu [aria-expanded=true]:not(button) + [role=menu] [role=menu] li {
			margin-left: 100px; }
		.gcweb-menu [aria-expanded=true]:not(button) + [role=menu] li:last-child [role=menu] [role=menuitem] {
			padding-left: 0px; }
		.gcweb-menu [role=menu] [role=menu] [role=menu] li {
			width: auto; }
	/*
 * Specific classes for authentication section which include Sign-on/Sign-off button and the Contextual Sign-in button.
 */
	#wb-bnr + hr + .container .col-md-8 .gcweb-menu > [role=menu] {
		margin-bottom: 50px; }
	#wb-bnr + hr + .container .col-xs-5, #wb-bnr + hr + .container .col-xs-6 {
		margin-top: -50px; }
	/*
  WET-BOEW
  @title: Small view and under (screen only)
 */
	#wb-info .gc-sub-footer, #wb-info .brand {
		/* START: To support footer <= v2.0 */
		/* END */ }
		#wb-info .gc-sub-footer nav ul, #wb-info .brand nav ul {
			/* START: To support footer v3.0 */
			display: block;
			/* END */ }
			#wb-info .gc-sub-footer nav ul + h4, #wb-info .brand nav ul + h4 {
				margin-top: 0; }
				#wb-info .gc-sub-footer nav ul + h4::before, #wb-info .brand nav ul + h4::before {
					border-width: 0 0 1px 0;
					display: block !important;
					height: 0;
					margin: 1em 0;
					position: static;
					width: 1.5em; }
			#wb-info .gc-sub-footer nav ul li, #wb-info .brand nav ul li {
				display: block; }
				#wb-info .gc-sub-footer nav ul li:not(:last-child), #wb-info .brand nav ul li:not(:last-child) {
					margin-bottom: .75em; }
				#wb-info .gc-sub-footer nav ul li::before, #wb-info .brand nav ul li::before {
					display: none; }
		#wb-info .gc-sub-footer .row nav, #wb-info .brand .row nav {
			margin: .75em 0 3em; }
			#wb-info .gc-sub-footer .row nav ul, #wb-info .brand .row nav ul {
				-webkit-column-count: 2;
				   -moz-column-count: 2;
				        column-count: 2;
				padding-top: 0; }
			#wb-info .gc-sub-footer .row nav li, #wb-info .brand .row nav li {
				display: block;
				margin-bottom: .75em; }
				#wb-info .gc-sub-footer .row nav li::before, #wb-info .brand .row nav li::before {
					content: "\2022";
					display: inline;
					margin-right: .75em; }
	/*
 Details Summary Styling (small view and under)
*/
	.dshbrd details {
		display: block; }
		.dshbrd details summary {
			background: #26374a;
			color: #fff;
			font-size: 1em;
			margin-top: 5px;
			max-height: 999px;
			padding: 1em; }
		.dshbrd details .cntnt {
			border: 1px solid #26374a;
			padding: 15px; }
	/*
 * Web Experience Toolkit (WET) / Boîte à outils de l'expérience Web (BOEW)
 * wet-boew.github.io/wet-boew/License-en.html / wet-boew.github.io/wet-boew/Licence-fr.html
 *
 * Small view and under (screen only) - Variable $screen-sm-max <= 991 px
 *
 *	Provisional GC Subway map menu
*/
	.provisional.gc-subway dt, .provisional.gc-subway li {
		max-width: initial; }
	/*
 * Web Experience Toolkit (WET) / Boîte à outils de l'expérience Web (BOEW)
 * wet-boew.github.io/wet-boew/License-en.html / wet-boew.github.io/wet-boew/Licence-fr.html
 */
	.dataTables_wrapper .dataTables_info {
		padding-bottom: 5px; }
	.dataTables_wrapper .dataTables_filter {
		float: left;
		text-align: left;
		width: 100%; }
	[dir=rtl] .dataTables_wrapper .dataTables_filter {
		float: right;
		text-align: right; }
	/*
 PROVISIONAL features: Responsive tables cards
*/
	.provisional.gc-table.table-bordered {
		border: 0; }
		.provisional.gc-table.table-bordered > thead > tr > th,
		.provisional.gc-table.table-bordered > thead > tr > td,
		.provisional.gc-table.table-bordered > tbody > tr > th,
		.provisional.gc-table.table-bordered > tbody > tr > td,
		.provisional.gc-table.table-bordered > tfoot > tr > th,
		.provisional.gc-table.table-bordered > tfoot > tr > td {
			border-bottom: 0;
			border-left: 0;
			border-right: 0; }
	.provisional.gc-table.dataTable.no-footer {
		border-bottom: 0; }
	.provisional.gc-table .text-left {
		clear: both;
		display: block; }
	.provisional.gc-table > tbody > tr > td:first-child,
	.provisional.gc-table > tfoot > tr > td:first-child {
		border-top: none; }
	.provisional.gc-table tr {
		border: 1px solid #ddd;
		display: block;
		margin-bottom: 0.625em;
		padding: .35em; }
	.provisional.gc-table > :last-child > tr:last-of-type {
		margin-bottom: 0; }
	.provisional.gc-table caption {
		font-size: 1.1em; }
	.provisional.gc-table thead {
		border: none;
		clip: rect(0 0 0 0);
		height: 1px;
		margin: -1px;
		overflow: hidden;
		padding: 0;
		position: absolute;
		width: 1px; }
	.provisional.gc-table tbody + tbody > tr:first-of-type {
		margin-top: 0.625em; }
	.provisional.gc-table td {
		display: block;
		font-size: 1em;
		text-align: right; }
		.provisional.gc-table td::before {
			content: attr(data-label);
			float: left;
			font-weight: bold;
			text-align: left; }
		.provisional.gc-table td:last-child {
			border-bottom: 0; }
	/*
 *
 * Web Experience Toolkit (WET) / Boîte à outils de l'expérience Web (BOEW)
 * wet-boew.github.io/wet-boew/License-en.html / wet-boew.github.io/wet-boew/Licence-fr.html
 *
 *
 *	GC Checkboxes and radio buttons - Small devices maximum
*/
	.gc-chckbxrdio.form-inline .label-inline {
		margin-bottom: 20px;
		padding-right: 20px; }
	/*
 * Web Experience Toolkit (WET) / Boîte à outils de l'expérience Web (BOEW)
 * wet-boew.github.io/wet-boew/License-en.html / wet-boew.github.io/wet-boew/Licence-fr.html
 */
	/**
 * Mobile-friendly styles
 */
	.wb-tabs.carousel-s1, .wb-tabs.carousel-s2 {
		border: 0; }
	.wb-tabs > details, .wb-tabs > .tabpanels > details {
		border: 0;
		border-bottom: #ccc solid 1px;
		border-bottom-left-radius: 0;
		border-bottom-right-radius: 0; }
		.wb-tabs > details:last-of-type, .wb-tabs > .tabpanels > details:last-of-type {
			border-bottom: 0; }
		.wb-tabs > details[style], .wb-tabs > .tabpanels > details[style] {
			min-height: 0 !important; }
		.wb-tabs > details > summary, .wb-tabs > .tabpanels > details > summary {
			border: 0; }
		.wb-tabs > details[open] > summary, .wb-tabs > .tabpanels > details[open] > summary {
			border: 0;
			margin-bottom: 0; }
	.wb-tabs {
		/* Only for backwards compatibility. Should be removed in v4.1. */
		border-color: #ccc;
		border-radius: 4px;
		border-style: solid;
		border-width: 1px;
		margin-bottom: 15px;
		padding-left: 0;
		padding-right: 0; }
		.wb-tabs.tabs-acc > ul {
			display: none; }
	/*
  Variant - GCWeb custom implementation
  @title: Small view and under (screen only)
 */ }

/* Medium view and under */
@media screen and (max-width: 1199px) {
	/*
  WET-BOEW
  @title: Medium view and under (screen only)
 */
	/*
  WET-BOEW
  @title: Medium view and under (screen only)
  @desc:  Variable $screen-md-max <= 1199px
 */
	/*
 * Site menu (medium view and under)
 */
	/*
 * Accessibility tweak for menu based overlapping at lowest desktop setting (text size 200%)
 */
	#wb-sm .menu {
		border-right: 1px solid #999; }
		#wb-sm .menu > li:last-child {
			border-right: 0; }
	/*
  WET-BOEW
  @title: Medium view and under (screen only)
 */
	/*
 * Home page style
 *
 * Set a responsive with for the h1 in the Well header responsive
 */
	.home .well.header-rwd h1 {
		width: 55%; }
	/*
  Variant - GCWeb custom implementation
  @title: Medium view and under (screen only)
 */ }

/* Large view and under */
@media screen and (max-width: 1599px) {
	/*
  WET-BOEW
  @title: Large view and under (screen only)
 */
	/*
  WET-BOEW
  @title: Large view and under (screen only)
  @desc:  Variable $screen-lg-max <= 1599px
 */
	/*
  Variant - GCWeb custom implementation
  @title: Large view and under (screen only)
 */ }

/* Extra-small view and over */
@media screen and (min-width: 480px) {
	/*
  WET-BOEW
  @title: Extra-small view and over (screen only)
 */
	/*
  WET-BOEW
  @title: Extra-small view and over (screen only)
  @desc:  Variable $screen-xs-min >= 480px
 */
	/*
 * Web Experience Toolkit (WET) / Boîte à outils de l'expérience Web (BOEW)
 * wet-boew.github.io/wet-boew/License-en.html / wet-boew.github.io/wet-boew/Licence-fr.html
 */
	#mb-pnl {
		min-width: 300px; }
	/*
 * Web Experience Toolkit (WET) / Boîte à outils de l'expérience Web (BOEW)
 * wet-boew.github.io/wet-boew/License-en.html / wet-boew.github.io/wet-boew/Licence-fr.html
 */
	.dataTables_wrapper .dataTables_info:after {
		content: "|";
		font-size: 1.2em;
		line-height: 1em;
		padding: 0 .25em; }
	/*
  WET-BOEW
  @title: Proximity CSS - Extra-small view and over
 */
	.colcount-xs-2 {
		-webkit-column-count: 2;
		   -moz-column-count: 2;
		        column-count: 2; }
	.colcount-xs-3 {
		-webkit-column-count: 3;
		   -moz-column-count: 3;
		        column-count: 3; }
	.colcount-xs-4 {
		-webkit-column-count: 4;
		   -moz-column-count: 4;
		        column-count: 4; }
	/*
  Variant - GCWeb custom implementation
  @title: Extra-small view and over (screen only)
 */ }

/* Small view and over */
@media screen and (min-width: 768px) {
	/*
  WET-BOEW
  @title: Small view and over (screen only)
 */
	.col-sm-auto {
		width: auto; }
	.form-inline .label-inline {
		display: inline-block;
		padding-right: 10px; }
		.form-inline .label-inline:last-child {
			padding-right: 0; }
	/*
  WET-BOEW
  @title: Small view and over (screen only)
  @desc:  Variable $screen-sm-min >= 768px
 */
	/*
  @title: Baseline styles for small breakpoint and over
*/
	ul.list-col-sm-1 > li {
		-ms-flex-preferred-size: 100%;
		    flex-basis: 100%; }
	ul.list-col-sm-2 > li {
		-ms-flex-preferred-size: 50%;
		    flex-basis: 50%; }
	ul.list-col-sm-3 > li {
		-ms-flex-preferred-size: 33.33%;
		    flex-basis: 33.33%; }
	ul.list-col-sm-4 > li {
		-ms-flex-preferred-size: 25%;
		    flex-basis: 25%; }
	.wb-filter .input-group {
		max-width: 80%; }
	/*
  WET-BOEW
  @title: Small view and over (screen only)
 */
	/*
 * Well header responsive
 */
	.well.header-rwd {
		width: 75%; }
	/*
 *
 * Web Experience Toolkit (WET) / Boîte à outils de l'expérience Web (BOEW)
 * wet-boew.github.io/wet-boew/License-en.html / wet-boew.github.io/wet-boew/Licence-fr.html
 *
 *
 *	GC Checkboxes and radio buttons - Small devices minimum
*/
	.form-inline .gc-chckbxrdio.checkbox input[type="checkbox"] {
		position: absolute; }
	.form-inline.gc-chckbxrdio .radio input[type="radio"],
	.form-inline.gc-chckbxrdio .checkbox input[type="checkbox"] {
		position: absolute; }
	/*
  WET-BOEW
  @title: Small view and over (screen only)
 */
	table.nws-tbl td {
		display: inline;
		margin-top: 10px; }
	table.nws-tbl .nws-tbl-dept,
	table.nws-tbl .nws-tbl-type {
		border-left: solid 1px #666; }
	table.nws-tbl .nws-tbl-ttl,
	table.nws-tbl .nws-tbl-desc {
		display: block; }
	/*
  Campaign
  @title: Small view and over (screen only)
 */
	.cmpgn-img {
		min-height: 117px; }
	.cmpgn-sctns {
		margin-top: -10%; }
		.cmpgn-sctns img {
			width: 40%; }
	/*
  WET-BOEW
  @title: Proximity CSS - Small view and over
 */
	.colcount-sm-2 {
		-webkit-column-count: 2;
		   -moz-column-count: 2;
		        column-count: 2; }
	.colcount-sm-3 {
		-webkit-column-count: 3;
		   -moz-column-count: 3;
		        column-count: 3; }
	.colcount-sm-4 {
		-webkit-column-count: 4;
		   -moz-column-count: 4;
		        column-count: 4; }
	.pstn-lft-sm {
		position: absolute;
		left: 0;
		right: auto; }
	.pstn-rght-sm {
		position: absolute;
		right: 0;
		left: auto; }
	.pstn-tp-sm {
		position: absolute;
		top: 0;
		bottom: auto; }
	.pstn-bttm-sm {
		position: absolute;
		bottom: 0;
		top: auto; }
	/*
  WET-BOEW
  @title: Bootstrap 4 suplemental style for WET-BOEW - Small view and over (screen only)
 */
	/* Alignment */
	.text-sm-left {
		text-align: left; }
	.text-sm-right {
		text-align: right; }
	/* Flexbox */
	.d-sm-flex {
		display: -webkit-box;
		display: -ms-flexbox;
		display: flex; }
	.flex-sm-wrap {
		-ms-flex-wrap: wrap;
		    flex-wrap: wrap; }
	.align-items-sm-center {
		-webkit-box-align: center;
		    -ms-flex-align: center;
		        align-items: center; }
	/* Margin */
	.mb-sm-5 {
		margin-bottom: 50px; }
	/* Padding */
	.p-sm-3 {
		padding: 15px; }
	.px-sm-3 {
		padding-left: 15px;
		padding-right: 15px; }
	.pr-sm-3 {
		padding-right: 15px !important; }
	/*
  Variant - GCWeb custom implementation
  @title: Small view and over (screen only)
 */ }

/* Medium view and over */
@media screen and (min-width: 992px) {
	/*
  WET-BOEW
  @title: Medium view and over (screen only)
 */
	[dir=rtl] main.col-md-push-3 {
		left: auto; }
	[dir=rtl] #wb-sec.col-md-pull-9 {
		right: auto; }
	.col-md-auto {
		width: auto; }
	/*
  WET-BOEW
  @title: Medium view and over (screen only)
  @desc:  Variable $screen-md-min >= 992px
 */
	/* PROVISIONAL features */
	.provisional {
		/* Contributors */
		/* Follow us */ }
		.provisional.gc-contributors ul li:first-child:before {
			content: none; }
		.provisional.gc-contributors ul li:before {
			content: "\2022";
			margin-right: .7em; }
		.provisional.gc-followus h2 {
			margin-top: 0 !important; }
	/*
  @title: Baseline styles for medium breakpoint and over
*/
	ul.list-col-md-1 > li {
		-ms-flex-preferred-size: 100%;
		    flex-basis: 100%; }
	ul.list-col-md-2 > li {
		-ms-flex-preferred-size: 50%;
		    flex-basis: 50%; }
	ul.list-col-md-3 > li {
		-ms-flex-preferred-size: 33.33%;
		    flex-basis: 33.33%; }
	ul.list-col-md-4 > li {
		-ms-flex-preferred-size: 25%;
		    flex-basis: 25%; }
	/*
  WET-BOEW
  @title: Medium view and over (screen only)
 */
	.gcweb-menu {
		margin-left: -15px;
		/* SubSubMenu (MostRequested) keep it black
	 *
	 * Todo: check to use this CSS selector: [data-keep-expanded=md-min][role=menuitem][aria-haspopup=true]
	 */ }
		.gcweb-menu [role=menu] [role=menu] [role=menuitem][aria-haspopup=true],
		.gcweb-menu [role=menu] [role=menu] [role=menuitem][aria-haspopup=true]:hover {
			color: #000;
			font-size: 20px;
			font-weight: 700;
			text-decoration: none; }
	#wb-bnr + .gcweb-menu {
		margin-left: 0px; }
	.wb-disable .gcweb-menu [role=menu] > li {
		float: left;
		padding-right: 5px;
		width: 30%; }
		.wb-disable .gcweb-menu [role=menu] > li:nth-child(3n+3) {
			clear: right; }
		.wb-disable .gcweb-menu [role=menu] > li:nth-child(3n+4) {
			clear: left; }
		.wb-disable .gcweb-menu [role=menu] > li:nth-child(2n+2) {
			clear: none; }
		.wb-disable .gcweb-menu [role=menu] > li:nth-child(2n+3) {
			clear: none; }
	/*
 * Web Experience Toolkit (WET) / Boîte à outils de l'expérience Web (BOEW)
 * wet-boew.github.io/wet-boew/License-en.html / wet-boew.github.io/wet-boew/Licence-fr.html
 */
	#details-flickr,
	#details-youtube {
		padding-left: 0;
		padding-right: 0; }
	/*
 * Web Experience Toolkit (WET) / Boîte à outils de l'expérience Web (BOEW)
 * wet-boew.github.io/wet-boew/License-en.html / wet-boew.github.io/wet-boew/Licence-fr.html
 */
	.wb-tabs > details, .wb-tabs > .tabpanels > details {
		border-color: #ccc;
		border-style: solid;
		border-width: 1px;
		display: none; }
		.wb-tabs > details[open], .wb-tabs > .tabpanels > details[open] {
			display: block; }
			.wb-tabs > details[open] > summary, .wb-tabs > .tabpanels > details[open] > summary {
				display: none !important; }
	.wb-tabs {
		/* Only for backwards compatibility. Should be removed in v4.1. */ }
		.wb-tabs.carousel-s2.show-thumbs [role="tablist"] li.active a {
			border-color: #666;
			border-style: solid;
			border-width: 10px;
			margin-bottom: 1px;
			padding: 0; }
			.wb-tabs.carousel-s2.show-thumbs [role="tablist"] li.active a:focus::before {
				content: "";
				height: calc(100% - 6px);
				left: 0;
				margin: 2px;
				outline: inherit;
					outline-color: #FFF;
				position: absolute;
				top: 0;
				width: calc(100% - 4px); }
		.wb-tabs.carousel-s2.show-thumbs [role="tablist"] li[role="presentation"] {
			display: inline-block; }
			.wb-tabs.carousel-s2.show-thumbs [role="tablist"] li[role="presentation"] img {
				opacity: .5;
				width: 140px; }
		.wb-tabs.carousel-s2.show-thumbs [role="tablist"] li[class="active"] img {
			opacity: 1; }
		.wb-tabs.carousel-s2.show-thumbs [role="tablist"] li.prv, .wb-tabs.carousel-s2.show-thumbs [role="tablist"] li.tab-count, .wb-tabs.carousel-s2.show-thumbs [role="tablist"] li.nxt {
			display: none; }
	/*
 Social Media Icons Medium View and over
*/
	/*
 *
 * Web Experience Toolkit (WET) / Boîte à outils de l'expérience Web (BOEW)
 * wet-boew.github.io/wet-boew/License-en.html / wet-boew.github.io/wet-boew/Licence-fr.html
 *
 *
 *	Provisional GC Subway map menu
*/
	.provisional {
		/*** GC subway desktop styles ***/
		/* Double H1 */ }
		.provisional.gc-subway {
			border-right: 0px;
			border-top: 0px;
			display: none;
			margin-top: 25px;
			padding-left: 15px; }
			.provisional.gc-subway.no-blink {
				display: block; }
			.provisional.gc-subway .gc-subway-menu-nav {
				float: right;
				width: 33.33%; }
			.provisional.gc-subway ul li:last-child {
				border-bottom: 0px;
				border-left: 4px solid transparent; }
		.provisional.gc-subway-section {
			padding-right: 15px;
			width: 66.66%; }
			.provisional.gc-subway-section h1, .provisional.gc-subway-section .gc-subway-h1 {
				margin-top: 0px; }
			.provisional.gc-subway-section .gc-subway-h1 {
				font-family: Lato, sans-serif;
				font-weight: inherit;
				margin-bottom: 0px;
				margin-right: 0px;
				padding-bottom: 0px !important;
				padding-left: 0px; }
	.wb-disable .provisional.gc-subway {
		display: block; }
	/*
  WET-BOEW
  @title: Proximity CSS - Medium view and over
 */
	.colcount-md-2 {
		-webkit-column-count: 2;
		   -moz-column-count: 2;
		        column-count: 2; }
	.colcount-md-3 {
		-webkit-column-count: 3;
		   -moz-column-count: 3;
		        column-count: 3; }
	.colcount-md-4 {
		-webkit-column-count: 4;
		   -moz-column-count: 4;
		        column-count: 4; }
	.pstn-lft-md {
		position: absolute;
		left: 0;
		right: auto; }
	.pstn-rght-md {
		position: absolute;
		right: 0;
		left: auto; }
	.pstn-tp-md {
		position: absolute;
		top: 0;
		bottom: auto; }
	.pstn-bttm-md {
		position: absolute;
		bottom: 0;
		top: auto; }
	/*
  Variant - GCWeb custom implementation
  @title: Medium view and over (screen only)
 */ }

/* Large view and over */
@media screen and (min-width: 1200px) {
	/*
  WET-BOEW
  @title: Large view and over (screen only)
 */
	.clr-lft-lg {
		clear: left; }
	.clr-rght-lg {
		clear: right; }
	.col-lg-auto {
		width: auto; }
	/*
  WET-BOEW
  @title: Large view and over (screen only)
  @desc:  Variable $screen-lg-min >= 1200px
 */
	/* Make a simple list multi-column and responsive (overide _defaults.scss) */
	.list-responsive > li {
		width: 25%; }
		.list-responsive > li:nth-child(4n+4) {
			clear: right; }
	/*
  @title: Baseline styles for large breakpoint and over
*/
	ul.list-col-lg-1 > li {
		-ms-flex-preferred-size: 100%;
		    flex-basis: 100%; }
	ul.list-col-lg-2 > li {
		-ms-flex-preferred-size: 50%;
		    flex-basis: 50%; }
	ul.list-col-lg-3 > li {
		-ms-flex-preferred-size: 33.33%;
		    flex-basis: 33.33%; }
	ul.list-col-lg-4 > li {
		-ms-flex-preferred-size: 25%;
		    flex-basis: 25%; }
	.wb-filter .input-group {
		max-width: 60%; }
	/*
  WET-BOEW
  @title: Large view and over (screen only)
 */
	/*
 * Well header responsive
 */
	.well.header-rwd {
		width: 50%; }
	/*
 * Home page style
 *
 * Set a responsive with for the h1 in the Well header responsive
 */
	.home .well.header-rwd h1 {
		width: 50%; }
	/*
 * Equal Heights overrides (large view and over)
 */
	.sect-lnks {
		margin-right: 15px;
		width: 31.7%; }
	main.col-md-9 .sect-lnks {
		width: 31.2%; }
	.lt-ie9 .sect-lnks {
		width: 30%; }
	.lt-ie9 main.col-md-9 .sect-lnks {
		width: 30%; }
	/*
  WET-BOEW
  @title: Proximity CSS - Medium view and over
 */
	.colcount-lg-2 {
		-webkit-column-count: 2;
		   -moz-column-count: 2;
		        column-count: 2; }
	.colcount-lg-3 {
		-webkit-column-count: 3;
		   -moz-column-count: 3;
		        column-count: 3; }
	.colcount-lg-4 {
		-webkit-column-count: 4;
		   -moz-column-count: 4;
		        column-count: 4; }
	.pstn-lft-lg {
		position: absolute;
		left: 0;
		right: auto; }
	.pstn-rght-lg {
		position: absolute;
		right: 0;
		left: auto; }
	.pstn-tp-lg {
		position: absolute;
		top: 0;
		bottom: auto; }
	.pstn-bttm-lg {
		position: absolute;
		bottom: 0;
		top: auto; }
	/*
  Variant - GCWeb custom implementation
  @title: Large view and over (screen only)
 */ }

/* Extra-extra-small view */
@media screen and (max-width: 479px) {
	/*
  WET-BOEW
  @title: Extra-extra-small view (screen only)
 */
	/*
  WET-BOEW
  @title: Extra-extra-small view (screen only)
  @desc:  Variable $screen-xxs-max <= 479px
 */
	/* Embedding a Fluid Survey */
	.gc-fld-srvy-container {
		padding-bottom: 100%; }
	#wb-srch input {
		max-width: inherit; }
	/*
 Banner (extra-extra-small view)
 */
	header .brand.col-xs-5, #wb-glb-mn {
		float: none !important;
		width: auto !important; }
	header .brand {
		/* Solely for the purpose of having the previous header look decent */ }
		header .brand object,
		header .brand img {
			padding-right: 0; }
	#wb-glb-mn ul {
		width: 100%; }
		#wb-glb-mn ul.chvrn {
			margin-left: auto; }
			#wb-glb-mn ul.chvrn:before {
				border: 0; }
	/*
 * Site information (extra-extra-small view)
 */
	#wb-info .gc-sub-footer, #wb-info .brand {
		/* START: To support footer <= v2.0 */
		/* END */ }
		#wb-info .gc-sub-footer object,
		#wb-info .gc-sub-footer img, #wb-info .brand object,
		#wb-info .brand img {
			height: 25px;
			margin-top: 15px;
			max-width: 100%;
			padding-right: 10px; }
		#wb-info .gc-sub-footer .row nav ul, #wb-info .brand .row nav ul {
			-webkit-column-count: 1;
			   -moz-column-count: 1;
			        column-count: 1; }
	/*
 * Web Experience Toolkit (WET) / Boîte à outils de l'expérience Web (BOEW)
 * wet-boew.github.io/wet-boew/License-en.html / wet-boew.github.io/wet-boew/Licence-fr.html
 */
	#mb-pnl {
		min-width: 65%; }
	/*
 * Web Experience Toolkit (WET) / Boîte à outils de l'expérience Web (BOEW)
 * wet-boew.github.io/wet-boew/License-en.html / wet-boew.github.io/wet-boew/Licence-fr.html
 */
	.dataTables_wrapper .dataTables_length {
		width: 100%; }
	/*
  WET-BOEW
  @title: Extra-extra-small view (screen only)
 */
	/*
 * Home page style
 *
 * Set a responsive with for the h1 in the Well header responsive
 */
	.home .well.header-rwd h1 {
		width: 80%; }
	/*
 * Web Experience Toolkit (WET) / Boîte à outils de l'expérience Web (BOEW)
 * wet-boew.github.io/wet-boew/License-en.html / wet-boew.github.io/wet-boew/Licence-fr.html
 */
	.wb-tabs.carousel-s2 [role="tablist"] li.prv, .wb-tabs.carousel-s2 [role="tablist"] li.nxt {
		margin-right: 0; }
	.wb-tabs.carousel-s2 [role="tablist"] li.prv {
		margin-left: 0; }
		.wb-tabs.carousel-s2 [role="tablist"] li.prv a {
			padding: 10px 0 10px .4em; }
	.wb-tabs.carousel-s2 [role="tablist"] li.nxt a {
		padding: 10px 0; }
	.wb-tabs.carousel-s2 [role="tablist"] li.tab-count {
		font-size: .9em;
		margin-right: 5px; }
	.wb-tabs.carousel-s2 [role="tablist"] li.plypause {
		margin-right: 2%; }
		.wb-tabs.carousel-s2 [role="tablist"] li.plypause a {
			font-size: 1.3em;
			margin-right: 0;
			padding: 12px 10px 7px; }
	/*
 Carousel (extra-extra-small view)
 */
	.prm-flpr .wb-tabs.carousel-s2 [role="tablist"] li .plypause a {
		font-size: 1em;
		vertical-align: middle; }
	.prm-flpr .wb-tabs.carousel-s2 [role="tablist"] li .tab-count {
		height: 0;
		visibility: hidden;
		width: 0; }
		.prm-flpr .wb-tabs.carousel-s2 [role="tablist"] li .tab-count .curr-count {
			font-size: 1em; }
	/*
  Variant - GCWeb custom implementation
  @title: Extra-extra-small view (screen only)
 */ }

/* Extra-small view */
@media screen and (min-width: 480px) and (max-width: 767px) {
	/*
  WET-BOEW
  @title: Extra-small view (screen only)
 */
	/*
  WET-BOEW
  @title: Extra-small view (screen only)
  @desc: Variable $screen-xs-min-to-screen-xs-max >= 480px <= 767px
 */
	#wb-srch input {
		max-width: 50%; }
	/*
  WET-BOEW
  @title: Extra-small view (screen only)
 */
	/*
 * Home page style
 *
 * Set a responsive with for the h1 in the Well header responsive
 */
	.home .well.header-rwd h1 {
		width: 59%; }
	/*
  Variant - GCWeb custom implementation
  @title: Extra-small view (screen only)
 */ }

/* Small view */
@media screen and (min-width: 768px) and (max-width: 991px) {
	/*
  WET-BOEW
  @title: Small view (screen only)
 */
	.clr-lft-sm {
		clear: left; }
	.clr-rght-sm {
		clear: right; }
	/*
  WET-BOEW
  @title: Small view (screen only)
  @desc:  Variable $screen-sm-min-to-screen-sm-max >= 768px <= 991px
 */
	/*
  WET-BOEW
  @title: Search Small view and under (screen only)
 */
	#wb-srch {
		margin-bottom: 15px; }
	/*
  Campaign
  @title: Small view (screen only)
 */
	.cmpgn-sctns {
		word-wrap: break-word; }
	/*
  Variant - GCWeb custom implementation
  @title: Small view (screen only)
 */ }

/* Medium view */
@media screen and (min-width: 992px) and (max-width: 1199px) {
	/*
  WET-BOEW
  @title: Medium view (screen only)
 */
	.clr-lft-md {
		clear: left; }
	.clr-rght-md {
		clear: right; }
	/*
  WET-BOEW
  @title: Medium view (screen only)
  @desc:  Variable $screen-md-min-to-screen-md-max >= 992px <= 1199px
 */
	/*
  WET-BOEW
  @title: Medium view (screen only)
 */
	.gcweb-menu {
		/*
	 * Tablet mode
	 *
	 * (Grid of the submenu panel)
	 */ }
		.gcweb-menu [role=menu] [role=menu] li {
			width: 100%; }
		.gcweb-menu [role=menu] [role=menu] li:last-child {
			left: auto;
			margin-top: 1em;
			position: relative;
			top: auto; }
		.gcweb-menu [role=menu] [role=menu] [role=menu] li:last-child {
			margin-top: 0px; }
		.gcweb-menu [role=menu] [role=menu] [role=menu] {
			margin-bottom: 0px;
			padding-bottom: 0px;
			position: relative; }
	/*
  WET-BOEW
  @title: Medium view (screen only)
 */
	/*
 * Home page style
 *
 * Set a responsive with for the h1 in the Well header responsive
 */
	.home .well.header-rwd h1 {
		width: 58.3%; }
	/*
 * Equal Heights overrides (medium view)
 */
	.sect-lnks {
		margin-right: 15px;
		width: 48.1%; }
	main.col-md-9 .sect-lnks {
		width: 47.5%; }
	.lt-ie9 .sect-lnks {
		width: 47%; }
	.lt-ie9 main.col-md-9 .sect-lnks {
		width: 46%; }
	/*
  Variant - GCWeb custom implementation
  @title: Medium view (screen only)
 */
	/*
  WET-BOEW
  @title: Search medium view and over (screen only)
 */
	.home .home-your-gov {
		background-image: url(https://www.canada.ca/content/dam/canada/carousel/bkg-home-yourgov-md.jpg), url(../assets/bkg-home-yourgov-md.jpg); } }

/* Large view */
@media screen and (min-width: 1200px) and (max-width: 1599px) {
	/*
  WET-BOEW
  @title: Large view (screen only)
 */
	/*
  WET-BOEW
  @title: Large view (screen only)
  @desc:  Variable $screen-lg-min-to-lg-max >= 1200 px <= 1599 px
 */
	/*
  Variant - GCWeb custom implementation
  @title: Large view (screen only)
 */ }

/* Extra-large view */
@media screen and (min-width: 1600px) {
	/*
  WET-BOEW
  @title: Extra-large view (screen only)
 */
	/*
  WET-BOEW
  @title: Extra-large view (screen only)
  @desc:  Variable $screen-xl-min >= 1600px
 */
	/*
  WET-BOEW
  @title: Proximity CSS - Medium view and over
 */
	.colcount-xl-2 {
		-webkit-column-count: 2;
		   -moz-column-count: 2;
		        column-count: 2; }
	.colcount-xl-3 {
		-webkit-column-count: 3;
		   -moz-column-count: 3;
		        column-count: 3; }
	.colcount-xl-4 {
		-webkit-column-count: 4;
		   -moz-column-count: 4;
		        column-count: 4; }
	/*
  Variant - GCWeb custom implementation
  @title: Extra-large view (screen only)
 */ }

/* Print view */
@media print {
	/*
  WET-BOEW
  @title: Print view
 */
	.pg-brk-aft {
		page-break-after: always; }
	a[href]:after {
		content: none; }
	#wb-tphp {
		display: none; }
	/*
  WET-BOEW
  @title: Print view
 */
	.features, #wb-lng, #wb-glb-mn,
	#wb-srch,
	#wb-sm, #wb-info, .tofpg, .gcweb-menu, #wb-sec, .pagedetails details, .pagedetails .btn, .followus {
		display: none !important; }
	header .brand {
		margin-bottom: 0; }
	h1 {
		margin-top: 0; }
	/*
  WET-BOEW
  @title: Breadcrumb print CSS overrides
 */
	#wb-bc .breadcrumb {
		margin-bottom: 0; }
	#wb-bc a[href]:after {
		content: ""; }
	/*
 Site information (print view)
*/
	/*
 Site menu (print view)
*/
	/*
 Search (print view)
 */
	/*
 Secondary menu (print view)
*/
	/*
 * Share/feedback-specific overrides (print view)
 */
	/*
 * Web Experience Toolkit (WET) / Boîte à outils de l'expérience Web (BOEW)
 * wet-boew.github.io/wet-boew/License-en.html / wet-boew.github.io/wet-boew/Licence-fr.html
 */
	.fn-lnk, .wb-fnote .fn-rtn a {
		background-color: transparent;
		border: 0;
		padding: 0; }
	.wb-fnote {
		border-left: 0;
		border-right: 0;
		margin-bottom: 1em;
		margin-left: 0;
		margin-right: 0; }
		.wb-fnote dd {
			border: 0;
			display: inline-block;
			width: 100%; }
		.wb-fnote .fn-rtn {
			overflow: visible; }
	/*
 * Web Experience Toolkit (WET) / Boîte à outils de l'expérience Web (BOEW)
 * wet-boew.github.io/wet-boew/License-eng.html / wet-boew.github.io/wet-boew/Licence-fra.html
*/
	.wb-geomap-detail, .olControlMousePosition, .olControlPanZoomBar {
		visibility: hidden; }
	/*
 * Web Experience Toolkit (WET) / Boîte à outils de l'expérience Web (BOEW)
 * wet-boew.github.io/wet-boew/License-en.html / wet-boew.github.io/wet-boew/Licence-fr.html
 */
	.mfp-wrap,
	.mfp-container {
		position: static; }
	.mfp-arrow,
	.mfp-close {
		display: none !important; }
	/*
  Multimedia Player Code (print view)
 */
	.wb-mm-ctrls,
	.wb-mm-ovrly, .wb-mltmd.cc_on .wb-mm-cc {
		display: none; }
	/*
 * Web Experience Toolkit (WET) / Boîte à outils de l'expérience Web (BOEW)
 * wet-boew.github.io/wet-boew/License-en.html / wet-boew.github.io/wet-boew/Licence-fr.html
 */
	/**
 * Print styles
 */
	.wb-overlay-dlg main > *, .wb-modal main > * {
		display: none; }
	.wb-overlay-dlg main .wb-overlay.open, .wb-overlay-dlg main .mfp-content, .wb-modal main .wb-overlay.open, .wb-modal main .mfp-content {
		display: block; }
	.wb-overlay.open {
		position: static; }
		.wb-overlay.open.no-print {
			display: none; }
	.mfp-content:before, .wb-overlay.open:before {
		content: attr(data-pgtitle);
		display: block;
		font-size: 1.9em; }
	/*
 * Web Experience Toolkit (WET) / Boîte à outils de l'expérience Web (BOEW)
 * wet-boew.github.io/wet-boew/License-en.html / wet-boew.github.io/wet-boew/Licence-fr.html
 */
	/* Use higher contrast and text-weight for printable form. */
	.kwd, .typ, .tag {
		font-weight: 700; }
	.kwd, .tag {
		color: #006; }
	.str, .atv {
		color: #060; }
	.pun, .opn, .clo {
		color: #440; }
	.typ, .atn {
		color: #404; }
	.com {
		color: #600;
		font-style: italic; }
	.lit {
		color: #044; }
	/*
 * Web Experience Toolkit (WET) / Boîte à outils de l'expérience Web (BOEW)
 * wet-boew.github.io/wet-boew/License-en.html / wet-boew.github.io/wet-boew/Licence-fr.html
 */
	/**
 * Print styles
 */
	.wb-tabs [role="tablist"], .wb-tabs.print-active > .tabpanels > div.out, .wb-tabs.print-active > .tabpanels > details.out .tgl-panel, .wb-tabs.print-active > .tabpanels > details > summary[aria-expanded="false"] + .tgl-panel {
		display: none !important; }
	.wb-tabs.carousel-s1 [role="tabpanel"], .wb-tabs.carousel-s2 [role="tabpanel"] {
		margin-bottom: .5em; }
	.wb-tabs.carousel-s1 figure, .wb-tabs.carousel-s2 figure {
		page-break-inside: avoid; }
	.wb-tabs.carousel-s1 figcaption, .wb-tabs.carousel-s2 figcaption {
		border: 1px solid #000; }
	.wb-tabs [role="tabpanel"] {
		display: block !important;
		opacity: 1 !important;
		overflow: visible !important;
		position: static !important;
		-webkit-transform: none;
		        transform: none;
		visibility: visible !important; }
		.wb-tabs [role="tabpanel"] figcaption {
			position: static; }
		.wb-tabs [role="tabpanel"] summary {
			display: list-item !important; }
		.wb-tabs [role="tabpanel"].noheight {
			max-height: none; }
	.wb-tabs > .tabpanels {
		overflow: visible !important; }
	/*
 * Priorities (Government of Canada activities and initiatives) (print view)
 */
	.gc-nttvs {
		display: none; }
	/* Deprecated as v4.0.28 */
	/*
 Social Media Icons Print view
*/
	/*
 * There is no working example, probably not used
 */
	.jumbotron.pagebrand figcaption {
		position: static; }
	/*
  Campaign
  @title: Print view
 */
	.cmpgn-sctns {
		margin-top: 20px; }
	/*
  Variant - GCWeb custom implementation
  @title: Print view
 */ }

/* Testing WCAG Spacing */
/*
 *
 * Web Experience Toolkit (WET) / Boîte à outils de l'expérience Web (BOEW)
 * wet-boew.github.io/wet-boew/License-en.html / wet-boew.github.io/wet-boew/Licence-fr.html
 *
 *The purpose of these utilities are to test WCAG success criterion 1.4.12: Text Spacing
 */
/* Text Spacing */
.test-textSpacing * {
	letter-spacing: .12em !important;
	line-height: 1.5em !important;
	word-spacing: .16em !important; }

.test-textSpacing p {
	margin-bottom: 2em !important; }
