@charset "utf-8";
/*!
 * @title Web Experience Toolkit (WET) / Boîte à outils de l'expérience Web (BOEW)
 * @license wet-boew.github.io/wet-boew/License-en.html / wet-boew.github.io/wet-boew/Licence-fr.html
 * v12.5.0 - 2022-12-13
 *
 */
/*!
 *
 * Web Experience Toolkit (WET) / Boîte à outils de l'expérience Web (BOEW)
 * wet-boew.github.io/wet-boew/License-en.html / wet-boew.github.io/wet-boew/Licence-fr.html
 *
 */
/*
 Global variables for GCWeb
 */
/* Headings font-sizes */
/* Small font-size */
/* Font weight */
/*
Left menu variables
*/
/*
 * Web Experience Toolkit (WET) / Boîte à outils de l'expérience Web (BOEW)
 * wet-boew.github.io/wet-boew/License-en.html / wet-boew.github.io/wet-boew/Licence-fr.html
 */
/*
 * HOW TO USE THIS FILE
 * Use this file to override Bootstrap variables and WET custom variables.
 * If there is a Bootstrap variable not shown here that you want to override, go to "../node_modules/bootstrap-sass/assets/stylesheets/bootstrap/variables" to view the variables that you can override. Simply copy and paste the variable and its applicable section (if applicable) from the Bootstrap file into this override file and override the variables as applicable.
 */
/*!
 * GLYPHICONS Halflings for Twitter Bootstrap by GLYPHICONS.com | Licensed under https://www.apache.org/licenses/LICENSE-2.0
 */
/*!
 * Bootstrap v3.4.1 (https://getbootstrap.com/)
 * Copyright 2011-2019 Twitter, Inc.
 * Licensed under MIT (https://github.com/twbs/bootstrap/blob/master/LICENSE)
 */
/*! normalize.css v3.0.3 | MIT License | github.com/necolas/normalize.css */
html {
	font-family: sans-serif;
	-ms-text-size-adjust: 100%;
	-webkit-text-size-adjust: 100%; }

body {
	margin: 0; }

article,
aside,
details,
figcaption,
figure,
footer,
header,
hgroup,
main,
menu,
nav,
section,
summary {
	display: block; }

audio,
canvas,
progress,
video {
	display: inline-block;
	vertical-align: baseline; }

audio:not([controls]) {
	display: none;
	height: 0; }

[hidden],
template {
	display: none; }

a {
	background-color: transparent; }

a:active,
a:hover {
	outline: 0; }

abbr[title] {
	border-bottom: none;
	text-decoration: underline;
	-webkit-text-decoration: underline dotted;
	        text-decoration: underline dotted; }

b,
strong {
	font-weight: bold; }

dfn {
	font-style: italic; }

h1 {
	font-size: 2em;
	margin: 0.67em 0; }

mark {
	background: #ff0;
	color: #000; }

small {
	font-size: 80%; }

sub,
sup {
	font-size: 75%;
	line-height: 0;
	position: relative;
	vertical-align: baseline; }

sup {
	top: -0.5em; }

sub {
	bottom: -0.25em; }

img {
	border: 0; }

svg:not(:root) {
	overflow: hidden; }

figure {
	margin: 1em 40px; }

hr {
	-webkit-box-sizing: content-box;
	        box-sizing: content-box;
	height: 0; }

pre {
	overflow: auto; }

code,
kbd,
pre,
samp {
	font-family: monospace, monospace;
	font-size: 1em; }

button,
input,
optgroup,
select,
textarea {
	color: inherit;
	font: inherit;
	margin: 0; }

button {
	overflow: visible; }

button,
select {
	text-transform: none; }

button,
html input[type="button"],
input[type="reset"],
input[type="submit"] {
	-webkit-appearance: button;
	cursor: pointer; }

button[disabled],
html input[disabled] {
	cursor: default; }

button::-moz-focus-inner,
input::-moz-focus-inner {
	border: 0;
	padding: 0; }

input {
	line-height: normal; }

input[type="checkbox"],
input[type="radio"] {
	-webkit-box-sizing: border-box;
	        box-sizing: border-box;
	padding: 0; }

input[type="number"]::-webkit-inner-spin-button,
input[type="number"]::-webkit-outer-spin-button {
	height: auto; }

input[type="search"] {
	-webkit-appearance: textfield;
	-webkit-box-sizing: content-box;
	        box-sizing: content-box; }

input[type="search"]::-webkit-search-cancel-button,
input[type="search"]::-webkit-search-decoration {
	-webkit-appearance: none; }

fieldset {
	border: 1px solid #c0c0c0;
	margin: 0 2px;
	padding: 0.35em 0.625em 0.75em; }

legend {
	border: 0;
	padding: 0; }

textarea {
	overflow: auto; }

optgroup {
	font-weight: bold; }

table {
	border-collapse: collapse;
	border-spacing: 0; }

td,
th {
	padding: 0; }

/*! Source: https://github.com/h5bp/html5-boilerplate/blob/master/src/css/main.css */
@media print {
	*,
	*:before,
	*:after {
		color: #000 !important;
		text-shadow: none !important;
		background: transparent !important;
		-webkit-box-shadow: none !important;
		        box-shadow: none !important; }
	a,
	a:visited {
		text-decoration: underline; }
	a[href]:after {
		content: " (" attr(href) ")"; }
	abbr[title]:after {
		content: " (" attr(title) ")"; }
	a[href^="#"]:after,
	a[href^="javascript:"]:after {
		content: ""; }
	pre,
	blockquote {
		border: 1px solid #999;
		page-break-inside: avoid; }
	thead {
		display: table-header-group; }
	tr,
	img {
		page-break-inside: avoid; }
	img {
		max-width: 100% !important; }
	p,
	h2,
	h3 {
		orphans: 3;
		widows: 3; }
	h2,
	h3 {
		page-break-after: avoid; }
	.navbar {
		display: none; }
	.btn > .caret,
	.dropup > .btn > .caret {
		border-top-color: #000 !important; }
	.label {
		border: 1px solid #000; }
	.table {
		border-collapse: collapse !important; }
		.table td,
		.table th {
			background-color: #fff !important; }
	.table-bordered th,
	.table-bordered td {
		border: 1px solid #ddd !important; } }

@font-face {
	font-family: "Glyphicons Halflings";
	src: url("../../wet-boew/fonts/glyphicons-halflings-regular.eot");
	src: url("../../wet-boew/fonts/glyphicons-halflings-regular.eot?#iefix") format("embedded-opentype"), url("../../wet-boew/fonts/glyphicons-halflings-regular.woff2") format("woff2"), url("../../wet-boew/fonts/glyphicons-halflings-regular.woff") format("woff"), url("../../wet-boew/fonts/glyphicons-halflings-regular.ttf") format("truetype"), url("../../wet-boew/fonts/glyphicons-halflings-regular.svg#glyphicons_halflingsregular") format("svg"); }

.glyphicon {
	position: relative;
	top: 1px;
	display: inline-block;
	font-family: "Glyphicons Halflings";
	font-style: normal;
	font-weight: 400;
	line-height: 1;
	-webkit-font-smoothing: antialiased;
	-moz-osx-font-smoothing: grayscale; }

.glyphicon-asterisk:before {
	content: "\002a"; }

.glyphicon-plus:before {
	content: "\002b"; }

.glyphicon-euro:before,
.glyphicon-eur:before {
	content: "\20ac"; }

.glyphicon-minus:before {
	content: "\2212"; }

.glyphicon-cloud:before {
	content: "\2601"; }

.glyphicon-envelope:before {
	content: "\2709"; }

.glyphicon-pencil:before {
	content: "\270f"; }

.glyphicon-glass:before {
	content: "\e001"; }

.glyphicon-music:before {
	content: "\e002"; }

.glyphicon-search:before {
	content: "\e003"; }

.glyphicon-heart:before {
	content: "\e005"; }

.glyphicon-star:before {
	content: "\e006"; }

.glyphicon-star-empty:before {
	content: "\e007"; }

.glyphicon-user:before {
	content: "\e008"; }

.glyphicon-film:before {
	content: "\e009"; }

.glyphicon-th-large:before {
	content: "\e010"; }

.glyphicon-th:before {
	content: "\e011"; }

.glyphicon-th-list:before {
	content: "\e012"; }

.glyphicon-ok:before {
	content: "\e013"; }

.glyphicon-remove:before {
	content: "\e014"; }

.glyphicon-zoom-in:before {
	content: "\e015"; }

.glyphicon-zoom-out:before {
	content: "\e016"; }

.glyphicon-off:before {
	content: "\e017"; }

.glyphicon-signal:before {
	content: "\e018"; }

.glyphicon-cog:before {
	content: "\e019"; }

.glyphicon-trash:before {
	content: "\e020"; }

.glyphicon-home:before {
	content: "\e021"; }

.glyphicon-file:before {
	content: "\e022"; }

.glyphicon-time:before {
	content: "\e023"; }

.glyphicon-road:before {
	content: "\e024"; }

.glyphicon-download-alt:before {
	content: "\e025"; }

.glyphicon-download:before {
	content: "\e026"; }

.glyphicon-upload:before {
	content: "\e027"; }

.glyphicon-inbox:before {
	content: "\e028"; }

.glyphicon-play-circle:before {
	content: "\e029"; }

.glyphicon-repeat:before {
	content: "\e030"; }

.glyphicon-refresh:before {
	content: "\e031"; }

.glyphicon-list-alt:before {
	content: "\e032"; }

.glyphicon-lock:before {
	content: "\e033"; }

.glyphicon-flag:before {
	content: "\e034"; }

.glyphicon-headphones:before {
	content: "\e035"; }

.glyphicon-volume-off:before {
	content: "\e036"; }

.glyphicon-volume-down:before {
	content: "\e037"; }

.glyphicon-volume-up:before {
	content: "\e038"; }

.glyphicon-qrcode:before {
	content: "\e039"; }

.glyphicon-barcode:before {
	content: "\e040"; }

.glyphicon-tag:before {
	content: "\e041"; }

.glyphicon-tags:before {
	content: "\e042"; }

.glyphicon-book:before {
	content: "\e043"; }

.glyphicon-bookmark:before {
	content: "\e044"; }

.glyphicon-print:before {
	content: "\e045"; }

.glyphicon-camera:before {
	content: "\e046"; }

.glyphicon-font:before {
	content: "\e047"; }

.glyphicon-bold:before {
	content: "\e048"; }

.glyphicon-italic:before {
	content: "\e049"; }

.glyphicon-text-height:before {
	content: "\e050"; }

.glyphicon-text-width:before {
	content: "\e051"; }

.glyphicon-align-left:before {
	content: "\e052"; }

.glyphicon-align-center:before {
	content: "\e053"; }

.glyphicon-align-right:before {
	content: "\e054"; }

.glyphicon-align-justify:before {
	content: "\e055"; }

.glyphicon-list:before {
	content: "\e056"; }

.glyphicon-indent-left:before {
	content: "\e057"; }

.glyphicon-indent-right:before {
	content: "\e058"; }

.glyphicon-facetime-video:before {
	content: "\e059"; }

.glyphicon-picture:before {
	content: "\e060"; }

.glyphicon-map-marker:before {
	content: "\e062"; }

.glyphicon-adjust:before {
	content: "\e063"; }

.glyphicon-tint:before {
	content: "\e064"; }

.glyphicon-edit:before {
	content: "\e065"; }

.glyphicon-share:before {
	content: "\e066"; }

.glyphicon-check:before {
	content: "\e067"; }

.glyphicon-move:before {
	content: "\e068"; }

.glyphicon-step-backward:before {
	content: "\e069"; }

.glyphicon-fast-backward:before {
	content: "\e070"; }

.glyphicon-backward:before {
	content: "\e071"; }

.glyphicon-play:before {
	content: "\e072"; }

.glyphicon-pause:before {
	content: "\e073"; }

.glyphicon-stop:before {
	content: "\e074"; }

.glyphicon-forward:before {
	content: "\e075"; }

.glyphicon-fast-forward:before {
	content: "\e076"; }

.glyphicon-step-forward:before {
	content: "\e077"; }

.glyphicon-eject:before {
	content: "\e078"; }

.glyphicon-chevron-left:before {
	content: "\e079"; }

.glyphicon-chevron-right:before {
	content: "\e080"; }

.glyphicon-plus-sign:before {
	content: "\e081"; }

.glyphicon-minus-sign:before {
	content: "\e082"; }

.glyphicon-remove-sign:before {
	content: "\e083"; }

.glyphicon-ok-sign:before {
	content: "\e084"; }

.glyphicon-question-sign:before {
	content: "\e085"; }

.glyphicon-info-sign:before {
	content: "\e086"; }

.glyphicon-screenshot:before {
	content: "\e087"; }

.glyphicon-remove-circle:before {
	content: "\e088"; }

.glyphicon-ok-circle:before {
	content: "\e089"; }

.glyphicon-ban-circle:before {
	content: "\e090"; }

.glyphicon-arrow-left:before {
	content: "\e091"; }

.glyphicon-arrow-right:before {
	content: "\e092"; }

.glyphicon-arrow-up:before {
	content: "\e093"; }

.glyphicon-arrow-down:before {
	content: "\e094"; }

.glyphicon-share-alt:before {
	content: "\e095"; }

.glyphicon-resize-full:before {
	content: "\e096"; }

.glyphicon-resize-small:before {
	content: "\e097"; }

.glyphicon-exclamation-sign:before {
	content: "\e101"; }

.glyphicon-gift:before {
	content: "\e102"; }

.glyphicon-leaf:before {
	content: "\e103"; }

.glyphicon-fire:before {
	content: "\e104"; }

.glyphicon-eye-open:before {
	content: "\e105"; }

.glyphicon-eye-close:before {
	content: "\e106"; }

.glyphicon-warning-sign:before {
	content: "\e107"; }

.glyphicon-plane:before {
	content: "\e108"; }

.glyphicon-calendar:before {
	content: "\e109"; }

.glyphicon-random:before {
	content: "\e110"; }

.glyphicon-comment:before {
	content: "\e111"; }

.glyphicon-magnet:before {
	content: "\e112"; }

.glyphicon-chevron-up:before {
	content: "\e113"; }

.glyphicon-chevron-down:before {
	content: "\e114"; }

.glyphicon-retweet:before {
	content: "\e115"; }

.glyphicon-shopping-cart:before {
	content: "\e116"; }

.glyphicon-folder-close:before {
	content: "\e117"; }

.glyphicon-folder-open:before {
	content: "\e118"; }

.glyphicon-resize-vertical:before {
	content: "\e119"; }

.glyphicon-resize-horizontal:before {
	content: "\e120"; }

.glyphicon-hdd:before {
	content: "\e121"; }

.glyphicon-bullhorn:before {
	content: "\e122"; }

.glyphicon-bell:before {
	content: "\e123"; }

.glyphicon-certificate:before {
	content: "\e124"; }

.glyphicon-thumbs-up:before {
	content: "\e125"; }

.glyphicon-thumbs-down:before {
	content: "\e126"; }

.glyphicon-hand-right:before {
	content: "\e127"; }

.glyphicon-hand-left:before {
	content: "\e128"; }

.glyphicon-hand-up:before {
	content: "\e129"; }

.glyphicon-hand-down:before {
	content: "\e130"; }

.glyphicon-circle-arrow-right:before {
	content: "\e131"; }

.glyphicon-circle-arrow-left:before {
	content: "\e132"; }

.glyphicon-circle-arrow-up:before {
	content: "\e133"; }

.glyphicon-circle-arrow-down:before {
	content: "\e134"; }

.glyphicon-globe:before {
	content: "\e135"; }

.glyphicon-wrench:before {
	content: "\e136"; }

.glyphicon-tasks:before {
	content: "\e137"; }

.glyphicon-filter:before {
	content: "\e138"; }

.glyphicon-briefcase:before {
	content: "\e139"; }

.glyphicon-fullscreen:before {
	content: "\e140"; }

.glyphicon-dashboard:before {
	content: "\e141"; }

.glyphicon-paperclip:before {
	content: "\e142"; }

.glyphicon-heart-empty:before {
	content: "\e143"; }

.glyphicon-link:before {
	content: "\e144"; }

.glyphicon-phone:before {
	content: "\e145"; }

.glyphicon-pushpin:before {
	content: "\e146"; }

.glyphicon-usd:before {
	content: "\e148"; }

.glyphicon-gbp:before {
	content: "\e149"; }

.glyphicon-sort:before {
	content: "\e150"; }

.glyphicon-sort-by-alphabet:before {
	content: "\e151"; }

.glyphicon-sort-by-alphabet-alt:before {
	content: "\e152"; }

.glyphicon-sort-by-order:before {
	content: "\e153"; }

.glyphicon-sort-by-order-alt:before {
	content: "\e154"; }

.glyphicon-sort-by-attributes:before {
	content: "\e155"; }

.glyphicon-sort-by-attributes-alt:before {
	content: "\e156"; }

.glyphicon-unchecked:before {
	content: "\e157"; }

.glyphicon-expand:before {
	content: "\e158"; }

.glyphicon-collapse-down:before {
	content: "\e159"; }

.glyphicon-collapse-up:before {
	content: "\e160"; }

.glyphicon-log-in:before {
	content: "\e161"; }

.glyphicon-flash:before {
	content: "\e162"; }

.glyphicon-log-out:before {
	content: "\e163"; }

.glyphicon-new-window:before {
	content: "\e164"; }

.glyphicon-record:before {
	content: "\e165"; }

.glyphicon-save:before {
	content: "\e166"; }

.glyphicon-open:before {
	content: "\e167"; }

.glyphicon-saved:before {
	content: "\e168"; }

.glyphicon-import:before {
	content: "\e169"; }

.glyphicon-export:before {
	content: "\e170"; }

.glyphicon-send:before {
	content: "\e171"; }

.glyphicon-floppy-disk:before {
	content: "\e172"; }

.glyphicon-floppy-saved:before {
	content: "\e173"; }

.glyphicon-floppy-remove:before {
	content: "\e174"; }

.glyphicon-floppy-save:before {
	content: "\e175"; }

.glyphicon-floppy-open:before {
	content: "\e176"; }

.glyphicon-credit-card:before {
	content: "\e177"; }

.glyphicon-transfer:before {
	content: "\e178"; }

.glyphicon-cutlery:before {
	content: "\e179"; }

.glyphicon-header:before {
	content: "\e180"; }

.glyphicon-compressed:before {
	content: "\e181"; }

.glyphicon-earphone:before {
	content: "\e182"; }

.glyphicon-phone-alt:before {
	content: "\e183"; }

.glyphicon-tower:before {
	content: "\e184"; }

.glyphicon-stats:before {
	content: "\e185"; }

.glyphicon-sd-video:before {
	content: "\e186"; }

.glyphicon-hd-video:before {
	content: "\e187"; }

.glyphicon-subtitles:before {
	content: "\e188"; }

.glyphicon-sound-stereo:before {
	content: "\e189"; }

.glyphicon-sound-dolby:before {
	content: "\e190"; }

.glyphicon-sound-5-1:before {
	content: "\e191"; }

.glyphicon-sound-6-1:before {
	content: "\e192"; }

.glyphicon-sound-7-1:before {
	content: "\e193"; }

.glyphicon-copyright-mark:before {
	content: "\e194"; }

.glyphicon-registration-mark:before {
	content: "\e195"; }

.glyphicon-cloud-download:before {
	content: "\e197"; }

.glyphicon-cloud-upload:before {
	content: "\e198"; }

.glyphicon-tree-conifer:before {
	content: "\e199"; }

.glyphicon-tree-deciduous:before {
	content: "\e200"; }

.glyphicon-cd:before {
	content: "\e201"; }

.glyphicon-save-file:before {
	content: "\e202"; }

.glyphicon-open-file:before {
	content: "\e203"; }

.glyphicon-level-up:before {
	content: "\e204"; }

.glyphicon-copy:before {
	content: "\e205"; }

.glyphicon-paste:before {
	content: "\e206"; }

.glyphicon-alert:before {
	content: "\e209"; }

.glyphicon-equalizer:before {
	content: "\e210"; }

.glyphicon-king:before {
	content: "\e211"; }

.glyphicon-queen:before {
	content: "\e212"; }

.glyphicon-pawn:before {
	content: "\e213"; }

.glyphicon-bishop:before {
	content: "\e214"; }

.glyphicon-knight:before {
	content: "\e215"; }

.glyphicon-baby-formula:before {
	content: "\e216"; }

.glyphicon-tent:before {
	content: "\26fa"; }

.glyphicon-blackboard:before {
	content: "\e218"; }

.glyphicon-bed:before {
	content: "\e219"; }

.glyphicon-apple:before {
	content: "\f8ff"; }

.glyphicon-erase:before {
	content: "\e221"; }

.glyphicon-hourglass:before {
	content: "\231b"; }

.glyphicon-lamp:before {
	content: "\e223"; }

.glyphicon-duplicate:before {
	content: "\e224"; }

.glyphicon-piggy-bank:before {
	content: "\e225"; }

.glyphicon-scissors:before {
	content: "\e226"; }

.glyphicon-bitcoin:before {
	content: "\e227"; }

.glyphicon-btc:before {
	content: "\e227"; }

.glyphicon-xbt:before {
	content: "\e227"; }

.glyphicon-yen:before {
	content: "\00a5"; }

.glyphicon-jpy:before {
	content: "\00a5"; }

.glyphicon-ruble:before {
	content: "\20bd"; }

.glyphicon-rub:before {
	content: "\20bd"; }

.glyphicon-scale:before {
	content: "\e230"; }

.glyphicon-ice-lolly:before {
	content: "\e231"; }

.glyphicon-ice-lolly-tasted:before {
	content: "\e232"; }

.glyphicon-education:before {
	content: "\e233"; }

.glyphicon-option-horizontal:before {
	content: "\e234"; }

.glyphicon-option-vertical:before {
	content: "\e235"; }

.glyphicon-menu-hamburger:before {
	content: "\e236"; }

.glyphicon-modal-window:before {
	content: "\e237"; }

.glyphicon-oil:before {
	content: "\e238"; }

.glyphicon-grain:before {
	content: "\e239"; }

.glyphicon-sunglasses:before {
	content: "\e240"; }

.glyphicon-text-size:before {
	content: "\e241"; }

.glyphicon-text-color:before {
	content: "\e242"; }

.glyphicon-text-background:before {
	content: "\e243"; }

.glyphicon-object-align-top:before {
	content: "\e244"; }

.glyphicon-object-align-bottom:before {
	content: "\e245"; }

.glyphicon-object-align-horizontal:before {
	content: "\e246"; }

.glyphicon-object-align-left:before {
	content: "\e247"; }

.glyphicon-object-align-vertical:before {
	content: "\e248"; }

.glyphicon-object-align-right:before {
	content: "\e249"; }

.glyphicon-triangle-right:before {
	content: "\e250"; }

.glyphicon-triangle-left:before {
	content: "\e251"; }

.glyphicon-triangle-bottom:before {
	content: "\e252"; }

.glyphicon-triangle-top:before {
	content: "\e253"; }

.glyphicon-console:before {
	content: "\e254"; }

.glyphicon-superscript:before {
	content: "\e255"; }

.glyphicon-subscript:before {
	content: "\e256"; }

.glyphicon-menu-left:before {
	content: "\e257"; }

.glyphicon-menu-right:before {
	content: "\e258"; }

.glyphicon-menu-down:before {
	content: "\e259"; }

.glyphicon-menu-up:before {
	content: "\e260"; }

* {
	-webkit-box-sizing: border-box;
	box-sizing: border-box; }

*:before,
*:after {
	-webkit-box-sizing: border-box;
	box-sizing: border-box; }

html {
	font-size: 10px;
	-webkit-tap-highlight-color: rgba(0, 0, 0, 0); }

body {
	font-family: "Noto Sans", sans-serif;
	font-size: 16px;
	line-height: 1.4375;
	color: #333333;
	background-color: #fff; }

input,
button,
select,
textarea {
	font-family: inherit;
	font-size: inherit;
	line-height: inherit; }

a {
	color: #295376;
	text-decoration: none; }
	a:hover, a:focus {
		color: #0535d2;
		text-decoration: underline; }
	a:focus {
		outline: 5px auto -webkit-focus-ring-color;
		outline-offset: -2px; }

figure {
	margin: 0; }

img {
	vertical-align: middle; }

.img-responsive {
	display: block;
	max-width: 100%;
	height: auto; }

.img-rounded {
	border-radius: 6px; }

.img-thumbnail {
	padding: 4px;
	line-height: 1.4375;
	background-color: #fff;
	border: 1px solid #ddd;
	border-radius: 4px;
	-webkit-transition: all 0.2s ease-in-out;
	transition: all 0.2s ease-in-out;
	display: inline-block;
	max-width: 100%;
	height: auto; }

.img-circle {
	border-radius: 50%; }

hr {
	margin-top: 23px;
	margin-bottom: 23px;
	border: 0;
	border-top: 1px solid #eeeeee; }

.sr-only {
	position: absolute;
	width: 1px;
	height: 1px;
	padding: 0;
	margin: -1px;
	overflow: hidden;
	clip: rect(0, 0, 0, 0);
	border: 0; }

.sr-only-focusable:active, .sr-only-focusable:focus {
	position: static;
	width: auto;
	height: auto;
	margin: 0;
	overflow: visible;
	clip: auto; }

[role="button"] {
	cursor: pointer; }

h1, h2, h3, h4, h5, h6,
.h1, .h2, .h3, .h4, .h5, .h6 {
	font-family: inherit;
	font-weight: 500;
	line-height: 1.1;
	color: inherit; }
	h1 small,
	h1 .small, h2 small,
	h2 .small, h3 small,
	h3 .small, h4 small,
	h4 .small, h5 small,
	h5 .small, h6 small,
	h6 .small,
	.h1 small,
	.h1 .small, .h2 small,
	.h2 .small, .h3 small,
	.h3 .small, .h4 small,
	.h4 .small, .h5 small,
	.h5 .small, .h6 small,
	.h6 .small {
		font-weight: 400;
		line-height: 1;
		color: #6f6f6f; }

h1, .h1,
h2, .h2,
h3, .h3 {
	margin-top: 23px;
	margin-bottom: 11.5px; }
	h1 small,
	h1 .small, .h1 small,
	.h1 .small,
	h2 small,
	h2 .small, .h2 small,
	.h2 .small,
	h3 small,
	h3 .small, .h3 small,
	.h3 .small {
		font-size: 65%; }

h4, .h4,
h5, .h5,
h6, .h6 {
	margin-top: 11.5px;
	margin-bottom: 11.5px; }
	h4 small,
	h4 .small, .h4 small,
	.h4 .small,
	h5 small,
	h5 .small, .h5 small,
	.h5 .small,
	h6 small,
	h6 .small, .h6 small,
	.h6 .small {
		font-size: 75%; }

h1, .h1 {
	font-size: 1.9em; }

h2, .h2 {
	font-size: 1.8em; }

h3, .h3 {
	font-size: 1.2em; }

h4, .h4 {
	font-size: 1.1em; }

h5, .h5 {
	font-size: 1em; }

h6, .h6 {
	font-size: 0.95em; }

p {
	margin: 0 0 11.5px; }

.lead {
	margin-bottom: 23px;
	font-size: 18px;
	font-weight: 300;
	line-height: 1.4; }
	@media (min-width: 768px) {
		.lead {
			font-size: 24px; } }

small,
.small {
	font-size: 87%; }

mark,
.mark {
	padding: .2em;
	background-color: #fcf8e3; }

.text-left {
	text-align: left; }

.text-right {
	text-align: right; }

.text-center {
	text-align: center; }

.text-justify {
	text-align: justify; }

.text-nowrap {
	white-space: nowrap; }

.text-lowercase {
	text-transform: lowercase; }

.text-uppercase, .initialism {
	text-transform: uppercase; }

.text-capitalize {
	text-transform: capitalize; }

.text-muted {
	color: #6f6f6f; }

.text-primary {
	color: #2572b4; }

a.text-primary:hover,
a.text-primary:focus {
	color: #1c578a; }

.text-success {
	color: #3c763d; }

a.text-success:hover,
a.text-success:focus {
	color: #2b542c; }

.text-info {
	color: #31708f; }

a.text-info:hover,
a.text-info:focus {
	color: #245269; }

.text-warning {
	color: #8a6d3b; }

a.text-warning:hover,
a.text-warning:focus {
	color: #66512c; }

.text-danger {
	color: #a94442; }

a.text-danger:hover,
a.text-danger:focus {
	color: #843534; }

.bg-primary {
	color: #fff; }

.bg-primary {
	background-color: #2572b4; }

a.bg-primary:hover,
a.bg-primary:focus {
	background-color: #1c578a; }

.bg-success {
	background-color: #dff0d8; }

a.bg-success:hover,
a.bg-success:focus {
	background-color: #c1e2b3; }

.bg-info {
	background-color: #d9edf7; }

a.bg-info:hover,
a.bg-info:focus {
	background-color: #afd9ee; }

.bg-warning {
	background-color: #fcf8e3; }

a.bg-warning:hover,
a.bg-warning:focus {
	background-color: #f7ecb5; }

.bg-danger {
	background-color: #f2dede; }

a.bg-danger:hover,
a.bg-danger:focus {
	background-color: #e4b9b9; }

.page-header {
	padding-bottom: 10.5px;
	margin: 46px 0 23px;
	border-bottom: 1px solid #eeeeee; }

ul,
ol {
	margin-top: 0;
	margin-bottom: 11.5px; }
	ul ul,
	ul ol,
	ol ul,
	ol ol {
		margin-bottom: 0; }

.list-unstyled {
	padding-left: 0;
	list-style: none; }

.list-inline {
	padding-left: 0;
	list-style: none;
	margin-left: -5px; }
	.list-inline > li {
		display: inline-block;
		padding-right: 5px;
		padding-left: 5px; }

dl {
	margin-top: 0;
	margin-bottom: 23px; }

dt,
dd {
	line-height: 1.4375; }

dt {
	font-weight: 700; }

dd {
	margin-left: 0; }

.dl-horizontal dd:before, .dl-horizontal dd:after {
	display: table;
	content: " "; }

.dl-horizontal dd:after {
	clear: both; }

@media (min-width: 768px) {
	.dl-horizontal dt {
		float: left;
		width: 160px;
		clear: left;
		text-align: right;
		overflow: hidden;
		text-overflow: ellipsis;
		white-space: nowrap; }
	.dl-horizontal dd {
		margin-left: 180px; } }

abbr[title],
abbr[data-original-title] {
	cursor: help; }

.initialism {
	font-size: 90%; }

blockquote {
	padding: 11.5px 23px;
	margin: 0 0 23px;
	font-size: 20px;
	border-left: 5px solid #eeeeee; }
	blockquote p:last-child,
	blockquote ul:last-child,
	blockquote ol:last-child {
		margin-bottom: 0; }
	blockquote footer,
	blockquote small,
	blockquote .small {
		display: block;
		font-size: 80%;
		line-height: 1.4375;
		color: #6f6f6f; }
		blockquote footer:before,
		blockquote small:before,
		blockquote .small:before {
			content: "\2014 \00A0"; }

.blockquote-reverse,
blockquote.pull-right {
	padding-right: 15px;
	padding-left: 0;
	text-align: right;
	border-right: 5px solid #eeeeee;
	border-left: 0; }
	.blockquote-reverse footer:before,
	.blockquote-reverse small:before,
	.blockquote-reverse .small:before,
	blockquote.pull-right footer:before,
	blockquote.pull-right small:before,
	blockquote.pull-right .small:before {
		content: ""; }
	.blockquote-reverse footer:after,
	.blockquote-reverse small:after,
	.blockquote-reverse .small:after,
	blockquote.pull-right footer:after,
	blockquote.pull-right small:after,
	blockquote.pull-right .small:after {
		content: "\00A0 \2014"; }

address {
	margin-bottom: 23px;
	font-style: normal;
	line-height: 1.4375; }

code,
kbd,
pre,
samp {
	font-family: Menlo, Monaco, Consolas, "Courier New", monospace; }

code {
	padding: 2px 4px;
	font-size: 90%;
	color: #c7254e;
	background-color: #f9f2f4;
	border-radius: 4px; }

kbd {
	padding: 2px 4px;
	font-size: 90%;
	color: #fff;
	background-color: #333;
	border-radius: 3px;
	-webkit-box-shadow: inset 0 -1px 0 rgba(0, 0, 0, 0.25);
	        box-shadow: inset 0 -1px 0 rgba(0, 0, 0, 0.25); }
	kbd kbd {
		padding: 0;
		font-size: 100%;
		font-weight: 700;
		-webkit-box-shadow: none;
		        box-shadow: none; }

pre {
	display: block;
	padding: 11px;
	margin: 0 0 11.5px;
	font-size: 15px;
	line-height: 1.4375;
	color: #333333;
	word-break: break-all;
	word-wrap: break-word;
	background-color: #f5f5f5;
	border: 1px solid #ccc;
	border-radius: 4px; }
	pre code {
		padding: 0;
		font-size: inherit;
		color: inherit;
		white-space: pre-wrap;
		background-color: transparent;
		border-radius: 0; }

.pre-scrollable {
	max-height: 340px;
	overflow-y: scroll; }

.container {
	padding-right: 15px;
	padding-left: 15px;
	margin-right: auto;
	margin-left: auto; }
	.container:before, .container:after {
		display: table;
		content: " "; }
	.container:after {
		clear: both; }
	@media (min-width: 768px) {
		.container {
			width: 750px; } }
	@media (min-width: 992px) {
		.container {
			width: 970px; } }
	@media (min-width: 1200px) {
		.container {
			width: 1170px; } }

.container-fluid {
	padding-right: 15px;
	padding-left: 15px;
	margin-right: auto;
	margin-left: auto; }
	.container-fluid:before, .container-fluid:after {
		display: table;
		content: " "; }
	.container-fluid:after {
		clear: both; }

.row {
	margin-right: -15px;
	margin-left: -15px; }
	.row:before, .row:after {
		display: table;
		content: " "; }
	.row:after {
		clear: both; }

.row-no-gutters {
	margin-right: 0;
	margin-left: 0; }
	.row-no-gutters [class*="col-"] {
		padding-right: 0;
		padding-left: 0; }

.col-xs-1, .col-sm-1, .col-md-1, .col-lg-1, .col-xs-2, .col-sm-2, .col-md-2, .col-lg-2, .col-xs-3, .col-sm-3, .col-md-3, .col-lg-3, .col-xs-4, .col-sm-4, .col-md-4, .col-lg-4, .col-xs-5, .col-sm-5, .col-md-5, .col-lg-5, .col-xs-6, .col-sm-6, .col-md-6, .col-lg-6, .col-xs-7, .col-sm-7, .col-md-7, .col-lg-7, .col-xs-8, .col-sm-8, .col-md-8, .col-lg-8, .col-xs-9, .col-sm-9, .col-md-9, .col-lg-9, .col-xs-10, .col-sm-10, .col-md-10, .col-lg-10, .col-xs-11, .col-sm-11, .col-md-11, .col-lg-11, .col-xs-12, .col-sm-12, .col-md-12, .col-lg-12 {
	position: relative;
	min-height: 1px;
	padding-right: 15px;
	padding-left: 15px; }

.col-xs-1, .col-xs-2, .col-xs-3, .col-xs-4, .col-xs-5, .col-xs-6, .col-xs-7, .col-xs-8, .col-xs-9, .col-xs-10, .col-xs-11, .col-xs-12 {
	float: left; }

.col-xs-1 {
	width: 8.3333333333%; }

.col-xs-2 {
	width: 16.6666666667%; }

.col-xs-3 {
	width: 25%; }

.col-xs-4 {
	width: 33.3333333333%; }

.col-xs-5 {
	width: 41.6666666667%; }

.col-xs-6 {
	width: 50%; }

.col-xs-7 {
	width: 58.3333333333%; }

.col-xs-8 {
	width: 66.6666666667%; }

.col-xs-9 {
	width: 75%; }

.col-xs-10 {
	width: 83.3333333333%; }

.col-xs-11 {
	width: 91.6666666667%; }

.col-xs-12 {
	width: 100%; }

.col-xs-pull-0 {
	right: auto; }

.col-xs-pull-1 {
	right: 8.3333333333%; }

.col-xs-pull-2 {
	right: 16.6666666667%; }

.col-xs-pull-3 {
	right: 25%; }

.col-xs-pull-4 {
	right: 33.3333333333%; }

.col-xs-pull-5 {
	right: 41.6666666667%; }

.col-xs-pull-6 {
	right: 50%; }

.col-xs-pull-7 {
	right: 58.3333333333%; }

.col-xs-pull-8 {
	right: 66.6666666667%; }

.col-xs-pull-9 {
	right: 75%; }

.col-xs-pull-10 {
	right: 83.3333333333%; }

.col-xs-pull-11 {
	right: 91.6666666667%; }

.col-xs-pull-12 {
	right: 100%; }

.col-xs-push-0 {
	left: auto; }

.col-xs-push-1 {
	left: 8.3333333333%; }

.col-xs-push-2 {
	left: 16.6666666667%; }

.col-xs-push-3 {
	left: 25%; }

.col-xs-push-4 {
	left: 33.3333333333%; }

.col-xs-push-5 {
	left: 41.6666666667%; }

.col-xs-push-6 {
	left: 50%; }

.col-xs-push-7 {
	left: 58.3333333333%; }

.col-xs-push-8 {
	left: 66.6666666667%; }

.col-xs-push-9 {
	left: 75%; }

.col-xs-push-10 {
	left: 83.3333333333%; }

.col-xs-push-11 {
	left: 91.6666666667%; }

.col-xs-push-12 {
	left: 100%; }

.col-xs-offset-0 {
	margin-left: 0%; }

.col-xs-offset-1 {
	margin-left: 8.3333333333%; }

.col-xs-offset-2 {
	margin-left: 16.6666666667%; }

.col-xs-offset-3 {
	margin-left: 25%; }

.col-xs-offset-4 {
	margin-left: 33.3333333333%; }

.col-xs-offset-5 {
	margin-left: 41.6666666667%; }

.col-xs-offset-6 {
	margin-left: 50%; }

.col-xs-offset-7 {
	margin-left: 58.3333333333%; }

.col-xs-offset-8 {
	margin-left: 66.6666666667%; }

.col-xs-offset-9 {
	margin-left: 75%; }

.col-xs-offset-10 {
	margin-left: 83.3333333333%; }

.col-xs-offset-11 {
	margin-left: 91.6666666667%; }

.col-xs-offset-12 {
	margin-left: 100%; }

@media (min-width: 768px) {
	.col-sm-1, .col-sm-2, .col-sm-3, .col-sm-4, .col-sm-5, .col-sm-6, .col-sm-7, .col-sm-8, .col-sm-9, .col-sm-10, .col-sm-11, .col-sm-12 {
		float: left; }
	.col-sm-1 {
		width: 8.3333333333%; }
	.col-sm-2 {
		width: 16.6666666667%; }
	.col-sm-3 {
		width: 25%; }
	.col-sm-4 {
		width: 33.3333333333%; }
	.col-sm-5 {
		width: 41.6666666667%; }
	.col-sm-6 {
		width: 50%; }
	.col-sm-7 {
		width: 58.3333333333%; }
	.col-sm-8 {
		width: 66.6666666667%; }
	.col-sm-9 {
		width: 75%; }
	.col-sm-10 {
		width: 83.3333333333%; }
	.col-sm-11 {
		width: 91.6666666667%; }
	.col-sm-12 {
		width: 100%; }
	.col-sm-pull-0 {
		right: auto; }
	.col-sm-pull-1 {
		right: 8.3333333333%; }
	.col-sm-pull-2 {
		right: 16.6666666667%; }
	.col-sm-pull-3 {
		right: 25%; }
	.col-sm-pull-4 {
		right: 33.3333333333%; }
	.col-sm-pull-5 {
		right: 41.6666666667%; }
	.col-sm-pull-6 {
		right: 50%; }
	.col-sm-pull-7 {
		right: 58.3333333333%; }
	.col-sm-pull-8 {
		right: 66.6666666667%; }
	.col-sm-pull-9 {
		right: 75%; }
	.col-sm-pull-10 {
		right: 83.3333333333%; }
	.col-sm-pull-11 {
		right: 91.6666666667%; }
	.col-sm-pull-12 {
		right: 100%; }
	.col-sm-push-0 {
		left: auto; }
	.col-sm-push-1 {
		left: 8.3333333333%; }
	.col-sm-push-2 {
		left: 16.6666666667%; }
	.col-sm-push-3 {
		left: 25%; }
	.col-sm-push-4 {
		left: 33.3333333333%; }
	.col-sm-push-5 {
		left: 41.6666666667%; }
	.col-sm-push-6 {
		left: 50%; }
	.col-sm-push-7 {
		left: 58.3333333333%; }
	.col-sm-push-8 {
		left: 66.6666666667%; }
	.col-sm-push-9 {
		left: 75%; }
	.col-sm-push-10 {
		left: 83.3333333333%; }
	.col-sm-push-11 {
		left: 91.6666666667%; }
	.col-sm-push-12 {
		left: 100%; }
	.col-sm-offset-0 {
		margin-left: 0%; }
	.col-sm-offset-1 {
		margin-left: 8.3333333333%; }
	.col-sm-offset-2 {
		margin-left: 16.6666666667%; }
	.col-sm-offset-3 {
		margin-left: 25%; }
	.col-sm-offset-4 {
		margin-left: 33.3333333333%; }
	.col-sm-offset-5 {
		margin-left: 41.6666666667%; }
	.col-sm-offset-6 {
		margin-left: 50%; }
	.col-sm-offset-7 {
		margin-left: 58.3333333333%; }
	.col-sm-offset-8 {
		margin-left: 66.6666666667%; }
	.col-sm-offset-9 {
		margin-left: 75%; }
	.col-sm-offset-10 {
		margin-left: 83.3333333333%; }
	.col-sm-offset-11 {
		margin-left: 91.6666666667%; }
	.col-sm-offset-12 {
		margin-left: 100%; } }

@media (min-width: 992px) {
	.col-md-1, .col-md-2, .col-md-3, .col-md-4, .col-md-5, .col-md-6, .col-md-7, .col-md-8, .col-md-9, .col-md-10, .col-md-11, .col-md-12 {
		float: left; }
	.col-md-1 {
		width: 8.3333333333%; }
	.col-md-2 {
		width: 16.6666666667%; }
	.col-md-3 {
		width: 25%; }
	.col-md-4 {
		width: 33.3333333333%; }
	.col-md-5 {
		width: 41.6666666667%; }
	.col-md-6 {
		width: 50%; }
	.col-md-7 {
		width: 58.3333333333%; }
	.col-md-8 {
		width: 66.6666666667%; }
	.col-md-9 {
		width: 75%; }
	.col-md-10 {
		width: 83.3333333333%; }
	.col-md-11 {
		width: 91.6666666667%; }
	.col-md-12 {
		width: 100%; }
	.col-md-pull-0 {
		right: auto; }
	.col-md-pull-1 {
		right: 8.3333333333%; }
	.col-md-pull-2 {
		right: 16.6666666667%; }
	.col-md-pull-3 {
		right: 25%; }
	.col-md-pull-4 {
		right: 33.3333333333%; }
	.col-md-pull-5 {
		right: 41.6666666667%; }
	.col-md-pull-6 {
		right: 50%; }
	.col-md-pull-7 {
		right: 58.3333333333%; }
	.col-md-pull-8 {
		right: 66.6666666667%; }
	.col-md-pull-9 {
		right: 75%; }
	.col-md-pull-10 {
		right: 83.3333333333%; }
	.col-md-pull-11 {
		right: 91.6666666667%; }
	.col-md-pull-12 {
		right: 100%; }
	.col-md-push-0 {
		left: auto; }
	.col-md-push-1 {
		left: 8.3333333333%; }
	.col-md-push-2 {
		left: 16.6666666667%; }
	.col-md-push-3 {
		left: 25%; }
	.col-md-push-4 {
		left: 33.3333333333%; }
	.col-md-push-5 {
		left: 41.6666666667%; }
	.col-md-push-6 {
		left: 50%; }
	.col-md-push-7 {
		left: 58.3333333333%; }
	.col-md-push-8 {
		left: 66.6666666667%; }
	.col-md-push-9 {
		left: 75%; }
	.col-md-push-10 {
		left: 83.3333333333%; }
	.col-md-push-11 {
		left: 91.6666666667%; }
	.col-md-push-12 {
		left: 100%; }
	.col-md-offset-0 {
		margin-left: 0%; }
	.col-md-offset-1 {
		margin-left: 8.3333333333%; }
	.col-md-offset-2 {
		margin-left: 16.6666666667%; }
	.col-md-offset-3 {
		margin-left: 25%; }
	.col-md-offset-4 {
		margin-left: 33.3333333333%; }
	.col-md-offset-5 {
		margin-left: 41.6666666667%; }
	.col-md-offset-6 {
		margin-left: 50%; }
	.col-md-offset-7 {
		margin-left: 58.3333333333%; }
	.col-md-offset-8 {
		margin-left: 66.6666666667%; }
	.col-md-offset-9 {
		margin-left: 75%; }
	.col-md-offset-10 {
		margin-left: 83.3333333333%; }
	.col-md-offset-11 {
		margin-left: 91.6666666667%; }
	.col-md-offset-12 {
		margin-left: 100%; } }

@media (min-width: 1200px) {
	.col-lg-1, .col-lg-2, .col-lg-3, .col-lg-4, .col-lg-5, .col-lg-6, .col-lg-7, .col-lg-8, .col-lg-9, .col-lg-10, .col-lg-11, .col-lg-12 {
		float: left; }
	.col-lg-1 {
		width: 8.3333333333%; }
	.col-lg-2 {
		width: 16.6666666667%; }
	.col-lg-3 {
		width: 25%; }
	.col-lg-4 {
		width: 33.3333333333%; }
	.col-lg-5 {
		width: 41.6666666667%; }
	.col-lg-6 {
		width: 50%; }
	.col-lg-7 {
		width: 58.3333333333%; }
	.col-lg-8 {
		width: 66.6666666667%; }
	.col-lg-9 {
		width: 75%; }
	.col-lg-10 {
		width: 83.3333333333%; }
	.col-lg-11 {
		width: 91.6666666667%; }
	.col-lg-12 {
		width: 100%; }
	.col-lg-pull-0 {
		right: auto; }
	.col-lg-pull-1 {
		right: 8.3333333333%; }
	.col-lg-pull-2 {
		right: 16.6666666667%; }
	.col-lg-pull-3 {
		right: 25%; }
	.col-lg-pull-4 {
		right: 33.3333333333%; }
	.col-lg-pull-5 {
		right: 41.6666666667%; }
	.col-lg-pull-6 {
		right: 50%; }
	.col-lg-pull-7 {
		right: 58.3333333333%; }
	.col-lg-pull-8 {
		right: 66.6666666667%; }
	.col-lg-pull-9 {
		right: 75%; }
	.col-lg-pull-10 {
		right: 83.3333333333%; }
	.col-lg-pull-11 {
		right: 91.6666666667%; }
	.col-lg-pull-12 {
		right: 100%; }
	.col-lg-push-0 {
		left: auto; }
	.col-lg-push-1 {
		left: 8.3333333333%; }
	.col-lg-push-2 {
		left: 16.6666666667%; }
	.col-lg-push-3 {
		left: 25%; }
	.col-lg-push-4 {
		left: 33.3333333333%; }
	.col-lg-push-5 {
		left: 41.6666666667%; }
	.col-lg-push-6 {
		left: 50%; }
	.col-lg-push-7 {
		left: 58.3333333333%; }
	.col-lg-push-8 {
		left: 66.6666666667%; }
	.col-lg-push-9 {
		left: 75%; }
	.col-lg-push-10 {
		left: 83.3333333333%; }
	.col-lg-push-11 {
		left: 91.6666666667%; }
	.col-lg-push-12 {
		left: 100%; }
	.col-lg-offset-0 {
		margin-left: 0%; }
	.col-lg-offset-1 {
		margin-left: 8.3333333333%; }
	.col-lg-offset-2 {
		margin-left: 16.6666666667%; }
	.col-lg-offset-3 {
		margin-left: 25%; }
	.col-lg-offset-4 {
		margin-left: 33.3333333333%; }
	.col-lg-offset-5 {
		margin-left: 41.6666666667%; }
	.col-lg-offset-6 {
		margin-left: 50%; }
	.col-lg-offset-7 {
		margin-left: 58.3333333333%; }
	.col-lg-offset-8 {
		margin-left: 66.6666666667%; }
	.col-lg-offset-9 {
		margin-left: 75%; }
	.col-lg-offset-10 {
		margin-left: 83.3333333333%; }
	.col-lg-offset-11 {
		margin-left: 91.6666666667%; }
	.col-lg-offset-12 {
		margin-left: 100%; } }

table {
	background-color: transparent; }
	table col[class*="col-"] {
		position: static;
		display: table-column;
		float: none; }
	table td[class*="col-"],
	table th[class*="col-"] {
		position: static;
		display: table-cell;
		float: none; }

caption {
	padding-top: 8px;
	padding-bottom: 8px;
	color: #6f6f6f;
	text-align: left; }

th {
	text-align: left; }

.table {
	width: 100%;
	max-width: 100%;
	margin-bottom: 23px; }
	.table > thead > tr > th,
	.table > thead > tr > td,
	.table > tbody > tr > th,
	.table > tbody > tr > td,
	.table > tfoot > tr > th,
	.table > tfoot > tr > td {
		padding: 8px;
		line-height: 1.4375;
		vertical-align: top;
		border-top: 1px solid #ddd; }
	.table > thead > tr > th {
		vertical-align: bottom;
		border-bottom: 2px solid #ddd; }
	.table > caption + thead > tr:first-child > th,
	.table > caption + thead > tr:first-child > td,
	.table > colgroup + thead > tr:first-child > th,
	.table > colgroup + thead > tr:first-child > td,
	.table > thead:first-child > tr:first-child > th,
	.table > thead:first-child > tr:first-child > td {
		border-top: 0; }
	.table > tbody + tbody {
		border-top: 2px solid #ddd; }
	.table .table {
		background-color: #fff; }

.table-condensed > thead > tr > th,
.table-condensed > thead > tr > td,
.table-condensed > tbody > tr > th,
.table-condensed > tbody > tr > td,
.table-condensed > tfoot > tr > th,
.table-condensed > tfoot > tr > td {
	padding: 5px; }

.table-bordered {
	border: 1px solid #ddd; }
	.table-bordered > thead > tr > th,
	.table-bordered > thead > tr > td,
	.table-bordered > tbody > tr > th,
	.table-bordered > tbody > tr > td,
	.table-bordered > tfoot > tr > th,
	.table-bordered > tfoot > tr > td {
		border: 1px solid #ddd; }
	.table-bordered > thead > tr > th,
	.table-bordered > thead > tr > td {
		border-bottom-width: 2px; }

.table-striped > tbody > tr:nth-of-type(odd) {
	background-color: #f5f5f5; }

.table-hover > tbody > tr:hover {
	background-color: #f0f0f0; }

.table > thead > tr > td.active,
.table > thead > tr > th.active,
.table > thead > tr.active > td,
.table > thead > tr.active > th,
.table > tbody > tr > td.active,
.table > tbody > tr > th.active,
.table > tbody > tr.active > td,
.table > tbody > tr.active > th,
.table > tfoot > tr > td.active,
.table > tfoot > tr > th.active,
.table > tfoot > tr.active > td,
.table > tfoot > tr.active > th {
	background-color: #f0f0f0; }

.table-hover > tbody > tr > td.active:hover,
.table-hover > tbody > tr > th.active:hover,
.table-hover > tbody > tr.active:hover > td,
.table-hover > tbody > tr:hover > .active,
.table-hover > tbody > tr.active:hover > th {
	background-color: #e3e3e3; }

.table > thead > tr > td.success,
.table > thead > tr > th.success,
.table > thead > tr.success > td,
.table > thead > tr.success > th,
.table > tbody > tr > td.success,
.table > tbody > tr > th.success,
.table > tbody > tr.success > td,
.table > tbody > tr.success > th,
.table > tfoot > tr > td.success,
.table > tfoot > tr > th.success,
.table > tfoot > tr.success > td,
.table > tfoot > tr.success > th {
	background-color: #dff0d8; }

.table-hover > tbody > tr > td.success:hover,
.table-hover > tbody > tr > th.success:hover,
.table-hover > tbody > tr.success:hover > td,
.table-hover > tbody > tr:hover > .success,
.table-hover > tbody > tr.success:hover > th {
	background-color: #d0e9c6; }

.table > thead > tr > td.info,
.table > thead > tr > th.info,
.table > thead > tr.info > td,
.table > thead > tr.info > th,
.table > tbody > tr > td.info,
.table > tbody > tr > th.info,
.table > tbody > tr.info > td,
.table > tbody > tr.info > th,
.table > tfoot > tr > td.info,
.table > tfoot > tr > th.info,
.table > tfoot > tr.info > td,
.table > tfoot > tr.info > th {
	background-color: #d9edf7; }

.table-hover > tbody > tr > td.info:hover,
.table-hover > tbody > tr > th.info:hover,
.table-hover > tbody > tr.info:hover > td,
.table-hover > tbody > tr:hover > .info,
.table-hover > tbody > tr.info:hover > th {
	background-color: #c4e3f3; }

.table > thead > tr > td.warning,
.table > thead > tr > th.warning,
.table > thead > tr.warning > td,
.table > thead > tr.warning > th,
.table > tbody > tr > td.warning,
.table > tbody > tr > th.warning,
.table > tbody > tr.warning > td,
.table > tbody > tr.warning > th,
.table > tfoot > tr > td.warning,
.table > tfoot > tr > th.warning,
.table > tfoot > tr.warning > td,
.table > tfoot > tr.warning > th {
	background-color: #fcf8e3; }

.table-hover > tbody > tr > td.warning:hover,
.table-hover > tbody > tr > th.warning:hover,
.table-hover > tbody > tr.warning:hover > td,
.table-hover > tbody > tr:hover > .warning,
.table-hover > tbody > tr.warning:hover > th {
	background-color: #faf2cc; }

.table > thead > tr > td.danger,
.table > thead > tr > th.danger,
.table > thead > tr.danger > td,
.table > thead > tr.danger > th,
.table > tbody > tr > td.danger,
.table > tbody > tr > th.danger,
.table > tbody > tr.danger > td,
.table > tbody > tr.danger > th,
.table > tfoot > tr > td.danger,
.table > tfoot > tr > th.danger,
.table > tfoot > tr.danger > td,
.table > tfoot > tr.danger > th {
	background-color: #f2dede; }

.table-hover > tbody > tr > td.danger:hover,
.table-hover > tbody > tr > th.danger:hover,
.table-hover > tbody > tr.danger:hover > td,
.table-hover > tbody > tr:hover > .danger,
.table-hover > tbody > tr.danger:hover > th {
	background-color: #ebcccc; }

.table-responsive {
	min-height: .01%;
	overflow-x: auto; }
	@media screen and (max-width: 767px) {
		.table-responsive {
			width: 100%;
			margin-bottom: 17.25px;
			overflow-y: hidden;
			-ms-overflow-style: -ms-autohiding-scrollbar;
			border: 1px solid #ddd; }
			.table-responsive > .table {
				margin-bottom: 0; }
				.table-responsive > .table > thead > tr > th,
				.table-responsive > .table > thead > tr > td,
				.table-responsive > .table > tbody > tr > th,
				.table-responsive > .table > tbody > tr > td,
				.table-responsive > .table > tfoot > tr > th,
				.table-responsive > .table > tfoot > tr > td {
					white-space: nowrap; }
			.table-responsive > .table-bordered {
				border: 0; }
				.table-responsive > .table-bordered > thead > tr > th:first-child,
				.table-responsive > .table-bordered > thead > tr > td:first-child,
				.table-responsive > .table-bordered > tbody > tr > th:first-child,
				.table-responsive > .table-bordered > tbody > tr > td:first-child,
				.table-responsive > .table-bordered > tfoot > tr > th:first-child,
				.table-responsive > .table-bordered > tfoot > tr > td:first-child {
					border-left: 0; }
				.table-responsive > .table-bordered > thead > tr > th:last-child,
				.table-responsive > .table-bordered > thead > tr > td:last-child,
				.table-responsive > .table-bordered > tbody > tr > th:last-child,
				.table-responsive > .table-bordered > tbody > tr > td:last-child,
				.table-responsive > .table-bordered > tfoot > tr > th:last-child,
				.table-responsive > .table-bordered > tfoot > tr > td:last-child {
					border-right: 0; }
				.table-responsive > .table-bordered > tbody > tr:last-child > th,
				.table-responsive > .table-bordered > tbody > tr:last-child > td,
				.table-responsive > .table-bordered > tfoot > tr:last-child > th,
				.table-responsive > .table-bordered > tfoot > tr:last-child > td {
					border-bottom: 0; } }

fieldset {
	min-width: 0;
	padding: 0;
	margin: 0;
	border: 0; }

legend {
	display: block;
	width: 100%;
	padding: 0;
	margin-bottom: 23px;
	font-size: 24px;
	line-height: inherit;
	color: #333333;
	border: 0;
	border-bottom: 1px solid #e5e5e5; }

label {
	display: inline-block;
	max-width: 100%;
	margin-bottom: 5px;
	font-weight: 700; }

input[type="search"] {
	-webkit-box-sizing: border-box;
	box-sizing: border-box;
	-webkit-appearance: none;
	-moz-appearance: none;
	     appearance: none; }

input[type="radio"],
input[type="checkbox"] {
	margin: 4px 0 0;
	margin-top: 1px \9;
	line-height: normal; }
	input[type="radio"][disabled], input[type="radio"].disabled,
	fieldset[disabled] input[type="radio"],
	input[type="checkbox"][disabled],
	input[type="checkbox"].disabled,
	fieldset[disabled]
	input[type="checkbox"] {
		cursor: not-allowed; }

input[type="file"] {
	display: block; }

input[type="range"] {
	display: block;
	width: 100%; }

select[multiple],
select[size] {
	height: auto; }

input[type="file"]:focus,
input[type="radio"]:focus,
input[type="checkbox"]:focus {
	outline: 5px auto -webkit-focus-ring-color;
	outline-offset: -2px; }

output {
	display: block;
	padding-top: 11px;
	font-size: 16px;
	line-height: 1.4375;
	color: #555555; }

.form-control {
	display: block;
	width: 100%;
	height: 37px;
	padding: 10px 14px;
	font-size: 16px;
	line-height: 1.4375;
	color: #555555;
	background-color: #fff;
	background-image: none;
	border: 1px solid #ccc;
	border-radius: 4px;
	-webkit-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075);
	box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075);
	-webkit-transition: border-color ease-in-out 0.15s, box-shadow ease-in-out 0.15s;
	-webkit-transition: border-color ease-in-out 0.15s, -webkit-box-shadow ease-in-out 0.15s;
	transition: border-color ease-in-out 0.15s, -webkit-box-shadow ease-in-out 0.15s;
	transition: border-color ease-in-out 0.15s, box-shadow ease-in-out 0.15s;
	transition: border-color ease-in-out 0.15s, box-shadow ease-in-out 0.15s, -webkit-box-shadow ease-in-out 0.15s; }
	.form-control:focus {
		border-color: #66afe9;
		outline: 0;
		-webkit-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075), 0 0 8px rgba(102, 175, 233, 0.6);
		box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075), 0 0 8px rgba(102, 175, 233, 0.6); }
	.form-control::-moz-placeholder {
		color: #5c5c5c !important;
		opacity: 1; }
	.form-control:-ms-input-placeholder {
		color: #5c5c5c !important; }
	.form-control::-webkit-input-placeholder {
		color: #5c5c5c !important; }
	.form-control::-ms-expand {
		background-color: transparent;
		border: 0; }
	.form-control[disabled], .form-control[readonly],
	fieldset[disabled] .form-control {
		background-color: #eeeeee;
		opacity: 1; }
	.form-control[disabled],
	fieldset[disabled] .form-control {
		cursor: not-allowed; }

textarea.form-control {
	height: auto; }

@media screen and (-webkit-min-device-pixel-ratio: 0) {
	input[type="date"].form-control,
	input[type="time"].form-control,
	input[type="datetime-local"].form-control,
	input[type="month"].form-control {
		line-height: 37px; }
	input[type="date"].input-sm, .input-group-sm > input.form-control[type="date"],
	.input-group-sm > input.input-group-addon[type="date"],
	.input-group-sm > .input-group-btn > input.btn[type="date"],
	.input-group-sm input[type="date"],
	input[type="time"].input-sm,
	.input-group-sm > input.form-control[type="time"],
	.input-group-sm > input.input-group-addon[type="time"],
	.input-group-sm > .input-group-btn > input.btn[type="time"],
	.input-group-sm
	input[type="time"],
	input[type="datetime-local"].input-sm,
	.input-group-sm > input.form-control[type="datetime-local"],
	.input-group-sm > input.input-group-addon[type="datetime-local"],
	.input-group-sm > .input-group-btn > input.btn[type="datetime-local"],
	.input-group-sm
	input[type="datetime-local"],
	input[type="month"].input-sm,
	.input-group-sm > input.form-control[type="month"],
	.input-group-sm > input.input-group-addon[type="month"],
	.input-group-sm > .input-group-btn > input.btn[type="month"],
	.input-group-sm
	input[type="month"] {
		line-height: 33px; }
	input[type="date"].input-lg, .input-group-lg > input.form-control[type="date"],
	.input-group-lg > input.input-group-addon[type="date"],
	.input-group-lg > .input-group-btn > input.btn[type="date"],
	.input-group-lg input[type="date"],
	input[type="time"].input-lg,
	.input-group-lg > input.form-control[type="time"],
	.input-group-lg > input.input-group-addon[type="time"],
	.input-group-lg > .input-group-btn > input.btn[type="time"],
	.input-group-lg
	input[type="time"],
	input[type="datetime-local"].input-lg,
	.input-group-lg > input.form-control[type="datetime-local"],
	.input-group-lg > input.input-group-addon[type="datetime-local"],
	.input-group-lg > .input-group-btn > input.btn[type="datetime-local"],
	.input-group-lg
	input[type="datetime-local"],
	input[type="month"].input-lg,
	.input-group-lg > input.form-control[type="month"],
	.input-group-lg > input.input-group-addon[type="month"],
	.input-group-lg > .input-group-btn > input.btn[type="month"],
	.input-group-lg
	input[type="month"] {
		line-height: 46px; } }

.form-group {
	margin-bottom: 15px; }

.radio,
.checkbox {
	position: relative;
	display: block;
	margin-top: 10px;
	margin-bottom: 10px; }
	.radio.disabled label,
	fieldset[disabled] .radio label,
	.checkbox.disabled label,
	fieldset[disabled]
	.checkbox label {
		cursor: not-allowed; }
	.radio label,
	.checkbox label {
		min-height: 23px;
		padding-left: 20px;
		margin-bottom: 0;
		font-weight: 400;
		cursor: pointer; }

.radio input[type="radio"],
.radio-inline input[type="radio"],
.checkbox input[type="checkbox"],
.checkbox-inline input[type="checkbox"] {
	position: absolute;
	margin-top: 4px \9;
	margin-left: -20px; }

.radio + .radio,
.checkbox + .checkbox {
	margin-top: -5px; }

.radio-inline,
.checkbox-inline {
	position: relative;
	display: inline-block;
	padding-left: 20px;
	margin-bottom: 0;
	font-weight: 400;
	vertical-align: middle;
	cursor: pointer; }
	.radio-inline.disabled,
	fieldset[disabled] .radio-inline,
	.checkbox-inline.disabled,
	fieldset[disabled]
	.checkbox-inline {
		cursor: not-allowed; }

.radio-inline + .radio-inline,
.checkbox-inline + .checkbox-inline {
	margin-top: 0;
	margin-left: 10px; }

.form-control-static {
	min-height: 39px;
	padding-top: 11px;
	padding-bottom: 11px;
	margin-bottom: 0; }
	.form-control-static.input-lg, .input-group-lg > .form-control-static.form-control,
	.input-group-lg > .form-control-static.input-group-addon,
	.input-group-lg > .input-group-btn > .form-control-static.btn, .form-control-static.input-sm, .input-group-sm > .form-control-static.form-control,
	.input-group-sm > .form-control-static.input-group-addon,
	.input-group-sm > .input-group-btn > .form-control-static.btn {
		padding-right: 0;
		padding-left: 0; }

.input-sm, .input-group-sm > .form-control,
.input-group-sm > .input-group-addon,
.input-group-sm > .input-group-btn > .btn {
	height: 33px;
	padding: 5px 10px;
	font-size: 14px;
	line-height: 1.5;
	border-radius: 3px; }

select.input-sm, .input-group-sm > select.form-control,
.input-group-sm > select.input-group-addon,
.input-group-sm > .input-group-btn > select.btn {
	height: 33px;
	line-height: 33px; }

textarea.input-sm, .input-group-sm > textarea.form-control,
.input-group-sm > textarea.input-group-addon,
.input-group-sm > .input-group-btn > textarea.btn,
select[multiple].input-sm,
.input-group-sm > select.form-control[multiple],
.input-group-sm > select.input-group-addon[multiple],
.input-group-sm > .input-group-btn > select.btn[multiple] {
	height: auto; }

.form-group-sm .form-control {
	height: 33px;
	padding: 5px 10px;
	font-size: 14px;
	line-height: 1.5;
	border-radius: 3px; }

.form-group-sm select.form-control {
	height: 33px;
	line-height: 33px; }

.form-group-sm textarea.form-control,
.form-group-sm select[multiple].form-control {
	height: auto; }

.form-group-sm .form-control-static {
	height: 33px;
	min-height: 37px;
	padding: 6px 10px;
	font-size: 14px;
	line-height: 1.5; }

.input-lg, .input-group-lg > .form-control,
.input-group-lg > .input-group-addon,
.input-group-lg > .input-group-btn > .btn {
	height: 46px;
	padding: 10px 16px;
	font-size: 18px;
	line-height: 1.3333333;
	border-radius: 6px; }

select.input-lg, .input-group-lg > select.form-control,
.input-group-lg > select.input-group-addon,
.input-group-lg > .input-group-btn > select.btn {
	height: 46px;
	line-height: 46px; }

textarea.input-lg, .input-group-lg > textarea.form-control,
.input-group-lg > textarea.input-group-addon,
.input-group-lg > .input-group-btn > textarea.btn,
select[multiple].input-lg,
.input-group-lg > select.form-control[multiple],
.input-group-lg > select.input-group-addon[multiple],
.input-group-lg > .input-group-btn > select.btn[multiple] {
	height: auto; }

.form-group-lg .form-control {
	height: 46px;
	padding: 10px 16px;
	font-size: 18px;
	line-height: 1.3333333;
	border-radius: 6px; }

.form-group-lg select.form-control {
	height: 46px;
	line-height: 46px; }

.form-group-lg textarea.form-control,
.form-group-lg select[multiple].form-control {
	height: auto; }

.form-group-lg .form-control-static {
	height: 46px;
	min-height: 41px;
	padding: 11px 16px;
	font-size: 18px;
	line-height: 1.3333333; }

.has-feedback {
	position: relative; }
	.has-feedback .form-control {
		padding-right: 46.25px; }

.form-control-feedback {
	position: absolute;
	top: 0;
	right: 0;
	z-index: 2;
	display: block;
	width: 37px;
	height: 37px;
	line-height: 37px;
	text-align: center;
	pointer-events: none; }

.input-lg + .form-control-feedback, .input-group-lg > .form-control + .form-control-feedback, .input-group-lg > .input-group-addon + .form-control-feedback, .input-group-lg > .input-group-btn > .btn + .form-control-feedback,
.input-group-lg + .form-control-feedback,
.form-group-lg .form-control + .form-control-feedback {
	width: 46px;
	height: 46px;
	line-height: 46px; }

.input-sm + .form-control-feedback, .input-group-sm > .form-control + .form-control-feedback, .input-group-sm > .input-group-addon + .form-control-feedback, .input-group-sm > .input-group-btn > .btn + .form-control-feedback,
.input-group-sm + .form-control-feedback,
.form-group-sm .form-control + .form-control-feedback {
	width: 33px;
	height: 33px;
	line-height: 33px; }

.has-success .help-block,
.has-success .control-label,
.has-success .radio,
.has-success .checkbox,
.has-success .radio-inline,
.has-success .checkbox-inline,
.has-success.radio label,
.has-success.checkbox label,
.has-success.radio-inline label,
.has-success.checkbox-inline label {
	color: #3c763d; }

.has-success .form-control {
	border-color: #3c763d;
	-webkit-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075);
	box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075); }
	.has-success .form-control:focus {
		border-color: #2b542c;
		-webkit-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075), 0 0 6px #67b168;
		box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075), 0 0 6px #67b168; }

.has-success .input-group-addon {
	color: #3c763d;
	background-color: #dff0d8;
	border-color: #3c763d; }

.has-success .form-control-feedback {
	color: #3c763d; }

.has-warning .help-block,
.has-warning .control-label,
.has-warning .radio,
.has-warning .checkbox,
.has-warning .radio-inline,
.has-warning .checkbox-inline,
.has-warning.radio label,
.has-warning.checkbox label,
.has-warning.radio-inline label,
.has-warning.checkbox-inline label {
	color: #8a6d3b; }

.has-warning .form-control {
	border-color: #8a6d3b;
	-webkit-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075);
	box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075); }
	.has-warning .form-control:focus {
		border-color: #66512c;
		-webkit-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075), 0 0 6px #c0a16b;
		box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075), 0 0 6px #c0a16b; }

.has-warning .input-group-addon {
	color: #8a6d3b;
	background-color: #fcf8e3;
	border-color: #8a6d3b; }

.has-warning .form-control-feedback {
	color: #8a6d3b; }

.has-error .help-block,
.has-error .control-label,
.has-error .radio,
.has-error .checkbox,
.has-error .radio-inline,
.has-error .checkbox-inline,
.has-error.radio label,
.has-error.checkbox label,
.has-error.radio-inline label,
.has-error.checkbox-inline label {
	color: #a94442; }

.has-error .form-control {
	border-color: #a94442;
	-webkit-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075);
	box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075); }
	.has-error .form-control:focus {
		border-color: #843534;
		-webkit-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075), 0 0 6px #ce8483;
		box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075), 0 0 6px #ce8483; }

.has-error .input-group-addon {
	color: #a94442;
	background-color: #f2dede;
	border-color: #a94442; }

.has-error .form-control-feedback {
	color: #a94442; }

.has-feedback label ~ .form-control-feedback {
	top: 28px; }

.has-feedback label.sr-only ~ .form-control-feedback {
	top: 0; }

.help-block {
	display: block;
	margin-top: 5px;
	margin-bottom: 10px;
	color: #737373; }

@media (min-width: 768px) {
	.form-inline .form-group {
		display: inline-block;
		margin-bottom: 0;
		vertical-align: middle; }
	.form-inline .form-control {
		display: inline-block;
		width: auto;
		vertical-align: middle; }
	.form-inline .form-control-static {
		display: inline-block; }
	.form-inline .input-group {
		display: inline-table;
		vertical-align: middle; }
		.form-inline .input-group .input-group-addon,
		.form-inline .input-group .input-group-btn,
		.form-inline .input-group .form-control {
			width: auto; }
	.form-inline .input-group > .form-control {
		width: 100%; }
	.form-inline .control-label {
		margin-bottom: 0;
		vertical-align: middle; }
	.form-inline .radio,
	.form-inline .checkbox {
		display: inline-block;
		margin-top: 0;
		margin-bottom: 0;
		vertical-align: middle; }
		.form-inline .radio label,
		.form-inline .checkbox label {
			padding-left: 0; }
	.form-inline .radio input[type="radio"],
	.form-inline .checkbox input[type="checkbox"] {
		position: relative;
		margin-left: 0; }
	.form-inline .has-feedback .form-control-feedback {
		top: 0; } }

.form-horizontal .radio,
.form-horizontal .checkbox,
.form-horizontal .radio-inline,
.form-horizontal .checkbox-inline {
	padding-top: 11px;
	margin-top: 0;
	margin-bottom: 0; }

.form-horizontal .radio,
.form-horizontal .checkbox {
	min-height: 34px; }

.form-horizontal .form-group {
	margin-right: -15px;
	margin-left: -15px; }
	.form-horizontal .form-group:before, .form-horizontal .form-group:after {
		display: table;
		content: " "; }
	.form-horizontal .form-group:after {
		clear: both; }

@media (min-width: 768px) {
	.form-horizontal .control-label {
		padding-top: 11px;
		margin-bottom: 0;
		text-align: right; } }

.form-horizontal .has-feedback .form-control-feedback {
	right: 15px; }

@media (min-width: 768px) {
	.form-horizontal .form-group-lg .control-label {
		padding-top: 11px;
		font-size: 18px; } }

@media (min-width: 768px) {
	.form-horizontal .form-group-sm .control-label {
		padding-top: 6px;
		font-size: 14px; } }

.btn {
	display: inline-block;
	margin-bottom: 0;
	font-weight: normal;
	text-align: center;
	white-space: nowrap;
	vertical-align: middle;
	-ms-touch-action: manipulation;
	    touch-action: manipulation;
	cursor: pointer;
	background-image: none;
	border: 1px solid transparent;
	padding: 10px 14px;
	font-size: 16px;
	line-height: 1.4375;
	border-radius: 4px;
	-webkit-user-select: none;
	-moz-user-select: none;
	-ms-user-select: none;
	user-select: none; }
	.btn:focus, .btn.focus, .btn:active:focus, .btn:active.focus, .btn.active:focus, .btn.active.focus {
		outline: 5px auto -webkit-focus-ring-color;
		outline-offset: -2px; }
	.btn:hover, .btn:focus, .btn.focus {
		color: #335075;
		text-decoration: none; }
	.btn:active, .btn.active {
		background-image: none;
		outline: 0;
		-webkit-box-shadow: inset 0 3px 5px rgba(0, 0, 0, 0.125);
		box-shadow: inset 0 3px 5px rgba(0, 0, 0, 0.125); }
	.btn.disabled, .btn[disabled],
	fieldset[disabled] .btn {
		cursor: not-allowed;
		filter: alpha(opacity=65);
		opacity: 0.65;
		-webkit-box-shadow: none;
		box-shadow: none; }

a.btn.disabled,
fieldset[disabled] a.btn {
	pointer-events: none; }

.btn-default {
	color: #335075;
	background-color: #eaebed;
	border-color: #dcdee1; }
	.btn-default:focus, .btn-default.focus {
		color: #335075;
		background-color: #cfd1d5;
		border-color: #989da6; }
	.btn-default:hover {
		color: #335075;
		background-color: #cfd1d5;
		border-color: #bbbfc5; }
	.btn-default:active, .btn-default.active,
	.open > .btn-default.dropdown-toggle {
		color: #335075;
		background-color: #cfd1d5;
		background-image: none;
		border-color: #bbbfc5; }
		.btn-default:active:hover, .btn-default:active:focus, .btn-default:active.focus, .btn-default.active:hover, .btn-default.active:focus, .btn-default.active.focus,
		.open > .btn-default.dropdown-toggle:hover,
		.open > .btn-default.dropdown-toggle:focus,
		.open > .btn-default.dropdown-toggle.focus {
			color: #335075;
			background-color: #bbbfc5;
			border-color: #989da6; }
	.btn-default.disabled:hover, .btn-default.disabled:focus, .btn-default.disabled.focus, .btn-default[disabled]:hover, .btn-default[disabled]:focus, .btn-default[disabled].focus,
	fieldset[disabled] .btn-default:hover,
	fieldset[disabled] .btn-default:focus,
	fieldset[disabled] .btn-default.focus {
		background-color: #eaebed;
		border-color: #dcdee1; }
	.btn-default .badge {
		color: #eaebed;
		background-color: #335075; }

.btn-primary {
	color: #fff;
	background-color: #2572b4;
	border-color: #143c5f; }
	.btn-primary:focus, .btn-primary.focus {
		color: #fff;
		background-color: #1c578a;
		border-color: black; }
	.btn-primary:hover {
		color: #fff;
		background-color: #1c578a;
		border-color: #091c2d; }
	.btn-primary:active, .btn-primary.active,
	.open > .btn-primary.dropdown-toggle {
		color: #fff;
		background-color: #1c578a;
		background-image: none;
		border-color: #091c2d; }
		.btn-primary:active:hover, .btn-primary:active:focus, .btn-primary:active.focus, .btn-primary.active:hover, .btn-primary.active:focus, .btn-primary.active.focus,
		.open > .btn-primary.dropdown-toggle:hover,
		.open > .btn-primary.dropdown-toggle:focus,
		.open > .btn-primary.dropdown-toggle.focus {
			color: #fff;
			background-color: #16446c;
			border-color: black; }
	.btn-primary.disabled:hover, .btn-primary.disabled:focus, .btn-primary.disabled.focus, .btn-primary[disabled]:hover, .btn-primary[disabled]:focus, .btn-primary[disabled].focus,
	fieldset[disabled] .btn-primary:hover,
	fieldset[disabled] .btn-primary:focus,
	fieldset[disabled] .btn-primary.focus {
		background-color: #2572b4;
		border-color: #143c5f; }
	.btn-primary .badge {
		color: #2572b4;
		background-color: #fff; }

.btn-success {
	color: #fff;
	background-color: #1b6c1c;
	border-color: #071a07; }
	.btn-success:focus, .btn-success.focus {
		color: #fff;
		background-color: #114311;
		border-color: black; }
	.btn-success:hover {
		color: #fff;
		background-color: #114311;
		border-color: black; }
	.btn-success:active, .btn-success.active,
	.open > .btn-success.dropdown-toggle {
		color: #fff;
		background-color: #114311;
		background-image: none;
		border-color: black; }
		.btn-success:active:hover, .btn-success:active:focus, .btn-success:active.focus, .btn-success.active:hover, .btn-success.active:focus, .btn-success.active.focus,
		.open > .btn-success.dropdown-toggle:hover,
		.open > .btn-success.dropdown-toggle:focus,
		.open > .btn-success.dropdown-toggle.focus {
			color: #fff;
			background-color: #0a270a;
			border-color: black; }
	.btn-success.disabled:hover, .btn-success.disabled:focus, .btn-success.disabled.focus, .btn-success[disabled]:hover, .btn-success[disabled]:focus, .btn-success[disabled].focus,
	fieldset[disabled] .btn-success:hover,
	fieldset[disabled] .btn-success:focus,
	fieldset[disabled] .btn-success.focus {
		background-color: #1b6c1c;
		border-color: #071a07; }
	.btn-success .badge {
		color: #1b6c1c;
		background-color: #fff; }

.btn-info {
	color: #fff;
	background-color: #4d4d4d;
	border-color: #1a1a1a; }
	.btn-info:focus, .btn-info.focus {
		color: #fff;
		background-color: #343333;
		border-color: black; }
	.btn-info:hover {
		color: #fff;
		background-color: #343333;
		border-color: black; }
	.btn-info:active, .btn-info.active,
	.open > .btn-info.dropdown-toggle {
		color: #fff;
		background-color: #343333;
		background-image: none;
		border-color: black; }
		.btn-info:active:hover, .btn-info:active:focus, .btn-info:active.focus, .btn-info.active:hover, .btn-info.active:focus, .btn-info.active.focus,
		.open > .btn-info.dropdown-toggle:hover,
		.open > .btn-info.dropdown-toggle:focus,
		.open > .btn-info.dropdown-toggle.focus {
			color: #fff;
			background-color: #222222;
			border-color: black; }
	.btn-info.disabled:hover, .btn-info.disabled:focus, .btn-info.disabled.focus, .btn-info[disabled]:hover, .btn-info[disabled]:focus, .btn-info[disabled].focus,
	fieldset[disabled] .btn-info:hover,
	fieldset[disabled] .btn-info:focus,
	fieldset[disabled] .btn-info.focus {
		background-color: #4d4d4d;
		border-color: #1a1a1a; }
	.btn-info .badge {
		color: #4d4d4d;
		background-color: #fff; }

.btn-warning {
	color: #000;
	background-color: #f2d40d;
	border-color: #917f08; }
	.btn-warning:focus, .btn-warning.focus {
		color: #000;
		background-color: #c2aa0a;
		border-color: #181501; }
	.btn-warning:hover {
		color: #000;
		background-color: #c2aa0a;
		border-color: #574c05; }
	.btn-warning:active, .btn-warning.active,
	.open > .btn-warning.dropdown-toggle {
		color: #000;
		background-color: #c2aa0a;
		background-image: none;
		border-color: #574c05; }
		.btn-warning:active:hover, .btn-warning:active:focus, .btn-warning:active.focus, .btn-warning.active:hover, .btn-warning.active:focus, .btn-warning.active.focus,
		.open > .btn-warning.dropdown-toggle:hover,
		.open > .btn-warning.dropdown-toggle:focus,
		.open > .btn-warning.dropdown-toggle.focus {
			color: #000;
			background-color: #a08c09;
			border-color: #181501; }
	.btn-warning.disabled:hover, .btn-warning.disabled:focus, .btn-warning.disabled.focus, .btn-warning[disabled]:hover, .btn-warning[disabled]:focus, .btn-warning[disabled].focus,
	fieldset[disabled] .btn-warning:hover,
	fieldset[disabled] .btn-warning:focus,
	fieldset[disabled] .btn-warning.focus {
		background-color: #f2d40d;
		border-color: #917f08; }
	.btn-warning .badge {
		color: #f2d40d;
		background-color: #000; }

.btn-danger {
	color: #fff;
	background-color: #bc3331;
	border-color: #6b1d1c; }
	.btn-danger:focus, .btn-danger.focus {
		color: #fff;
		background-color: #942826;
		border-color: #060202; }
	.btn-danger:hover {
		color: #fff;
		background-color: #942826;
		border-color: #3b100f; }
	.btn-danger:active, .btn-danger.active,
	.open > .btn-danger.dropdown-toggle {
		color: #fff;
		background-color: #942826;
		background-image: none;
		border-color: #3b100f; }
		.btn-danger:active:hover, .btn-danger:active:focus, .btn-danger:active.focus, .btn-danger.active:hover, .btn-danger.active:focus, .btn-danger.active.focus,
		.open > .btn-danger.dropdown-toggle:hover,
		.open > .btn-danger.dropdown-toggle:focus,
		.open > .btn-danger.dropdown-toggle.focus {
			color: #fff;
			background-color: #77201f;
			border-color: #060202; }
	.btn-danger.disabled:hover, .btn-danger.disabled:focus, .btn-danger.disabled.focus, .btn-danger[disabled]:hover, .btn-danger[disabled]:focus, .btn-danger[disabled].focus,
	fieldset[disabled] .btn-danger:hover,
	fieldset[disabled] .btn-danger:focus,
	fieldset[disabled] .btn-danger.focus {
		background-color: #bc3331;
		border-color: #6b1d1c; }
	.btn-danger .badge {
		color: #bc3331;
		background-color: #fff; }

.btn-link {
	font-weight: 400;
	color: #295376;
	border-radius: 0; }
	.btn-link, .btn-link:active, .btn-link.active, .btn-link[disabled],
	fieldset[disabled] .btn-link {
		background-color: transparent;
		-webkit-box-shadow: none;
		box-shadow: none; }
	.btn-link, .btn-link:hover, .btn-link:focus, .btn-link:active {
		border-color: transparent; }
	.btn-link:hover, .btn-link:focus {
		color: #0535d2;
		text-decoration: underline;
		background-color: transparent; }
	.btn-link[disabled]:hover, .btn-link[disabled]:focus,
	fieldset[disabled] .btn-link:hover,
	fieldset[disabled] .btn-link:focus {
		color: #6f6f6f;
		text-decoration: none; }

.btn-lg, .btn-group-lg > .btn {
	padding: 10px 16px;
	font-size: 18px;
	line-height: 1.3333333;
	border-radius: 6px; }

.btn-sm, .btn-group-sm > .btn {
	padding: 5px 10px;
	font-size: 14px;
	line-height: 1.5;
	border-radius: 3px; }

.btn-xs, .btn-group-xs > .btn {
	padding: 1px 5px;
	font-size: 14px;
	line-height: 1.5;
	border-radius: 3px; }

.btn-block {
	display: block;
	width: 100%; }

.btn-block + .btn-block {
	margin-top: 5px; }

input[type="submit"].btn-block,
input[type="reset"].btn-block,
input[type="button"].btn-block {
	width: 100%; }

.fade {
	opacity: 0;
	-webkit-transition: opacity 0.15s linear;
	transition: opacity 0.15s linear; }
	.fade.in {
		opacity: 1; }

.collapse {
	display: none; }
	.collapse.in {
		display: block; }

tr.collapse.in {
	display: table-row; }

tbody.collapse.in {
	display: table-row-group; }

.collapsing {
	position: relative;
	height: 0;
	overflow: hidden;
	-webkit-transition-property: height, visibility;
	transition-property: height, visibility;
	-webkit-transition-duration: 0.35s;
	transition-duration: 0.35s;
	-webkit-transition-timing-function: ease;
	transition-timing-function: ease; }

.caret {
	display: inline-block;
	width: 0;
	height: 0;
	margin-left: 2px;
	vertical-align: middle;
	border-top: 4px dashed;
	border-top: 4px solid \9;
	border-right: 4px solid transparent;
	border-left: 4px solid transparent; }

.dropup,
.dropdown {
	position: relative; }

.dropdown-toggle:focus {
	outline: 0; }

.dropdown-menu {
	position: absolute;
	top: 100%;
	left: 0;
	z-index: 1000;
	display: none;
	float: left;
	min-width: 160px;
	padding: 5px 0;
	margin: 2px 0 0;
	font-size: 16px;
	text-align: left;
	list-style: none;
	background-color: #fff;
	background-clip: padding-box;
	border: 1px solid #ccc;
	border: 1px solid rgba(0, 0, 0, 0.15);
	border-radius: 4px;
	-webkit-box-shadow: 0 6px 12px rgba(0, 0, 0, 0.175);
	box-shadow: 0 6px 12px rgba(0, 0, 0, 0.175); }
	.dropdown-menu.pull-right {
		right: 0;
		left: auto; }
	.dropdown-menu .divider {
		height: 1px;
		margin: 10.5px 0;
		overflow: hidden;
		background-color: #e5e5e5; }
	.dropdown-menu > li > a {
		display: block;
		padding: 3px 20px;
		clear: both;
		font-weight: 400;
		line-height: 1.4375;
		color: #333333;
		white-space: nowrap; }
		.dropdown-menu > li > a:hover, .dropdown-menu > li > a:focus {
			color: #262626;
			text-decoration: none;
			background-color: #f5f5f5; }

.dropdown-menu > .active > a, .dropdown-menu > .active > a:hover, .dropdown-menu > .active > a:focus {
	color: #fff;
	text-decoration: none;
	background-color: #2572b4;
	outline: 0; }

.dropdown-menu > .disabled > a, .dropdown-menu > .disabled > a:hover, .dropdown-menu > .disabled > a:focus {
	color: #6f6f6f; }

.dropdown-menu > .disabled > a:hover, .dropdown-menu > .disabled > a:focus {
	text-decoration: none;
	cursor: not-allowed;
	background-color: transparent;
	background-image: none;
	filter: progid:DXImageTransform.Microsoft.gradient(enabled = false); }

.open > .dropdown-menu {
	display: block; }

.open > a {
	outline: 0; }

.dropdown-menu-right {
	right: 0;
	left: auto; }

.dropdown-menu-left {
	right: auto;
	left: 0; }

.dropdown-header {
	display: block;
	padding: 3px 20px;
	font-size: 14px;
	line-height: 1.4375;
	color: #6f6f6f;
	white-space: nowrap; }

.dropdown-backdrop {
	position: fixed;
	top: 0;
	right: 0;
	bottom: 0;
	left: 0;
	z-index: 990; }

.pull-right > .dropdown-menu {
	right: 0;
	left: auto; }

.dropup .caret,
.navbar-fixed-bottom .dropdown .caret {
	content: "";
	border-top: 0;
	border-bottom: 4px dashed;
	border-bottom: 4px solid \9; }

.dropup .dropdown-menu,
.navbar-fixed-bottom .dropdown .dropdown-menu {
	top: auto;
	bottom: 100%;
	margin-bottom: 2px; }

@media (min-width: 768px) {
	.navbar-right .dropdown-menu {
		right: 0;
		left: auto; }
	.navbar-right .dropdown-menu-left {
		left: 0;
		right: auto; } }

.btn-group,
.btn-group-vertical {
	position: relative;
	display: inline-block;
	vertical-align: middle; }
	.btn-group > .btn,
	.btn-group-vertical > .btn {
		position: relative;
		float: left; }
		.btn-group > .btn:hover, .btn-group > .btn:focus, .btn-group > .btn:active, .btn-group > .btn.active,
		.btn-group-vertical > .btn:hover,
		.btn-group-vertical > .btn:focus,
		.btn-group-vertical > .btn:active,
		.btn-group-vertical > .btn.active {
			z-index: 2; }

.btn-group .btn + .btn,
.btn-group .btn + .btn-group,
.btn-group .btn-group + .btn,
.btn-group .btn-group + .btn-group {
	margin-left: -1px; }

.btn-toolbar {
	margin-left: -5px; }
	.btn-toolbar:before, .btn-toolbar:after {
		display: table;
		content: " "; }
	.btn-toolbar:after {
		clear: both; }
	.btn-toolbar .btn,
	.btn-toolbar .btn-group,
	.btn-toolbar .input-group {
		float: left; }
	.btn-toolbar > .btn,
	.btn-toolbar > .btn-group,
	.btn-toolbar > .input-group {
		margin-left: 5px; }

.btn-group > .btn:not(:first-child):not(:last-child):not(.dropdown-toggle) {
	border-radius: 0; }

.btn-group > .btn:first-child {
	margin-left: 0; }
	.btn-group > .btn:first-child:not(:last-child):not(.dropdown-toggle) {
		border-top-right-radius: 0;
		border-bottom-right-radius: 0; }

.btn-group > .btn:last-child:not(:first-child),
.btn-group > .dropdown-toggle:not(:first-child) {
	border-top-left-radius: 0;
	border-bottom-left-radius: 0; }

.btn-group > .btn-group {
	float: left; }

.btn-group > .btn-group:not(:first-child):not(:last-child) > .btn {
	border-radius: 0; }

.btn-group > .btn-group:first-child:not(:last-child) > .btn:last-child,
.btn-group > .btn-group:first-child:not(:last-child) > .dropdown-toggle {
	border-top-right-radius: 0;
	border-bottom-right-radius: 0; }

.btn-group > .btn-group:last-child:not(:first-child) > .btn:first-child {
	border-top-left-radius: 0;
	border-bottom-left-radius: 0; }

.btn-group .dropdown-toggle:active,
.btn-group.open .dropdown-toggle {
	outline: 0; }

.btn-group > .btn + .dropdown-toggle {
	padding-right: 8px;
	padding-left: 8px; }

.btn-group > .btn-lg + .dropdown-toggle, .btn-group-lg.btn-group > .btn + .dropdown-toggle {
	padding-right: 12px;
	padding-left: 12px; }

.btn-group.open .dropdown-toggle {
	-webkit-box-shadow: inset 0 3px 5px rgba(0, 0, 0, 0.125);
	box-shadow: inset 0 3px 5px rgba(0, 0, 0, 0.125); }
	.btn-group.open .dropdown-toggle.btn-link {
		-webkit-box-shadow: none;
		box-shadow: none; }

.btn .caret {
	margin-left: 0; }

.btn-lg .caret, .btn-group-lg > .btn .caret {
	border-width: 5px 5px 0;
	border-bottom-width: 0; }

.dropup .btn-lg .caret, .dropup .btn-group-lg > .btn .caret {
	border-width: 0 5px 5px; }

.btn-group-vertical > .btn,
.btn-group-vertical > .btn-group,
.btn-group-vertical > .btn-group > .btn {
	display: block;
	float: none;
	width: 100%;
	max-width: 100%; }

.btn-group-vertical > .btn-group:before, .btn-group-vertical > .btn-group:after {
	display: table;
	content: " "; }

.btn-group-vertical > .btn-group:after {
	clear: both; }

.btn-group-vertical > .btn-group > .btn {
	float: none; }

.btn-group-vertical > .btn + .btn,
.btn-group-vertical > .btn + .btn-group,
.btn-group-vertical > .btn-group + .btn,
.btn-group-vertical > .btn-group + .btn-group {
	margin-top: -1px;
	margin-left: 0; }

.btn-group-vertical > .btn:not(:first-child):not(:last-child) {
	border-radius: 0; }

.btn-group-vertical > .btn:first-child:not(:last-child) {
	border-top-left-radius: 4px;
	border-top-right-radius: 4px;
	border-bottom-right-radius: 0;
	border-bottom-left-radius: 0; }

.btn-group-vertical > .btn:last-child:not(:first-child) {
	border-top-left-radius: 0;
	border-top-right-radius: 0;
	border-bottom-right-radius: 4px;
	border-bottom-left-radius: 4px; }

.btn-group-vertical > .btn-group:not(:first-child):not(:last-child) > .btn {
	border-radius: 0; }

.btn-group-vertical > .btn-group:first-child:not(:last-child) > .btn:last-child,
.btn-group-vertical > .btn-group:first-child:not(:last-child) > .dropdown-toggle {
	border-bottom-right-radius: 0;
	border-bottom-left-radius: 0; }

.btn-group-vertical > .btn-group:last-child:not(:first-child) > .btn:first-child {
	border-top-left-radius: 0;
	border-top-right-radius: 0; }

.btn-group-justified {
	display: table;
	width: 100%;
	table-layout: fixed;
	border-collapse: separate; }
	.btn-group-justified > .btn,
	.btn-group-justified > .btn-group {
		display: table-cell;
		float: none;
		width: 1%; }
	.btn-group-justified > .btn-group .btn {
		width: 100%; }
	.btn-group-justified > .btn-group .dropdown-menu {
		left: auto; }

[data-toggle="buttons"] > .btn input[type="radio"],
[data-toggle="buttons"] > .btn input[type="checkbox"],
[data-toggle="buttons"] > .btn-group > .btn input[type="radio"],
[data-toggle="buttons"] > .btn-group > .btn input[type="checkbox"] {
	position: absolute;
	clip: rect(0, 0, 0, 0);
	pointer-events: none; }

.input-group {
	position: relative;
	display: table;
	border-collapse: separate; }
	.input-group[class*="col-"] {
		float: none;
		padding-right: 0;
		padding-left: 0; }
	.input-group .form-control {
		position: relative;
		z-index: 2;
		float: left;
		width: 100%;
		margin-bottom: 0; }
		.input-group .form-control:focus {
			z-index: 3; }

.input-group-addon,
.input-group-btn,
.input-group .form-control {
	display: table-cell; }
	.input-group-addon:not(:first-child):not(:last-child),
	.input-group-btn:not(:first-child):not(:last-child),
	.input-group .form-control:not(:first-child):not(:last-child) {
		border-radius: 0; }

.input-group-addon,
.input-group-btn {
	width: 1%;
	white-space: nowrap;
	vertical-align: middle; }

.input-group-addon {
	padding: 10px 14px;
	font-size: 16px;
	font-weight: 400;
	line-height: 1;
	color: #555555;
	text-align: center;
	background-color: #eeeeee;
	border: 1px solid #ccc;
	border-radius: 4px; }
	.input-group-addon.input-sm,
	.input-group-sm > .input-group-addon,
	.input-group-sm > .input-group-btn > .input-group-addon.btn {
		padding: 5px 10px;
		font-size: 14px;
		border-radius: 3px; }
	.input-group-addon.input-lg,
	.input-group-lg > .input-group-addon,
	.input-group-lg > .input-group-btn > .input-group-addon.btn {
		padding: 10px 16px;
		font-size: 18px;
		border-radius: 6px; }
	.input-group-addon input[type="radio"],
	.input-group-addon input[type="checkbox"] {
		margin-top: 0; }

.input-group .form-control:first-child,
.input-group-addon:first-child,
.input-group-btn:first-child > .btn,
.input-group-btn:first-child > .btn-group > .btn,
.input-group-btn:first-child > .dropdown-toggle,
.input-group-btn:last-child > .btn:not(:last-child):not(.dropdown-toggle),
.input-group-btn:last-child > .btn-group:not(:last-child) > .btn {
	border-top-right-radius: 0;
	border-bottom-right-radius: 0; }

.input-group-addon:first-child {
	border-right: 0; }

.input-group .form-control:last-child,
.input-group-addon:last-child,
.input-group-btn:last-child > .btn,
.input-group-btn:last-child > .btn-group > .btn,
.input-group-btn:last-child > .dropdown-toggle,
.input-group-btn:first-child > .btn:not(:first-child),
.input-group-btn:first-child > .btn-group:not(:first-child) > .btn {
	border-top-left-radius: 0;
	border-bottom-left-radius: 0; }

.input-group-addon:last-child {
	border-left: 0; }

.input-group-btn {
	position: relative;
	font-size: 0;
	white-space: nowrap; }
	.input-group-btn > .btn {
		position: relative; }
		.input-group-btn > .btn + .btn {
			margin-left: -1px; }
		.input-group-btn > .btn:hover, .input-group-btn > .btn:focus, .input-group-btn > .btn:active {
			z-index: 2; }
	.input-group-btn:first-child > .btn,
	.input-group-btn:first-child > .btn-group {
		margin-right: -1px; }
	.input-group-btn:last-child > .btn,
	.input-group-btn:last-child > .btn-group {
		z-index: 2;
		margin-left: -1px; }

.nav {
	padding-left: 0;
	margin-bottom: 0;
	list-style: none; }
	.nav:before, .nav:after {
		display: table;
		content: " "; }
	.nav:after {
		clear: both; }
	.nav > li {
		position: relative;
		display: block; }
		.nav > li > a {
			position: relative;
			display: block;
			padding: 10px 15px; }
			.nav > li > a:hover, .nav > li > a:focus {
				text-decoration: none;
				background-color: #eeeeee; }
		.nav > li.disabled > a {
			color: #6f6f6f; }
			.nav > li.disabled > a:hover, .nav > li.disabled > a:focus {
				color: #6f6f6f;
				text-decoration: none;
				cursor: not-allowed;
				background-color: transparent; }
	.nav .open > a, .nav .open > a:hover, .nav .open > a:focus {
		background-color: #eeeeee;
		border-color: #295376; }
	.nav .nav-divider {
		height: 1px;
		margin: 10.5px 0;
		overflow: hidden;
		background-color: #e5e5e5; }
	.nav > li > a > img {
		max-width: none; }

.nav-tabs {
	border-bottom: 1px solid #ddd; }
	.nav-tabs > li {
		float: left;
		margin-bottom: -1px; }
		.nav-tabs > li > a {
			margin-right: 2px;
			line-height: 1.4375;
			border: 1px solid transparent;
			border-radius: 4px 4px 0 0; }
			.nav-tabs > li > a:hover {
				border-color: #eeeeee #eeeeee #ddd; }
		.nav-tabs > li.active > a, .nav-tabs > li.active > a:hover, .nav-tabs > li.active > a:focus {
			color: #555555;
			cursor: default;
			background-color: #fff;
			border: 1px solid #ddd;
			border-bottom-color: transparent; }

.nav-pills > li {
	float: left; }
	.nav-pills > li > a {
		border-radius: 4px; }
	.nav-pills > li + li {
		margin-left: 2px; }
	.nav-pills > li.active > a, .nav-pills > li.active > a:hover, .nav-pills > li.active > a:focus {
		color: #fff;
		background-color: #2572b4; }

.nav-stacked > li {
	float: none; }
	.nav-stacked > li + li {
		margin-top: 2px;
		margin-left: 0; }

.nav-justified, .nav-tabs.nav-justified {
	width: 100%; }
	.nav-justified > li, .nav-tabs.nav-justified > li {
		float: none; }
		.nav-justified > li > a, .nav-tabs.nav-justified > li > a {
			margin-bottom: 5px;
			text-align: center; }
	.nav-justified > .dropdown .dropdown-menu {
		top: auto;
		left: auto; }
	@media (min-width: 768px) {
		.nav-justified > li, .nav-tabs.nav-justified > li {
			display: table-cell;
			width: 1%; }
			.nav-justified > li > a, .nav-tabs.nav-justified > li > a {
				margin-bottom: 0; } }

.nav-tabs-justified, .nav-tabs.nav-justified {
	border-bottom: 0; }
	.nav-tabs-justified > li > a, .nav-tabs.nav-justified > li > a {
		margin-right: 0;
		border-radius: 4px; }
	.nav-tabs-justified > .active > a, .nav-tabs.nav-justified > .active > a,
	.nav-tabs-justified > .active > a:hover,
	.nav-tabs.nav-justified > .active > a:hover,
	.nav-tabs-justified > .active > a:focus,
	.nav-tabs.nav-justified > .active > a:focus {
		border: 1px solid #ddd; }
	@media (min-width: 768px) {
		.nav-tabs-justified > li > a, .nav-tabs.nav-justified > li > a {
			border-bottom: 1px solid #ddd;
			border-radius: 4px 4px 0 0; }
		.nav-tabs-justified > .active > a, .nav-tabs.nav-justified > .active > a,
		.nav-tabs-justified > .active > a:hover,
		.nav-tabs.nav-justified > .active > a:hover,
		.nav-tabs-justified > .active > a:focus,
		.nav-tabs.nav-justified > .active > a:focus {
			border-bottom-color: #fff; } }

.tab-content > .tab-pane {
	display: none; }

.tab-content > .active {
	display: block; }

.nav-tabs .dropdown-menu {
	margin-top: -1px;
	border-top-left-radius: 0;
	border-top-right-radius: 0; }

.navbar {
	position: relative;
	min-height: 50px;
	margin-bottom: 23px;
	border: 1px solid transparent; }
	.navbar:before, .navbar:after {
		display: table;
		content: " "; }
	.navbar:after {
		clear: both; }
	@media (min-width: 768px) {
		.navbar {
			border-radius: 4px; } }

.navbar-header:before, .navbar-header:after {
	display: table;
	content: " "; }

.navbar-header:after {
	clear: both; }

@media (min-width: 768px) {
	.navbar-header {
		float: left; } }

.navbar-collapse {
	padding-right: 15px;
	padding-left: 15px;
	overflow-x: visible;
	border-top: 1px solid transparent;
	-webkit-box-shadow: inset 0 1px 0 rgba(255, 255, 255, 0.1);
	        box-shadow: inset 0 1px 0 rgba(255, 255, 255, 0.1);
	-webkit-overflow-scrolling: touch; }
	.navbar-collapse:before, .navbar-collapse:after {
		display: table;
		content: " "; }
	.navbar-collapse:after {
		clear: both; }
	.navbar-collapse.in {
		overflow-y: auto; }
	@media (min-width: 768px) {
		.navbar-collapse {
			width: auto;
			border-top: 0;
			-webkit-box-shadow: none;
			        box-shadow: none; }
			.navbar-collapse.collapse {
				display: block !important;
				height: auto !important;
				padding-bottom: 0;
				overflow: visible !important; }
			.navbar-collapse.in {
				overflow-y: visible; }
			.navbar-fixed-top .navbar-collapse,
			.navbar-static-top .navbar-collapse,
			.navbar-fixed-bottom .navbar-collapse {
				padding-right: 0;
				padding-left: 0; } }

.navbar-fixed-top,
.navbar-fixed-bottom {
	position: fixed;
	right: 0;
	left: 0;
	z-index: 1030; }
	.navbar-fixed-top .navbar-collapse,
	.navbar-fixed-bottom .navbar-collapse {
		max-height: 340px; }
		@media (max-device-width: 480px) and (orientation: landscape) {
			.navbar-fixed-top .navbar-collapse,
			.navbar-fixed-bottom .navbar-collapse {
				max-height: 200px; } }
	@media (min-width: 768px) {
		.navbar-fixed-top,
		.navbar-fixed-bottom {
			border-radius: 0; } }

.navbar-fixed-top {
	top: 0;
	border-width: 0 0 1px; }

.navbar-fixed-bottom {
	bottom: 0;
	margin-bottom: 0;
	border-width: 1px 0 0; }

.container > .navbar-header,
.container > .navbar-collapse,
.container-fluid > .navbar-header,
.container-fluid > .navbar-collapse {
	margin-right: -15px;
	margin-left: -15px; }
	@media (min-width: 768px) {
		.container > .navbar-header,
		.container > .navbar-collapse,
		.container-fluid > .navbar-header,
		.container-fluid > .navbar-collapse {
			margin-right: 0;
			margin-left: 0; } }

.navbar-static-top {
	z-index: 1000;
	border-width: 0 0 1px; }
	@media (min-width: 768px) {
		.navbar-static-top {
			border-radius: 0; } }

.navbar-brand {
	float: left;
	height: 50px;
	padding: 13.5px 15px;
	font-size: 18px;
	line-height: 23px; }
	.navbar-brand:hover, .navbar-brand:focus {
		text-decoration: none; }
	.navbar-brand > img {
		display: block; }
	@media (min-width: 768px) {
		.navbar > .container .navbar-brand,
		.navbar > .container-fluid .navbar-brand {
			margin-left: -15px; } }

.navbar-toggle {
	position: relative;
	float: right;
	padding: 9px 10px;
	margin-right: 15px;
	margin-top: 8px;
	margin-bottom: 8px;
	background-color: transparent;
	background-image: none;
	border: 1px solid transparent;
	border-radius: 4px; }
	.navbar-toggle:focus {
		outline: 0; }
	.navbar-toggle .icon-bar {
		display: block;
		width: 22px;
		height: 2px;
		border-radius: 1px; }
	.navbar-toggle .icon-bar + .icon-bar {
		margin-top: 4px; }
	@media (min-width: 768px) {
		.navbar-toggle {
			display: none; } }

.navbar-nav {
	margin: 6.75px -15px; }
	.navbar-nav > li > a {
		padding-top: 10px;
		padding-bottom: 10px;
		line-height: 23px; }
	@media (max-width: 767px) {
		.navbar-nav .open .dropdown-menu {
			position: static;
			float: none;
			width: auto;
			margin-top: 0;
			background-color: transparent;
			border: 0;
			-webkit-box-shadow: none;
			        box-shadow: none; }
			.navbar-nav .open .dropdown-menu > li > a,
			.navbar-nav .open .dropdown-menu .dropdown-header {
				padding: 5px 15px 5px 25px; }
			.navbar-nav .open .dropdown-menu > li > a {
				line-height: 23px; }
				.navbar-nav .open .dropdown-menu > li > a:hover, .navbar-nav .open .dropdown-menu > li > a:focus {
					background-image: none; } }
	@media (min-width: 768px) {
		.navbar-nav {
			float: left;
			margin: 0; }
			.navbar-nav > li {
				float: left; }
				.navbar-nav > li > a {
					padding-top: 13.5px;
					padding-bottom: 13.5px; } }

.navbar-form {
	padding: 10px 15px;
	margin-right: -15px;
	margin-left: -15px;
	border-top: 1px solid transparent;
	border-bottom: 1px solid transparent;
	-webkit-box-shadow: inset 0 1px 0 rgba(255, 255, 255, 0.1), 0 1px 0 rgba(255, 255, 255, 0.1);
	box-shadow: inset 0 1px 0 rgba(255, 255, 255, 0.1), 0 1px 0 rgba(255, 255, 255, 0.1);
	margin-top: 6.5px;
	margin-bottom: 6.5px; }
	@media (min-width: 768px) {
		.navbar-form .form-group {
			display: inline-block;
			margin-bottom: 0;
			vertical-align: middle; }
		.navbar-form .form-control {
			display: inline-block;
			width: auto;
			vertical-align: middle; }
		.navbar-form .form-control-static {
			display: inline-block; }
		.navbar-form .input-group {
			display: inline-table;
			vertical-align: middle; }
			.navbar-form .input-group .input-group-addon,
			.navbar-form .input-group .input-group-btn,
			.navbar-form .input-group .form-control {
				width: auto; }
		.navbar-form .input-group > .form-control {
			width: 100%; }
		.navbar-form .control-label {
			margin-bottom: 0;
			vertical-align: middle; }
		.navbar-form .radio,
		.navbar-form .checkbox {
			display: inline-block;
			margin-top: 0;
			margin-bottom: 0;
			vertical-align: middle; }
			.navbar-form .radio label,
			.navbar-form .checkbox label {
				padding-left: 0; }
		.navbar-form .radio input[type="radio"],
		.navbar-form .checkbox input[type="checkbox"] {
			position: relative;
			margin-left: 0; }
		.navbar-form .has-feedback .form-control-feedback {
			top: 0; } }
	@media (max-width: 767px) {
		.navbar-form .form-group {
			margin-bottom: 5px; }
			.navbar-form .form-group:last-child {
				margin-bottom: 0; } }
	@media (min-width: 768px) {
		.navbar-form {
			width: auto;
			padding-top: 0;
			padding-bottom: 0;
			margin-right: 0;
			margin-left: 0;
			border: 0;
			-webkit-box-shadow: none;
			box-shadow: none; } }

.navbar-nav > li > .dropdown-menu {
	margin-top: 0;
	border-top-left-radius: 0;
	border-top-right-radius: 0; }

.navbar-fixed-bottom .navbar-nav > li > .dropdown-menu {
	margin-bottom: 0;
	border-top-left-radius: 4px;
	border-top-right-radius: 4px;
	border-bottom-right-radius: 0;
	border-bottom-left-radius: 0; }

.navbar-btn {
	margin-top: 6.5px;
	margin-bottom: 6.5px; }
	.navbar-btn.btn-sm, .btn-group-sm > .navbar-btn.btn {
		margin-top: 8.5px;
		margin-bottom: 8.5px; }
	.navbar-btn.btn-xs, .btn-group-xs > .navbar-btn.btn {
		margin-top: 14px;
		margin-bottom: 14px; }

.navbar-text {
	margin-top: 13.5px;
	margin-bottom: 13.5px; }
	@media (min-width: 768px) {
		.navbar-text {
			float: left;
			margin-right: 15px;
			margin-left: 15px; } }

@media (min-width: 768px) {
	.navbar-left {
		float: left !important; }
	.navbar-right {
		float: right !important;
		margin-right: -15px; }
		.navbar-right ~ .navbar-right {
			margin-right: 0; } }

.navbar-default {
	background-color: #f8f8f8;
	border-color: #e7e7e7; }
	.navbar-default .navbar-brand {
		color: #777; }
		.navbar-default .navbar-brand:hover, .navbar-default .navbar-brand:focus {
			color: #5e5d5d;
			background-color: transparent; }
	.navbar-default .navbar-text {
		color: #777; }
	.navbar-default .navbar-nav > li > a {
		color: #777; }
		.navbar-default .navbar-nav > li > a:hover, .navbar-default .navbar-nav > li > a:focus {
			color: #333;
			background-color: transparent; }
	.navbar-default .navbar-nav > .active > a, .navbar-default .navbar-nav > .active > a:hover, .navbar-default .navbar-nav > .active > a:focus {
		color: #555;
		background-color: #e7e7e7; }
	.navbar-default .navbar-nav > .disabled > a, .navbar-default .navbar-nav > .disabled > a:hover, .navbar-default .navbar-nav > .disabled > a:focus {
		color: #ccc;
		background-color: transparent; }
	.navbar-default .navbar-nav > .open > a, .navbar-default .navbar-nav > .open > a:hover, .navbar-default .navbar-nav > .open > a:focus {
		color: #555;
		background-color: #e7e7e7; }
	@media (max-width: 767px) {
		.navbar-default .navbar-nav .open .dropdown-menu > li > a {
			color: #777; }
			.navbar-default .navbar-nav .open .dropdown-menu > li > a:hover, .navbar-default .navbar-nav .open .dropdown-menu > li > a:focus {
				color: #333;
				background-color: transparent; }
		.navbar-default .navbar-nav .open .dropdown-menu > .active > a, .navbar-default .navbar-nav .open .dropdown-menu > .active > a:hover, .navbar-default .navbar-nav .open .dropdown-menu > .active > a:focus {
			color: #555;
			background-color: #e7e7e7; }
		.navbar-default .navbar-nav .open .dropdown-menu > .disabled > a, .navbar-default .navbar-nav .open .dropdown-menu > .disabled > a:hover, .navbar-default .navbar-nav .open .dropdown-menu > .disabled > a:focus {
			color: #ccc;
			background-color: transparent; } }
	.navbar-default .navbar-toggle {
		border-color: #ddd; }
		.navbar-default .navbar-toggle:hover, .navbar-default .navbar-toggle:focus {
			background-color: #ddd; }
		.navbar-default .navbar-toggle .icon-bar {
			background-color: #888; }
	.navbar-default .navbar-collapse,
	.navbar-default .navbar-form {
		border-color: #e7e7e7; }
	.navbar-default .navbar-link {
		color: #777; }
		.navbar-default .navbar-link:hover {
			color: #333; }
	.navbar-default .btn-link {
		color: #777; }
		.navbar-default .btn-link:hover, .navbar-default .btn-link:focus {
			color: #333; }
		.navbar-default .btn-link[disabled]:hover, .navbar-default .btn-link[disabled]:focus,
		fieldset[disabled] .navbar-default .btn-link:hover,
		fieldset[disabled] .navbar-default .btn-link:focus {
			color: #ccc; }

.navbar-inverse {
	background-color: #222;
	border-color: #090808; }
	.navbar-inverse .navbar-brand {
		color: #959595; }
		.navbar-inverse .navbar-brand:hover, .navbar-inverse .navbar-brand:focus {
			color: #fff;
			background-color: transparent; }
	.navbar-inverse .navbar-text {
		color: #959595; }
	.navbar-inverse .navbar-nav > li > a {
		color: #959595; }
		.navbar-inverse .navbar-nav > li > a:hover, .navbar-inverse .navbar-nav > li > a:focus {
			color: #fff;
			background-color: transparent; }
	.navbar-inverse .navbar-nav > .active > a, .navbar-inverse .navbar-nav > .active > a:hover, .navbar-inverse .navbar-nav > .active > a:focus {
		color: #fff;
		background-color: #090808; }
	.navbar-inverse .navbar-nav > .disabled > a, .navbar-inverse .navbar-nav > .disabled > a:hover, .navbar-inverse .navbar-nav > .disabled > a:focus {
		color: #444;
		background-color: transparent; }
	.navbar-inverse .navbar-nav > .open > a, .navbar-inverse .navbar-nav > .open > a:hover, .navbar-inverse .navbar-nav > .open > a:focus {
		color: #fff;
		background-color: #090808; }
	@media (max-width: 767px) {
		.navbar-inverse .navbar-nav .open .dropdown-menu > .dropdown-header {
			border-color: #090808; }
		.navbar-inverse .navbar-nav .open .dropdown-menu .divider {
			background-color: #090808; }
		.navbar-inverse .navbar-nav .open .dropdown-menu > li > a {
			color: #959595; }
			.navbar-inverse .navbar-nav .open .dropdown-menu > li > a:hover, .navbar-inverse .navbar-nav .open .dropdown-menu > li > a:focus {
				color: #fff;
				background-color: transparent; }
		.navbar-inverse .navbar-nav .open .dropdown-menu > .active > a, .navbar-inverse .navbar-nav .open .dropdown-menu > .active > a:hover, .navbar-inverse .navbar-nav .open .dropdown-menu > .active > a:focus {
			color: #fff;
			background-color: #090808; }
		.navbar-inverse .navbar-nav .open .dropdown-menu > .disabled > a, .navbar-inverse .navbar-nav .open .dropdown-menu > .disabled > a:hover, .navbar-inverse .navbar-nav .open .dropdown-menu > .disabled > a:focus {
			color: #444;
			background-color: transparent; } }
	.navbar-inverse .navbar-toggle {
		border-color: #333; }
		.navbar-inverse .navbar-toggle:hover, .navbar-inverse .navbar-toggle:focus {
			background-color: #333; }
		.navbar-inverse .navbar-toggle .icon-bar {
			background-color: #fff; }
	.navbar-inverse .navbar-collapse,
	.navbar-inverse .navbar-form {
		border-color: #101010; }
	.navbar-inverse .navbar-link {
		color: #959595; }
		.navbar-inverse .navbar-link:hover {
			color: #fff; }
	.navbar-inverse .btn-link {
		color: #959595; }
		.navbar-inverse .btn-link:hover, .navbar-inverse .btn-link:focus {
			color: #fff; }
		.navbar-inverse .btn-link[disabled]:hover, .navbar-inverse .btn-link[disabled]:focus,
		fieldset[disabled] .navbar-inverse .btn-link:hover,
		fieldset[disabled] .navbar-inverse .btn-link:focus {
			color: #444; }

.breadcrumb {
	padding: 8px 15px;
	margin-bottom: 23px;
	list-style: none;
	background-color: transparent;
	border-radius: 4px; }
	.breadcrumb > li {
		display: inline-block; }
		.breadcrumb > li + li:before {
			padding: 0 5px;
			color: #ccc;
			content: "/ "; }
	.breadcrumb > .active {
		color: #6f6f6f; }

.pagination {
	display: inline-block;
	padding-left: 0;
	margin: 23px 0;
	border-radius: 4px; }
	.pagination > li {
		display: inline; }
		.pagination > li > a,
		.pagination > li > span {
			position: relative;
			float: left;
			padding: 10px 14px;
			margin-left: -1px;
			line-height: 1.4375;
			color: #335075;
			text-decoration: none;
			background-color: #eaebed;
			border: 1px solid #dcdee1; }
			.pagination > li > a:hover, .pagination > li > a:focus,
			.pagination > li > span:hover,
			.pagination > li > span:focus {
				z-index: 2;
				color: #335075;
				background-color: #d4d6da;
				border-color: #bbbfc5; }
		.pagination > li:first-child > a,
		.pagination > li:first-child > span {
			margin-left: 0;
			border-top-left-radius: 4px;
			border-bottom-left-radius: 4px; }
		.pagination > li:last-child > a,
		.pagination > li:last-child > span {
			border-top-right-radius: 4px;
			border-bottom-right-radius: 4px; }
	.pagination > .active > a, .pagination > .active > a:hover, .pagination > .active > a:focus,
	.pagination > .active > span,
	.pagination > .active > span:hover,
	.pagination > .active > span:focus {
		z-index: 3;
		color: #fff;
		cursor: default;
		background-color: #2572b4;
		border-color: #2572b4; }
	.pagination > .disabled > span,
	.pagination > .disabled > span:hover,
	.pagination > .disabled > span:focus,
	.pagination > .disabled > a,
	.pagination > .disabled > a:hover,
	.pagination > .disabled > a:focus {
		color: #6f6f6f;
		cursor: not-allowed;
		background-color: #fff;
		border-color: #ddd; }

.pagination-lg > li > a,
.pagination-lg > li > span {
	padding: 10px 16px;
	font-size: 18px;
	line-height: 1.3333333; }

.pagination-lg > li:first-child > a,
.pagination-lg > li:first-child > span {
	border-top-left-radius: 6px;
	border-bottom-left-radius: 6px; }

.pagination-lg > li:last-child > a,
.pagination-lg > li:last-child > span {
	border-top-right-radius: 6px;
	border-bottom-right-radius: 6px; }

.pagination-sm > li > a,
.pagination-sm > li > span {
	padding: 5px 10px;
	font-size: 14px;
	line-height: 1.5; }

.pagination-sm > li:first-child > a,
.pagination-sm > li:first-child > span {
	border-top-left-radius: 3px;
	border-bottom-left-radius: 3px; }

.pagination-sm > li:last-child > a,
.pagination-sm > li:last-child > span {
	border-top-right-radius: 3px;
	border-bottom-right-radius: 3px; }

.pager {
	padding-left: 0;
	margin: 23px 0;
	text-align: center;
	list-style: none; }
	.pager:before, .pager:after {
		display: table;
		content: " "; }
	.pager:after {
		clear: both; }
	.pager li {
		display: inline; }
		.pager li > a,
		.pager li > span {
			display: inline-block;
			padding: 5px 14px;
			background-color: #eaebed;
			border: 1px solid #dcdee1;
			border-radius: 4px; }
		.pager li > a:hover,
		.pager li > a:focus {
			text-decoration: none;
			background-color: #d4d6da; }
	.pager .next > a,
	.pager .next > span {
		float: right; }
	.pager .previous > a,
	.pager .previous > span {
		float: left; }
	.pager .disabled > a,
	.pager .disabled > a:hover,
	.pager .disabled > a:focus,
	.pager .disabled > span {
		color: #6f6f6f;
		cursor: not-allowed;
		background-color: #eaebed; }

.label {
	display: inline;
	padding: .2em .6em .3em;
	font-size: 75%;
	font-weight: 700;
	line-height: 1;
	color: #fff;
	text-align: center;
	white-space: nowrap;
	vertical-align: baseline;
	border-radius: .25em; }
	.label:empty {
		display: none; }
	.btn .label {
		position: relative;
		top: -1px; }

a.label:hover, a.label:focus {
	color: #fff;
	text-decoration: none;
	cursor: pointer; }

.label-default {
	background-color: #6f6f6f; }
	.label-default[href]:hover, .label-default[href]:focus {
		background-color: #565555; }

.label-primary {
	background-color: #2572b4; }
	.label-primary[href]:hover, .label-primary[href]:focus {
		background-color: #1c578a; }

.label-success {
	background-color: #1b6c1c; }
	.label-success[href]:hover, .label-success[href]:focus {
		background-color: #114311; }

.label-info {
	background-color: #4d4d4d; }
	.label-info[href]:hover, .label-info[href]:focus {
		background-color: #343333; }

.label-warning {
	background-color: #f2d40d; }
	.label-warning[href]:hover, .label-warning[href]:focus {
		background-color: #c2aa0a; }

.label-danger {
	background-color: #bc3331; }
	.label-danger[href]:hover, .label-danger[href]:focus {
		background-color: #942826; }

.badge {
	display: inline-block;
	min-width: 10px;
	padding: 3px 7px;
	font-size: 14px;
	font-weight: bold;
	line-height: 1;
	color: #fff;
	text-align: center;
	white-space: nowrap;
	vertical-align: middle;
	background-color: #6f6f6f;
	border-radius: 10px; }
	.badge:empty {
		display: none; }
	.btn .badge {
		position: relative;
		top: -1px; }
	.btn-xs .badge, .btn-group-xs > .btn .badge,
	.btn-group-xs > .btn .badge {
		top: 0;
		padding: 1px 5px; }
	.list-group-item.active > .badge,
	.nav-pills > .active > a > .badge {
		color: #295376;
		background-color: #fff; }
	.list-group-item > .badge {
		float: right; }
	.list-group-item > .badge + .badge {
		margin-right: 5px; }
	.nav-pills > li > a > .badge {
		margin-left: 3px; }

a.badge:hover, a.badge:focus {
	color: #fff;
	text-decoration: none;
	cursor: pointer; }

.jumbotron {
	padding-top: 30px;
	padding-bottom: 30px;
	margin-bottom: 30px;
	color: inherit;
	background-color: #eeeeee; }
	.jumbotron h1,
	.jumbotron .h1 {
		color: inherit; }
	.jumbotron p {
		margin-bottom: 15px;
		font-size: 24px;
		font-weight: 200; }
	.jumbotron > hr {
		border-top-color: #d5d5d5; }
	.container .jumbotron,
	.container-fluid .jumbotron {
		padding-right: 15px;
		padding-left: 15px;
		border-radius: 6px; }
	.jumbotron .container {
		max-width: 100%; }
	@media screen and (min-width: 768px) {
		.jumbotron {
			padding-top: 48px;
			padding-bottom: 48px; }
			.container .jumbotron,
			.container-fluid .jumbotron {
				padding-right: 60px;
				padding-left: 60px; }
			.jumbotron h1,
			.jumbotron .h1 {
				font-size: 72px; } }

.thumbnail {
	display: block;
	padding: 4px;
	margin-bottom: 23px;
	line-height: 1.4375;
	background-color: #fff;
	border: 1px solid #ddd;
	border-radius: 4px;
	-webkit-transition: border 0.2s ease-in-out;
	transition: border 0.2s ease-in-out; }
	.thumbnail > img,
	.thumbnail a > img {
		display: block;
		max-width: 100%;
		height: auto;
		margin-right: auto;
		margin-left: auto; }
	.thumbnail .caption {
		padding: 9px;
		color: #333333; }

a.thumbnail:hover,
a.thumbnail:focus,
a.thumbnail.active {
	border-color: #295376; }

.alert {
	padding: 15px;
	margin-bottom: 23px;
	border: 1px solid transparent;
	border-radius: 4px; }
	.alert h4 {
		margin-top: 0;
		color: inherit; }
	.alert .alert-link {
		font-weight: bold; }
	.alert > p,
	.alert > ul {
		margin-bottom: 0; }
	.alert > p + p {
		margin-top: 5px; }

.alert-dismissable,
.alert-dismissible {
	padding-right: 35px; }
	.alert-dismissable .close,
	.alert-dismissible .close {
		position: relative;
		top: -2px;
		right: -21px;
		color: inherit; }

.alert-success {
	color: #3c763d;
	background-color: #dff0d8;
	border-color: #d6e9c6; }
	.alert-success hr {
		border-top-color: #c9e2b3; }
	.alert-success .alert-link {
		color: #2b542c; }

.alert-info {
	color: #31708f;
	background-color: #d9edf7;
	border-color: #bce8f1; }
	.alert-info hr {
		border-top-color: #a6e1ec; }
	.alert-info .alert-link {
		color: #245269; }

.alert-warning {
	color: #8a6d3b;
	background-color: #fcf8e3;
	border-color: #faebcc; }
	.alert-warning hr {
		border-top-color: #f7e1b5; }
	.alert-warning .alert-link {
		color: #66512c; }

.alert-danger {
	color: #a94442;
	background-color: #f2dede;
	border-color: #ebccd1; }
	.alert-danger hr {
		border-top-color: #e4b9c0; }
	.alert-danger .alert-link {
		color: #843534; }

@-webkit-keyframes progress-bar-stripes {
	from {
		background-position: 40px 0; }
	to {
		background-position: 0 0; } }

@keyframes progress-bar-stripes {
	from {
		background-position: 40px 0; }
	to {
		background-position: 0 0; } }

.progress {
	height: 23px;
	margin-bottom: 23px;
	overflow: hidden;
	background-color: #f5f5f5;
	border-radius: 4px;
	-webkit-box-shadow: inset 0 1px 2px rgba(0, 0, 0, 0.1);
	box-shadow: inset 0 1px 2px rgba(0, 0, 0, 0.1); }

.progress-bar {
	float: left;
	width: 0%;
	height: 100%;
	font-size: 14px;
	line-height: 23px;
	color: #fff;
	text-align: center;
	background-color: #2572b4;
	-webkit-box-shadow: inset 0 -1px 0 rgba(0, 0, 0, 0.15);
	box-shadow: inset 0 -1px 0 rgba(0, 0, 0, 0.15);
	-webkit-transition: width 0.6s ease;
	transition: width 0.6s ease; }

.progress-striped .progress-bar,
.progress-bar-striped {
	background-image: linear-gradient(45deg, rgba(255, 255, 255, 0.15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.15) 50%, rgba(255, 255, 255, 0.15) 75%, transparent 75%, transparent);
	background-size: 40px 40px; }

.progress.active .progress-bar,
.progress-bar.active {
	-webkit-animation: progress-bar-stripes 2s linear infinite;
	animation: progress-bar-stripes 2s linear infinite; }

.progress-bar-success {
	background-color: #1b6c1c; }
	.progress-striped .progress-bar-success {
		background-image: linear-gradient(45deg, rgba(255, 255, 255, 0.15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.15) 50%, rgba(255, 255, 255, 0.15) 75%, transparent 75%, transparent); }

.progress-bar-info {
	background-color: #4d4d4d; }
	.progress-striped .progress-bar-info {
		background-image: linear-gradient(45deg, rgba(255, 255, 255, 0.15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.15) 50%, rgba(255, 255, 255, 0.15) 75%, transparent 75%, transparent); }

.progress-bar-warning {
	background-color: #f2d40d; }
	.progress-striped .progress-bar-warning {
		background-image: linear-gradient(45deg, rgba(255, 255, 255, 0.15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.15) 50%, rgba(255, 255, 255, 0.15) 75%, transparent 75%, transparent); }

.progress-bar-danger {
	background-color: #bc3331; }
	.progress-striped .progress-bar-danger {
		background-image: linear-gradient(45deg, rgba(255, 255, 255, 0.15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.15) 50%, rgba(255, 255, 255, 0.15) 75%, transparent 75%, transparent); }

.media {
	margin-top: 15px; }
	.media:first-child {
		margin-top: 0; }

.media,
.media-body {
	overflow: hidden;
	zoom: 1; }

.media-body {
	width: 10000px; }

.media-object {
	display: block; }
	.media-object.img-thumbnail {
		max-width: none; }

.media-right,
.media > .pull-right {
	padding-left: 10px; }

.media-left,
.media > .pull-left {
	padding-right: 10px; }

.media-left,
.media-right,
.media-body {
	display: table-cell;
	vertical-align: top; }

.media-middle {
	vertical-align: middle; }

.media-bottom {
	vertical-align: bottom; }

.media-heading {
	margin-top: 0;
	margin-bottom: 5px; }

.media-list {
	padding-left: 0;
	list-style: none; }

.list-group {
	padding-left: 0;
	margin-bottom: 20px; }

.list-group-item {
	position: relative;
	display: block;
	padding: 10px 15px;
	margin-bottom: -1px;
	background-color: #fff;
	border: 1px solid #ddd; }
	.list-group-item:first-child {
		border-top-left-radius: 4px;
		border-top-right-radius: 4px; }
	.list-group-item:last-child {
		margin-bottom: 0;
		border-bottom-right-radius: 4px;
		border-bottom-left-radius: 4px; }
	.list-group-item.disabled, .list-group-item.disabled:hover, .list-group-item.disabled:focus {
		color: #6f6f6f;
		cursor: not-allowed;
		background-color: #eeeeee; }
		.list-group-item.disabled .list-group-item-heading, .list-group-item.disabled:hover .list-group-item-heading, .list-group-item.disabled:focus .list-group-item-heading {
			color: inherit; }
		.list-group-item.disabled .list-group-item-text, .list-group-item.disabled:hover .list-group-item-text, .list-group-item.disabled:focus .list-group-item-text {
			color: #6f6f6f; }
	.list-group-item.active, .list-group-item.active:hover, .list-group-item.active:focus {
		z-index: 2;
		color: #fff;
		background-color: #2572b4;
		border-color: #2572b4; }
		.list-group-item.active .list-group-item-heading,
		.list-group-item.active .list-group-item-heading > small,
		.list-group-item.active .list-group-item-heading > .small, .list-group-item.active:hover .list-group-item-heading,
		.list-group-item.active:hover .list-group-item-heading > small,
		.list-group-item.active:hover .list-group-item-heading > .small, .list-group-item.active:focus .list-group-item-heading,
		.list-group-item.active:focus .list-group-item-heading > small,
		.list-group-item.active:focus .list-group-item-heading > .small {
			color: inherit; }
		.list-group-item.active .list-group-item-text, .list-group-item.active:hover .list-group-item-text, .list-group-item.active:focus .list-group-item-text {
			color: #b5d5f0; }

a.list-group-item,
button.list-group-item {
	color: #555; }
	a.list-group-item .list-group-item-heading,
	button.list-group-item .list-group-item-heading {
		color: #333; }
	a.list-group-item:hover, a.list-group-item:focus,
	button.list-group-item:hover,
	button.list-group-item:focus {
		color: #555;
		text-decoration: none;
		background-color: #f5f5f5; }

button.list-group-item {
	width: 100%;
	text-align: left; }

.list-group-item-success {
	color: #3c763d;
	background-color: #dff0d8; }

a.list-group-item-success,
button.list-group-item-success {
	color: #3c763d; }
	a.list-group-item-success .list-group-item-heading,
	button.list-group-item-success .list-group-item-heading {
		color: inherit; }
	a.list-group-item-success:hover, a.list-group-item-success:focus,
	button.list-group-item-success:hover,
	button.list-group-item-success:focus {
		color: #3c763d;
		background-color: #d0e9c6; }
	a.list-group-item-success.active, a.list-group-item-success.active:hover, a.list-group-item-success.active:focus,
	button.list-group-item-success.active,
	button.list-group-item-success.active:hover,
	button.list-group-item-success.active:focus {
		color: #fff;
		background-color: #3c763d;
		border-color: #3c763d; }

.list-group-item-info {
	color: #31708f;
	background-color: #d9edf7; }

a.list-group-item-info,
button.list-group-item-info {
	color: #31708f; }
	a.list-group-item-info .list-group-item-heading,
	button.list-group-item-info .list-group-item-heading {
		color: inherit; }
	a.list-group-item-info:hover, a.list-group-item-info:focus,
	button.list-group-item-info:hover,
	button.list-group-item-info:focus {
		color: #31708f;
		background-color: #c4e3f3; }
	a.list-group-item-info.active, a.list-group-item-info.active:hover, a.list-group-item-info.active:focus,
	button.list-group-item-info.active,
	button.list-group-item-info.active:hover,
	button.list-group-item-info.active:focus {
		color: #fff;
		background-color: #31708f;
		border-color: #31708f; }

.list-group-item-warning {
	color: #8a6d3b;
	background-color: #fcf8e3; }

a.list-group-item-warning,
button.list-group-item-warning {
	color: #8a6d3b; }
	a.list-group-item-warning .list-group-item-heading,
	button.list-group-item-warning .list-group-item-heading {
		color: inherit; }
	a.list-group-item-warning:hover, a.list-group-item-warning:focus,
	button.list-group-item-warning:hover,
	button.list-group-item-warning:focus {
		color: #8a6d3b;
		background-color: #faf2cc; }
	a.list-group-item-warning.active, a.list-group-item-warning.active:hover, a.list-group-item-warning.active:focus,
	button.list-group-item-warning.active,
	button.list-group-item-warning.active:hover,
	button.list-group-item-warning.active:focus {
		color: #fff;
		background-color: #8a6d3b;
		border-color: #8a6d3b; }

.list-group-item-danger {
	color: #a94442;
	background-color: #f2dede; }

a.list-group-item-danger,
button.list-group-item-danger {
	color: #a94442; }
	a.list-group-item-danger .list-group-item-heading,
	button.list-group-item-danger .list-group-item-heading {
		color: inherit; }
	a.list-group-item-danger:hover, a.list-group-item-danger:focus,
	button.list-group-item-danger:hover,
	button.list-group-item-danger:focus {
		color: #a94442;
		background-color: #ebcccc; }
	a.list-group-item-danger.active, a.list-group-item-danger.active:hover, a.list-group-item-danger.active:focus,
	button.list-group-item-danger.active,
	button.list-group-item-danger.active:hover,
	button.list-group-item-danger.active:focus {
		color: #fff;
		background-color: #a94442;
		border-color: #a94442; }

.list-group-item-heading {
	margin-top: 0;
	margin-bottom: 5px; }

.list-group-item-text {
	margin-bottom: 0;
	line-height: 1.3; }

.panel {
	margin-bottom: 23px;
	background-color: #fff;
	border: 1px solid transparent;
	border-radius: 4px;
	-webkit-box-shadow: 0 1px 1px rgba(0, 0, 0, 0.05);
	box-shadow: 0 1px 1px rgba(0, 0, 0, 0.05); }

.panel-body {
	padding: 15px; }
	.panel-body:before, .panel-body:after {
		display: table;
		content: " "; }
	.panel-body:after {
		clear: both; }

.panel-heading {
	padding: 10px 15px;
	border-bottom: 1px solid transparent;
	border-top-left-radius: 3px;
	border-top-right-radius: 3px; }
	.panel-heading > .dropdown .dropdown-toggle {
		color: inherit; }

.panel-title {
	margin-top: 0;
	margin-bottom: 0;
	font-size: 18px;
	color: inherit; }
	.panel-title > a,
	.panel-title > small,
	.panel-title > .small,
	.panel-title > small > a,
	.panel-title > .small > a {
		color: inherit; }

.panel-footer {
	padding: 10px 15px;
	background-color: #f5f5f5;
	border-top: 1px solid #8e8e8e;
	border-bottom-right-radius: 3px;
	border-bottom-left-radius: 3px; }

.panel > .list-group,
.panel > .panel-collapse > .list-group {
	margin-bottom: 0; }
	.panel > .list-group .list-group-item,
	.panel > .panel-collapse > .list-group .list-group-item {
		border-width: 1px 0;
		border-radius: 0; }
	.panel > .list-group:first-child .list-group-item:first-child,
	.panel > .panel-collapse > .list-group:first-child .list-group-item:first-child {
		border-top: 0;
		border-top-left-radius: 3px;
		border-top-right-radius: 3px; }
	.panel > .list-group:last-child .list-group-item:last-child,
	.panel > .panel-collapse > .list-group:last-child .list-group-item:last-child {
		border-bottom: 0;
		border-bottom-right-radius: 3px;
		border-bottom-left-radius: 3px; }

.panel > .panel-heading + .panel-collapse > .list-group .list-group-item:first-child {
	border-top-left-radius: 0;
	border-top-right-radius: 0; }

.panel-heading + .list-group .list-group-item:first-child {
	border-top-width: 0; }

.list-group + .panel-footer {
	border-top-width: 0; }

.panel > .table,
.panel > .table-responsive > .table,
.panel > .panel-collapse > .table {
	margin-bottom: 0; }
	.panel > .table caption,
	.panel > .table-responsive > .table caption,
	.panel > .panel-collapse > .table caption {
		padding-right: 15px;
		padding-left: 15px; }

.panel > .table:first-child,
.panel > .table-responsive:first-child > .table:first-child {
	border-top-left-radius: 3px;
	border-top-right-radius: 3px; }
	.panel > .table:first-child > thead:first-child > tr:first-child,
	.panel > .table:first-child > tbody:first-child > tr:first-child,
	.panel > .table-responsive:first-child > .table:first-child > thead:first-child > tr:first-child,
	.panel > .table-responsive:first-child > .table:first-child > tbody:first-child > tr:first-child {
		border-top-left-radius: 3px;
		border-top-right-radius: 3px; }
		.panel > .table:first-child > thead:first-child > tr:first-child td:first-child,
		.panel > .table:first-child > thead:first-child > tr:first-child th:first-child,
		.panel > .table:first-child > tbody:first-child > tr:first-child td:first-child,
		.panel > .table:first-child > tbody:first-child > tr:first-child th:first-child,
		.panel > .table-responsive:first-child > .table:first-child > thead:first-child > tr:first-child td:first-child,
		.panel > .table-responsive:first-child > .table:first-child > thead:first-child > tr:first-child th:first-child,
		.panel > .table-responsive:first-child > .table:first-child > tbody:first-child > tr:first-child td:first-child,
		.panel > .table-responsive:first-child > .table:first-child > tbody:first-child > tr:first-child th:first-child {
			border-top-left-radius: 3px; }
		.panel > .table:first-child > thead:first-child > tr:first-child td:last-child,
		.panel > .table:first-child > thead:first-child > tr:first-child th:last-child,
		.panel > .table:first-child > tbody:first-child > tr:first-child td:last-child,
		.panel > .table:first-child > tbody:first-child > tr:first-child th:last-child,
		.panel > .table-responsive:first-child > .table:first-child > thead:first-child > tr:first-child td:last-child,
		.panel > .table-responsive:first-child > .table:first-child > thead:first-child > tr:first-child th:last-child,
		.panel > .table-responsive:first-child > .table:first-child > tbody:first-child > tr:first-child td:last-child,
		.panel > .table-responsive:first-child > .table:first-child > tbody:first-child > tr:first-child th:last-child {
			border-top-right-radius: 3px; }

.panel > .table:last-child,
.panel > .table-responsive:last-child > .table:last-child {
	border-bottom-right-radius: 3px;
	border-bottom-left-radius: 3px; }
	.panel > .table:last-child > tbody:last-child > tr:last-child,
	.panel > .table:last-child > tfoot:last-child > tr:last-child,
	.panel > .table-responsive:last-child > .table:last-child > tbody:last-child > tr:last-child,
	.panel > .table-responsive:last-child > .table:last-child > tfoot:last-child > tr:last-child {
		border-bottom-right-radius: 3px;
		border-bottom-left-radius: 3px; }
		.panel > .table:last-child > tbody:last-child > tr:last-child td:first-child,
		.panel > .table:last-child > tbody:last-child > tr:last-child th:first-child,
		.panel > .table:last-child > tfoot:last-child > tr:last-child td:first-child,
		.panel > .table:last-child > tfoot:last-child > tr:last-child th:first-child,
		.panel > .table-responsive:last-child > .table:last-child > tbody:last-child > tr:last-child td:first-child,
		.panel > .table-responsive:last-child > .table:last-child > tbody:last-child > tr:last-child th:first-child,
		.panel > .table-responsive:last-child > .table:last-child > tfoot:last-child > tr:last-child td:first-child,
		.panel > .table-responsive:last-child > .table:last-child > tfoot:last-child > tr:last-child th:first-child {
			border-bottom-left-radius: 3px; }
		.panel > .table:last-child > tbody:last-child > tr:last-child td:last-child,
		.panel > .table:last-child > tbody:last-child > tr:last-child th:last-child,
		.panel > .table:last-child > tfoot:last-child > tr:last-child td:last-child,
		.panel > .table:last-child > tfoot:last-child > tr:last-child th:last-child,
		.panel > .table-responsive:last-child > .table:last-child > tbody:last-child > tr:last-child td:last-child,
		.panel > .table-responsive:last-child > .table:last-child > tbody:last-child > tr:last-child th:last-child,
		.panel > .table-responsive:last-child > .table:last-child > tfoot:last-child > tr:last-child td:last-child,
		.panel > .table-responsive:last-child > .table:last-child > tfoot:last-child > tr:last-child th:last-child {
			border-bottom-right-radius: 3px; }

.panel > .panel-body + .table,
.panel > .panel-body + .table-responsive,
.panel > .table + .panel-body,
.panel > .table-responsive + .panel-body {
	border-top: 1px solid #ddd; }

.panel > .table > tbody:first-child > tr:first-child th,
.panel > .table > tbody:first-child > tr:first-child td {
	border-top: 0; }

.panel > .table-bordered,
.panel > .table-responsive > .table-bordered {
	border: 0; }
	.panel > .table-bordered > thead > tr > th:first-child,
	.panel > .table-bordered > thead > tr > td:first-child,
	.panel > .table-bordered > tbody > tr > th:first-child,
	.panel > .table-bordered > tbody > tr > td:first-child,
	.panel > .table-bordered > tfoot > tr > th:first-child,
	.panel > .table-bordered > tfoot > tr > td:first-child,
	.panel > .table-responsive > .table-bordered > thead > tr > th:first-child,
	.panel > .table-responsive > .table-bordered > thead > tr > td:first-child,
	.panel > .table-responsive > .table-bordered > tbody > tr > th:first-child,
	.panel > .table-responsive > .table-bordered > tbody > tr > td:first-child,
	.panel > .table-responsive > .table-bordered > tfoot > tr > th:first-child,
	.panel > .table-responsive > .table-bordered > tfoot > tr > td:first-child {
		border-left: 0; }
	.panel > .table-bordered > thead > tr > th:last-child,
	.panel > .table-bordered > thead > tr > td:last-child,
	.panel > .table-bordered > tbody > tr > th:last-child,
	.panel > .table-bordered > tbody > tr > td:last-child,
	.panel > .table-bordered > tfoot > tr > th:last-child,
	.panel > .table-bordered > tfoot > tr > td:last-child,
	.panel > .table-responsive > .table-bordered > thead > tr > th:last-child,
	.panel > .table-responsive > .table-bordered > thead > tr > td:last-child,
	.panel > .table-responsive > .table-bordered > tbody > tr > th:last-child,
	.panel > .table-responsive > .table-bordered > tbody > tr > td:last-child,
	.panel > .table-responsive > .table-bordered > tfoot > tr > th:last-child,
	.panel > .table-responsive > .table-bordered > tfoot > tr > td:last-child {
		border-right: 0; }
	.panel > .table-bordered > thead > tr:first-child > td,
	.panel > .table-bordered > thead > tr:first-child > th,
	.panel > .table-bordered > tbody > tr:first-child > td,
	.panel > .table-bordered > tbody > tr:first-child > th,
	.panel > .table-responsive > .table-bordered > thead > tr:first-child > td,
	.panel > .table-responsive > .table-bordered > thead > tr:first-child > th,
	.panel > .table-responsive > .table-bordered > tbody > tr:first-child > td,
	.panel > .table-responsive > .table-bordered > tbody > tr:first-child > th {
		border-bottom: 0; }
	.panel > .table-bordered > tbody > tr:last-child > td,
	.panel > .table-bordered > tbody > tr:last-child > th,
	.panel > .table-bordered > tfoot > tr:last-child > td,
	.panel > .table-bordered > tfoot > tr:last-child > th,
	.panel > .table-responsive > .table-bordered > tbody > tr:last-child > td,
	.panel > .table-responsive > .table-bordered > tbody > tr:last-child > th,
	.panel > .table-responsive > .table-bordered > tfoot > tr:last-child > td,
	.panel > .table-responsive > .table-bordered > tfoot > tr:last-child > th {
		border-bottom: 0; }

.panel > .table-responsive {
	margin-bottom: 0;
	border: 0; }

.panel-group {
	margin-bottom: 23px; }
	.panel-group .panel {
		margin-bottom: 0;
		border-radius: 4px; }
		.panel-group .panel + .panel {
			margin-top: 5px; }
	.panel-group .panel-heading {
		border-bottom: 0; }
		.panel-group .panel-heading + .panel-collapse > .panel-body,
		.panel-group .panel-heading + .panel-collapse > .list-group {
			border-top: 1px solid #8e8e8e; }
	.panel-group .panel-footer {
		border-top: 0; }
		.panel-group .panel-footer + .panel-collapse .panel-body {
			border-bottom: 1px solid #8e8e8e; }

.panel-default {
	border-color: #8e8e8e; }
	.panel-default > .panel-heading {
		color: #333333;
		background-color: #f5f5f5;
		border-color: #8e8e8e; }
		.panel-default > .panel-heading + .panel-collapse > .panel-body {
			border-top-color: #8e8e8e; }
		.panel-default > .panel-heading .badge {
			color: #f5f5f5;
			background-color: #333333; }
	.panel-default > .panel-footer + .panel-collapse > .panel-body {
		border-bottom-color: #8e8e8e; }

.panel-primary {
	border-color: #2572b4; }
	.panel-primary > .panel-heading {
		color: #fff;
		background-color: #2572b4;
		border-color: #2572b4; }
		.panel-primary > .panel-heading + .panel-collapse > .panel-body {
			border-top-color: #2572b4; }
		.panel-primary > .panel-heading .badge {
			color: #2572b4;
			background-color: #fff; }
	.panel-primary > .panel-footer + .panel-collapse > .panel-body {
		border-bottom-color: #2572b4; }

.panel-success {
	border-color: #629339; }
	.panel-success > .panel-heading {
		color: #3c763d;
		background-color: #dff0d8;
		border-color: #629339; }
		.panel-success > .panel-heading + .panel-collapse > .panel-body {
			border-top-color: #629339; }
		.panel-success > .panel-heading .badge {
			color: #dff0d8;
			background-color: #3c763d; }
	.panel-success > .panel-footer + .panel-collapse > .panel-body {
		border-bottom-color: #629339; }

.panel-info {
	border-color: #2392A9; }
	.panel-info > .panel-heading {
		color: #31708f;
		background-color: #d9edf7;
		border-color: #2392A9; }
		.panel-info > .panel-heading + .panel-collapse > .panel-body {
			border-top-color: #2392A9; }
		.panel-info > .panel-heading .badge {
			color: #d9edf7;
			background-color: #31708f; }
	.panel-info > .panel-footer + .panel-collapse > .panel-body {
		border-bottom-color: #2392A9; }

.panel-warning {
	border-color: #BA8312; }
	.panel-warning > .panel-heading {
		color: #8a6d3b;
		background-color: #fcf8e3;
		border-color: #BA8312; }
		.panel-warning > .panel-heading + .panel-collapse > .panel-body {
			border-top-color: #BA8312; }
		.panel-warning > .panel-heading .badge {
			color: #fcf8e3;
			background-color: #8a6d3b; }
	.panel-warning > .panel-footer + .panel-collapse > .panel-body {
		border-bottom-color: #BA8312; }

.panel-danger {
	border-color: #C16171; }
	.panel-danger > .panel-heading {
		color: #a94442;
		background-color: #f2dede;
		border-color: #C16171; }
		.panel-danger > .panel-heading + .panel-collapse > .panel-body {
			border-top-color: #C16171; }
		.panel-danger > .panel-heading .badge {
			color: #f2dede;
			background-color: #a94442; }
	.panel-danger > .panel-footer + .panel-collapse > .panel-body {
		border-bottom-color: #C16171; }

.embed-responsive {
	position: relative;
	display: block;
	height: 0;
	padding: 0;
	overflow: hidden; }
	.embed-responsive .embed-responsive-item,
	.embed-responsive iframe,
	.embed-responsive embed,
	.embed-responsive object,
	.embed-responsive video {
		position: absolute;
		top: 0;
		bottom: 0;
		left: 0;
		width: 100%;
		height: 100%;
		border: 0; }

.embed-responsive-16by9 {
	padding-bottom: 56.25%; }

.embed-responsive-4by3 {
	padding-bottom: 75%; }

.well {
	min-height: 20px;
	padding: 19px;
	margin-bottom: 20px;
	background-color: #f5f5f5;
	border: 1px solid #e3e3e3;
	border-radius: 4px;
	-webkit-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.05);
	box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.05); }
	.well blockquote {
		border-color: #ddd;
		border-color: rgba(0, 0, 0, 0.15); }

.well-lg {
	padding: 24px;
	border-radius: 6px; }

.well-sm {
	padding: 9px;
	border-radius: 3px; }

.close {
	float: right;
	font-size: 24px;
	font-weight: bold;
	line-height: 1;
	color: #000;
	text-shadow: 0 1px 0 #fff;
	filter: alpha(opacity=20);
	opacity: 0.2; }
	.close:hover, .close:focus {
		color: #000;
		text-decoration: none;
		cursor: pointer;
		filter: alpha(opacity=50);
		opacity: 0.5; }

button.close {
	padding: 0;
	cursor: pointer;
	background: transparent;
	border: 0;
	-webkit-appearance: none;
	-moz-appearance: none;
	     appearance: none; }

.modal-open {
	overflow: hidden; }

.modal {
	position: fixed;
	top: 0;
	right: 0;
	bottom: 0;
	left: 0;
	z-index: 1050;
	display: none;
	overflow: hidden;
	-webkit-overflow-scrolling: touch;
	outline: 0; }
	.modal.fade .modal-dialog {
		-webkit-transform: translate(0, -25%);
		transform: translate(0, -25%);
		-webkit-transition: -webkit-transform 0.3s ease-out;
		transition: -webkit-transform 0.3s ease-out;
		transition: transform 0.3s ease-out;
		transition: transform 0.3s ease-out, -webkit-transform 0.3s ease-out; }
	.modal.in .modal-dialog {
		-webkit-transform: translate(0, 0);
		transform: translate(0, 0); }

.modal-open .modal {
	overflow-x: hidden;
	overflow-y: auto; }

.modal-dialog {
	position: relative;
	width: auto;
	margin: 10px; }

.modal-content {
	position: relative;
	background-color: #fff;
	background-clip: padding-box;
	border: 1px solid #999;
	border: 1px solid rgba(0, 0, 0, 0.2);
	border-radius: 6px;
	-webkit-box-shadow: 0 3px 9px rgba(0, 0, 0, 0.5);
	box-shadow: 0 3px 9px rgba(0, 0, 0, 0.5);
	outline: 0; }

.modal-backdrop {
	position: fixed;
	top: 0;
	right: 0;
	bottom: 0;
	left: 0;
	z-index: 1040;
	background-color: #000; }
	.modal-backdrop.fade {
		filter: alpha(opacity=0);
		opacity: 0; }
	.modal-backdrop.in {
		filter: alpha(opacity=50);
		opacity: 0.5; }

.modal-header {
	padding: 15px;
	border-bottom: 1px solid #e5e5e5; }
	.modal-header:before, .modal-header:after {
		display: table;
		content: " "; }
	.modal-header:after {
		clear: both; }

.modal-header .close {
	margin-top: -2px; }

.modal-title {
	margin: 0;
	line-height: 1.4375; }

.modal-body {
	position: relative;
	padding: 15px; }

.modal-footer {
	padding: 15px;
	text-align: right;
	border-top: 1px solid #e5e5e5; }
	.modal-footer:before, .modal-footer:after {
		display: table;
		content: " "; }
	.modal-footer:after {
		clear: both; }
	.modal-footer .btn + .btn {
		margin-bottom: 0;
		margin-left: 5px; }
	.modal-footer .btn-group .btn + .btn {
		margin-left: -1px; }
	.modal-footer .btn-block + .btn-block {
		margin-left: 0; }

.modal-scrollbar-measure {
	position: absolute;
	top: -9999px;
	width: 50px;
	height: 50px;
	overflow: scroll; }

@media (min-width: 768px) {
	.modal-dialog {
		width: 600px;
		margin: 30px auto; }
	.modal-content {
		-webkit-box-shadow: 0 5px 15px rgba(0, 0, 0, 0.5);
		box-shadow: 0 5px 15px rgba(0, 0, 0, 0.5); }
	.modal-sm {
		width: 300px; } }

@media (min-width: 992px) {
	.modal-lg {
		width: 900px; } }

.tooltip {
	position: absolute;
	z-index: 1070;
	display: block;
	font-family: "Noto Sans", sans-serif;
	font-style: normal;
	font-weight: 400;
	line-height: 1.4375;
	line-break: auto;
	text-align: left;
	text-align: start;
	text-decoration: none;
	text-shadow: none;
	text-transform: none;
	letter-spacing: normal;
	word-break: normal;
	word-spacing: normal;
	word-wrap: normal;
	white-space: normal;
	font-size: 14px;
	filter: alpha(opacity=0);
	opacity: 0; }
	.tooltip.in {
		filter: alpha(opacity=90);
		opacity: 0.9; }
	.tooltip.top {
		padding: 5px 0;
		margin-top: -3px; }
	.tooltip.right {
		padding: 0 5px;
		margin-left: 3px; }
	.tooltip.bottom {
		padding: 5px 0;
		margin-top: 3px; }
	.tooltip.left {
		padding: 0 5px;
		margin-left: -3px; }
	.tooltip.top .tooltip-arrow {
		bottom: 0;
		left: 50%;
		margin-left: -5px;
		border-width: 5px 5px 0;
		border-top-color: #000; }
	.tooltip.top-left .tooltip-arrow {
		right: 5px;
		bottom: 0;
		margin-bottom: -5px;
		border-width: 5px 5px 0;
		border-top-color: #000; }
	.tooltip.top-right .tooltip-arrow {
		bottom: 0;
		left: 5px;
		margin-bottom: -5px;
		border-width: 5px 5px 0;
		border-top-color: #000; }
	.tooltip.right .tooltip-arrow {
		top: 50%;
		left: 0;
		margin-top: -5px;
		border-width: 5px 5px 5px 0;
		border-right-color: #000; }
	.tooltip.left .tooltip-arrow {
		top: 50%;
		right: 0;
		margin-top: -5px;
		border-width: 5px 0 5px 5px;
		border-left-color: #000; }
	.tooltip.bottom .tooltip-arrow {
		top: 0;
		left: 50%;
		margin-left: -5px;
		border-width: 0 5px 5px;
		border-bottom-color: #000; }
	.tooltip.bottom-left .tooltip-arrow {
		top: 0;
		right: 5px;
		margin-top: -5px;
		border-width: 0 5px 5px;
		border-bottom-color: #000; }
	.tooltip.bottom-right .tooltip-arrow {
		top: 0;
		left: 5px;
		margin-top: -5px;
		border-width: 0 5px 5px;
		border-bottom-color: #000; }

.tooltip-inner {
	max-width: 200px;
	padding: 3px 8px;
	color: #fff;
	text-align: center;
	background-color: #000;
	border-radius: 4px; }

.tooltip-arrow {
	position: absolute;
	width: 0;
	height: 0;
	border-color: transparent;
	border-style: solid; }

.popover {
	position: absolute;
	top: 0;
	left: 0;
	z-index: 1060;
	display: none;
	max-width: 276px;
	padding: 1px;
	font-family: "Noto Sans", sans-serif;
	font-style: normal;
	font-weight: 400;
	line-height: 1.4375;
	line-break: auto;
	text-align: left;
	text-align: start;
	text-decoration: none;
	text-shadow: none;
	text-transform: none;
	letter-spacing: normal;
	word-break: normal;
	word-spacing: normal;
	word-wrap: normal;
	white-space: normal;
	font-size: 16px;
	background-color: #fff;
	background-clip: padding-box;
	border: 1px solid #ccc;
	border: 1px solid rgba(0, 0, 0, 0.2);
	border-radius: 6px;
	-webkit-box-shadow: 0 5px 10px rgba(0, 0, 0, 0.2);
	box-shadow: 0 5px 10px rgba(0, 0, 0, 0.2); }
	.popover.top {
		margin-top: -10px; }
	.popover.right {
		margin-left: 10px; }
	.popover.bottom {
		margin-top: 10px; }
	.popover.left {
		margin-left: -10px; }
	.popover > .arrow {
		border-width: 11px; }
		.popover > .arrow, .popover > .arrow:after {
			position: absolute;
			display: block;
			width: 0;
			height: 0;
			border-color: transparent;
			border-style: solid; }
		.popover > .arrow:after {
			content: "";
			border-width: 10px; }
	.popover.top > .arrow {
		bottom: -11px;
		left: 50%;
		margin-left: -11px;
		border-top-color: #999999;
		border-top-color: rgba(0, 0, 0, 0.25);
		border-bottom-width: 0; }
		.popover.top > .arrow:after {
			bottom: 1px;
			margin-left: -10px;
			content: " ";
			border-top-color: #fff;
			border-bottom-width: 0; }
	.popover.right > .arrow {
		top: 50%;
		left: -11px;
		margin-top: -11px;
		border-right-color: #999999;
		border-right-color: rgba(0, 0, 0, 0.25);
		border-left-width: 0; }
		.popover.right > .arrow:after {
			bottom: -10px;
			left: 1px;
			content: " ";
			border-right-color: #fff;
			border-left-width: 0; }
	.popover.bottom > .arrow {
		top: -11px;
		left: 50%;
		margin-left: -11px;
		border-top-width: 0;
		border-bottom-color: #999999;
		border-bottom-color: rgba(0, 0, 0, 0.25); }
		.popover.bottom > .arrow:after {
			top: 1px;
			margin-left: -10px;
			content: " ";
			border-top-width: 0;
			border-bottom-color: #fff; }
	.popover.left > .arrow {
		top: 50%;
		right: -11px;
		margin-top: -11px;
		border-right-width: 0;
		border-left-color: #999999;
		border-left-color: rgba(0, 0, 0, 0.25); }
		.popover.left > .arrow:after {
			right: 1px;
			bottom: -10px;
			content: " ";
			border-right-width: 0;
			border-left-color: #fff; }

.popover-title {
	padding: 8px 14px;
	margin: 0;
	font-size: 16px;
	background-color: #f7f7f7;
	border-bottom: 1px solid #ebebeb;
	border-radius: 5px 5px 0 0; }

.popover-content {
	padding: 9px 14px; }

.carousel {
	position: relative; }

.carousel-inner {
	position: relative;
	width: 100%;
	overflow: hidden; }
	.carousel-inner > .item {
		position: relative;
		display: none;
		-webkit-transition: 0.6s ease-in-out left;
		transition: 0.6s ease-in-out left; }
		.carousel-inner > .item > img,
		.carousel-inner > .item > a > img {
			display: block;
			max-width: 100%;
			height: auto;
			line-height: 1; }
		@media all and (transform-3d), (-webkit-transform-3d) {
			.carousel-inner > .item {
				-webkit-transition: -webkit-transform 0.6s ease-in-out;
				transition: -webkit-transform 0.6s ease-in-out;
				transition: transform 0.6s ease-in-out;
				transition: transform 0.6s ease-in-out, -webkit-transform 0.6s ease-in-out;
				-webkit-backface-visibility: hidden;
				backface-visibility: hidden;
				-webkit-perspective: 1000px;
				perspective: 1000px; }
				.carousel-inner > .item.next, .carousel-inner > .item.active.right {
					-webkit-transform: translate3d(100%, 0, 0);
					transform: translate3d(100%, 0, 0);
					left: 0; }
				.carousel-inner > .item.prev, .carousel-inner > .item.active.left {
					-webkit-transform: translate3d(-100%, 0, 0);
					transform: translate3d(-100%, 0, 0);
					left: 0; }
				.carousel-inner > .item.next.left, .carousel-inner > .item.prev.right, .carousel-inner > .item.active {
					-webkit-transform: translate3d(0, 0, 0);
					transform: translate3d(0, 0, 0);
					left: 0; } }
	.carousel-inner > .active,
	.carousel-inner > .next,
	.carousel-inner > .prev {
		display: block; }
	.carousel-inner > .active {
		left: 0; }
	.carousel-inner > .next,
	.carousel-inner > .prev {
		position: absolute;
		top: 0;
		width: 100%; }
	.carousel-inner > .next {
		left: 100%; }
	.carousel-inner > .prev {
		left: -100%; }
	.carousel-inner > .next.left,
	.carousel-inner > .prev.right {
		left: 0; }
	.carousel-inner > .active.left {
		left: -100%; }
	.carousel-inner > .active.right {
		left: 100%; }

.carousel-control {
	position: absolute;
	top: 0;
	bottom: 0;
	left: 0;
	width: 15%;
	font-size: 20px;
	color: #fff;
	text-align: center;
	text-shadow: 0 1px 2px rgba(0, 0, 0, 0.6);
	background-color: rgba(0, 0, 0, 0);
	filter: alpha(opacity=50);
	opacity: 0.5; }
	.carousel-control.left {
		background-image: -webkit-gradient(linear, left top, right top, from(rgba(0, 0, 0, 0.5)), to(rgba(0, 0, 0, 0.0001)));
		background-image: linear-gradient(to right, rgba(0, 0, 0, 0.5) 0%, rgba(0, 0, 0, 0.0001) 100%);
		filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#80000000', endColorstr='#00000000', GradientType=1);
		background-repeat: repeat-x; }
	.carousel-control.right {
		right: 0;
		left: auto;
		background-image: -webkit-gradient(linear, left top, right top, from(rgba(0, 0, 0, 0.0001)), to(rgba(0, 0, 0, 0.5)));
		background-image: linear-gradient(to right, rgba(0, 0, 0, 0.0001) 0%, rgba(0, 0, 0, 0.5) 100%);
		filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#00000000', endColorstr='#80000000', GradientType=1);
		background-repeat: repeat-x; }
	.carousel-control:hover, .carousel-control:focus {
		color: #fff;
		text-decoration: none;
		outline: 0;
		filter: alpha(opacity=90);
		opacity: 0.9; }
	.carousel-control .icon-prev,
	.carousel-control .icon-next,
	.carousel-control .glyphicon-chevron-left,
	.carousel-control .glyphicon-chevron-right {
		position: absolute;
		top: 50%;
		z-index: 5;
		display: inline-block;
		margin-top: -10px; }
	.carousel-control .icon-prev,
	.carousel-control .glyphicon-chevron-left {
		left: 50%;
		margin-left: -10px; }
	.carousel-control .icon-next,
	.carousel-control .glyphicon-chevron-right {
		right: 50%;
		margin-right: -10px; }
	.carousel-control .icon-prev,
	.carousel-control .icon-next {
		width: 20px;
		height: 20px;
		font-family: serif;
		line-height: 1; }
	.carousel-control .icon-prev:before {
		content: "\2039"; }
	.carousel-control .icon-next:before {
		content: "\203a"; }

.carousel-indicators {
	position: absolute;
	bottom: 10px;
	left: 50%;
	z-index: 15;
	width: 60%;
	padding-left: 0;
	margin-left: -30%;
	text-align: center;
	list-style: none; }
	.carousel-indicators li {
		display: inline-block;
		width: 10px;
		height: 10px;
		margin: 1px;
		text-indent: -999px;
		cursor: pointer;
		background-color: #000 \9;
		background-color: rgba(0, 0, 0, 0);
		border: 1px solid #fff;
		border-radius: 10px; }
	.carousel-indicators .active {
		width: 12px;
		height: 12px;
		margin: 0;
		background-color: #fff; }

.carousel-caption {
	position: absolute;
	right: 15%;
	bottom: 20px;
	left: 15%;
	z-index: 10;
	padding-top: 20px;
	padding-bottom: 20px;
	color: #fff;
	text-align: center;
	text-shadow: 0 1px 2px rgba(0, 0, 0, 0.6); }
	.carousel-caption .btn {
		text-shadow: none; }

@media screen and (min-width: 768px) {
	.carousel-control .glyphicon-chevron-left,
	.carousel-control .glyphicon-chevron-right,
	.carousel-control .icon-prev,
	.carousel-control .icon-next {
		width: 30px;
		height: 30px;
		margin-top: -10px;
		font-size: 30px; }
	.carousel-control .glyphicon-chevron-left,
	.carousel-control .icon-prev {
		margin-left: -10px; }
	.carousel-control .glyphicon-chevron-right,
	.carousel-control .icon-next {
		margin-right: -10px; }
	.carousel-caption {
		right: 20%;
		left: 20%;
		padding-bottom: 30px; }
	.carousel-indicators {
		bottom: 20px; } }

.clearfix:before, .clearfix:after {
	display: table;
	content: " "; }

.clearfix:after {
	clear: both; }

.center-block {
	display: block;
	margin-right: auto;
	margin-left: auto; }

.pull-right {
	float: right !important; }

.pull-left {
	float: left !important; }

.hide {
	display: none !important; }

.show {
	display: block !important; }

.invisible {
	visibility: hidden; }

.text-hide {
	font: 0/0 a;
	color: transparent;
	text-shadow: none;
	background-color: transparent;
	border: 0; }

.hidden {
	display: none !important; }

.affix {
	position: fixed; }

@-ms-viewport {
	width: device-width; }

.visible-xs {
	display: none !important; }

.visible-sm {
	display: none !important; }

.visible-md {
	display: none !important; }

.visible-lg {
	display: none !important; }

.visible-xs-block,
.visible-xs-inline,
.visible-xs-inline-block,
.visible-sm-block,
.visible-sm-inline,
.visible-sm-inline-block,
.visible-md-block,
.visible-md-inline,
.visible-md-inline-block,
.visible-lg-block,
.visible-lg-inline,
.visible-lg-inline-block {
	display: none !important; }

@media (max-width: 767px) {
	.visible-xs {
		display: block !important; }
	table.visible-xs {
		display: table !important; }
	tr.visible-xs {
		display: table-row !important; }
	th.visible-xs,
	td.visible-xs {
		display: table-cell !important; } }

@media (max-width: 767px) {
	.visible-xs-block {
		display: block !important; } }

@media (max-width: 767px) {
	.visible-xs-inline {
		display: inline !important; } }

@media (max-width: 767px) {
	.visible-xs-inline-block {
		display: inline-block !important; } }

@media (min-width: 768px) and (max-width: 991px) {
	.visible-sm {
		display: block !important; }
	table.visible-sm {
		display: table !important; }
	tr.visible-sm {
		display: table-row !important; }
	th.visible-sm,
	td.visible-sm {
		display: table-cell !important; } }

@media (min-width: 768px) and (max-width: 991px) {
	.visible-sm-block {
		display: block !important; } }

@media (min-width: 768px) and (max-width: 991px) {
	.visible-sm-inline {
		display: inline !important; } }

@media (min-width: 768px) and (max-width: 991px) {
	.visible-sm-inline-block {
		display: inline-block !important; } }

@media (min-width: 992px) and (max-width: 1199px) {
	.visible-md {
		display: block !important; }
	table.visible-md {
		display: table !important; }
	tr.visible-md {
		display: table-row !important; }
	th.visible-md,
	td.visible-md {
		display: table-cell !important; } }

@media (min-width: 992px) and (max-width: 1199px) {
	.visible-md-block {
		display: block !important; } }

@media (min-width: 992px) and (max-width: 1199px) {
	.visible-md-inline {
		display: inline !important; } }

@media (min-width: 992px) and (max-width: 1199px) {
	.visible-md-inline-block {
		display: inline-block !important; } }

@media (min-width: 1200px) {
	.visible-lg {
		display: block !important; }
	table.visible-lg {
		display: table !important; }
	tr.visible-lg {
		display: table-row !important; }
	th.visible-lg,
	td.visible-lg {
		display: table-cell !important; } }

@media (min-width: 1200px) {
	.visible-lg-block {
		display: block !important; } }

@media (min-width: 1200px) {
	.visible-lg-inline {
		display: inline !important; } }

@media (min-width: 1200px) {
	.visible-lg-inline-block {
		display: inline-block !important; } }

@media (max-width: 767px) {
	.hidden-xs {
		display: none !important; } }

@media (min-width: 768px) and (max-width: 991px) {
	.hidden-sm {
		display: none !important; } }

@media (min-width: 992px) and (max-width: 1199px) {
	.hidden-md {
		display: none !important; } }

@media (min-width: 1200px) {
	.hidden-lg {
		display: none !important; } }

.visible-print {
	display: none !important; }

@media print {
	.visible-print {
		display: block !important; }
	table.visible-print {
		display: table !important; }
	tr.visible-print {
		display: table-row !important; }
	th.visible-print,
	td.visible-print {
		display: table-cell !important; } }

.visible-print-block {
	display: none !important; }
	@media print {
		.visible-print-block {
			display: block !important; } }

.visible-print-inline {
	display: none !important; }
	@media print {
		.visible-print-inline {
			display: inline !important; } }

.visible-print-inline-block {
	display: none !important; }
	@media print {
		.visible-print-inline-block {
			display: inline-block !important; } }

@media print {
	.hidden-print {
		display: none !important; } }

/*
  WET-BOEW
  @title: Bootstrap overrides for WET-BOEW
 */
/*
  WET-BOEW
  @title: Bootstrap overrides for WET-BOEW - Helper - Variables
 */
/*
 *  Firefox-safe line height on input[type="reset|button|submit"]
 */
/*
	WET-BOEW
	@title: Bootstrap overrides for WET-BOEW - Core CSS
 */
/*! Placeholders */
a.btn, .nav a {
	text-decoration: none; }

/*
 *  Link colour and decoration
 */
a {
	text-decoration: underline; }
	a:visited {
		color: #7834bc; }
	a:not([href]) {
		color: inherit;
		text-decoration: none; }
		a:not([href]):hover, a:not([href]):focus {
			color: inherit;
			outline: none;
			text-decoration: none; }

@media (min-width: 768px) {
	.dl-horizontal.brdr-0 dt,
	.dl-horizontal.brdr-0 dd {
		border: 0 !important; }
	.dl-horizontal dt {
		border-top: 1px solid #ccc;
		padding: 10px 10px 10px 0;
		text-align: left;
		white-space: normal; }
	.dl-horizontal dd {
		border-top: 1px solid #ccc;
		margin-bottom: 3px;
		margin-left: 160px;
		padding: 10px 10px 10px 0; }
	.dl-horizontal dt + dd {
		padding-bottom: 0; } }

/*
 *  Abbreviations with title attributes
 *  Workaround for abbreviations with titles using solid underlines in IE11/Edge in Bootstrap 3.4.0 (via normalize.css 4.0.1-8.0.1):
 *  - Use a dotted underline in browsers that support it (e.g. Firefox, Chrome, etc...)
 *  - Fallback on a dotted bottom border in browsers that don't support it (e.g. IE11, Edge, etc...)
 *  Source: https://github.com/necolas/normalize.css/pull/738#issuecomment-387549760
 *  Created by: @mattbrundage
 */
abbr[title] {
	border-bottom: 1px dotted;
	text-decoration: none; }

@supports ((-webkit-text-decoration: underline dotted) or (text-decoration: underline dotted)) {
	abbr[title] {
		border-bottom: 0;
		-webkit-text-decoration: underline dotted;
		        text-decoration: underline dotted;
		-webkit-text-decoration-skip-ink: none;
		        text-decoration-skip-ink: none; } }

/*
 * Code
 */
code {
	white-space: normal; }

/*
 * Adding space for definition list items
 */
dt {
	margin-bottom: 3px; }

dd {
	margin-bottom: 15px; }

/*
 *  Blockquote font size
 */
blockquote {
	font-size: 16px; }

/*
 *  Right-to-left support
 */
[dir=rtl] .list-unstyled {
	padding-right: 0; }

mark {
	background-color: #ff0;
	color: #000;
	font-weight: 700; }

[hidden] {
	display: none !important; }

q:before, q:after {
	content: ""; }

/*
	WET-BOEW
	@title: Bootstrap overrides for WET-BOEW - Core CSS - button
 */
.btn-default:visited {
	color: #335075; }

.btn-primary:visited {
	color: #fff; }

.btn-success:visited {
	color: #fff; }

.btn-info:visited {
	color: #fff; }

.btn-warning:visited {
	color: #000; }

.btn-danger:visited {
	color: #fff; }

/*
 *  Use button border style 'outset' to give buttons depth, except when disabled
 */
.btn {
	border-style: outset;
	/*
	 * These two property overrides should be recommended upstream to
	 * Bootstrap as a fix for button wrapping (see wet-boew/wet-boew#4454)
	 */
	height: auto;
	min-height: 36px;
	min-width: 36px;
	white-space: normal; }

/*
	WET-BOEW
	@title: Bootstrap overrides for WET-BOEW - Core CSS - heading
 */
/*! Placeholders */
h1,
.h1, h2,
.h2, h3,
.h3, h4,
.h4, h5,
.h5, h6,
.h6 {
	font-weight: 700; }

h1,
.h1, h2,
.h2 {
	margin-top: 38px; }

/*
 *  Heading top margins
 */
h3, .h3 {
	margin-top: 32px; }

h4, .h4 {
	margin-top: 26px; }

h5, .h5 {
	margin-top: 23px; }

h6, .h6 {
	margin-top: 21px; }

/*
	WET-BOEW
	@title: Bootstrap overrides for WET-BOEW - Core CSS - table
 */
caption {
	color: #333;
	font-size: 1.1em;
	font-weight: bold;
	text-align: center; }

.table-responsive > .table, th, td {
	white-space: normal; }

/*
	WET-BOEW
	@title: Bootstrap overrides for WET-BOEW - Core CSS - forms
 */
/*! Placeholders */
.btn.disabled, .btn[disabled], fieldset[disabled] .btn {
	border-style: solid; }

/*
 *  Firefox-safe line height on input[type="reset|button|submit"]
 */
input[type="reset"], input[type="button"], input[type="submit"] {
	height: 37px; }
	input[type="reset"].btn-lg, .btn-group-lg > input.btn[type="reset"], input[type="reset"].input-lg, .input-group-lg > input.form-control[type="reset"],
	.input-group-lg > input.input-group-addon[type="reset"],
	.input-group-lg > .input-group-btn > input.btn[type="reset"], input[type="button"].btn-lg, .btn-group-lg > input.btn[type="button"], input[type="button"].input-lg, .input-group-lg > input.form-control[type="button"],
	.input-group-lg > input.input-group-addon[type="button"],
	.input-group-lg > .input-group-btn > input.btn[type="button"], input[type="submit"].btn-lg, .btn-group-lg > input.btn[type="submit"], input[type="submit"].input-lg, .input-group-lg > input.form-control[type="submit"],
	.input-group-lg > input.input-group-addon[type="submit"],
	.input-group-lg > .input-group-btn > input.btn[type="submit"] {
		height: 46px; }
	input[type="reset"].btn-sm, .btn-group-sm > input.btn[type="reset"], input[type="reset"].input-sm, .input-group-sm > input.form-control[type="reset"],
	.input-group-sm > input.input-group-addon[type="reset"],
	.input-group-sm > .input-group-btn > input.btn[type="reset"], input[type="button"].btn-sm, .btn-group-sm > input.btn[type="button"], input[type="button"].input-sm, .input-group-sm > input.form-control[type="button"],
	.input-group-sm > input.input-group-addon[type="button"],
	.input-group-sm > .input-group-btn > input.btn[type="button"], input[type="submit"].btn-sm, .btn-group-sm > input.btn[type="submit"], input[type="submit"].input-sm, .input-group-sm > input.form-control[type="submit"],
	.input-group-sm > input.input-group-addon[type="submit"],
	.input-group-sm > .input-group-btn > input.btn[type="submit"] {
		height: 33px; }
	input[type="reset"].btn-xs, .btn-group-xs > input.btn[type="reset"], input[type="button"].btn-xs, .btn-group-xs > input.btn[type="button"], input[type="submit"].btn-xs, .btn-group-xs > input.btn[type="submit"] {
		height: 25px; }

/*
 *  Form control width
 *
 *  Default should be representative of the expected length of input.
 *  Full width should be only for cases when the expected length of input is
 *  greater than the available width.
 *  height:37px; rule of Bootstrap was overwritten by height: auto; first
 *  then a min-height specified, in order to address the issue #8492. July 2019.
 */
input[type=button], input[type=reset], input[type=submit] {
	height: auto;
	min-height: 37px; }

.form-control {
	height: auto;
	max-width: 100%;
	min-height: 37px;
	width: auto; }

/*
 * Explicit labels for checkbox and radio button inputs
 *
 * Allow the use of horizontal explicit labels instead of the default implicit
 * labelling pattern for checkbox and radio button inputs provided by Bootstrap.
 */
.form-inline .label-inline {
	position: relative;
	vertical-align: middle; }
	.form-inline .label-inline label {
		font-weight: 400;
		margin-bottom: 0px;
		padding-left: 2px; }

/*
 *  Fieldset/legend border position
 *
 *  Bootstrap puts the border below the legend which creates a visual
 *  separation between the legend and the fields to which it relates. Putting
 *  the border above eliminates that visual separation. Putting it on the
 *  fieldset element instead ensures that all fieldsets will have a separation
 *  even when no legend is used.
 */
legend {
	border-bottom: 0;
	float: left; }

fieldset {
	border-top: 1px solid #e5e5e5;
	padding-top: 10px;
	/*
	 *  Allows fieldSet/legend to have a bottom border under legend title
	 *  https://github.com/wet-boew/wet-boew/issues/7766
	 */
	/*
	 *  Fieldset/legend as a label for a group of checkboxes or radio buttons
	 *  https://github.com/wet-boew/wet-boew/issues/5797
	 */ }
	fieldset:first-child {
		border-top: 0; }
	fieldset.legend-brdr-bttm {
		border-top: 0; }
		fieldset.legend-brdr-bttm legend {
			border-bottom: 1px solid #e5e5e5;
			float: none;
			margin-bottom: 10px; }
	fieldset.chkbxrdio-grp {
		border-top: 0;
		padding-top: 0; }
		fieldset.chkbxrdio-grp legend {
			font-size: 16px;
			font-weight: bold;
			margin-bottom: 5px; }

/*
	WET-BOEW
	@title: Bootstrap overrides for WET-BOEW - Components
 */
/*! Placeholders */
.pagination > li:first-child [rel="prev"]:before,
.pager > li:first-child [rel="prev"]:before, [dir=rtl] .pagination [rel="next"]:before,
[dir=rtl] .pager [rel="next"]:before, .dataTables_wrapper .dataTables_paginate .paginate_button.previous:before, [dir=rtl] .dataTables_wrapper .dataTables_paginate .paginate_button.next:before, .pagination > li:last-child [rel="next"]:after,
.pager > li:last-child [rel="next"]:after, [dir=rtl] .pagination [rel="prev"]:after,
[dir=rtl] .pager [rel="prev"]:after, .dataTables_wrapper .dataTables_paginate .paginate_button.next:after, [dir=rtl] .dataTables_wrapper .dataTables_paginate .paginate_button.previous:after, table.dataTable thead .sorting-icons:before, table.dataTable thead .sorting-icons:after {
	content: " ";
	font-family: "Glyphicons Halflings";
	font-weight: 400;
	line-height: 1em;
	position: relative;
	top: .1em; }

.pagination > li:first-child [rel="prev"]:before,
.pager > li:first-child [rel="prev"]:before, [dir=rtl] .pagination [rel="next"]:before,
[dir=rtl] .pager [rel="next"]:before, .dataTables_wrapper .dataTables_paginate .paginate_button.previous:before, [dir=rtl] .dataTables_wrapper .dataTables_paginate .paginate_button.next:before {
	content: "\e091";
	margin-right: .5em; }

.pagination > li:last-child [rel="next"]:after,
.pager > li:last-child [rel="next"]:after, [dir=rtl] .pagination [rel="prev"]:after,
[dir=rtl] .pager [rel="prev"]:after, .dataTables_wrapper .dataTables_paginate .paginate_button.next:after, [dir=rtl] .dataTables_wrapper .dataTables_paginate .paginate_button.previous:after {
	content: "\e092";
	margin-left: .5em; }

/*
 * btn-xs should be equal to btn-sm in >v4.0.*
*/
.btn-group-xs .btn,
.btn.btn-xs,
.btn-group-xs > .btn {
	min-height: 0; }

.dropdown-menu > li > a:visited {
	color: #333333; }

.nav > li > a:visited {
	color: #295376; }

.nav-pills > li.active > a:visited {
	color: #fff; }

.navbar-default .navbar-nav > li > a:visited {
	color: #777; }

@media (max-width: 767px) {
	.navbar-default .open .dropdown-menu > li > a {
		color: #777; } }

.navbar-default .navbar-link:visited {
	color: #777; }

.navbar-inverse .navbar-nav > li > a:visited {
	color: #959595; }

@media (max-width: 767px) {
	.navbar-inverse .open .dropdown-menu > li > a:visited {
		color: #959595; } }

.navbar-inverse .navbar-link:visited {
	color: #959595; }

/*
 *  Pagination
 *    * Add left/right arrows to previous/next buttons
 *    * Increase size of the pagination buttons
 *    * Prevent contrast ratio issues on active placeholder links
 */
.pagination > li > a,
.pager > li > a {
	cursor: pointer;
	display: inline-block;
	margin-bottom: .5em;
	padding: 10px 16px; }

.pagination > li.active > a,
.pager > li.active > a {
	cursor: default; }

.pagination > li.disabled + li > a,
.pager > li.disabled + li > a {
	border-top-left-radius: 4px;
	border-bottom-left-radius: 4px; }

.pager > li > a {
	text-decoration: none; }

.pager > li > a:hover, .pager > li > a:focus,
.pager > li > span:hover,
.pager > li > span:focus {
	border-color: #bbbfc5;
	color: #335075; }

.pagination > .active {
	color: #fff; }

/*
 *  Right-to-left support
 */
[dir=rtl] .pagination [rel="prev"],
[dir=rtl] .pager [rel="prev"] {
	border-top-left-radius: 0;
	border-bottom-left-radius: 0;
	border-top-right-radius: 4px;
	border-bottom-right-radius: 4px; }

[dir=rtl] .pagination [rel="next"],
[dir=rtl] .pager [rel="next"] {
	border-top-left-radius: 4px;
	border-bottom-left-radius: 4px;
	border-top-right-radius: 0;
	border-bottom-right-radius: 0; }

[dir=rtl] .pagination > li,
[dir=rtl] .pager > li {
	float: right; }
	[dir=rtl] .pagination > li.disabled + li > a,
	[dir=rtl] .pager > li.disabled + li > a {
		border-top-left-radius: 0;
		border-bottom-left-radius: 0;
		border-top-right-radius: 4px;
		border-bottom-right-radius: 4px; }

/*
	WET-BOEW
	@title: Bootstrap overrides for WET-BOEW - Helper - Placeholders
 */
/*
 *  Alerts and labels
 */
.alert, .label {
	border-radius: 0;
	border-style: solid;
	border-width: 0 0 0 4px; }

.alert-success, .alert-info, .alert-warning, .alert-danger, .label-default, .label-default[href]:hover, .label-default[href]:focus, .label-default[href]:active, .label-primary, .label-primary[href]:hover, .label-primary[href]:focus, .label-primary[href]:active, .label-success, .label-success[href]:hover, .label-success[href]:focus, .label-success[href]:active, .label-info, .label-info[href]:hover, .label-info[href]:focus, .label-info[href]:active, .label-warning, .label-warning[href]:hover, .label-warning[href]:focus, .label-warning[href]:active, .label-danger, .label-danger[href]:hover, .label-danger[href]:focus, .label-danger[href]:active {
	color: #000; }

.label-default[href]:hover, .label-default[href]:focus, .label-default[href]:active, .label-primary[href]:hover, .label-primary[href]:focus, .label-primary[href]:active, .label-success[href]:hover, .label-success[href]:focus, .label-success[href]:active, .label-info[href]:hover, .label-info[href]:focus, .label-info[href]:active, .label-warning[href]:hover, .label-warning[href]:focus, .label-warning[href]:active, .label-danger[href]:hover, .label-danger[href]:focus, .label-danger[href]:active {
	text-decoration: underline; }

.label-default, .label-default[href]:hover, .label-default[href]:focus, .label-default[href]:active {
	background: #eee;
	border-color: #acacac; }

.label-primary, .label-primary[href]:hover, .label-primary[href]:focus, .label-primary[href]:active {
	background: #e8f2f4;
	border-color: #083c6c; }

.alert-success, .label-success, .label-success[href]:hover, .label-success[href]:focus, .label-success[href]:active, details.alert.alert-success, details.alert.alert-success[open] {
	background: #d8eeca;
	border-color: #278400; }

.alert-info, .label-info, .label-info[href]:hover, .label-info[href]:focus, .label-info[href]:active, details.alert.alert-info, details.alert.alert-info[open] {
	background: #d7faff;
	border-color: #269abc; }

.alert-warning, .label-warning, .label-warning[href]:hover, .label-warning[href]:focus, .label-warning[href]:active, details.alert.alert-warning, details.alert.alert-warning[open] {
	background: #f9f4d4;
	border-color: #f90; }

.alert-danger, .label-danger, .label-danger[href]:hover, .label-danger[href]:focus, .label-danger[href]:active, details.alert.alert-danger, details.alert.alert-danger[open] {
	background: #f3e9e8;
	border-color: #d3080c; }

/*
  WET-BOEW
  @title: Bootstrap overrides for WET-BOEW - Components - Alert
 */
/*
 *	Override the design of alerts and labels
 */
.alert > :first-child {
	margin-left: 1.2em;
	margin-top: auto; }
	.alert > :first-child:before {
		display: inline-block;
		font-family: "Glyphicons Halflings";
		margin-left: -1.3em;
		position: absolute; }

.alert > strong:first-child,
.alert > em:first-child,
.alert > span:first-child {
	display: inline-block; }

.alert-success > :first-child:before {
	color: #278400;
	content: "\e084"; }

.alert-info > :first-child:before {
	color: #269abc;
	content: "\e086"; }

.alert-warning > :first-child:before {
	color: #f90;
	content: "\e107"; }

.alert-danger > :first-child:before {
	color: #d3080c;
	content: "\e101"; }

/*
 *  Right-to-left support
 */
[dir=rtl] .alert > :first-child {
	margin-left: auto;
	margin-right: 1.2em; }
	[dir=rtl] .alert > :first-child:before {
		margin-left: auto;
		margin-right: -1.3em; }

[dir=rtl] details.alert {
	padding-right: 45px; }
	[dir=rtl] details.alert:before {
		margin-right: -1.3em; }
	[dir=rtl] details.alert > * {
		margin-right: .7em; }
	[dir=rtl] details.alert > :first-child {
		margin-right: .4em; }

/*
  WET-BOEW
  @title: Bootstrap overrides for WET-BOEW - Components - Alert
 */
/*
 *	Override the design of alerts and labels
 */
/*
  WET-BOEW
  @title: Bootstrap 4 suplemental style for WET-BOEW
 */
/* Spacing */
.p-0 {
	padding: 0 !important; }

.pl-2,
.px-2 {
	padding-left: 5px !important; }

.pr-2,
.px-2 {
	padding-right: 5px !important; }

.pt-4,
.py-4 {
	padding-top: 30px !important; }

.pb-4,
.py-4 {
	padding-bottom: 30px !important; }

.mt-auto {
	margin-top: auto !important; }

/* Stretched link */
.stretched-link:after {
	background-color: rgba(0, 0, 0, 0);
	bottom: 0;
	content: "";
	left: 0;
	pointer-events: auto;
	position: absolute;
	right: 0;
	top: 0;
	z-index: 1; }

/* Sizing */
.h-100 {
	height: 100% !important; }

/* Positioning */
.position-relative {
	position: relative !important; }

/* Flexbox */
.d-flex {
	display: -webkit-box !important;
	display: -ms-flexbox !important;
	display: flex !important; }

.flex-column {
	-webkit-box-orient: vertical !important;
	-webkit-box-direction: normal !important;
	    -ms-flex-direction: column !important;
	        flex-direction: column !important; }

.align-items-center {
	-webkit-box-align: center !important;
	    -ms-flex-align: center !important;
	        align-items: center !important; }

.align-self-center {
	-ms-flex-item-align: center !important;
	    align-self: center !important; }

.align-self-end {
	-ms-flex-item-align: end !important;
	    align-self: flex-end !important; }

/* Vertical alignment */
.align-top {
	vertical-align: top !important; }

.align-middle {
	vertical-align: middle !important; }

.align-bottom {
	vertical-align: bottom !important; }

/* Color scheme */
.text-white, a.text-white:visited {
	color: #fff; }

a.text-white:hover, a.text-white:focus {
	color: #b3ffff; }

.btn.text-white:hover, .btn.text-white:focus {
	color: #b3ffff; }

/* WET Core */
/*
 * Web Experience Toolkit (WET) / Boîte à outils de l'expérience Web (BOEW)
 * wet-boew.github.io/wet-boew/License-en.html / wet-boew.github.io/wet-boew/Licence-fr.html
 */
/*! Global and helpers */
/*
 * Web Experience Toolkit (WET) / Boîte à outils de l'expérience Web (BOEW)
 * wet-boew.github.io/wet-boew/License-en.html / wet-boew.github.io/wet-boew/Licence-fr.html
 */
/*
 * HOW TO USE THIS FILE
 * Use this file to override Bootstrap variables and WET custom variables.
 * If there is a Bootstrap variable not shown here that you want to override, go to "../node_modules/bootstrap-sass/assets/stylesheets/bootstrap/variables" to view the variables that you can override. Simply copy and paste the variable and its applicable section (if applicable) from the Bootstrap file into this override file and override the variables as applicable.
 */
/*
  WET-BOEW
  @title: Bootstrap overrides for WET-BOEW - Helper - Variables
 */
/*
 *  Firefox-safe line height on input[type="reset|button|submit"]
 */
/*
  WET-BOEW
  @title: Helper - Global mixin
 */
/*
  WET-BOEW
  @title: Proximity CSS - Helper mixin
 */
/*
  WET-BOEW
  @title: Helper - Global Placeholders
 */
.pagination.disabled,
.pager.disabled, .pagination > li.disabled,
.pager > li.disabled, [dir=rtl] .pagination [rel="prev"]:before,
[dir=rtl] .pager [rel="prev"]:before, [dir=rtl] .pagination [rel="next"]:after,
[dir=rtl] .pager [rel="next"]:after, #wb-bc li:first-child:before, [dir=rtl] #wb-bc li:first-child:before, #mb-pnl .modal-body h2, table.dataTable thead .sorting-icons, table.dataTable thead .sorting_asc_disabled .sorting-icons:before, table.dataTable thead .sorting_desc_disabled .sorting-icons:after, .dataTables_wrapper .dataTables_paginate .paginate_button.disabled, [dir=rtl] .dataTables_wrapper .dataTables_paginate .paginate_button.previous:before, [dir=rtl] .dataTables_wrapper .dataTables_paginate .paginate_button.next:after, [dir=rtl] .dataTables_wrapper .dataTables_paginate .paginate_button.disabled, .wb-tabs.carousel-s1 [role="tablist"] > li, .wb-tabs.carousel-s2 [role="tablist"] > li {
	display: none; }

.wb-menu .sm.open li, .wb-disable .wb-tabs > details, .wb-disable .wb-tabs > .tabpanels > details {
	display: block; }

.wb-disable .mfp-hide, .wb-disable #wb-srch, .wb-disable #wb-sm, .wb-disable #wb-sec, .wb-disable #wb-info, .wb-disable .wb-overlay {
	display: block !important; }

.wb-menu .menu > li a, .wb-menu .menu > li a:hover, .wb-menu .menu > li a:focus, .wb-menu .active > a {
	text-decoration: none; }

.wb-mltmd.video.waiting .display:after, .wb-enable .wb-twitter .twitter-timeline:after, .geomap-progress:after, .wb-mltmd.video:not(.playing):not(.waiting) .display:after, .wb-mltmd.video.waiting .display:before, .wb-enable .wb-twitter .twitter-timeline:before, .geomap-progress:before, .wb-mltmd.video:not(.playing):not(.waiting) .display:before {
	bottom: 0;
	content: " ";
	height: 100px;
	left: 0;
	margin: auto;
	position: absolute;
	right: 0;
	top: 0;
	width: 100px; }

.wb-mltmd.video.waiting .display:after, .wb-enable .wb-twitter .twitter-timeline:after, .geomap-progress:after, .wb-mltmd.video:not(.playing):not(.waiting) .display:after {
	z-index: 1; }

.wb-mltmd.video.waiting .display:before, .wb-enable .wb-twitter .twitter-timeline:before, .geomap-progress:before, .wb-mltmd.video:not(.playing):not(.waiting) .display:before {
	background: rgba(0, 0, 0, 0.7);
	border-radius: 10px; }

/* TODO: Use bootstrap placeholder when nested extends are supported */
.wb-mltmd.video.waiting .display:after, .wb-enable .wb-twitter .twitter-timeline:after, .geomap-progress:after {
	-webkit-animation-duration: 500ms;
	        animation-duration: 500ms;
	-webkit-animation-iteration-count: infinite;
	        animation-iteration-count: infinite;
	-webkit-animation-name: spin;
	        animation-name: spin;
	-webkit-animation-timing-function: linear;
	        animation-timing-function: linear;
	color: #fff;
	content: "\e031";
	font-family: "Glyphicons Halflings";
	font-size: 3.5em;
	height: 1em;
	line-height: 1.03;
	width: 1em;
	z-index: 2; }

/*! Reset and dependencies */
/*! normalize.css v3.0.3 | MIT License | github.com/necolas/normalize.css */
html {
	font-family: sans-serif;
	-ms-text-size-adjust: 100%;
	-webkit-text-size-adjust: 100%; }

body {
	margin: 0; }

article,
aside,
details,
figcaption,
figure,
footer,
header,
hgroup,
main,
menu,
nav,
section,
summary {
	display: block; }

audio,
canvas,
progress,
video {
	display: inline-block;
	vertical-align: baseline; }

audio:not([controls]) {
	display: none;
	height: 0; }

[hidden],
template {
	display: none; }

a {
	background-color: transparent; }

a:active,
a:hover {
	outline: 0; }

abbr[title] {
	border-bottom: none;
	text-decoration: underline;
	-webkit-text-decoration: underline dotted;
	        text-decoration: underline dotted; }

b,
strong {
	font-weight: bold; }

dfn {
	font-style: italic; }

h1 {
	font-size: 2em;
	margin: 0.67em 0; }

mark {
	background: #ff0;
	color: #000; }

small {
	font-size: 80%; }

sub,
sup {
	font-size: 75%;
	line-height: 0;
	position: relative;
	vertical-align: baseline; }

sup {
	top: -0.5em; }

sub {
	bottom: -0.25em; }

img {
	border: 0; }

svg:not(:root) {
	overflow: hidden; }

figure {
	margin: 1em 40px; }

hr {
	-webkit-box-sizing: content-box;
	        box-sizing: content-box;
	height: 0; }

pre {
	overflow: auto; }

code,
kbd,
pre,
samp {
	font-family: monospace, monospace;
	font-size: 1em; }

button,
input,
optgroup,
select,
textarea {
	color: inherit;
	font: inherit;
	margin: 0; }

button {
	overflow: visible; }

button,
select {
	text-transform: none; }

button,
html input[type="button"],
input[type="reset"],
input[type="submit"] {
	-webkit-appearance: button;
	cursor: pointer; }

button[disabled],
html input[disabled] {
	cursor: default; }

button::-moz-focus-inner,
input::-moz-focus-inner {
	border: 0;
	padding: 0; }

input {
	line-height: normal; }

input[type="checkbox"],
input[type="radio"] {
	-webkit-box-sizing: border-box;
	        box-sizing: border-box;
	padding: 0; }

input[type="number"]::-webkit-inner-spin-button,
input[type="number"]::-webkit-outer-spin-button {
	height: auto; }

input[type="search"] {
	-webkit-appearance: textfield;
	-webkit-box-sizing: content-box;
	        box-sizing: content-box; }

input[type="search"]::-webkit-search-cancel-button,
input[type="search"]::-webkit-search-decoration {
	-webkit-appearance: none; }

fieldset {
	border: 1px solid #c0c0c0;
	margin: 0 2px;
	padding: 0.35em 0.625em 0.75em; }

legend {
	border: 0;
	padding: 0; }

textarea {
	overflow: auto; }

optgroup {
	font-weight: bold; }

table {
	border-collapse: collapse;
	border-spacing: 0; }

td,
th {
	padding: 0; }

/*! Source: https://github.com/h5bp/html5-boilerplate/blob/master/src/css/main.css */
@media print {
	*,
	*:before,
	*:after {
		color: #000 !important;
		text-shadow: none !important;
		background: transparent !important;
		-webkit-box-shadow: none !important;
		        box-shadow: none !important; }
	a,
	a:visited {
		text-decoration: underline; }
	a[href]:after {
		content: " (" attr(href) ")"; }
	abbr[title]:after {
		content: " (" attr(title) ")"; }
	a[href^="#"]:after,
	a[href^="javascript:"]:after {
		content: ""; }
	pre,
	blockquote {
		border: 1px solid #999;
		page-break-inside: avoid; }
	thead {
		display: table-header-group; }
	tr,
	img {
		page-break-inside: avoid; }
	img {
		max-width: 100% !important; }
	p,
	h2,
	h3 {
		orphans: 3;
		widows: 3; }
	h2,
	h3 {
		page-break-after: avoid; }
	.navbar {
		display: none; }
	.btn > .caret,
	.dropup > .btn > .caret {
		border-top-color: #000 !important; }
	.label {
		border: 1px solid #000; }
	.table {
		border-collapse: collapse !important; }
		.table td,
		.table th {
			background-color: #fff !important; }
	.table-bordered th,
	.table-bordered td {
		border: 1px solid #ddd !important; } }

@font-face {
	font-family: "Glyphicons Halflings";
	src: url("../../wet-boew/fonts/glyphicons-halflings-regular.eot");
	src: url("../../wet-boew/fonts/glyphicons-halflings-regular.eot?#iefix") format("embedded-opentype"), url("../../wet-boew/fonts/glyphicons-halflings-regular.woff2") format("woff2"), url("../../wet-boew/fonts/glyphicons-halflings-regular.woff") format("woff"), url("../../wet-boew/fonts/glyphicons-halflings-regular.ttf") format("truetype"), url("../../wet-boew/fonts/glyphicons-halflings-regular.svg#glyphicons_halflingsregular") format("svg"); }

.glyphicon {
	position: relative;
	top: 1px;
	display: inline-block;
	font-family: "Glyphicons Halflings";
	font-style: normal;
	font-weight: 400;
	line-height: 1;
	-webkit-font-smoothing: antialiased;
	-moz-osx-font-smoothing: grayscale; }

.glyphicon-asterisk:before {
	content: "\002a"; }

.glyphicon-plus:before {
	content: "\002b"; }

.glyphicon-euro:before,
.glyphicon-eur:before {
	content: "\20ac"; }

.glyphicon-minus:before {
	content: "\2212"; }

.glyphicon-cloud:before {
	content: "\2601"; }

.glyphicon-envelope:before {
	content: "\2709"; }

.glyphicon-pencil:before {
	content: "\270f"; }

.glyphicon-glass:before {
	content: "\e001"; }

.glyphicon-music:before {
	content: "\e002"; }

.glyphicon-search:before {
	content: "\e003"; }

.glyphicon-heart:before {
	content: "\e005"; }

.glyphicon-star:before {
	content: "\e006"; }

.glyphicon-star-empty:before {
	content: "\e007"; }

.glyphicon-user:before {
	content: "\e008"; }

.glyphicon-film:before {
	content: "\e009"; }

.glyphicon-th-large:before {
	content: "\e010"; }

.glyphicon-th:before {
	content: "\e011"; }

.glyphicon-th-list:before {
	content: "\e012"; }

.glyphicon-ok:before {
	content: "\e013"; }

.glyphicon-remove:before {
	content: "\e014"; }

.glyphicon-zoom-in:before {
	content: "\e015"; }

.glyphicon-zoom-out:before {
	content: "\e016"; }

.glyphicon-off:before {
	content: "\e017"; }

.glyphicon-signal:before {
	content: "\e018"; }

.glyphicon-cog:before {
	content: "\e019"; }

.glyphicon-trash:before {
	content: "\e020"; }

.glyphicon-home:before {
	content: "\e021"; }

.glyphicon-file:before {
	content: "\e022"; }

.glyphicon-time:before {
	content: "\e023"; }

.glyphicon-road:before {
	content: "\e024"; }

.glyphicon-download-alt:before {
	content: "\e025"; }

.glyphicon-download:before {
	content: "\e026"; }

.glyphicon-upload:before {
	content: "\e027"; }

.glyphicon-inbox:before {
	content: "\e028"; }

.glyphicon-play-circle:before {
	content: "\e029"; }

.glyphicon-repeat:before {
	content: "\e030"; }

.glyphicon-refresh:before {
	content: "\e031"; }

.glyphicon-list-alt:before {
	content: "\e032"; }

.glyphicon-lock:before {
	content: "\e033"; }

.glyphicon-flag:before {
	content: "\e034"; }

.glyphicon-headphones:before {
	content: "\e035"; }

.glyphicon-volume-off:before {
	content: "\e036"; }

.glyphicon-volume-down:before {
	content: "\e037"; }

.glyphicon-volume-up:before {
	content: "\e038"; }

.glyphicon-qrcode:before {
	content: "\e039"; }

.glyphicon-barcode:before {
	content: "\e040"; }

.glyphicon-tag:before {
	content: "\e041"; }

.glyphicon-tags:before {
	content: "\e042"; }

.glyphicon-book:before {
	content: "\e043"; }

.glyphicon-bookmark:before {
	content: "\e044"; }

.glyphicon-print:before {
	content: "\e045"; }

.glyphicon-camera:before {
	content: "\e046"; }

.glyphicon-font:before {
	content: "\e047"; }

.glyphicon-bold:before {
	content: "\e048"; }

.glyphicon-italic:before {
	content: "\e049"; }

.glyphicon-text-height:before {
	content: "\e050"; }

.glyphicon-text-width:before {
	content: "\e051"; }

.glyphicon-align-left:before {
	content: "\e052"; }

.glyphicon-align-center:before {
	content: "\e053"; }

.glyphicon-align-right:before {
	content: "\e054"; }

.glyphicon-align-justify:before {
	content: "\e055"; }

.glyphicon-list:before {
	content: "\e056"; }

.glyphicon-indent-left:before {
	content: "\e057"; }

.glyphicon-indent-right:before {
	content: "\e058"; }

.glyphicon-facetime-video:before {
	content: "\e059"; }

.glyphicon-picture:before {
	content: "\e060"; }

.glyphicon-map-marker:before {
	content: "\e062"; }

.glyphicon-adjust:before {
	content: "\e063"; }

.glyphicon-tint:before {
	content: "\e064"; }

.glyphicon-edit:before {
	content: "\e065"; }

.glyphicon-share:before {
	content: "\e066"; }

.glyphicon-check:before {
	content: "\e067"; }

.glyphicon-move:before {
	content: "\e068"; }

.glyphicon-step-backward:before {
	content: "\e069"; }

.glyphicon-fast-backward:before {
	content: "\e070"; }

.glyphicon-backward:before {
	content: "\e071"; }

.glyphicon-play:before {
	content: "\e072"; }

.glyphicon-pause:before {
	content: "\e073"; }

.glyphicon-stop:before {
	content: "\e074"; }

.glyphicon-forward:before {
	content: "\e075"; }

.glyphicon-fast-forward:before {
	content: "\e076"; }

.glyphicon-step-forward:before {
	content: "\e077"; }

.glyphicon-eject:before {
	content: "\e078"; }

.glyphicon-chevron-left:before {
	content: "\e079"; }

.glyphicon-chevron-right:before {
	content: "\e080"; }

.glyphicon-plus-sign:before {
	content: "\e081"; }

.glyphicon-minus-sign:before {
	content: "\e082"; }

.glyphicon-remove-sign:before {
	content: "\e083"; }

.glyphicon-ok-sign:before {
	content: "\e084"; }

.glyphicon-question-sign:before {
	content: "\e085"; }

.glyphicon-info-sign:before {
	content: "\e086"; }

.glyphicon-screenshot:before {
	content: "\e087"; }

.glyphicon-remove-circle:before {
	content: "\e088"; }

.glyphicon-ok-circle:before {
	content: "\e089"; }

.glyphicon-ban-circle:before {
	content: "\e090"; }

.glyphicon-arrow-left:before {
	content: "\e091"; }

.glyphicon-arrow-right:before {
	content: "\e092"; }

.glyphicon-arrow-up:before {
	content: "\e093"; }

.glyphicon-arrow-down:before {
	content: "\e094"; }

.glyphicon-share-alt:before {
	content: "\e095"; }

.glyphicon-resize-full:before {
	content: "\e096"; }

.glyphicon-resize-small:before {
	content: "\e097"; }

.glyphicon-exclamation-sign:before {
	content: "\e101"; }

.glyphicon-gift:before {
	content: "\e102"; }

.glyphicon-leaf:before {
	content: "\e103"; }

.glyphicon-fire:before {
	content: "\e104"; }

.glyphicon-eye-open:before {
	content: "\e105"; }

.glyphicon-eye-close:before {
	content: "\e106"; }

.glyphicon-warning-sign:before {
	content: "\e107"; }

.glyphicon-plane:before {
	content: "\e108"; }

.glyphicon-calendar:before {
	content: "\e109"; }

.glyphicon-random:before {
	content: "\e110"; }

.glyphicon-comment:before {
	content: "\e111"; }

.glyphicon-magnet:before {
	content: "\e112"; }

.glyphicon-chevron-up:before {
	content: "\e113"; }

.glyphicon-chevron-down:before {
	content: "\e114"; }

.glyphicon-retweet:before {
	content: "\e115"; }

.glyphicon-shopping-cart:before {
	content: "\e116"; }

.glyphicon-folder-close:before {
	content: "\e117"; }

.glyphicon-folder-open:before {
	content: "\e118"; }

.glyphicon-resize-vertical:before {
	content: "\e119"; }

.glyphicon-resize-horizontal:before {
	content: "\e120"; }

.glyphicon-hdd:before {
	content: "\e121"; }

.glyphicon-bullhorn:before {
	content: "\e122"; }

.glyphicon-bell:before {
	content: "\e123"; }

.glyphicon-certificate:before {
	content: "\e124"; }

.glyphicon-thumbs-up:before {
	content: "\e125"; }

.glyphicon-thumbs-down:before {
	content: "\e126"; }

.glyphicon-hand-right:before {
	content: "\e127"; }

.glyphicon-hand-left:before {
	content: "\e128"; }

.glyphicon-hand-up:before {
	content: "\e129"; }

.glyphicon-hand-down:before {
	content: "\e130"; }

.glyphicon-circle-arrow-right:before {
	content: "\e131"; }

.glyphicon-circle-arrow-left:before {
	content: "\e132"; }

.glyphicon-circle-arrow-up:before {
	content: "\e133"; }

.glyphicon-circle-arrow-down:before {
	content: "\e134"; }

.glyphicon-globe:before {
	content: "\e135"; }

.glyphicon-wrench:before {
	content: "\e136"; }

.glyphicon-tasks:before {
	content: "\e137"; }

.glyphicon-filter:before {
	content: "\e138"; }

.glyphicon-briefcase:before {
	content: "\e139"; }

.glyphicon-fullscreen:before {
	content: "\e140"; }

.glyphicon-dashboard:before {
	content: "\e141"; }

.glyphicon-paperclip:before {
	content: "\e142"; }

.glyphicon-heart-empty:before {
	content: "\e143"; }

.glyphicon-link:before {
	content: "\e144"; }

.glyphicon-phone:before {
	content: "\e145"; }

.glyphicon-pushpin:before {
	content: "\e146"; }

.glyphicon-usd:before {
	content: "\e148"; }

.glyphicon-gbp:before {
	content: "\e149"; }

.glyphicon-sort:before {
	content: "\e150"; }

.glyphicon-sort-by-alphabet:before {
	content: "\e151"; }

.glyphicon-sort-by-alphabet-alt:before {
	content: "\e152"; }

.glyphicon-sort-by-order:before {
	content: "\e153"; }

.glyphicon-sort-by-order-alt:before {
	content: "\e154"; }

.glyphicon-sort-by-attributes:before {
	content: "\e155"; }

.glyphicon-sort-by-attributes-alt:before {
	content: "\e156"; }

.glyphicon-unchecked:before {
	content: "\e157"; }

.glyphicon-expand:before {
	content: "\e158"; }

.glyphicon-collapse-down:before {
	content: "\e159"; }

.glyphicon-collapse-up:before {
	content: "\e160"; }

.glyphicon-log-in:before {
	content: "\e161"; }

.glyphicon-flash:before {
	content: "\e162"; }

.glyphicon-log-out:before {
	content: "\e163"; }

.glyphicon-new-window:before {
	content: "\e164"; }

.glyphicon-record:before {
	content: "\e165"; }

.glyphicon-save:before {
	content: "\e166"; }

.glyphicon-open:before {
	content: "\e167"; }

.glyphicon-saved:before {
	content: "\e168"; }

.glyphicon-import:before {
	content: "\e169"; }

.glyphicon-export:before {
	content: "\e170"; }

.glyphicon-send:before {
	content: "\e171"; }

.glyphicon-floppy-disk:before {
	content: "\e172"; }

.glyphicon-floppy-saved:before {
	content: "\e173"; }

.glyphicon-floppy-remove:before {
	content: "\e174"; }

.glyphicon-floppy-save:before {
	content: "\e175"; }

.glyphicon-floppy-open:before {
	content: "\e176"; }

.glyphicon-credit-card:before {
	content: "\e177"; }

.glyphicon-transfer:before {
	content: "\e178"; }

.glyphicon-cutlery:before {
	content: "\e179"; }

.glyphicon-header:before {
	content: "\e180"; }

.glyphicon-compressed:before {
	content: "\e181"; }

.glyphicon-earphone:before {
	content: "\e182"; }

.glyphicon-phone-alt:before {
	content: "\e183"; }

.glyphicon-tower:before {
	content: "\e184"; }

.glyphicon-stats:before {
	content: "\e185"; }

.glyphicon-sd-video:before {
	content: "\e186"; }

.glyphicon-hd-video:before {
	content: "\e187"; }

.glyphicon-subtitles:before {
	content: "\e188"; }

.glyphicon-sound-stereo:before {
	content: "\e189"; }

.glyphicon-sound-dolby:before {
	content: "\e190"; }

.glyphicon-sound-5-1:before {
	content: "\e191"; }

.glyphicon-sound-6-1:before {
	content: "\e192"; }

.glyphicon-sound-7-1:before {
	content: "\e193"; }

.glyphicon-copyright-mark:before {
	content: "\e194"; }

.glyphicon-registration-mark:before {
	content: "\e195"; }

.glyphicon-cloud-download:before {
	content: "\e197"; }

.glyphicon-cloud-upload:before {
	content: "\e198"; }

.glyphicon-tree-conifer:before {
	content: "\e199"; }

.glyphicon-tree-deciduous:before {
	content: "\e200"; }

.glyphicon-cd:before {
	content: "\e201"; }

.glyphicon-save-file:before {
	content: "\e202"; }

.glyphicon-open-file:before {
	content: "\e203"; }

.glyphicon-level-up:before {
	content: "\e204"; }

.glyphicon-copy:before {
	content: "\e205"; }

.glyphicon-paste:before {
	content: "\e206"; }

.glyphicon-alert:before {
	content: "\e209"; }

.glyphicon-equalizer:before {
	content: "\e210"; }

.glyphicon-king:before {
	content: "\e211"; }

.glyphicon-queen:before {
	content: "\e212"; }

.glyphicon-pawn:before {
	content: "\e213"; }

.glyphicon-bishop:before {
	content: "\e214"; }

.glyphicon-knight:before {
	content: "\e215"; }

.glyphicon-baby-formula:before {
	content: "\e216"; }

.glyphicon-tent:before {
	content: "\26fa"; }

.glyphicon-blackboard:before {
	content: "\e218"; }

.glyphicon-bed:before {
	content: "\e219"; }

.glyphicon-apple:before {
	content: "\f8ff"; }

.glyphicon-erase:before {
	content: "\e221"; }

.glyphicon-hourglass:before {
	content: "\231b"; }

.glyphicon-lamp:before {
	content: "\e223"; }

.glyphicon-duplicate:before {
	content: "\e224"; }

.glyphicon-piggy-bank:before {
	content: "\e225"; }

.glyphicon-scissors:before {
	content: "\e226"; }

.glyphicon-bitcoin:before {
	content: "\e227"; }

.glyphicon-btc:before {
	content: "\e227"; }

.glyphicon-xbt:before {
	content: "\e227"; }

.glyphicon-yen:before {
	content: "\00a5"; }

.glyphicon-jpy:before {
	content: "\00a5"; }

.glyphicon-ruble:before {
	content: "\20bd"; }

.glyphicon-rub:before {
	content: "\20bd"; }

.glyphicon-scale:before {
	content: "\e230"; }

.glyphicon-ice-lolly:before {
	content: "\e231"; }

.glyphicon-ice-lolly-tasted:before {
	content: "\e232"; }

.glyphicon-education:before {
	content: "\e233"; }

.glyphicon-option-horizontal:before {
	content: "\e234"; }

.glyphicon-option-vertical:before {
	content: "\e235"; }

.glyphicon-menu-hamburger:before {
	content: "\e236"; }

.glyphicon-modal-window:before {
	content: "\e237"; }

.glyphicon-oil:before {
	content: "\e238"; }

.glyphicon-grain:before {
	content: "\e239"; }

.glyphicon-sunglasses:before {
	content: "\e240"; }

.glyphicon-text-size:before {
	content: "\e241"; }

.glyphicon-text-color:before {
	content: "\e242"; }

.glyphicon-text-background:before {
	content: "\e243"; }

.glyphicon-object-align-top:before {
	content: "\e244"; }

.glyphicon-object-align-bottom:before {
	content: "\e245"; }

.glyphicon-object-align-horizontal:before {
	content: "\e246"; }

.glyphicon-object-align-left:before {
	content: "\e247"; }

.glyphicon-object-align-vertical:before {
	content: "\e248"; }

.glyphicon-object-align-right:before {
	content: "\e249"; }

.glyphicon-triangle-right:before {
	content: "\e250"; }

.glyphicon-triangle-left:before {
	content: "\e251"; }

.glyphicon-triangle-bottom:before {
	content: "\e252"; }

.glyphicon-triangle-top:before {
	content: "\e253"; }

.glyphicon-console:before {
	content: "\e254"; }

.glyphicon-superscript:before {
	content: "\e255"; }

.glyphicon-subscript:before {
	content: "\e256"; }

.glyphicon-menu-left:before {
	content: "\e257"; }

.glyphicon-menu-right:before {
	content: "\e258"; }

.glyphicon-menu-down:before {
	content: "\e259"; }

.glyphicon-menu-up:before {
	content: "\e260"; }

/*! Core - HTML */
* {
	-webkit-box-sizing: border-box;
	box-sizing: border-box; }

*:before,
*:after {
	-webkit-box-sizing: border-box;
	box-sizing: border-box; }

html {
	font-size: 10px;
	-webkit-tap-highlight-color: rgba(0, 0, 0, 0); }

body {
	font-family: "Noto Sans", sans-serif;
	font-size: 16px;
	line-height: 1.4375;
	color: #333333;
	background-color: #fff; }

input,
button,
select,
textarea {
	font-family: inherit;
	font-size: inherit;
	line-height: inherit; }

a {
	color: #295376;
	text-decoration: none; }
	a:hover, a:focus {
		color: #0535d2;
		text-decoration: underline; }
	a:focus {
		outline: 5px auto -webkit-focus-ring-color;
		outline-offset: -2px; }

figure {
	margin: 0; }

img {
	vertical-align: middle; }

.img-responsive {
	display: block;
	max-width: 100%;
	height: auto; }

.img-rounded {
	border-radius: 6px; }

.img-thumbnail {
	padding: 4px;
	line-height: 1.4375;
	background-color: #fff;
	border: 1px solid #ddd;
	border-radius: 4px;
	-webkit-transition: all 0.2s ease-in-out;
	transition: all 0.2s ease-in-out;
	display: inline-block;
	max-width: 100%;
	height: auto; }

.img-circle {
	border-radius: 50%; }

hr {
	margin-top: 23px;
	margin-bottom: 23px;
	border: 0;
	border-top: 1px solid #eeeeee; }

.sr-only {
	position: absolute;
	width: 1px;
	height: 1px;
	padding: 0;
	margin: -1px;
	overflow: hidden;
	clip: rect(0, 0, 0, 0);
	border: 0; }

.sr-only-focusable:active, .sr-only-focusable:focus {
	position: static;
	width: auto;
	height: auto;
	margin: 0;
	overflow: visible;
	clip: auto; }

[role="button"] {
	cursor: pointer; }

h1, h2, h3, h4, h5, h6,
.h1, .h2, .h3, .h4, .h5, .h6 {
	font-family: inherit;
	font-weight: 500;
	line-height: 1.1;
	color: inherit; }
	h1 small,
	h1 .small, h2 small,
	h2 .small, h3 small,
	h3 .small, h4 small,
	h4 .small, h5 small,
	h5 .small, h6 small,
	h6 .small,
	.h1 small,
	.h1 .small, .h2 small,
	.h2 .small, .h3 small,
	.h3 .small, .h4 small,
	.h4 .small, .h5 small,
	.h5 .small, .h6 small,
	.h6 .small {
		font-weight: 400;
		line-height: 1;
		color: #6f6f6f; }

h1, .h1,
h2, .h2,
h3, .h3 {
	margin-top: 23px;
	margin-bottom: 11.5px; }
	h1 small,
	h1 .small, .h1 small,
	.h1 .small,
	h2 small,
	h2 .small, .h2 small,
	.h2 .small,
	h3 small,
	h3 .small, .h3 small,
	.h3 .small {
		font-size: 65%; }

h4, .h4,
h5, .h5,
h6, .h6 {
	margin-top: 11.5px;
	margin-bottom: 11.5px; }
	h4 small,
	h4 .small, .h4 small,
	.h4 .small,
	h5 small,
	h5 .small, .h5 small,
	.h5 .small,
	h6 small,
	h6 .small, .h6 small,
	.h6 .small {
		font-size: 75%; }

h1, .h1 {
	font-size: 1.9em; }

h2, .h2 {
	font-size: 1.8em; }

h3, .h3 {
	font-size: 1.2em; }

h4, .h4 {
	font-size: 1.1em; }

h5, .h5 {
	font-size: 1em; }

h6, .h6 {
	font-size: 0.95em; }

p {
	margin: 0 0 11.5px; }

.lead {
	margin-bottom: 23px;
	font-size: 18px;
	font-weight: 300;
	line-height: 1.4; }
	@media (min-width: 768px) {
		.lead {
			font-size: 24px; } }

small,
.small {
	font-size: 87%; }

mark,
.mark {
	padding: .2em;
	background-color: #fcf8e3; }

.text-left {
	text-align: left; }

.text-right {
	text-align: right; }

.text-center {
	text-align: center; }

.text-justify {
	text-align: justify; }

.text-nowrap {
	white-space: nowrap; }

.text-lowercase {
	text-transform: lowercase; }

.text-uppercase, .initialism {
	text-transform: uppercase; }

.text-capitalize {
	text-transform: capitalize; }

.text-muted {
	color: #6f6f6f; }

.text-primary {
	color: #2572b4; }

a.text-primary:hover,
a.text-primary:focus {
	color: #1c578a; }

.text-success {
	color: #3c763d; }

a.text-success:hover,
a.text-success:focus {
	color: #2b542c; }

.text-info {
	color: #31708f; }

a.text-info:hover,
a.text-info:focus {
	color: #245269; }

.text-warning {
	color: #8a6d3b; }

a.text-warning:hover,
a.text-warning:focus {
	color: #66512c; }

.text-danger {
	color: #a94442; }

a.text-danger:hover,
a.text-danger:focus {
	color: #843534; }

.bg-primary {
	color: #fff; }

.bg-primary {
	background-color: #2572b4; }

a.bg-primary:hover,
a.bg-primary:focus {
	background-color: #1c578a; }

.bg-success {
	background-color: #dff0d8; }

a.bg-success:hover,
a.bg-success:focus {
	background-color: #c1e2b3; }

.bg-info {
	background-color: #d9edf7; }

a.bg-info:hover,
a.bg-info:focus {
	background-color: #afd9ee; }

.bg-warning {
	background-color: #fcf8e3; }

a.bg-warning:hover,
a.bg-warning:focus {
	background-color: #f7ecb5; }

.bg-danger {
	background-color: #f2dede; }

a.bg-danger:hover,
a.bg-danger:focus {
	background-color: #e4b9b9; }

.page-header {
	padding-bottom: 10.5px;
	margin: 46px 0 23px;
	border-bottom: 1px solid #eeeeee; }

ul,
ol {
	margin-top: 0;
	margin-bottom: 11.5px; }
	ul ul,
	ul ol,
	ol ul,
	ol ol {
		margin-bottom: 0; }

.list-unstyled {
	padding-left: 0;
	list-style: none; }

.list-inline {
	padding-left: 0;
	list-style: none;
	margin-left: -5px; }
	.list-inline > li {
		display: inline-block;
		padding-right: 5px;
		padding-left: 5px; }

dl {
	margin-top: 0;
	margin-bottom: 23px; }

dt,
dd {
	line-height: 1.4375; }

dt {
	font-weight: 700; }

dd {
	margin-left: 0; }

.dl-horizontal dd:before, .dl-horizontal dd:after {
	display: table;
	content: " "; }

.dl-horizontal dd:after {
	clear: both; }

@media (min-width: 768px) {
	.dl-horizontal dt {
		float: left;
		width: 160px;
		clear: left;
		text-align: right;
		overflow: hidden;
		text-overflow: ellipsis;
		white-space: nowrap; }
	.dl-horizontal dd {
		margin-left: 180px; } }

abbr[title],
abbr[data-original-title] {
	cursor: help; }

.initialism {
	font-size: 90%; }

blockquote {
	padding: 11.5px 23px;
	margin: 0 0 23px;
	font-size: 20px;
	border-left: 5px solid #eeeeee; }
	blockquote p:last-child,
	blockquote ul:last-child,
	blockquote ol:last-child {
		margin-bottom: 0; }
	blockquote footer,
	blockquote small,
	blockquote .small {
		display: block;
		font-size: 80%;
		line-height: 1.4375;
		color: #6f6f6f; }
		blockquote footer:before,
		blockquote small:before,
		blockquote .small:before {
			content: "\2014 \00A0"; }

.blockquote-reverse,
blockquote.pull-right {
	padding-right: 15px;
	padding-left: 0;
	text-align: right;
	border-right: 5px solid #eeeeee;
	border-left: 0; }
	.blockquote-reverse footer:before,
	.blockquote-reverse small:before,
	.blockquote-reverse .small:before,
	blockquote.pull-right footer:before,
	blockquote.pull-right small:before,
	blockquote.pull-right .small:before {
		content: ""; }
	.blockquote-reverse footer:after,
	.blockquote-reverse small:after,
	.blockquote-reverse .small:after,
	blockquote.pull-right footer:after,
	blockquote.pull-right small:after,
	blockquote.pull-right .small:after {
		content: "\00A0 \2014"; }

address {
	margin-bottom: 23px;
	font-style: normal;
	line-height: 1.4375; }

/*
	WET-BOEW
	@title: Bootstrap overrides for WET-BOEW - Core CSS - heading
 */
/*! Placeholders */
h1,
.h1, h2,
.h2, h3,
.h3, h4,
.h4, h5,
.h5, h6,
.h6 {
	font-weight: 700; }

h1,
.h1, h2,
.h2 {
	margin-top: 38px; }

/*
 *  Heading top margins
 */
h3, .h3 {
	margin-top: 32px; }

h4, .h4 {
	margin-top: 26px; }

h5, .h5 {
	margin-top: 23px; }

h6, .h6 {
	margin-top: 21px; }

/*
  WET-BOEW
  @title: List CSS
 */
.lst-lwr-alph {
	list-style-type: lower-alpha; }

.lst-upr-alph {
	list-style-type: upper-alpha; }

.lst-lwr-rmn {
	list-style-type: lower-roman; }

.lst-upr-rmn {
	list-style-type: upper-roman; }

.lst-num {
	list-style-type: decimal; }

.lst-none {
	list-style-type: none; }

.lst-spcd > li {
	margin-bottom: 10px; }

.lst-spcd ul,
.lst-spcd ol {
	margin-top: 10px; }

/*
	WET-BOEW
	@title: Bootstrap overrides for WET-BOEW - Core CSS
 */
/*! Placeholders */
a.btn, .nav a {
	text-decoration: none; }

/*
 *  Link colour and decoration
 */
a {
	text-decoration: underline; }
	a:visited {
		color: #7834bc; }
	a:not([href]) {
		color: inherit;
		text-decoration: none; }
		a:not([href]):hover, a:not([href]):focus {
			color: inherit;
			outline: none;
			text-decoration: none; }

@media (min-width: 768px) {
	.dl-horizontal.brdr-0 dt,
	.dl-horizontal.brdr-0 dd {
		border: 0 !important; }
	.dl-horizontal dt {
		border-top: 1px solid #ccc;
		padding: 10px 10px 10px 0;
		text-align: left;
		white-space: normal; }
	.dl-horizontal dd {
		border-top: 1px solid #ccc;
		margin-bottom: 3px;
		margin-left: 160px;
		padding: 10px 10px 10px 0; }
	.dl-horizontal dt + dd {
		padding-bottom: 0; } }

/*
 *  Abbreviations with title attributes
 *  Workaround for abbreviations with titles using solid underlines in IE11/Edge in Bootstrap 3.4.0 (via normalize.css 4.0.1-8.0.1):
 *  - Use a dotted underline in browsers that support it (e.g. Firefox, Chrome, etc...)
 *  - Fallback on a dotted bottom border in browsers that don't support it (e.g. IE11, Edge, etc...)
 *  Source: https://github.com/necolas/normalize.css/pull/738#issuecomment-387549760
 *  Created by: @mattbrundage
 */
abbr[title] {
	border-bottom: 1px dotted;
	text-decoration: none; }

@supports ((-webkit-text-decoration: underline dotted) or (text-decoration: underline dotted)) {
	abbr[title] {
		border-bottom: 0;
		-webkit-text-decoration: underline dotted;
		        text-decoration: underline dotted;
		-webkit-text-decoration-skip-ink: none;
		        text-decoration-skip-ink: none; } }

/*
 * Code
 */
code {
	white-space: normal; }

/*
 * Adding space for definition list items
 */
dt {
	margin-bottom: 3px; }

dd {
	margin-bottom: 15px; }

/*
 *  Blockquote font size
 */
blockquote {
	font-size: 16px; }

/*
 *  Right-to-left support
 */
[dir=rtl] .list-unstyled {
	padding-right: 0; }

mark {
	background-color: #ff0;
	color: #000;
	font-weight: 700; }

[hidden] {
	display: none !important; }

q:before, q:after {
	content: ""; }

/*
  WET-BOEW
  @title: Details/summary CSS
 */
summary {
	cursor: pointer; }
	summary:hover, summary:focus {
		background: #ddd;
		color: #000; }
	summary > :first-child {
		display: inline; }

details {
	padding-left: 1.1em;
	padding-right: 1.1em; }
	details > summary {
		margin-left: -1.1em;
		margin-right: -1.1em; }
	details[open] {
		padding-bottom: 1em; }

code,
kbd,
pre,
samp {
	font-family: Menlo, Monaco, Consolas, "Courier New", monospace; }

code {
	padding: 2px 4px;
	font-size: 90%;
	color: #c7254e;
	background-color: #f9f2f4;
	border-radius: 4px; }

kbd {
	padding: 2px 4px;
	font-size: 90%;
	color: #fff;
	background-color: #333;
	border-radius: 3px;
	-webkit-box-shadow: inset 0 -1px 0 rgba(0, 0, 0, 0.25);
	        box-shadow: inset 0 -1px 0 rgba(0, 0, 0, 0.25); }
	kbd kbd {
		padding: 0;
		font-size: 100%;
		font-weight: 700;
		-webkit-box-shadow: none;
		        box-shadow: none; }

pre {
	display: block;
	padding: 11px;
	margin: 0 0 11.5px;
	font-size: 15px;
	line-height: 1.4375;
	color: #333333;
	word-break: break-all;
	word-wrap: break-word;
	background-color: #f5f5f5;
	border: 1px solid #ccc;
	border-radius: 4px; }
	pre code {
		padding: 0;
		font-size: inherit;
		color: inherit;
		white-space: pre-wrap;
		background-color: transparent;
		border-radius: 0; }

.pre-scrollable {
	max-height: 340px;
	overflow-y: scroll; }

.container {
	padding-right: 15px;
	padding-left: 15px;
	margin-right: auto;
	margin-left: auto; }
	.container:before, .container:after {
		display: table;
		content: " "; }
	.container:after {
		clear: both; }
	@media (min-width: 768px) {
		.container {
			width: 750px; } }
	@media (min-width: 992px) {
		.container {
			width: 970px; } }
	@media (min-width: 1200px) {
		.container {
			width: 1170px; } }

.container-fluid {
	padding-right: 15px;
	padding-left: 15px;
	margin-right: auto;
	margin-left: auto; }
	.container-fluid:before, .container-fluid:after {
		display: table;
		content: " "; }
	.container-fluid:after {
		clear: both; }

.row {
	margin-right: -15px;
	margin-left: -15px; }
	.row:before, .row:after {
		display: table;
		content: " "; }
	.row:after {
		clear: both; }

.row-no-gutters {
	margin-right: 0;
	margin-left: 0; }
	.row-no-gutters [class*="col-"] {
		padding-right: 0;
		padding-left: 0; }

.col-xs-1, .col-sm-1, .col-md-1, .col-lg-1, .col-xs-2, .col-sm-2, .col-md-2, .col-lg-2, .col-xs-3, .col-sm-3, .col-md-3, .col-lg-3, .col-xs-4, .col-sm-4, .col-md-4, .col-lg-4, .col-xs-5, .col-sm-5, .col-md-5, .col-lg-5, .col-xs-6, .col-sm-6, .col-md-6, .col-lg-6, .col-xs-7, .col-sm-7, .col-md-7, .col-lg-7, .col-xs-8, .col-sm-8, .col-md-8, .col-lg-8, .col-xs-9, .col-sm-9, .col-md-9, .col-lg-9, .col-xs-10, .col-sm-10, .col-md-10, .col-lg-10, .col-xs-11, .col-sm-11, .col-md-11, .col-lg-11, .col-xs-12, .col-sm-12, .col-md-12, .col-lg-12 {
	position: relative;
	min-height: 1px;
	padding-right: 15px;
	padding-left: 15px; }

.col-xs-1, .col-xs-2, .col-xs-3, .col-xs-4, .col-xs-5, .col-xs-6, .col-xs-7, .col-xs-8, .col-xs-9, .col-xs-10, .col-xs-11, .col-xs-12 {
	float: left; }

.col-xs-1 {
	width: 8.3333333333%; }

.col-xs-2 {
	width: 16.6666666667%; }

.col-xs-3 {
	width: 25%; }

.col-xs-4 {
	width: 33.3333333333%; }

.col-xs-5 {
	width: 41.6666666667%; }

.col-xs-6 {
	width: 50%; }

.col-xs-7 {
	width: 58.3333333333%; }

.col-xs-8 {
	width: 66.6666666667%; }

.col-xs-9 {
	width: 75%; }

.col-xs-10 {
	width: 83.3333333333%; }

.col-xs-11 {
	width: 91.6666666667%; }

.col-xs-12 {
	width: 100%; }

.col-xs-pull-0 {
	right: auto; }

.col-xs-pull-1 {
	right: 8.3333333333%; }

.col-xs-pull-2 {
	right: 16.6666666667%; }

.col-xs-pull-3 {
	right: 25%; }

.col-xs-pull-4 {
	right: 33.3333333333%; }

.col-xs-pull-5 {
	right: 41.6666666667%; }

.col-xs-pull-6 {
	right: 50%; }

.col-xs-pull-7 {
	right: 58.3333333333%; }

.col-xs-pull-8 {
	right: 66.6666666667%; }

.col-xs-pull-9 {
	right: 75%; }

.col-xs-pull-10 {
	right: 83.3333333333%; }

.col-xs-pull-11 {
	right: 91.6666666667%; }

.col-xs-pull-12 {
	right: 100%; }

.col-xs-push-0 {
	left: auto; }

.col-xs-push-1 {
	left: 8.3333333333%; }

.col-xs-push-2 {
	left: 16.6666666667%; }

.col-xs-push-3 {
	left: 25%; }

.col-xs-push-4 {
	left: 33.3333333333%; }

.col-xs-push-5 {
	left: 41.6666666667%; }

.col-xs-push-6 {
	left: 50%; }

.col-xs-push-7 {
	left: 58.3333333333%; }

.col-xs-push-8 {
	left: 66.6666666667%; }

.col-xs-push-9 {
	left: 75%; }

.col-xs-push-10 {
	left: 83.3333333333%; }

.col-xs-push-11 {
	left: 91.6666666667%; }

.col-xs-push-12 {
	left: 100%; }

.col-xs-offset-0 {
	margin-left: 0%; }

.col-xs-offset-1 {
	margin-left: 8.3333333333%; }

.col-xs-offset-2 {
	margin-left: 16.6666666667%; }

.col-xs-offset-3 {
	margin-left: 25%; }

.col-xs-offset-4 {
	margin-left: 33.3333333333%; }

.col-xs-offset-5 {
	margin-left: 41.6666666667%; }

.col-xs-offset-6 {
	margin-left: 50%; }

.col-xs-offset-7 {
	margin-left: 58.3333333333%; }

.col-xs-offset-8 {
	margin-left: 66.6666666667%; }

.col-xs-offset-9 {
	margin-left: 75%; }

.col-xs-offset-10 {
	margin-left: 83.3333333333%; }

.col-xs-offset-11 {
	margin-left: 91.6666666667%; }

.col-xs-offset-12 {
	margin-left: 100%; }

@media (min-width: 768px) {
	.col-sm-1, .col-sm-2, .col-sm-3, .col-sm-4, .col-sm-5, .col-sm-6, .col-sm-7, .col-sm-8, .col-sm-9, .col-sm-10, .col-sm-11, .col-sm-12 {
		float: left; }
	.col-sm-1 {
		width: 8.3333333333%; }
	.col-sm-2 {
		width: 16.6666666667%; }
	.col-sm-3 {
		width: 25%; }
	.col-sm-4 {
		width: 33.3333333333%; }
	.col-sm-5 {
		width: 41.6666666667%; }
	.col-sm-6 {
		width: 50%; }
	.col-sm-7 {
		width: 58.3333333333%; }
	.col-sm-8 {
		width: 66.6666666667%; }
	.col-sm-9 {
		width: 75%; }
	.col-sm-10 {
		width: 83.3333333333%; }
	.col-sm-11 {
		width: 91.6666666667%; }
	.col-sm-12 {
		width: 100%; }
	.col-sm-pull-0 {
		right: auto; }
	.col-sm-pull-1 {
		right: 8.3333333333%; }
	.col-sm-pull-2 {
		right: 16.6666666667%; }
	.col-sm-pull-3 {
		right: 25%; }
	.col-sm-pull-4 {
		right: 33.3333333333%; }
	.col-sm-pull-5 {
		right: 41.6666666667%; }
	.col-sm-pull-6 {
		right: 50%; }
	.col-sm-pull-7 {
		right: 58.3333333333%; }
	.col-sm-pull-8 {
		right: 66.6666666667%; }
	.col-sm-pull-9 {
		right: 75%; }
	.col-sm-pull-10 {
		right: 83.3333333333%; }
	.col-sm-pull-11 {
		right: 91.6666666667%; }
	.col-sm-pull-12 {
		right: 100%; }
	.col-sm-push-0 {
		left: auto; }
	.col-sm-push-1 {
		left: 8.3333333333%; }
	.col-sm-push-2 {
		left: 16.6666666667%; }
	.col-sm-push-3 {
		left: 25%; }
	.col-sm-push-4 {
		left: 33.3333333333%; }
	.col-sm-push-5 {
		left: 41.6666666667%; }
	.col-sm-push-6 {
		left: 50%; }
	.col-sm-push-7 {
		left: 58.3333333333%; }
	.col-sm-push-8 {
		left: 66.6666666667%; }
	.col-sm-push-9 {
		left: 75%; }
	.col-sm-push-10 {
		left: 83.3333333333%; }
	.col-sm-push-11 {
		left: 91.6666666667%; }
	.col-sm-push-12 {
		left: 100%; }
	.col-sm-offset-0 {
		margin-left: 0%; }
	.col-sm-offset-1 {
		margin-left: 8.3333333333%; }
	.col-sm-offset-2 {
		margin-left: 16.6666666667%; }
	.col-sm-offset-3 {
		margin-left: 25%; }
	.col-sm-offset-4 {
		margin-left: 33.3333333333%; }
	.col-sm-offset-5 {
		margin-left: 41.6666666667%; }
	.col-sm-offset-6 {
		margin-left: 50%; }
	.col-sm-offset-7 {
		margin-left: 58.3333333333%; }
	.col-sm-offset-8 {
		margin-left: 66.6666666667%; }
	.col-sm-offset-9 {
		margin-left: 75%; }
	.col-sm-offset-10 {
		margin-left: 83.3333333333%; }
	.col-sm-offset-11 {
		margin-left: 91.6666666667%; }
	.col-sm-offset-12 {
		margin-left: 100%; } }

@media (min-width: 992px) {
	.col-md-1, .col-md-2, .col-md-3, .col-md-4, .col-md-5, .col-md-6, .col-md-7, .col-md-8, .col-md-9, .col-md-10, .col-md-11, .col-md-12 {
		float: left; }
	.col-md-1 {
		width: 8.3333333333%; }
	.col-md-2 {
		width: 16.6666666667%; }
	.col-md-3 {
		width: 25%; }
	.col-md-4 {
		width: 33.3333333333%; }
	.col-md-5 {
		width: 41.6666666667%; }
	.col-md-6 {
		width: 50%; }
	.col-md-7 {
		width: 58.3333333333%; }
	.col-md-8 {
		width: 66.6666666667%; }
	.col-md-9 {
		width: 75%; }
	.col-md-10 {
		width: 83.3333333333%; }
	.col-md-11 {
		width: 91.6666666667%; }
	.col-md-12 {
		width: 100%; }
	.col-md-pull-0 {
		right: auto; }
	.col-md-pull-1 {
		right: 8.3333333333%; }
	.col-md-pull-2 {
		right: 16.6666666667%; }
	.col-md-pull-3 {
		right: 25%; }
	.col-md-pull-4 {
		right: 33.3333333333%; }
	.col-md-pull-5 {
		right: 41.6666666667%; }
	.col-md-pull-6 {
		right: 50%; }
	.col-md-pull-7 {
		right: 58.3333333333%; }
	.col-md-pull-8 {
		right: 66.6666666667%; }
	.col-md-pull-9 {
		right: 75%; }
	.col-md-pull-10 {
		right: 83.3333333333%; }
	.col-md-pull-11 {
		right: 91.6666666667%; }
	.col-md-pull-12 {
		right: 100%; }
	.col-md-push-0 {
		left: auto; }
	.col-md-push-1 {
		left: 8.3333333333%; }
	.col-md-push-2 {
		left: 16.6666666667%; }
	.col-md-push-3 {
		left: 25%; }
	.col-md-push-4 {
		left: 33.3333333333%; }
	.col-md-push-5 {
		left: 41.6666666667%; }
	.col-md-push-6 {
		left: 50%; }
	.col-md-push-7 {
		left: 58.3333333333%; }
	.col-md-push-8 {
		left: 66.6666666667%; }
	.col-md-push-9 {
		left: 75%; }
	.col-md-push-10 {
		left: 83.3333333333%; }
	.col-md-push-11 {
		left: 91.6666666667%; }
	.col-md-push-12 {
		left: 100%; }
	.col-md-offset-0 {
		margin-left: 0%; }
	.col-md-offset-1 {
		margin-left: 8.3333333333%; }
	.col-md-offset-2 {
		margin-left: 16.6666666667%; }
	.col-md-offset-3 {
		margin-left: 25%; }
	.col-md-offset-4 {
		margin-left: 33.3333333333%; }
	.col-md-offset-5 {
		margin-left: 41.6666666667%; }
	.col-md-offset-6 {
		margin-left: 50%; }
	.col-md-offset-7 {
		margin-left: 58.3333333333%; }
	.col-md-offset-8 {
		margin-left: 66.6666666667%; }
	.col-md-offset-9 {
		margin-left: 75%; }
	.col-md-offset-10 {
		margin-left: 83.3333333333%; }
	.col-md-offset-11 {
		margin-left: 91.6666666667%; }
	.col-md-offset-12 {
		margin-left: 100%; } }

@media (min-width: 1200px) {
	.col-lg-1, .col-lg-2, .col-lg-3, .col-lg-4, .col-lg-5, .col-lg-6, .col-lg-7, .col-lg-8, .col-lg-9, .col-lg-10, .col-lg-11, .col-lg-12 {
		float: left; }
	.col-lg-1 {
		width: 8.3333333333%; }
	.col-lg-2 {
		width: 16.6666666667%; }
	.col-lg-3 {
		width: 25%; }
	.col-lg-4 {
		width: 33.3333333333%; }
	.col-lg-5 {
		width: 41.6666666667%; }
	.col-lg-6 {
		width: 50%; }
	.col-lg-7 {
		width: 58.3333333333%; }
	.col-lg-8 {
		width: 66.6666666667%; }
	.col-lg-9 {
		width: 75%; }
	.col-lg-10 {
		width: 83.3333333333%; }
	.col-lg-11 {
		width: 91.6666666667%; }
	.col-lg-12 {
		width: 100%; }
	.col-lg-pull-0 {
		right: auto; }
	.col-lg-pull-1 {
		right: 8.3333333333%; }
	.col-lg-pull-2 {
		right: 16.6666666667%; }
	.col-lg-pull-3 {
		right: 25%; }
	.col-lg-pull-4 {
		right: 33.3333333333%; }
	.col-lg-pull-5 {
		right: 41.6666666667%; }
	.col-lg-pull-6 {
		right: 50%; }
	.col-lg-pull-7 {
		right: 58.3333333333%; }
	.col-lg-pull-8 {
		right: 66.6666666667%; }
	.col-lg-pull-9 {
		right: 75%; }
	.col-lg-pull-10 {
		right: 83.3333333333%; }
	.col-lg-pull-11 {
		right: 91.6666666667%; }
	.col-lg-pull-12 {
		right: 100%; }
	.col-lg-push-0 {
		left: auto; }
	.col-lg-push-1 {
		left: 8.3333333333%; }
	.col-lg-push-2 {
		left: 16.6666666667%; }
	.col-lg-push-3 {
		left: 25%; }
	.col-lg-push-4 {
		left: 33.3333333333%; }
	.col-lg-push-5 {
		left: 41.6666666667%; }
	.col-lg-push-6 {
		left: 50%; }
	.col-lg-push-7 {
		left: 58.3333333333%; }
	.col-lg-push-8 {
		left: 66.6666666667%; }
	.col-lg-push-9 {
		left: 75%; }
	.col-lg-push-10 {
		left: 83.3333333333%; }
	.col-lg-push-11 {
		left: 91.6666666667%; }
	.col-lg-push-12 {
		left: 100%; }
	.col-lg-offset-0 {
		margin-left: 0%; }
	.col-lg-offset-1 {
		margin-left: 8.3333333333%; }
	.col-lg-offset-2 {
		margin-left: 16.6666666667%; }
	.col-lg-offset-3 {
		margin-left: 25%; }
	.col-lg-offset-4 {
		margin-left: 33.3333333333%; }
	.col-lg-offset-5 {
		margin-left: 41.6666666667%; }
	.col-lg-offset-6 {
		margin-left: 50%; }
	.col-lg-offset-7 {
		margin-left: 58.3333333333%; }
	.col-lg-offset-8 {
		margin-left: 66.6666666667%; }
	.col-lg-offset-9 {
		margin-left: 75%; }
	.col-lg-offset-10 {
		margin-left: 83.3333333333%; }
	.col-lg-offset-11 {
		margin-left: 91.6666666667%; }
	.col-lg-offset-12 {
		margin-left: 100%; } }

table {
	background-color: transparent; }
	table col[class*="col-"] {
		position: static;
		display: table-column;
		float: none; }
	table td[class*="col-"],
	table th[class*="col-"] {
		position: static;
		display: table-cell;
		float: none; }

caption {
	padding-top: 8px;
	padding-bottom: 8px;
	color: #6f6f6f;
	text-align: left; }

th {
	text-align: left; }

.table {
	width: 100%;
	max-width: 100%;
	margin-bottom: 23px; }
	.table > thead > tr > th,
	.table > thead > tr > td,
	.table > tbody > tr > th,
	.table > tbody > tr > td,
	.table > tfoot > tr > th,
	.table > tfoot > tr > td {
		padding: 8px;
		line-height: 1.4375;
		vertical-align: top;
		border-top: 1px solid #ddd; }
	.table > thead > tr > th {
		vertical-align: bottom;
		border-bottom: 2px solid #ddd; }
	.table > caption + thead > tr:first-child > th,
	.table > caption + thead > tr:first-child > td,
	.table > colgroup + thead > tr:first-child > th,
	.table > colgroup + thead > tr:first-child > td,
	.table > thead:first-child > tr:first-child > th,
	.table > thead:first-child > tr:first-child > td {
		border-top: 0; }
	.table > tbody + tbody {
		border-top: 2px solid #ddd; }
	.table .table {
		background-color: #fff; }

.table-condensed > thead > tr > th,
.table-condensed > thead > tr > td,
.table-condensed > tbody > tr > th,
.table-condensed > tbody > tr > td,
.table-condensed > tfoot > tr > th,
.table-condensed > tfoot > tr > td {
	padding: 5px; }

.table-bordered {
	border: 1px solid #ddd; }
	.table-bordered > thead > tr > th,
	.table-bordered > thead > tr > td,
	.table-bordered > tbody > tr > th,
	.table-bordered > tbody > tr > td,
	.table-bordered > tfoot > tr > th,
	.table-bordered > tfoot > tr > td {
		border: 1px solid #ddd; }
	.table-bordered > thead > tr > th,
	.table-bordered > thead > tr > td {
		border-bottom-width: 2px; }

.table-striped > tbody > tr:nth-of-type(odd) {
	background-color: #f5f5f5; }

.table-hover > tbody > tr:hover {
	background-color: #f0f0f0; }

.table > thead > tr > td.active,
.table > thead > tr > th.active,
.table > thead > tr.active > td,
.table > thead > tr.active > th,
.table > tbody > tr > td.active,
.table > tbody > tr > th.active,
.table > tbody > tr.active > td,
.table > tbody > tr.active > th,
.table > tfoot > tr > td.active,
.table > tfoot > tr > th.active,
.table > tfoot > tr.active > td,
.table > tfoot > tr.active > th {
	background-color: #f0f0f0; }

.table-hover > tbody > tr > td.active:hover,
.table-hover > tbody > tr > th.active:hover,
.table-hover > tbody > tr.active:hover > td,
.table-hover > tbody > tr:hover > .active,
.table-hover > tbody > tr.active:hover > th {
	background-color: #e3e3e3; }

.table > thead > tr > td.success,
.table > thead > tr > th.success,
.table > thead > tr.success > td,
.table > thead > tr.success > th,
.table > tbody > tr > td.success,
.table > tbody > tr > th.success,
.table > tbody > tr.success > td,
.table > tbody > tr.success > th,
.table > tfoot > tr > td.success,
.table > tfoot > tr > th.success,
.table > tfoot > tr.success > td,
.table > tfoot > tr.success > th {
	background-color: #dff0d8; }

.table-hover > tbody > tr > td.success:hover,
.table-hover > tbody > tr > th.success:hover,
.table-hover > tbody > tr.success:hover > td,
.table-hover > tbody > tr:hover > .success,
.table-hover > tbody > tr.success:hover > th {
	background-color: #d0e9c6; }

.table > thead > tr > td.info,
.table > thead > tr > th.info,
.table > thead > tr.info > td,
.table > thead > tr.info > th,
.table > tbody > tr > td.info,
.table > tbody > tr > th.info,
.table > tbody > tr.info > td,
.table > tbody > tr.info > th,
.table > tfoot > tr > td.info,
.table > tfoot > tr > th.info,
.table > tfoot > tr.info > td,
.table > tfoot > tr.info > th {
	background-color: #d9edf7; }

.table-hover > tbody > tr > td.info:hover,
.table-hover > tbody > tr > th.info:hover,
.table-hover > tbody > tr.info:hover > td,
.table-hover > tbody > tr:hover > .info,
.table-hover > tbody > tr.info:hover > th {
	background-color: #c4e3f3; }

.table > thead > tr > td.warning,
.table > thead > tr > th.warning,
.table > thead > tr.warning > td,
.table > thead > tr.warning > th,
.table > tbody > tr > td.warning,
.table > tbody > tr > th.warning,
.table > tbody > tr.warning > td,
.table > tbody > tr.warning > th,
.table > tfoot > tr > td.warning,
.table > tfoot > tr > th.warning,
.table > tfoot > tr.warning > td,
.table > tfoot > tr.warning > th {
	background-color: #fcf8e3; }

.table-hover > tbody > tr > td.warning:hover,
.table-hover > tbody > tr > th.warning:hover,
.table-hover > tbody > tr.warning:hover > td,
.table-hover > tbody > tr:hover > .warning,
.table-hover > tbody > tr.warning:hover > th {
	background-color: #faf2cc; }

.table > thead > tr > td.danger,
.table > thead > tr > th.danger,
.table > thead > tr.danger > td,
.table > thead > tr.danger > th,
.table > tbody > tr > td.danger,
.table > tbody > tr > th.danger,
.table > tbody > tr.danger > td,
.table > tbody > tr.danger > th,
.table > tfoot > tr > td.danger,
.table > tfoot > tr > th.danger,
.table > tfoot > tr.danger > td,
.table > tfoot > tr.danger > th {
	background-color: #f2dede; }

.table-hover > tbody > tr > td.danger:hover,
.table-hover > tbody > tr > th.danger:hover,
.table-hover > tbody > tr.danger:hover > td,
.table-hover > tbody > tr:hover > .danger,
.table-hover > tbody > tr.danger:hover > th {
	background-color: #ebcccc; }

.table-responsive {
	min-height: .01%;
	overflow-x: auto; }
	@media screen and (max-width: 767px) {
		.table-responsive {
			width: 100%;
			margin-bottom: 17.25px;
			overflow-y: hidden;
			-ms-overflow-style: -ms-autohiding-scrollbar;
			border: 1px solid #ddd; }
			.table-responsive > .table {
				margin-bottom: 0; }
				.table-responsive > .table > thead > tr > th,
				.table-responsive > .table > thead > tr > td,
				.table-responsive > .table > tbody > tr > th,
				.table-responsive > .table > tbody > tr > td,
				.table-responsive > .table > tfoot > tr > th,
				.table-responsive > .table > tfoot > tr > td {
					white-space: nowrap; }
			.table-responsive > .table-bordered {
				border: 0; }
				.table-responsive > .table-bordered > thead > tr > th:first-child,
				.table-responsive > .table-bordered > thead > tr > td:first-child,
				.table-responsive > .table-bordered > tbody > tr > th:first-child,
				.table-responsive > .table-bordered > tbody > tr > td:first-child,
				.table-responsive > .table-bordered > tfoot > tr > th:first-child,
				.table-responsive > .table-bordered > tfoot > tr > td:first-child {
					border-left: 0; }
				.table-responsive > .table-bordered > thead > tr > th:last-child,
				.table-responsive > .table-bordered > thead > tr > td:last-child,
				.table-responsive > .table-bordered > tbody > tr > th:last-child,
				.table-responsive > .table-bordered > tbody > tr > td:last-child,
				.table-responsive > .table-bordered > tfoot > tr > th:last-child,
				.table-responsive > .table-bordered > tfoot > tr > td:last-child {
					border-right: 0; }
				.table-responsive > .table-bordered > tbody > tr:last-child > th,
				.table-responsive > .table-bordered > tbody > tr:last-child > td,
				.table-responsive > .table-bordered > tfoot > tr:last-child > th,
				.table-responsive > .table-bordered > tfoot > tr:last-child > td {
					border-bottom: 0; } }

fieldset {
	min-width: 0;
	padding: 0;
	margin: 0;
	border: 0; }

legend {
	display: block;
	width: 100%;
	padding: 0;
	margin-bottom: 23px;
	font-size: 24px;
	line-height: inherit;
	color: #333333;
	border: 0;
	border-bottom: 1px solid #e5e5e5; }

label {
	display: inline-block;
	max-width: 100%;
	margin-bottom: 5px;
	font-weight: 700; }

input[type="search"] {
	-webkit-box-sizing: border-box;
	box-sizing: border-box;
	-webkit-appearance: none;
	-moz-appearance: none;
	     appearance: none; }

input[type="radio"],
input[type="checkbox"] {
	margin: 4px 0 0;
	margin-top: 1px \9;
	line-height: normal; }
	input[type="radio"][disabled], input[type="radio"].disabled,
	fieldset[disabled] input[type="radio"],
	input[type="checkbox"][disabled],
	input[type="checkbox"].disabled,
	fieldset[disabled]
	input[type="checkbox"] {
		cursor: not-allowed; }

input[type="file"] {
	display: block; }

input[type="range"] {
	display: block;
	width: 100%; }

select[multiple],
select[size] {
	height: auto; }

input[type="file"]:focus,
input[type="radio"]:focus,
input[type="checkbox"]:focus {
	outline: 5px auto -webkit-focus-ring-color;
	outline-offset: -2px; }

output {
	display: block;
	padding-top: 11px;
	font-size: 16px;
	line-height: 1.4375;
	color: #555555; }

.form-control {
	display: block;
	width: 100%;
	height: 37px;
	padding: 10px 14px;
	font-size: 16px;
	line-height: 1.4375;
	color: #555555;
	background-color: #fff;
	background-image: none;
	border: 1px solid #ccc;
	border-radius: 4px;
	-webkit-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075);
	box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075);
	-webkit-transition: border-color ease-in-out 0.15s, box-shadow ease-in-out 0.15s;
	-webkit-transition: border-color ease-in-out 0.15s, -webkit-box-shadow ease-in-out 0.15s;
	transition: border-color ease-in-out 0.15s, -webkit-box-shadow ease-in-out 0.15s;
	transition: border-color ease-in-out 0.15s, box-shadow ease-in-out 0.15s;
	transition: border-color ease-in-out 0.15s, box-shadow ease-in-out 0.15s, -webkit-box-shadow ease-in-out 0.15s; }
	.form-control:focus {
		border-color: #66afe9;
		outline: 0;
		-webkit-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075), 0 0 8px rgba(102, 175, 233, 0.6);
		box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075), 0 0 8px rgba(102, 175, 233, 0.6); }
	.form-control::-moz-placeholder {
		color: #5c5c5c !important;
		opacity: 1; }
	.form-control:-ms-input-placeholder {
		color: #5c5c5c !important; }
	.form-control::-webkit-input-placeholder {
		color: #5c5c5c !important; }
	.form-control::-ms-expand {
		background-color: transparent;
		border: 0; }
	.form-control[disabled], .form-control[readonly],
	fieldset[disabled] .form-control {
		background-color: #eeeeee;
		opacity: 1; }
	.form-control[disabled],
	fieldset[disabled] .form-control {
		cursor: not-allowed; }

textarea.form-control {
	height: auto; }

@media screen and (-webkit-min-device-pixel-ratio: 0) {
	input[type="date"].form-control,
	input[type="time"].form-control,
	input[type="datetime-local"].form-control,
	input[type="month"].form-control {
		line-height: 37px; }
	input[type="date"].input-sm, .input-group-sm > input.form-control[type="date"],
	.input-group-sm > input.input-group-addon[type="date"],
	.input-group-sm > .input-group-btn > input.btn[type="date"],
	.input-group-sm input[type="date"],
	input[type="time"].input-sm,
	.input-group-sm > input.form-control[type="time"],
	.input-group-sm > input.input-group-addon[type="time"],
	.input-group-sm > .input-group-btn > input.btn[type="time"],
	.input-group-sm
	input[type="time"],
	input[type="datetime-local"].input-sm,
	.input-group-sm > input.form-control[type="datetime-local"],
	.input-group-sm > input.input-group-addon[type="datetime-local"],
	.input-group-sm > .input-group-btn > input.btn[type="datetime-local"],
	.input-group-sm
	input[type="datetime-local"],
	input[type="month"].input-sm,
	.input-group-sm > input.form-control[type="month"],
	.input-group-sm > input.input-group-addon[type="month"],
	.input-group-sm > .input-group-btn > input.btn[type="month"],
	.input-group-sm
	input[type="month"] {
		line-height: 33px; }
	input[type="date"].input-lg, .input-group-lg > input.form-control[type="date"],
	.input-group-lg > input.input-group-addon[type="date"],
	.input-group-lg > .input-group-btn > input.btn[type="date"],
	.input-group-lg input[type="date"],
	input[type="time"].input-lg,
	.input-group-lg > input.form-control[type="time"],
	.input-group-lg > input.input-group-addon[type="time"],
	.input-group-lg > .input-group-btn > input.btn[type="time"],
	.input-group-lg
	input[type="time"],
	input[type="datetime-local"].input-lg,
	.input-group-lg > input.form-control[type="datetime-local"],
	.input-group-lg > input.input-group-addon[type="datetime-local"],
	.input-group-lg > .input-group-btn > input.btn[type="datetime-local"],
	.input-group-lg
	input[type="datetime-local"],
	input[type="month"].input-lg,
	.input-group-lg > input.form-control[type="month"],
	.input-group-lg > input.input-group-addon[type="month"],
	.input-group-lg > .input-group-btn > input.btn[type="month"],
	.input-group-lg
	input[type="month"] {
		line-height: 46px; } }

.form-group {
	margin-bottom: 15px; }

.radio,
.checkbox {
	position: relative;
	display: block;
	margin-top: 10px;
	margin-bottom: 10px; }
	.radio.disabled label,
	fieldset[disabled] .radio label,
	.checkbox.disabled label,
	fieldset[disabled]
	.checkbox label {
		cursor: not-allowed; }
	.radio label,
	.checkbox label {
		min-height: 23px;
		padding-left: 20px;
		margin-bottom: 0;
		font-weight: 400;
		cursor: pointer; }

.radio input[type="radio"],
.radio-inline input[type="radio"],
.checkbox input[type="checkbox"],
.checkbox-inline input[type="checkbox"] {
	position: absolute;
	margin-top: 4px \9;
	margin-left: -20px; }

.radio + .radio,
.checkbox + .checkbox {
	margin-top: -5px; }

.radio-inline,
.checkbox-inline {
	position: relative;
	display: inline-block;
	padding-left: 20px;
	margin-bottom: 0;
	font-weight: 400;
	vertical-align: middle;
	cursor: pointer; }
	.radio-inline.disabled,
	fieldset[disabled] .radio-inline,
	.checkbox-inline.disabled,
	fieldset[disabled]
	.checkbox-inline {
		cursor: not-allowed; }

.radio-inline + .radio-inline,
.checkbox-inline + .checkbox-inline {
	margin-top: 0;
	margin-left: 10px; }

.form-control-static {
	min-height: 39px;
	padding-top: 11px;
	padding-bottom: 11px;
	margin-bottom: 0; }
	.form-control-static.input-lg, .input-group-lg > .form-control-static.form-control,
	.input-group-lg > .form-control-static.input-group-addon,
	.input-group-lg > .input-group-btn > .form-control-static.btn, .form-control-static.input-sm, .input-group-sm > .form-control-static.form-control,
	.input-group-sm > .form-control-static.input-group-addon,
	.input-group-sm > .input-group-btn > .form-control-static.btn {
		padding-right: 0;
		padding-left: 0; }

.input-sm, .input-group-sm > .form-control,
.input-group-sm > .input-group-addon,
.input-group-sm > .input-group-btn > .btn {
	height: 33px;
	padding: 5px 10px;
	font-size: 14px;
	line-height: 1.5;
	border-radius: 3px; }

select.input-sm, .input-group-sm > select.form-control,
.input-group-sm > select.input-group-addon,
.input-group-sm > .input-group-btn > select.btn {
	height: 33px;
	line-height: 33px; }

textarea.input-sm, .input-group-sm > textarea.form-control,
.input-group-sm > textarea.input-group-addon,
.input-group-sm > .input-group-btn > textarea.btn,
select[multiple].input-sm,
.input-group-sm > select.form-control[multiple],
.input-group-sm > select.input-group-addon[multiple],
.input-group-sm > .input-group-btn > select.btn[multiple] {
	height: auto; }

.form-group-sm .form-control {
	height: 33px;
	padding: 5px 10px;
	font-size: 14px;
	line-height: 1.5;
	border-radius: 3px; }

.form-group-sm select.form-control {
	height: 33px;
	line-height: 33px; }

.form-group-sm textarea.form-control,
.form-group-sm select[multiple].form-control {
	height: auto; }

.form-group-sm .form-control-static {
	height: 33px;
	min-height: 37px;
	padding: 6px 10px;
	font-size: 14px;
	line-height: 1.5; }

.input-lg, .input-group-lg > .form-control,
.input-group-lg > .input-group-addon,
.input-group-lg > .input-group-btn > .btn {
	height: 46px;
	padding: 10px 16px;
	font-size: 18px;
	line-height: 1.3333333;
	border-radius: 6px; }

select.input-lg, .input-group-lg > select.form-control,
.input-group-lg > select.input-group-addon,
.input-group-lg > .input-group-btn > select.btn {
	height: 46px;
	line-height: 46px; }

textarea.input-lg, .input-group-lg > textarea.form-control,
.input-group-lg > textarea.input-group-addon,
.input-group-lg > .input-group-btn > textarea.btn,
select[multiple].input-lg,
.input-group-lg > select.form-control[multiple],
.input-group-lg > select.input-group-addon[multiple],
.input-group-lg > .input-group-btn > select.btn[multiple] {
	height: auto; }

.form-group-lg .form-control {
	height: 46px;
	padding: 10px 16px;
	font-size: 18px;
	line-height: 1.3333333;
	border-radius: 6px; }

.form-group-lg select.form-control {
	height: 46px;
	line-height: 46px; }

.form-group-lg textarea.form-control,
.form-group-lg select[multiple].form-control {
	height: auto; }

.form-group-lg .form-control-static {
	height: 46px;
	min-height: 41px;
	padding: 11px 16px;
	font-size: 18px;
	line-height: 1.3333333; }

.has-feedback {
	position: relative; }
	.has-feedback .form-control {
		padding-right: 46.25px; }

.form-control-feedback {
	position: absolute;
	top: 0;
	right: 0;
	z-index: 2;
	display: block;
	width: 37px;
	height: 37px;
	line-height: 37px;
	text-align: center;
	pointer-events: none; }

.input-lg + .form-control-feedback, .input-group-lg > .form-control + .form-control-feedback, .input-group-lg > .input-group-addon + .form-control-feedback, .input-group-lg > .input-group-btn > .btn + .form-control-feedback,
.input-group-lg + .form-control-feedback,
.form-group-lg .form-control + .form-control-feedback {
	width: 46px;
	height: 46px;
	line-height: 46px; }

.input-sm + .form-control-feedback, .input-group-sm > .form-control + .form-control-feedback, .input-group-sm > .input-group-addon + .form-control-feedback, .input-group-sm > .input-group-btn > .btn + .form-control-feedback,
.input-group-sm + .form-control-feedback,
.form-group-sm .form-control + .form-control-feedback {
	width: 33px;
	height: 33px;
	line-height: 33px; }

.has-success .help-block,
.has-success .control-label,
.has-success .radio,
.has-success .checkbox,
.has-success .radio-inline,
.has-success .checkbox-inline,
.has-success.radio label,
.has-success.checkbox label,
.has-success.radio-inline label,
.has-success.checkbox-inline label {
	color: #3c763d; }

.has-success .form-control {
	border-color: #3c763d;
	-webkit-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075);
	box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075); }
	.has-success .form-control:focus {
		border-color: #2b542c;
		-webkit-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075), 0 0 6px #67b168;
		box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075), 0 0 6px #67b168; }

.has-success .input-group-addon {
	color: #3c763d;
	background-color: #dff0d8;
	border-color: #3c763d; }

.has-success .form-control-feedback {
	color: #3c763d; }

.has-warning .help-block,
.has-warning .control-label,
.has-warning .radio,
.has-warning .checkbox,
.has-warning .radio-inline,
.has-warning .checkbox-inline,
.has-warning.radio label,
.has-warning.checkbox label,
.has-warning.radio-inline label,
.has-warning.checkbox-inline label {
	color: #8a6d3b; }

.has-warning .form-control {
	border-color: #8a6d3b;
	-webkit-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075);
	box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075); }
	.has-warning .form-control:focus {
		border-color: #66512c;
		-webkit-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075), 0 0 6px #c0a16b;
		box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075), 0 0 6px #c0a16b; }

.has-warning .input-group-addon {
	color: #8a6d3b;
	background-color: #fcf8e3;
	border-color: #8a6d3b; }

.has-warning .form-control-feedback {
	color: #8a6d3b; }

.has-error .help-block,
.has-error .control-label,
.has-error .radio,
.has-error .checkbox,
.has-error .radio-inline,
.has-error .checkbox-inline,
.has-error.radio label,
.has-error.checkbox label,
.has-error.radio-inline label,
.has-error.checkbox-inline label {
	color: #a94442; }

.has-error .form-control {
	border-color: #a94442;
	-webkit-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075);
	box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075); }
	.has-error .form-control:focus {
		border-color: #843534;
		-webkit-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075), 0 0 6px #ce8483;
		box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075), 0 0 6px #ce8483; }

.has-error .input-group-addon {
	color: #a94442;
	background-color: #f2dede;
	border-color: #a94442; }

.has-error .form-control-feedback {
	color: #a94442; }

.has-feedback label ~ .form-control-feedback {
	top: 28px; }

.has-feedback label.sr-only ~ .form-control-feedback {
	top: 0; }

.help-block {
	display: block;
	margin-top: 5px;
	margin-bottom: 10px;
	color: #737373; }

@media (min-width: 768px) {
	.form-inline .form-group {
		display: inline-block;
		margin-bottom: 0;
		vertical-align: middle; }
	.form-inline .form-control {
		display: inline-block;
		width: auto;
		vertical-align: middle; }
	.form-inline .form-control-static {
		display: inline-block; }
	.form-inline .input-group {
		display: inline-table;
		vertical-align: middle; }
		.form-inline .input-group .input-group-addon,
		.form-inline .input-group .input-group-btn,
		.form-inline .input-group .form-control {
			width: auto; }
	.form-inline .input-group > .form-control {
		width: 100%; }
	.form-inline .control-label {
		margin-bottom: 0;
		vertical-align: middle; }
	.form-inline .radio,
	.form-inline .checkbox {
		display: inline-block;
		margin-top: 0;
		margin-bottom: 0;
		vertical-align: middle; }
		.form-inline .radio label,
		.form-inline .checkbox label {
			padding-left: 0; }
	.form-inline .radio input[type="radio"],
	.form-inline .checkbox input[type="checkbox"] {
		position: relative;
		margin-left: 0; }
	.form-inline .has-feedback .form-control-feedback {
		top: 0; } }

.form-horizontal .radio,
.form-horizontal .checkbox,
.form-horizontal .radio-inline,
.form-horizontal .checkbox-inline {
	padding-top: 11px;
	margin-top: 0;
	margin-bottom: 0; }

.form-horizontal .radio,
.form-horizontal .checkbox {
	min-height: 34px; }

.form-horizontal .form-group {
	margin-right: -15px;
	margin-left: -15px; }
	.form-horizontal .form-group:before, .form-horizontal .form-group:after {
		display: table;
		content: " "; }
	.form-horizontal .form-group:after {
		clear: both; }

@media (min-width: 768px) {
	.form-horizontal .control-label {
		padding-top: 11px;
		margin-bottom: 0;
		text-align: right; } }

.form-horizontal .has-feedback .form-control-feedback {
	right: 15px; }

@media (min-width: 768px) {
	.form-horizontal .form-group-lg .control-label {
		padding-top: 11px;
		font-size: 18px; } }

@media (min-width: 768px) {
	.form-horizontal .form-group-sm .control-label {
		padding-top: 6px;
		font-size: 14px; } }

/*
	WET-BOEW
	@title: Bootstrap overrides for WET-BOEW - Core CSS - forms
 */
/*! Placeholders */
.btn.disabled, .btn[disabled], fieldset[disabled] .btn {
	border-style: solid; }

/*
 *  Firefox-safe line height on input[type="reset|button|submit"]
 */
input[type="reset"], input[type="button"], input[type="submit"] {
	height: 37px; }
	input[type="reset"].btn-lg, .btn-group-lg > input.btn[type="reset"], input[type="reset"].input-lg, .input-group-lg > input.form-control[type="reset"],
	.input-group-lg > input.input-group-addon[type="reset"],
	.input-group-lg > .input-group-btn > input.btn[type="reset"], input[type="button"].btn-lg, .btn-group-lg > input.btn[type="button"], input[type="button"].input-lg, .input-group-lg > input.form-control[type="button"],
	.input-group-lg > input.input-group-addon[type="button"],
	.input-group-lg > .input-group-btn > input.btn[type="button"], input[type="submit"].btn-lg, .btn-group-lg > input.btn[type="submit"], input[type="submit"].input-lg, .input-group-lg > input.form-control[type="submit"],
	.input-group-lg > input.input-group-addon[type="submit"],
	.input-group-lg > .input-group-btn > input.btn[type="submit"] {
		height: 46px; }
	input[type="reset"].btn-sm, .btn-group-sm > input.btn[type="reset"], input[type="reset"].input-sm, .input-group-sm > input.form-control[type="reset"],
	.input-group-sm > input.input-group-addon[type="reset"],
	.input-group-sm > .input-group-btn > input.btn[type="reset"], input[type="button"].btn-sm, .btn-group-sm > input.btn[type="button"], input[type="button"].input-sm, .input-group-sm > input.form-control[type="button"],
	.input-group-sm > input.input-group-addon[type="button"],
	.input-group-sm > .input-group-btn > input.btn[type="button"], input[type="submit"].btn-sm, .btn-group-sm > input.btn[type="submit"], input[type="submit"].input-sm, .input-group-sm > input.form-control[type="submit"],
	.input-group-sm > input.input-group-addon[type="submit"],
	.input-group-sm > .input-group-btn > input.btn[type="submit"] {
		height: 33px; }
	input[type="reset"].btn-xs, .btn-group-xs > input.btn[type="reset"], input[type="button"].btn-xs, .btn-group-xs > input.btn[type="button"], input[type="submit"].btn-xs, .btn-group-xs > input.btn[type="submit"] {
		height: 25px; }

/*
 *  Form control width
 *
 *  Default should be representative of the expected length of input.
 *  Full width should be only for cases when the expected length of input is
 *  greater than the available width.
 *  height:37px; rule of Bootstrap was overwritten by height: auto; first
 *  then a min-height specified, in order to address the issue #8492. July 2019.
 */
input[type=button], input[type=reset], input[type=submit] {
	height: auto;
	min-height: 37px; }

.form-control {
	height: auto;
	max-width: 100%;
	min-height: 37px;
	width: auto; }

/*
 * Explicit labels for checkbox and radio button inputs
 *
 * Allow the use of horizontal explicit labels instead of the default implicit
 * labelling pattern for checkbox and radio button inputs provided by Bootstrap.
 */
.form-inline .label-inline {
	position: relative;
	vertical-align: middle; }
	.form-inline .label-inline label {
		font-weight: 400;
		margin-bottom: 0px;
		padding-left: 2px; }

/*
 *  Fieldset/legend border position
 *
 *  Bootstrap puts the border below the legend which creates a visual
 *  separation between the legend and the fields to which it relates. Putting
 *  the border above eliminates that visual separation. Putting it on the
 *  fieldset element instead ensures that all fieldsets will have a separation
 *  even when no legend is used.
 */
legend {
	border-bottom: 0;
	float: left; }

fieldset {
	border-top: 1px solid #e5e5e5;
	padding-top: 10px;
	/*
	 *  Allows fieldSet/legend to have a bottom border under legend title
	 *  https://github.com/wet-boew/wet-boew/issues/7766
	 */
	/*
	 *  Fieldset/legend as a label for a group of checkboxes or radio buttons
	 *  https://github.com/wet-boew/wet-boew/issues/5797
	 */ }
	fieldset:first-child {
		border-top: 0; }
	fieldset.legend-brdr-bttm {
		border-top: 0; }
		fieldset.legend-brdr-bttm legend {
			border-bottom: 1px solid #e5e5e5;
			float: none;
			margin-bottom: 10px; }
	fieldset.chkbxrdio-grp {
		border-top: 0;
		padding-top: 0; }
		fieldset.chkbxrdio-grp legend {
			font-size: 16px;
			font-weight: bold;
			margin-bottom: 5px; }

/*
  WET-BOEW
  @title: Form additions to WET-BOEW
 */
label.required:before,
legend.required:before,
.checkbox.required:before, label.required strong.required,
legend.required strong.required,
.checkbox.required strong.required {
	color: #d3080c;
	font-weight: 700; }

label.required:before,
legend.required:before,
.checkbox.required:before {
	content: "* ";
	margin-left: -0.87em;
	vertical-align: top; }

.form-group.has-error .checkbox {
	color: #333333; }

.form-group .checkbox.checkbox-standalone label {
	font-weight: 700; }

[dir=rtl] label.required:before,
[dir=rtl] legend.required:before {
	margin-left: auto;
	margin-right: -0.87em; }

.btn {
	display: inline-block;
	margin-bottom: 0;
	font-weight: normal;
	text-align: center;
	white-space: nowrap;
	vertical-align: middle;
	-ms-touch-action: manipulation;
	    touch-action: manipulation;
	cursor: pointer;
	background-image: none;
	border: 1px solid transparent;
	padding: 10px 14px;
	font-size: 16px;
	line-height: 1.4375;
	border-radius: 4px;
	-webkit-user-select: none;
	-moz-user-select: none;
	-ms-user-select: none;
	user-select: none; }
	.btn:focus, .btn.focus, .btn:active:focus, .btn:active.focus, .btn.active:focus, .btn.active.focus {
		outline: 5px auto -webkit-focus-ring-color;
		outline-offset: -2px; }
	.btn:hover, .btn:focus, .btn.focus {
		color: #335075;
		text-decoration: none; }
	.btn:active, .btn.active {
		background-image: none;
		outline: 0;
		-webkit-box-shadow: inset 0 3px 5px rgba(0, 0, 0, 0.125);
		box-shadow: inset 0 3px 5px rgba(0, 0, 0, 0.125); }
	.btn.disabled, .btn[disabled],
	fieldset[disabled] .btn {
		cursor: not-allowed;
		filter: alpha(opacity=65);
		opacity: 0.65;
		-webkit-box-shadow: none;
		box-shadow: none; }

a.btn.disabled,
fieldset[disabled] a.btn {
	pointer-events: none; }

.btn-default {
	color: #335075;
	background-color: #eaebed;
	border-color: #dcdee1; }
	.btn-default:focus, .btn-default.focus {
		color: #335075;
		background-color: #cfd1d5;
		border-color: #989da6; }
	.btn-default:hover {
		color: #335075;
		background-color: #cfd1d5;
		border-color: #bbbfc5; }
	.btn-default:active, .btn-default.active,
	.open > .btn-default.dropdown-toggle {
		color: #335075;
		background-color: #cfd1d5;
		background-image: none;
		border-color: #bbbfc5; }
		.btn-default:active:hover, .btn-default:active:focus, .btn-default:active.focus, .btn-default.active:hover, .btn-default.active:focus, .btn-default.active.focus,
		.open > .btn-default.dropdown-toggle:hover,
		.open > .btn-default.dropdown-toggle:focus,
		.open > .btn-default.dropdown-toggle.focus {
			color: #335075;
			background-color: #bbbfc5;
			border-color: #989da6; }
	.btn-default.disabled:hover, .btn-default.disabled:focus, .btn-default.disabled.focus, .btn-default[disabled]:hover, .btn-default[disabled]:focus, .btn-default[disabled].focus,
	fieldset[disabled] .btn-default:hover,
	fieldset[disabled] .btn-default:focus,
	fieldset[disabled] .btn-default.focus {
		background-color: #eaebed;
		border-color: #dcdee1; }
	.btn-default .badge {
		color: #eaebed;
		background-color: #335075; }

.btn-primary {
	color: #fff;
	background-color: #2572b4;
	border-color: #143c5f; }
	.btn-primary:focus, .btn-primary.focus {
		color: #fff;
		background-color: #1c578a;
		border-color: black; }
	.btn-primary:hover {
		color: #fff;
		background-color: #1c578a;
		border-color: #091c2d; }
	.btn-primary:active, .btn-primary.active,
	.open > .btn-primary.dropdown-toggle {
		color: #fff;
		background-color: #1c578a;
		background-image: none;
		border-color: #091c2d; }
		.btn-primary:active:hover, .btn-primary:active:focus, .btn-primary:active.focus, .btn-primary.active:hover, .btn-primary.active:focus, .btn-primary.active.focus,
		.open > .btn-primary.dropdown-toggle:hover,
		.open > .btn-primary.dropdown-toggle:focus,
		.open > .btn-primary.dropdown-toggle.focus {
			color: #fff;
			background-color: #16446c;
			border-color: black; }
	.btn-primary.disabled:hover, .btn-primary.disabled:focus, .btn-primary.disabled.focus, .btn-primary[disabled]:hover, .btn-primary[disabled]:focus, .btn-primary[disabled].focus,
	fieldset[disabled] .btn-primary:hover,
	fieldset[disabled] .btn-primary:focus,
	fieldset[disabled] .btn-primary.focus {
		background-color: #2572b4;
		border-color: #143c5f; }
	.btn-primary .badge {
		color: #2572b4;
		background-color: #fff; }

.btn-success {
	color: #fff;
	background-color: #1b6c1c;
	border-color: #071a07; }
	.btn-success:focus, .btn-success.focus {
		color: #fff;
		background-color: #114311;
		border-color: black; }
	.btn-success:hover {
		color: #fff;
		background-color: #114311;
		border-color: black; }
	.btn-success:active, .btn-success.active,
	.open > .btn-success.dropdown-toggle {
		color: #fff;
		background-color: #114311;
		background-image: none;
		border-color: black; }
		.btn-success:active:hover, .btn-success:active:focus, .btn-success:active.focus, .btn-success.active:hover, .btn-success.active:focus, .btn-success.active.focus,
		.open > .btn-success.dropdown-toggle:hover,
		.open > .btn-success.dropdown-toggle:focus,
		.open > .btn-success.dropdown-toggle.focus {
			color: #fff;
			background-color: #0a270a;
			border-color: black; }
	.btn-success.disabled:hover, .btn-success.disabled:focus, .btn-success.disabled.focus, .btn-success[disabled]:hover, .btn-success[disabled]:focus, .btn-success[disabled].focus,
	fieldset[disabled] .btn-success:hover,
	fieldset[disabled] .btn-success:focus,
	fieldset[disabled] .btn-success.focus {
		background-color: #1b6c1c;
		border-color: #071a07; }
	.btn-success .badge {
		color: #1b6c1c;
		background-color: #fff; }

.btn-info {
	color: #fff;
	background-color: #4d4d4d;
	border-color: #1a1a1a; }
	.btn-info:focus, .btn-info.focus {
		color: #fff;
		background-color: #343333;
		border-color: black; }
	.btn-info:hover {
		color: #fff;
		background-color: #343333;
		border-color: black; }
	.btn-info:active, .btn-info.active,
	.open > .btn-info.dropdown-toggle {
		color: #fff;
		background-color: #343333;
		background-image: none;
		border-color: black; }
		.btn-info:active:hover, .btn-info:active:focus, .btn-info:active.focus, .btn-info.active:hover, .btn-info.active:focus, .btn-info.active.focus,
		.open > .btn-info.dropdown-toggle:hover,
		.open > .btn-info.dropdown-toggle:focus,
		.open > .btn-info.dropdown-toggle.focus {
			color: #fff;
			background-color: #222222;
			border-color: black; }
	.btn-info.disabled:hover, .btn-info.disabled:focus, .btn-info.disabled.focus, .btn-info[disabled]:hover, .btn-info[disabled]:focus, .btn-info[disabled].focus,
	fieldset[disabled] .btn-info:hover,
	fieldset[disabled] .btn-info:focus,
	fieldset[disabled] .btn-info.focus {
		background-color: #4d4d4d;
		border-color: #1a1a1a; }
	.btn-info .badge {
		color: #4d4d4d;
		background-color: #fff; }

.btn-warning {
	color: #000;
	background-color: #f2d40d;
	border-color: #917f08; }
	.btn-warning:focus, .btn-warning.focus {
		color: #000;
		background-color: #c2aa0a;
		border-color: #181501; }
	.btn-warning:hover {
		color: #000;
		background-color: #c2aa0a;
		border-color: #574c05; }
	.btn-warning:active, .btn-warning.active,
	.open > .btn-warning.dropdown-toggle {
		color: #000;
		background-color: #c2aa0a;
		background-image: none;
		border-color: #574c05; }
		.btn-warning:active:hover, .btn-warning:active:focus, .btn-warning:active.focus, .btn-warning.active:hover, .btn-warning.active:focus, .btn-warning.active.focus,
		.open > .btn-warning.dropdown-toggle:hover,
		.open > .btn-warning.dropdown-toggle:focus,
		.open > .btn-warning.dropdown-toggle.focus {
			color: #000;
			background-color: #a08c09;
			border-color: #181501; }
	.btn-warning.disabled:hover, .btn-warning.disabled:focus, .btn-warning.disabled.focus, .btn-warning[disabled]:hover, .btn-warning[disabled]:focus, .btn-warning[disabled].focus,
	fieldset[disabled] .btn-warning:hover,
	fieldset[disabled] .btn-warning:focus,
	fieldset[disabled] .btn-warning.focus {
		background-color: #f2d40d;
		border-color: #917f08; }
	.btn-warning .badge {
		color: #f2d40d;
		background-color: #000; }

.btn-danger {
	color: #fff;
	background-color: #bc3331;
	border-color: #6b1d1c; }
	.btn-danger:focus, .btn-danger.focus {
		color: #fff;
		background-color: #942826;
		border-color: #060202; }
	.btn-danger:hover {
		color: #fff;
		background-color: #942826;
		border-color: #3b100f; }
	.btn-danger:active, .btn-danger.active,
	.open > .btn-danger.dropdown-toggle {
		color: #fff;
		background-color: #942826;
		background-image: none;
		border-color: #3b100f; }
		.btn-danger:active:hover, .btn-danger:active:focus, .btn-danger:active.focus, .btn-danger.active:hover, .btn-danger.active:focus, .btn-danger.active.focus,
		.open > .btn-danger.dropdown-toggle:hover,
		.open > .btn-danger.dropdown-toggle:focus,
		.open > .btn-danger.dropdown-toggle.focus {
			color: #fff;
			background-color: #77201f;
			border-color: #060202; }
	.btn-danger.disabled:hover, .btn-danger.disabled:focus, .btn-danger.disabled.focus, .btn-danger[disabled]:hover, .btn-danger[disabled]:focus, .btn-danger[disabled].focus,
	fieldset[disabled] .btn-danger:hover,
	fieldset[disabled] .btn-danger:focus,
	fieldset[disabled] .btn-danger.focus {
		background-color: #bc3331;
		border-color: #6b1d1c; }
	.btn-danger .badge {
		color: #bc3331;
		background-color: #fff; }

.btn-link {
	font-weight: 400;
	color: #295376;
	border-radius: 0; }
	.btn-link, .btn-link:active, .btn-link.active, .btn-link[disabled],
	fieldset[disabled] .btn-link {
		background-color: transparent;
		-webkit-box-shadow: none;
		box-shadow: none; }
	.btn-link, .btn-link:hover, .btn-link:focus, .btn-link:active {
		border-color: transparent; }
	.btn-link:hover, .btn-link:focus {
		color: #0535d2;
		text-decoration: underline;
		background-color: transparent; }
	.btn-link[disabled]:hover, .btn-link[disabled]:focus,
	fieldset[disabled] .btn-link:hover,
	fieldset[disabled] .btn-link:focus {
		color: #6f6f6f;
		text-decoration: none; }

.btn-lg, .btn-group-lg > .btn {
	padding: 10px 16px;
	font-size: 18px;
	line-height: 1.3333333;
	border-radius: 6px; }

.btn-sm, .btn-group-sm > .btn {
	padding: 5px 10px;
	font-size: 14px;
	line-height: 1.5;
	border-radius: 3px; }

.btn-xs, .btn-group-xs > .btn {
	padding: 1px 5px;
	font-size: 14px;
	line-height: 1.5;
	border-radius: 3px; }

.btn-block {
	display: block;
	width: 100%; }

.btn-block + .btn-block {
	margin-top: 5px; }

input[type="submit"].btn-block,
input[type="reset"].btn-block,
input[type="button"].btn-block {
	width: 100%; }

/*
	WET-BOEW
	@title: Bootstrap overrides for WET-BOEW - Core CSS - button
 */
.btn-default:visited {
	color: #335075; }

.btn-primary:visited {
	color: #fff; }

.btn-success:visited {
	color: #fff; }

.btn-info:visited {
	color: #fff; }

.btn-warning:visited {
	color: #000; }

.btn-danger:visited {
	color: #fff; }

/*
 *  Use button border style 'outset' to give buttons depth, except when disabled
 */
.btn {
	border-style: outset;
	/*
	 * These two property overrides should be recommended upstream to
	 * Bootstrap as a fix for button wrapping (see wet-boew/wet-boew#4454)
	 */
	height: auto;
	min-height: 36px;
	min-width: 36px;
	white-space: normal; }

/*
 Polyfills
 */
/*
 * Web Experience Toolkit (WET) / Boîte à outils de l'expérience Web (BOEW)
 * wet-boew.github.io/wet-boew/License-en.html / wet-boew.github.io/wet-boew/Licence-fr.html
 */
datalist {
	display: none; }

/*
  WET-BOEW
  @title: Details/summary polyfill pre-Modernizr CSS
 */
summary {
	display: list-item !important;
	list-style-type: none;
	list-style-type: disclosure-closed;
	visibility: visible !important; }

details:not([open]) details summary, details .out details summary {
	display: none !important; }

details {
	margin-bottom: .25em; }
	details summary {
		border: 1px solid #ddd;
		border-radius: 4px;
		color: #295376;
		padding: 5px 15px; }
		details summary:focus, details summary:hover {
			background-color: transparent;
			color: #0535d2;
			text-decoration: underline; }
		details summary:focus {
			outline-style: dotted;
			outline-width: 1px; }
	details[open] {
		border: 1px solid #ddd;
		border-radius: 4px; }
		details[open] > summary {
			border: 0;
			border-bottom: 1px solid #ddd;
			border-bottom-left-radius: 0;
			border-bottom-right-radius: 0;
			list-style-type: disclosure-open;
			margin-bottom: .25em; }
	details:not([open]) {
		visibility: hidden; }
		details:not([open]) > details,
		details:not([open]) > * {
			display: none; }
	details.alert:not([open]) {
		visibility: visible; }

.tabpanels > details:not([open]) {
	visibility: visible; }

.wb-disable details {
	visibility: visible !important; }
	.wb-disable details > *:not(summary) {
		display: block !important; }

/*
 * Web Experience Toolkit (WET) / Boîte à outils de l'expérience Web (BOEW)
 * wet-boew.github.io/wet-boew/License-en.html / wet-boew.github.io/wet-boew/Licence-fr.html
 */
.datepicker-format {
	display: none; }

.picker-overlay {
	width: 19em; }

/*! Components (CSS type only) */
.fade {
	opacity: 0;
	-webkit-transition: opacity 0.15s linear;
	transition: opacity 0.15s linear; }
	.fade.in {
		opacity: 1; }

.collapse {
	display: none; }
	.collapse.in {
		display: block; }

tr.collapse.in {
	display: table-row; }

tbody.collapse.in {
	display: table-row-group; }

.collapsing {
	position: relative;
	height: 0;
	overflow: hidden;
	-webkit-transition-property: height, visibility;
	transition-property: height, visibility;
	-webkit-transition-duration: 0.35s;
	transition-duration: 0.35s;
	-webkit-transition-timing-function: ease;
	transition-timing-function: ease; }

/*
* Based upon jQuery Mobile Transitions (https://jquerymobile.com)
*
* Copyright 2010, 2013 jQuery Foundation, Inc. and other contributors
* Released under the MIT license.
* https://jquery.org/license
*
*/
/*! Placeholders */
.pop.in, .fade.in, .fade.reverse.out {
	opacity: 1;
	visibility: visible; }

.pop.out, .fade.out, .fade.reverse.in {
	opacity: 0;
	visibility: hidden; }

@keyframes spin {
	from {
		-webkit-transform: rotate(0);
		        transform: rotate(0); }
	to {
		-webkit-transform: rotate(360deg);
		        transform: rotate(360deg); } }

.out {
	display: none !important; }

.csstransitions .out {
	display: block !important; }

.pop {
	-webkit-transform-origin: 50% 50%;
	        transform-origin: 50% 50%; }
	.pop.in {
		-webkit-animation-duration: 350ms;
		        animation-duration: 350ms;
		-webkit-animation-name: popin;
		        animation-name: popin;
		-webkit-transform: scale(1);
		        transform: scale(1);
		visibility: visible; }
	.pop.out {
		-webkit-animation-duration: 100ms;
		        animation-duration: 100ms;
		-webkit-animation-name: fadeout;
		        animation-name: fadeout;
		visibility: hidden; }
	.pop.reverse.in {
		-webkit-animation-name: fadein;
		        animation-name: fadein; }
	.pop.reverse.out {
		-webkit-animation-name: popout;
		        animation-name: popout;
		-webkit-transform: scale(0.8);
		        transform: scale(0.8); }

@-webkit-keyframes popin {
	0% {
		opacity: 1;
		visibility: visible;
		-webkit-transform: scale(0.8);
		        transform: scale(0.8); }
	100% {
		opacity: 0;
		visibility: hidden;
		-webkit-transform: scale(1);
		        transform: scale(1); } }

@keyframes popin {
	0% {
		opacity: 1;
		visibility: visible;
		-webkit-transform: scale(0.8);
		        transform: scale(0.8); }
	100% {
		opacity: 0;
		visibility: hidden;
		-webkit-transform: scale(1);
		        transform: scale(1); } }

@-webkit-keyframes popout {
	0% {
		opacity: 1;
		visibility: visible;
		-webkit-transform: scale(1);
		        transform: scale(1); }
	100% {
		opacity: 0;
		visibility: hidden;
		-webkit-transform: scale(0.8);
		        transform: scale(0.8); } }

@keyframes popout {
	0% {
		opacity: 1;
		visibility: visible;
		-webkit-transform: scale(1);
		        transform: scale(1); }
	100% {
		opacity: 0;
		visibility: hidden;
		-webkit-transform: scale(0.8);
		        transform: scale(0.8); } }

.fade {
	-webkit-transition: all 0 ease 0;
	transition: all 0 ease 0; }
	.fade.in {
		-webkit-animation-duration: 225ms;
		        animation-duration: 225ms;
		-webkit-animation-name: fadein;
		        animation-name: fadein; }
	.fade.out {
		-webkit-animation-duration: 125ms;
		        animation-duration: 125ms;
		-webkit-animation-name: fadeout;
		        animation-name: fadeout;
		z-index: -1; }
		.fade.out.noheight {
			-webkit-animation-name: fadeoutnoheight;
			        animation-name: fadeoutnoheight;
			max-height: 0; }
	.fade.reverse.in {
		-webkit-animation-name: fadeout;
		        animation-name: fadeout; }
	.fade.reverse.out {
		-webkit-animation-name: fadein;
		        animation-name: fadein; }

@-webkit-keyframes fadein {
	0% {
		opacity: 0;
		visibility: hidden; }
	100% {
		opacity: 1;
		visibility: visible; } }

@keyframes fadein {
	0% {
		opacity: 0;
		visibility: hidden; }
	100% {
		opacity: 1;
		visibility: visible; } }

@-webkit-keyframes fadeout {
	0% {
		opacity: 1;
		visibility: visible; }
	100% {
		opacity: 0;
		visibility: hidden; } }

@keyframes fadeout {
	0% {
		opacity: 1;
		visibility: visible; }
	100% {
		opacity: 0;
		visibility: hidden; } }

@-webkit-keyframes fadeoutnoheight {
	0% {
		opacity: 1;
		visibility: visible;
		max-height: 100%; }
	99.9999% {
		max-height: 100%; }
	100% {
		opacity: 0;
		visibility: hidden;
		max-height: 0; } }

@keyframes fadeoutnoheight {
	0% {
		opacity: 1;
		visibility: visible;
		max-height: 100%; }
	99.9999% {
		max-height: 100%; }
	100% {
		opacity: 0;
		visibility: hidden;
		max-height: 0; } }

.slide.out, .slide.in {
	-webkit-animation-duration: 350ms;
	        animation-duration: 350ms;
	-webkit-animation-timing-function: ease-out;
	        animation-timing-function: ease-out; }

.slide.out {
	-webkit-animation-name: slideouttoleft;
	        animation-name: slideouttoleft;
	-webkit-transform: translateX(-100%);
	        transform: translateX(-100%);
	visibility: hidden; }

.slide.in {
	-webkit-animation-name: slideinfromright;
	        animation-name: slideinfromright;
	-webkit-transform: translateX(0);
	        transform: translateX(0);
	visibility: visible; }

.slide.reverse.out {
	-webkit-animation-name: slideouttoright;
	        animation-name: slideouttoright;
	-webkit-transform: translateX(100%);
	        transform: translateX(100%); }

.slide.reverse.in {
	-webkit-animation-name: slideinfromleft;
	        animation-name: slideinfromleft; }

/* keyframes for slidein from sides */
@-webkit-keyframes slideinfromright {
	0% {
		-webkit-transform: translateX(100%);
		        transform: translateX(100%); }
	100% {
		-webkit-transform: translateX(0);
		        transform: translateX(0); } }
@keyframes slideinfromright {
	0% {
		-webkit-transform: translateX(100%);
		        transform: translateX(100%); }
	100% {
		-webkit-transform: translateX(0);
		        transform: translateX(0); } }

@-webkit-keyframes slideinfromleft {
	0% {
		-webkit-transform: translateX(-100%);
		        transform: translateX(-100%); }
	100% {
		-webkit-transform: translateX(0);
		        transform: translateX(0); } }

@keyframes slideinfromleft {
	0% {
		-webkit-transform: translateX(-100%);
		        transform: translateX(-100%); }
	100% {
		-webkit-transform: translateX(0);
		        transform: translateX(0); } }

/* keyframes for slideout to sides */
@-webkit-keyframes slideouttoleft {
	0% {
		-webkit-transform: translateX(0);
		        transform: translateX(0);
		visibility: visible; }
	99% {
		visibility: visible; }
	100% {
		-webkit-transform: translateX(-100%);
		        transform: translateX(-100%);
		visibility: hidden; } }
@keyframes slideouttoleft {
	0% {
		-webkit-transform: translateX(0);
		        transform: translateX(0);
		visibility: visible; }
	99% {
		visibility: visible; }
	100% {
		-webkit-transform: translateX(-100%);
		        transform: translateX(-100%);
		visibility: hidden; } }

@-webkit-keyframes slideouttoright {
	0% {
		-webkit-transform: translateX(0);
		        transform: translateX(0);
		visibility: visible; }
	99% {
		visibility: visible; }
	100% {
		-webkit-transform: translateX(100%);
		        transform: translateX(100%);
		visibility: hidden; } }

@keyframes slideouttoright {
	0% {
		-webkit-transform: translateX(0);
		        transform: translateX(0);
		visibility: visible; }
	99% {
		visibility: visible; }
	100% {
		-webkit-transform: translateX(100%);
		        transform: translateX(100%);
		visibility: hidden; } }

.slidefade.out {
	-webkit-animation-duration: 225ms;
	        animation-duration: 225ms;
	-webkit-animation-name: slideouttoleft;
	        animation-name: slideouttoleft;
	-webkit-transform: translateX(-100%);
	        transform: translateX(-100%); }

.slidefade.in {
	-webkit-animation-duration: 200ms;
	        animation-duration: 200ms;
	-webkit-animation-name: fadein;
	        animation-name: fadein;
	-webkit-transform: translateX(0);
	        transform: translateX(0); }

.slidefade.reverse.out {
	-webkit-animation-name: slideouttoright;
	        animation-name: slideouttoright;
	-webkit-transform: translateX(100%);
	        transform: translateX(100%); }

/* slide up/down */
.slidevert.out, .slidevert.in {
	-webkit-animation-duration: 350ms;
	        animation-duration: 350ms;
	-webkit-animation-timing-function: ease-out;
	        animation-timing-function: ease-out; }

.slidevert.out {
	-webkit-animation-name: slideouttobottom;
	        animation-name: slideouttobottom;
	-webkit-transform: translateY(100%);
	        transform: translateY(100%);
	visibility: hidden; }

.slidevert.in {
	-webkit-animation-name: slideinfromtop;
	        animation-name: slideinfromtop;
	-webkit-transform: translateY(0);
	        transform: translateY(0);
	visibility: visible; }

.slidevert.reverse.out {
	-webkit-animation-name: slideouttotop;
	        animation-name: slideouttotop;
	-webkit-transform: translateY(-100%);
	        transform: translateY(-100%); }

.slidevert.reverse.in {
	-webkit-animation-name: slideinfrombottom;
	        animation-name: slideinfrombottom; }

@-webkit-keyframes slideinfromtop {
	0% {
		-webkit-transform: translateY(-100%);
		        transform: translateY(-100%); }
	100% {
		-webkit-transform: translateY(0);
		        transform: translateY(0); } }

@keyframes slideinfromtop {
	0% {
		-webkit-transform: translateY(-100%);
		        transform: translateY(-100%); }
	100% {
		-webkit-transform: translateY(0);
		        transform: translateY(0); } }

@-webkit-keyframes slideouttotop {
	0% {
		-webkit-transform: translateY(0);
		        transform: translateY(0);
		visibility: visible; }
	99% {
		visibility: visible; }
	100% {
		-webkit-transform: translateY(-100%);
		        transform: translateY(-100%);
		visibility: hidden; } }

@keyframes slideouttotop {
	0% {
		-webkit-transform: translateY(0);
		        transform: translateY(0);
		visibility: visible; }
	99% {
		visibility: visible; }
	100% {
		-webkit-transform: translateY(-100%);
		        transform: translateY(-100%);
		visibility: hidden; } }

@-webkit-keyframes slideinfrombottom {
	0% {
		-webkit-transform: translateY(100%);
		        transform: translateY(100%); }
	100% {
		-webkit-transform: translateY(0);
		        transform: translateY(0); } }

@keyframes slideinfrombottom {
	0% {
		-webkit-transform: translateY(100%);
		        transform: translateY(100%); }
	100% {
		-webkit-transform: translateY(0);
		        transform: translateY(0); } }

@-webkit-keyframes slideouttobottom {
	0% {
		-webkit-transform: translateY(0);
		        transform: translateY(0);
		visibility: visible; }
	99% {
		visibility: visible; }
	100% {
		-webkit-transform: translateY(100%);
		        transform: translateY(100%);
		visibility: hidden; } }

@keyframes slideouttobottom {
	0% {
		-webkit-transform: translateY(0);
		        transform: translateY(0);
		visibility: visible; }
	99% {
		visibility: visible; }
	100% {
		-webkit-transform: translateY(100%);
		        transform: translateY(100%);
		visibility: hidden; } }

.caret {
	display: inline-block;
	width: 0;
	height: 0;
	margin-left: 2px;
	vertical-align: middle;
	border-top: 4px dashed;
	border-top: 4px solid \9;
	border-right: 4px solid transparent;
	border-left: 4px solid transparent; }

.dropup,
.dropdown {
	position: relative; }

.dropdown-toggle:focus {
	outline: 0; }

.dropdown-menu {
	position: absolute;
	top: 100%;
	left: 0;
	z-index: 1000;
	display: none;
	float: left;
	min-width: 160px;
	padding: 5px 0;
	margin: 2px 0 0;
	font-size: 16px;
	text-align: left;
	list-style: none;
	background-color: #fff;
	background-clip: padding-box;
	border: 1px solid #ccc;
	border: 1px solid rgba(0, 0, 0, 0.15);
	border-radius: 4px;
	-webkit-box-shadow: 0 6px 12px rgba(0, 0, 0, 0.175);
	box-shadow: 0 6px 12px rgba(0, 0, 0, 0.175); }
	.dropdown-menu.pull-right {
		right: 0;
		left: auto; }
	.dropdown-menu .divider {
		height: 1px;
		margin: 10.5px 0;
		overflow: hidden;
		background-color: #e5e5e5; }
	.dropdown-menu > li > a {
		display: block;
		padding: 3px 20px;
		clear: both;
		font-weight: 400;
		line-height: 1.4375;
		color: #333333;
		white-space: nowrap; }
		.dropdown-menu > li > a:hover, .dropdown-menu > li > a:focus {
			color: #262626;
			text-decoration: none;
			background-color: #f5f5f5; }

.dropdown-menu > .active > a, .dropdown-menu > .active > a:hover, .dropdown-menu > .active > a:focus {
	color: #fff;
	text-decoration: none;
	background-color: #2572b4;
	outline: 0; }

.dropdown-menu > .disabled > a, .dropdown-menu > .disabled > a:hover, .dropdown-menu > .disabled > a:focus {
	color: #6f6f6f; }

.dropdown-menu > .disabled > a:hover, .dropdown-menu > .disabled > a:focus {
	text-decoration: none;
	cursor: not-allowed;
	background-color: transparent;
	background-image: none;
	filter: progid:DXImageTransform.Microsoft.gradient(enabled = false); }

.open > .dropdown-menu {
	display: block; }

.open > a {
	outline: 0; }

.dropdown-menu-right {
	right: 0;
	left: auto; }

.dropdown-menu-left {
	right: auto;
	left: 0; }

.dropdown-header {
	display: block;
	padding: 3px 20px;
	font-size: 14px;
	line-height: 1.4375;
	color: #6f6f6f;
	white-space: nowrap; }

.dropdown-backdrop {
	position: fixed;
	top: 0;
	right: 0;
	bottom: 0;
	left: 0;
	z-index: 990; }

.pull-right > .dropdown-menu {
	right: 0;
	left: auto; }

.dropup .caret,
.navbar-fixed-bottom .dropdown .caret {
	content: "";
	border-top: 0;
	border-bottom: 4px dashed;
	border-bottom: 4px solid \9; }

.dropup .dropdown-menu,
.navbar-fixed-bottom .dropdown .dropdown-menu {
	top: auto;
	bottom: 100%;
	margin-bottom: 2px; }

@media (min-width: 768px) {
	.navbar-right .dropdown-menu {
		right: 0;
		left: auto; }
	.navbar-right .dropdown-menu-left {
		left: 0;
		right: auto; } }

.btn-group,
.btn-group-vertical {
	position: relative;
	display: inline-block;
	vertical-align: middle; }
	.btn-group > .btn,
	.btn-group-vertical > .btn {
		position: relative;
		float: left; }
		.btn-group > .btn:hover, .btn-group > .btn:focus, .btn-group > .btn:active, .btn-group > .btn.active,
		.btn-group-vertical > .btn:hover,
		.btn-group-vertical > .btn:focus,
		.btn-group-vertical > .btn:active,
		.btn-group-vertical > .btn.active {
			z-index: 2; }

.btn-group .btn + .btn,
.btn-group .btn + .btn-group,
.btn-group .btn-group + .btn,
.btn-group .btn-group + .btn-group {
	margin-left: -1px; }

.btn-toolbar {
	margin-left: -5px; }
	.btn-toolbar:before, .btn-toolbar:after {
		display: table;
		content: " "; }
	.btn-toolbar:after {
		clear: both; }
	.btn-toolbar .btn,
	.btn-toolbar .btn-group,
	.btn-toolbar .input-group {
		float: left; }
	.btn-toolbar > .btn,
	.btn-toolbar > .btn-group,
	.btn-toolbar > .input-group {
		margin-left: 5px; }

.btn-group > .btn:not(:first-child):not(:last-child):not(.dropdown-toggle) {
	border-radius: 0; }

.btn-group > .btn:first-child {
	margin-left: 0; }
	.btn-group > .btn:first-child:not(:last-child):not(.dropdown-toggle) {
		border-top-right-radius: 0;
		border-bottom-right-radius: 0; }

.btn-group > .btn:last-child:not(:first-child),
.btn-group > .dropdown-toggle:not(:first-child) {
	border-top-left-radius: 0;
	border-bottom-left-radius: 0; }

.btn-group > .btn-group {
	float: left; }

.btn-group > .btn-group:not(:first-child):not(:last-child) > .btn {
	border-radius: 0; }

.btn-group > .btn-group:first-child:not(:last-child) > .btn:last-child,
.btn-group > .btn-group:first-child:not(:last-child) > .dropdown-toggle {
	border-top-right-radius: 0;
	border-bottom-right-radius: 0; }

.btn-group > .btn-group:last-child:not(:first-child) > .btn:first-child {
	border-top-left-radius: 0;
	border-bottom-left-radius: 0; }

.btn-group .dropdown-toggle:active,
.btn-group.open .dropdown-toggle {
	outline: 0; }

.btn-group > .btn + .dropdown-toggle {
	padding-right: 8px;
	padding-left: 8px; }

.btn-group > .btn-lg + .dropdown-toggle, .btn-group-lg.btn-group > .btn + .dropdown-toggle {
	padding-right: 12px;
	padding-left: 12px; }

.btn-group.open .dropdown-toggle {
	-webkit-box-shadow: inset 0 3px 5px rgba(0, 0, 0, 0.125);
	box-shadow: inset 0 3px 5px rgba(0, 0, 0, 0.125); }
	.btn-group.open .dropdown-toggle.btn-link {
		-webkit-box-shadow: none;
		box-shadow: none; }

.btn .caret {
	margin-left: 0; }

.btn-lg .caret, .btn-group-lg > .btn .caret {
	border-width: 5px 5px 0;
	border-bottom-width: 0; }

.dropup .btn-lg .caret, .dropup .btn-group-lg > .btn .caret {
	border-width: 0 5px 5px; }

.btn-group-vertical > .btn,
.btn-group-vertical > .btn-group,
.btn-group-vertical > .btn-group > .btn {
	display: block;
	float: none;
	width: 100%;
	max-width: 100%; }

.btn-group-vertical > .btn-group:before, .btn-group-vertical > .btn-group:after {
	display: table;
	content: " "; }

.btn-group-vertical > .btn-group:after {
	clear: both; }

.btn-group-vertical > .btn-group > .btn {
	float: none; }

.btn-group-vertical > .btn + .btn,
.btn-group-vertical > .btn + .btn-group,
.btn-group-vertical > .btn-group + .btn,
.btn-group-vertical > .btn-group + .btn-group {
	margin-top: -1px;
	margin-left: 0; }

.btn-group-vertical > .btn:not(:first-child):not(:last-child) {
	border-radius: 0; }

.btn-group-vertical > .btn:first-child:not(:last-child) {
	border-top-left-radius: 4px;
	border-top-right-radius: 4px;
	border-bottom-right-radius: 0;
	border-bottom-left-radius: 0; }

.btn-group-vertical > .btn:last-child:not(:first-child) {
	border-top-left-radius: 0;
	border-top-right-radius: 0;
	border-bottom-right-radius: 4px;
	border-bottom-left-radius: 4px; }

.btn-group-vertical > .btn-group:not(:first-child):not(:last-child) > .btn {
	border-radius: 0; }

.btn-group-vertical > .btn-group:first-child:not(:last-child) > .btn:last-child,
.btn-group-vertical > .btn-group:first-child:not(:last-child) > .dropdown-toggle {
	border-bottom-right-radius: 0;
	border-bottom-left-radius: 0; }

.btn-group-vertical > .btn-group:last-child:not(:first-child) > .btn:first-child {
	border-top-left-radius: 0;
	border-top-right-radius: 0; }

.btn-group-justified {
	display: table;
	width: 100%;
	table-layout: fixed;
	border-collapse: separate; }
	.btn-group-justified > .btn,
	.btn-group-justified > .btn-group {
		display: table-cell;
		float: none;
		width: 1%; }
	.btn-group-justified > .btn-group .btn {
		width: 100%; }
	.btn-group-justified > .btn-group .dropdown-menu {
		left: auto; }

[data-toggle="buttons"] > .btn input[type="radio"],
[data-toggle="buttons"] > .btn input[type="checkbox"],
[data-toggle="buttons"] > .btn-group > .btn input[type="radio"],
[data-toggle="buttons"] > .btn-group > .btn input[type="checkbox"] {
	position: absolute;
	clip: rect(0, 0, 0, 0);
	pointer-events: none; }

.input-group {
	position: relative;
	display: table;
	border-collapse: separate; }
	.input-group[class*="col-"] {
		float: none;
		padding-right: 0;
		padding-left: 0; }
	.input-group .form-control {
		position: relative;
		z-index: 2;
		float: left;
		width: 100%;
		margin-bottom: 0; }
		.input-group .form-control:focus {
			z-index: 3; }

.input-group-addon,
.input-group-btn,
.input-group .form-control {
	display: table-cell; }
	.input-group-addon:not(:first-child):not(:last-child),
	.input-group-btn:not(:first-child):not(:last-child),
	.input-group .form-control:not(:first-child):not(:last-child) {
		border-radius: 0; }

.input-group-addon,
.input-group-btn {
	width: 1%;
	white-space: nowrap;
	vertical-align: middle; }

.input-group-addon {
	padding: 10px 14px;
	font-size: 16px;
	font-weight: 400;
	line-height: 1;
	color: #555555;
	text-align: center;
	background-color: #eeeeee;
	border: 1px solid #ccc;
	border-radius: 4px; }
	.input-group-addon.input-sm,
	.input-group-sm > .input-group-addon,
	.input-group-sm > .input-group-btn > .input-group-addon.btn {
		padding: 5px 10px;
		font-size: 14px;
		border-radius: 3px; }
	.input-group-addon.input-lg,
	.input-group-lg > .input-group-addon,
	.input-group-lg > .input-group-btn > .input-group-addon.btn {
		padding: 10px 16px;
		font-size: 18px;
		border-radius: 6px; }
	.input-group-addon input[type="radio"],
	.input-group-addon input[type="checkbox"] {
		margin-top: 0; }

.input-group .form-control:first-child,
.input-group-addon:first-child,
.input-group-btn:first-child > .btn,
.input-group-btn:first-child > .btn-group > .btn,
.input-group-btn:first-child > .dropdown-toggle,
.input-group-btn:last-child > .btn:not(:last-child):not(.dropdown-toggle),
.input-group-btn:last-child > .btn-group:not(:last-child) > .btn {
	border-top-right-radius: 0;
	border-bottom-right-radius: 0; }

.input-group-addon:first-child {
	border-right: 0; }

.input-group .form-control:last-child,
.input-group-addon:last-child,
.input-group-btn:last-child > .btn,
.input-group-btn:last-child > .btn-group > .btn,
.input-group-btn:last-child > .dropdown-toggle,
.input-group-btn:first-child > .btn:not(:first-child),
.input-group-btn:first-child > .btn-group:not(:first-child) > .btn {
	border-top-left-radius: 0;
	border-bottom-left-radius: 0; }

.input-group-addon:last-child {
	border-left: 0; }

.input-group-btn {
	position: relative;
	font-size: 0;
	white-space: nowrap; }
	.input-group-btn > .btn {
		position: relative; }
		.input-group-btn > .btn + .btn {
			margin-left: -1px; }
		.input-group-btn > .btn:hover, .input-group-btn > .btn:focus, .input-group-btn > .btn:active {
			z-index: 2; }
	.input-group-btn:first-child > .btn,
	.input-group-btn:first-child > .btn-group {
		margin-right: -1px; }
	.input-group-btn:last-child > .btn,
	.input-group-btn:last-child > .btn-group {
		z-index: 2;
		margin-left: -1px; }

.nav {
	padding-left: 0;
	margin-bottom: 0;
	list-style: none; }
	.nav:before, .nav:after {
		display: table;
		content: " "; }
	.nav:after {
		clear: both; }
	.nav > li {
		position: relative;
		display: block; }
		.nav > li > a {
			position: relative;
			display: block;
			padding: 10px 15px; }
			.nav > li > a:hover, .nav > li > a:focus {
				text-decoration: none;
				background-color: #eeeeee; }
		.nav > li.disabled > a {
			color: #6f6f6f; }
			.nav > li.disabled > a:hover, .nav > li.disabled > a:focus {
				color: #6f6f6f;
				text-decoration: none;
				cursor: not-allowed;
				background-color: transparent; }
	.nav .open > a, .nav .open > a:hover, .nav .open > a:focus {
		background-color: #eeeeee;
		border-color: #295376; }
	.nav .nav-divider {
		height: 1px;
		margin: 10.5px 0;
		overflow: hidden;
		background-color: #e5e5e5; }
	.nav > li > a > img {
		max-width: none; }

.nav-tabs {
	border-bottom: 1px solid #ddd; }
	.nav-tabs > li {
		float: left;
		margin-bottom: -1px; }
		.nav-tabs > li > a {
			margin-right: 2px;
			line-height: 1.4375;
			border: 1px solid transparent;
			border-radius: 4px 4px 0 0; }
			.nav-tabs > li > a:hover {
				border-color: #eeeeee #eeeeee #ddd; }
		.nav-tabs > li.active > a, .nav-tabs > li.active > a:hover, .nav-tabs > li.active > a:focus {
			color: #555555;
			cursor: default;
			background-color: #fff;
			border: 1px solid #ddd;
			border-bottom-color: transparent; }

.nav-pills > li {
	float: left; }
	.nav-pills > li > a {
		border-radius: 4px; }
	.nav-pills > li + li {
		margin-left: 2px; }
	.nav-pills > li.active > a, .nav-pills > li.active > a:hover, .nav-pills > li.active > a:focus {
		color: #fff;
		background-color: #2572b4; }

.nav-stacked > li {
	float: none; }
	.nav-stacked > li + li {
		margin-top: 2px;
		margin-left: 0; }

.nav-justified, .nav-tabs.nav-justified {
	width: 100%; }
	.nav-justified > li, .nav-tabs.nav-justified > li {
		float: none; }
		.nav-justified > li > a, .nav-tabs.nav-justified > li > a {
			margin-bottom: 5px;
			text-align: center; }
	.nav-justified > .dropdown .dropdown-menu {
		top: auto;
		left: auto; }
	@media (min-width: 768px) {
		.nav-justified > li, .nav-tabs.nav-justified > li {
			display: table-cell;
			width: 1%; }
			.nav-justified > li > a, .nav-tabs.nav-justified > li > a {
				margin-bottom: 0; } }

.nav-tabs-justified, .nav-tabs.nav-justified {
	border-bottom: 0; }
	.nav-tabs-justified > li > a, .nav-tabs.nav-justified > li > a {
		margin-right: 0;
		border-radius: 4px; }
	.nav-tabs-justified > .active > a, .nav-tabs.nav-justified > .active > a,
	.nav-tabs-justified > .active > a:hover,
	.nav-tabs.nav-justified > .active > a:hover,
	.nav-tabs-justified > .active > a:focus,
	.nav-tabs.nav-justified > .active > a:focus {
		border: 1px solid #ddd; }
	@media (min-width: 768px) {
		.nav-tabs-justified > li > a, .nav-tabs.nav-justified > li > a {
			border-bottom: 1px solid #ddd;
			border-radius: 4px 4px 0 0; }
		.nav-tabs-justified > .active > a, .nav-tabs.nav-justified > .active > a,
		.nav-tabs-justified > .active > a:hover,
		.nav-tabs.nav-justified > .active > a:hover,
		.nav-tabs-justified > .active > a:focus,
		.nav-tabs.nav-justified > .active > a:focus {
			border-bottom-color: #fff; } }

.tab-content > .tab-pane {
	display: none; }

.tab-content > .active {
	display: block; }

.nav-tabs .dropdown-menu {
	margin-top: -1px;
	border-top-left-radius: 0;
	border-top-right-radius: 0; }

.navbar {
	position: relative;
	min-height: 50px;
	margin-bottom: 23px;
	border: 1px solid transparent; }
	.navbar:before, .navbar:after {
		display: table;
		content: " "; }
	.navbar:after {
		clear: both; }
	@media (min-width: 768px) {
		.navbar {
			border-radius: 4px; } }

.navbar-header:before, .navbar-header:after {
	display: table;
	content: " "; }

.navbar-header:after {
	clear: both; }

@media (min-width: 768px) {
	.navbar-header {
		float: left; } }

.navbar-collapse {
	padding-right: 15px;
	padding-left: 15px;
	overflow-x: visible;
	border-top: 1px solid transparent;
	-webkit-box-shadow: inset 0 1px 0 rgba(255, 255, 255, 0.1);
	        box-shadow: inset 0 1px 0 rgba(255, 255, 255, 0.1);
	-webkit-overflow-scrolling: touch; }
	.navbar-collapse:before, .navbar-collapse:after {
		display: table;
		content: " "; }
	.navbar-collapse:after {
		clear: both; }
	.navbar-collapse.in {
		overflow-y: auto; }
	@media (min-width: 768px) {
		.navbar-collapse {
			width: auto;
			border-top: 0;
			-webkit-box-shadow: none;
			        box-shadow: none; }
			.navbar-collapse.collapse {
				display: block !important;
				height: auto !important;
				padding-bottom: 0;
				overflow: visible !important; }
			.navbar-collapse.in {
				overflow-y: visible; }
			.navbar-fixed-top .navbar-collapse,
			.navbar-static-top .navbar-collapse,
			.navbar-fixed-bottom .navbar-collapse {
				padding-right: 0;
				padding-left: 0; } }

.navbar-fixed-top,
.navbar-fixed-bottom {
	position: fixed;
	right: 0;
	left: 0;
	z-index: 1030; }
	.navbar-fixed-top .navbar-collapse,
	.navbar-fixed-bottom .navbar-collapse {
		max-height: 340px; }
		@media (max-device-width: 480px) and (orientation: landscape) {
			.navbar-fixed-top .navbar-collapse,
			.navbar-fixed-bottom .navbar-collapse {
				max-height: 200px; } }
	@media (min-width: 768px) {
		.navbar-fixed-top,
		.navbar-fixed-bottom {
			border-radius: 0; } }

.navbar-fixed-top {
	top: 0;
	border-width: 0 0 1px; }

.navbar-fixed-bottom {
	bottom: 0;
	margin-bottom: 0;
	border-width: 1px 0 0; }

.container > .navbar-header,
.container > .navbar-collapse,
.container-fluid > .navbar-header,
.container-fluid > .navbar-collapse {
	margin-right: -15px;
	margin-left: -15px; }
	@media (min-width: 768px) {
		.container > .navbar-header,
		.container > .navbar-collapse,
		.container-fluid > .navbar-header,
		.container-fluid > .navbar-collapse {
			margin-right: 0;
			margin-left: 0; } }

.navbar-static-top {
	z-index: 1000;
	border-width: 0 0 1px; }
	@media (min-width: 768px) {
		.navbar-static-top {
			border-radius: 0; } }

.navbar-brand {
	float: left;
	height: 50px;
	padding: 13.5px 15px;
	font-size: 18px;
	line-height: 23px; }
	.navbar-brand:hover, .navbar-brand:focus {
		text-decoration: none; }
	.navbar-brand > img {
		display: block; }
	@media (min-width: 768px) {
		.navbar > .container .navbar-brand,
		.navbar > .container-fluid .navbar-brand {
			margin-left: -15px; } }

.navbar-toggle {
	position: relative;
	float: right;
	padding: 9px 10px;
	margin-right: 15px;
	margin-top: 8px;
	margin-bottom: 8px;
	background-color: transparent;
	background-image: none;
	border: 1px solid transparent;
	border-radius: 4px; }
	.navbar-toggle:focus {
		outline: 0; }
	.navbar-toggle .icon-bar {
		display: block;
		width: 22px;
		height: 2px;
		border-radius: 1px; }
	.navbar-toggle .icon-bar + .icon-bar {
		margin-top: 4px; }
	@media (min-width: 768px) {
		.navbar-toggle {
			display: none; } }

.navbar-nav {
	margin: 6.75px -15px; }
	.navbar-nav > li > a {
		padding-top: 10px;
		padding-bottom: 10px;
		line-height: 23px; }
	@media (max-width: 767px) {
		.navbar-nav .open .dropdown-menu {
			position: static;
			float: none;
			width: auto;
			margin-top: 0;
			background-color: transparent;
			border: 0;
			-webkit-box-shadow: none;
			        box-shadow: none; }
			.navbar-nav .open .dropdown-menu > li > a,
			.navbar-nav .open .dropdown-menu .dropdown-header {
				padding: 5px 15px 5px 25px; }
			.navbar-nav .open .dropdown-menu > li > a {
				line-height: 23px; }
				.navbar-nav .open .dropdown-menu > li > a:hover, .navbar-nav .open .dropdown-menu > li > a:focus {
					background-image: none; } }
	@media (min-width: 768px) {
		.navbar-nav {
			float: left;
			margin: 0; }
			.navbar-nav > li {
				float: left; }
				.navbar-nav > li > a {
					padding-top: 13.5px;
					padding-bottom: 13.5px; } }

.navbar-form {
	padding: 10px 15px;
	margin-right: -15px;
	margin-left: -15px;
	border-top: 1px solid transparent;
	border-bottom: 1px solid transparent;
	-webkit-box-shadow: inset 0 1px 0 rgba(255, 255, 255, 0.1), 0 1px 0 rgba(255, 255, 255, 0.1);
	box-shadow: inset 0 1px 0 rgba(255, 255, 255, 0.1), 0 1px 0 rgba(255, 255, 255, 0.1);
	margin-top: 6.5px;
	margin-bottom: 6.5px; }
	@media (min-width: 768px) {
		.navbar-form .form-group {
			display: inline-block;
			margin-bottom: 0;
			vertical-align: middle; }
		.navbar-form .form-control {
			display: inline-block;
			width: auto;
			vertical-align: middle; }
		.navbar-form .form-control-static {
			display: inline-block; }
		.navbar-form .input-group {
			display: inline-table;
			vertical-align: middle; }
			.navbar-form .input-group .input-group-addon,
			.navbar-form .input-group .input-group-btn,
			.navbar-form .input-group .form-control {
				width: auto; }
		.navbar-form .input-group > .form-control {
			width: 100%; }
		.navbar-form .control-label {
			margin-bottom: 0;
			vertical-align: middle; }
		.navbar-form .radio,
		.navbar-form .checkbox {
			display: inline-block;
			margin-top: 0;
			margin-bottom: 0;
			vertical-align: middle; }
			.navbar-form .radio label,
			.navbar-form .checkbox label {
				padding-left: 0; }
		.navbar-form .radio input[type="radio"],
		.navbar-form .checkbox input[type="checkbox"] {
			position: relative;
			margin-left: 0; }
		.navbar-form .has-feedback .form-control-feedback {
			top: 0; } }
	@media (max-width: 767px) {
		.navbar-form .form-group {
			margin-bottom: 5px; }
			.navbar-form .form-group:last-child {
				margin-bottom: 0; } }
	@media (min-width: 768px) {
		.navbar-form {
			width: auto;
			padding-top: 0;
			padding-bottom: 0;
			margin-right: 0;
			margin-left: 0;
			border: 0;
			-webkit-box-shadow: none;
			box-shadow: none; } }

.navbar-nav > li > .dropdown-menu {
	margin-top: 0;
	border-top-left-radius: 0;
	border-top-right-radius: 0; }

.navbar-fixed-bottom .navbar-nav > li > .dropdown-menu {
	margin-bottom: 0;
	border-top-left-radius: 4px;
	border-top-right-radius: 4px;
	border-bottom-right-radius: 0;
	border-bottom-left-radius: 0; }

.navbar-btn {
	margin-top: 6.5px;
	margin-bottom: 6.5px; }
	.navbar-btn.btn-sm, .btn-group-sm > .navbar-btn.btn {
		margin-top: 8.5px;
		margin-bottom: 8.5px; }
	.navbar-btn.btn-xs, .btn-group-xs > .navbar-btn.btn {
		margin-top: 14px;
		margin-bottom: 14px; }

.navbar-text {
	margin-top: 13.5px;
	margin-bottom: 13.5px; }
	@media (min-width: 768px) {
		.navbar-text {
			float: left;
			margin-right: 15px;
			margin-left: 15px; } }

@media (min-width: 768px) {
	.navbar-left {
		float: left !important; }
	.navbar-right {
		float: right !important;
		margin-right: -15px; }
		.navbar-right ~ .navbar-right {
			margin-right: 0; } }

.navbar-default {
	background-color: #f8f8f8;
	border-color: #e7e7e7; }
	.navbar-default .navbar-brand {
		color: #777; }
		.navbar-default .navbar-brand:hover, .navbar-default .navbar-brand:focus {
			color: #5e5d5d;
			background-color: transparent; }
	.navbar-default .navbar-text {
		color: #777; }
	.navbar-default .navbar-nav > li > a {
		color: #777; }
		.navbar-default .navbar-nav > li > a:hover, .navbar-default .navbar-nav > li > a:focus {
			color: #333;
			background-color: transparent; }
	.navbar-default .navbar-nav > .active > a, .navbar-default .navbar-nav > .active > a:hover, .navbar-default .navbar-nav > .active > a:focus {
		color: #555;
		background-color: #e7e7e7; }
	.navbar-default .navbar-nav > .disabled > a, .navbar-default .navbar-nav > .disabled > a:hover, .navbar-default .navbar-nav > .disabled > a:focus {
		color: #ccc;
		background-color: transparent; }
	.navbar-default .navbar-nav > .open > a, .navbar-default .navbar-nav > .open > a:hover, .navbar-default .navbar-nav > .open > a:focus {
		color: #555;
		background-color: #e7e7e7; }
	@media (max-width: 767px) {
		.navbar-default .navbar-nav .open .dropdown-menu > li > a {
			color: #777; }
			.navbar-default .navbar-nav .open .dropdown-menu > li > a:hover, .navbar-default .navbar-nav .open .dropdown-menu > li > a:focus {
				color: #333;
				background-color: transparent; }
		.navbar-default .navbar-nav .open .dropdown-menu > .active > a, .navbar-default .navbar-nav .open .dropdown-menu > .active > a:hover, .navbar-default .navbar-nav .open .dropdown-menu > .active > a:focus {
			color: #555;
			background-color: #e7e7e7; }
		.navbar-default .navbar-nav .open .dropdown-menu > .disabled > a, .navbar-default .navbar-nav .open .dropdown-menu > .disabled > a:hover, .navbar-default .navbar-nav .open .dropdown-menu > .disabled > a:focus {
			color: #ccc;
			background-color: transparent; } }
	.navbar-default .navbar-toggle {
		border-color: #ddd; }
		.navbar-default .navbar-toggle:hover, .navbar-default .navbar-toggle:focus {
			background-color: #ddd; }
		.navbar-default .navbar-toggle .icon-bar {
			background-color: #888; }
	.navbar-default .navbar-collapse,
	.navbar-default .navbar-form {
		border-color: #e7e7e7; }
	.navbar-default .navbar-link {
		color: #777; }
		.navbar-default .navbar-link:hover {
			color: #333; }
	.navbar-default .btn-link {
		color: #777; }
		.navbar-default .btn-link:hover, .navbar-default .btn-link:focus {
			color: #333; }
		.navbar-default .btn-link[disabled]:hover, .navbar-default .btn-link[disabled]:focus,
		fieldset[disabled] .navbar-default .btn-link:hover,
		fieldset[disabled] .navbar-default .btn-link:focus {
			color: #ccc; }

.navbar-inverse {
	background-color: #222;
	border-color: #090808; }
	.navbar-inverse .navbar-brand {
		color: #959595; }
		.navbar-inverse .navbar-brand:hover, .navbar-inverse .navbar-brand:focus {
			color: #fff;
			background-color: transparent; }
	.navbar-inverse .navbar-text {
		color: #959595; }
	.navbar-inverse .navbar-nav > li > a {
		color: #959595; }
		.navbar-inverse .navbar-nav > li > a:hover, .navbar-inverse .navbar-nav > li > a:focus {
			color: #fff;
			background-color: transparent; }
	.navbar-inverse .navbar-nav > .active > a, .navbar-inverse .navbar-nav > .active > a:hover, .navbar-inverse .navbar-nav > .active > a:focus {
		color: #fff;
		background-color: #090808; }
	.navbar-inverse .navbar-nav > .disabled > a, .navbar-inverse .navbar-nav > .disabled > a:hover, .navbar-inverse .navbar-nav > .disabled > a:focus {
		color: #444;
		background-color: transparent; }
	.navbar-inverse .navbar-nav > .open > a, .navbar-inverse .navbar-nav > .open > a:hover, .navbar-inverse .navbar-nav > .open > a:focus {
		color: #fff;
		background-color: #090808; }
	@media (max-width: 767px) {
		.navbar-inverse .navbar-nav .open .dropdown-menu > .dropdown-header {
			border-color: #090808; }
		.navbar-inverse .navbar-nav .open .dropdown-menu .divider {
			background-color: #090808; }
		.navbar-inverse .navbar-nav .open .dropdown-menu > li > a {
			color: #959595; }
			.navbar-inverse .navbar-nav .open .dropdown-menu > li > a:hover, .navbar-inverse .navbar-nav .open .dropdown-menu > li > a:focus {
				color: #fff;
				background-color: transparent; }
		.navbar-inverse .navbar-nav .open .dropdown-menu > .active > a, .navbar-inverse .navbar-nav .open .dropdown-menu > .active > a:hover, .navbar-inverse .navbar-nav .open .dropdown-menu > .active > a:focus {
			color: #fff;
			background-color: #090808; }
		.navbar-inverse .navbar-nav .open .dropdown-menu > .disabled > a, .navbar-inverse .navbar-nav .open .dropdown-menu > .disabled > a:hover, .navbar-inverse .navbar-nav .open .dropdown-menu > .disabled > a:focus {
			color: #444;
			background-color: transparent; } }
	.navbar-inverse .navbar-toggle {
		border-color: #333; }
		.navbar-inverse .navbar-toggle:hover, .navbar-inverse .navbar-toggle:focus {
			background-color: #333; }
		.navbar-inverse .navbar-toggle .icon-bar {
			background-color: #fff; }
	.navbar-inverse .navbar-collapse,
	.navbar-inverse .navbar-form {
		border-color: #101010; }
	.navbar-inverse .navbar-link {
		color: #959595; }
		.navbar-inverse .navbar-link:hover {
			color: #fff; }
	.navbar-inverse .btn-link {
		color: #959595; }
		.navbar-inverse .btn-link:hover, .navbar-inverse .btn-link:focus {
			color: #fff; }
		.navbar-inverse .btn-link[disabled]:hover, .navbar-inverse .btn-link[disabled]:focus,
		fieldset[disabled] .navbar-inverse .btn-link:hover,
		fieldset[disabled] .navbar-inverse .btn-link:focus {
			color: #444; }

.breadcrumb {
	padding: 8px 15px;
	margin-bottom: 23px;
	list-style: none;
	background-color: transparent;
	border-radius: 4px; }
	.breadcrumb > li {
		display: inline-block; }
		.breadcrumb > li + li:before {
			padding: 0 5px;
			color: #ccc;
			content: "/ "; }
	.breadcrumb > .active {
		color: #6f6f6f; }

.pagination {
	display: inline-block;
	padding-left: 0;
	margin: 23px 0;
	border-radius: 4px; }
	.pagination > li {
		display: inline; }
		.pagination > li > a,
		.pagination > li > span {
			position: relative;
			float: left;
			padding: 10px 14px;
			margin-left: -1px;
			line-height: 1.4375;
			color: #335075;
			text-decoration: none;
			background-color: #eaebed;
			border: 1px solid #dcdee1; }
			.pagination > li > a:hover, .pagination > li > a:focus,
			.pagination > li > span:hover,
			.pagination > li > span:focus {
				z-index: 2;
				color: #335075;
				background-color: #d4d6da;
				border-color: #bbbfc5; }
		.pagination > li:first-child > a,
		.pagination > li:first-child > span {
			margin-left: 0;
			border-top-left-radius: 4px;
			border-bottom-left-radius: 4px; }
		.pagination > li:last-child > a,
		.pagination > li:last-child > span {
			border-top-right-radius: 4px;
			border-bottom-right-radius: 4px; }
	.pagination > .active > a, .pagination > .active > a:hover, .pagination > .active > a:focus,
	.pagination > .active > span,
	.pagination > .active > span:hover,
	.pagination > .active > span:focus {
		z-index: 3;
		color: #fff;
		cursor: default;
		background-color: #2572b4;
		border-color: #2572b4; }
	.pagination > .disabled > span,
	.pagination > .disabled > span:hover,
	.pagination > .disabled > span:focus,
	.pagination > .disabled > a,
	.pagination > .disabled > a:hover,
	.pagination > .disabled > a:focus {
		color: #6f6f6f;
		cursor: not-allowed;
		background-color: #fff;
		border-color: #ddd; }

.pagination-lg > li > a,
.pagination-lg > li > span {
	padding: 10px 16px;
	font-size: 18px;
	line-height: 1.3333333; }

.pagination-lg > li:first-child > a,
.pagination-lg > li:first-child > span {
	border-top-left-radius: 6px;
	border-bottom-left-radius: 6px; }

.pagination-lg > li:last-child > a,
.pagination-lg > li:last-child > span {
	border-top-right-radius: 6px;
	border-bottom-right-radius: 6px; }

.pagination-sm > li > a,
.pagination-sm > li > span {
	padding: 5px 10px;
	font-size: 14px;
	line-height: 1.5; }

.pagination-sm > li:first-child > a,
.pagination-sm > li:first-child > span {
	border-top-left-radius: 3px;
	border-bottom-left-radius: 3px; }

.pagination-sm > li:last-child > a,
.pagination-sm > li:last-child > span {
	border-top-right-radius: 3px;
	border-bottom-right-radius: 3px; }

.pager {
	padding-left: 0;
	margin: 23px 0;
	text-align: center;
	list-style: none; }
	.pager:before, .pager:after {
		display: table;
		content: " "; }
	.pager:after {
		clear: both; }
	.pager li {
		display: inline; }
		.pager li > a,
		.pager li > span {
			display: inline-block;
			padding: 5px 14px;
			background-color: #eaebed;
			border: 1px solid #dcdee1;
			border-radius: 4px; }
		.pager li > a:hover,
		.pager li > a:focus {
			text-decoration: none;
			background-color: #d4d6da; }
	.pager .next > a,
	.pager .next > span {
		float: right; }
	.pager .previous > a,
	.pager .previous > span {
		float: left; }
	.pager .disabled > a,
	.pager .disabled > a:hover,
	.pager .disabled > a:focus,
	.pager .disabled > span {
		color: #6f6f6f;
		cursor: not-allowed;
		background-color: #eaebed; }

.label {
	display: inline;
	padding: .2em .6em .3em;
	font-size: 75%;
	font-weight: 700;
	line-height: 1;
	color: #fff;
	text-align: center;
	white-space: nowrap;
	vertical-align: baseline;
	border-radius: .25em; }
	.label:empty {
		display: none; }
	.btn .label {
		position: relative;
		top: -1px; }

a.label:hover, a.label:focus {
	color: #fff;
	text-decoration: none;
	cursor: pointer; }

.label-default {
	background-color: #6f6f6f; }
	.label-default[href]:hover, .label-default[href]:focus {
		background-color: #565555; }

.label-primary {
	background-color: #2572b4; }
	.label-primary[href]:hover, .label-primary[href]:focus {
		background-color: #1c578a; }

.label-success {
	background-color: #1b6c1c; }
	.label-success[href]:hover, .label-success[href]:focus {
		background-color: #114311; }

.label-info {
	background-color: #4d4d4d; }
	.label-info[href]:hover, .label-info[href]:focus {
		background-color: #343333; }

.label-warning {
	background-color: #f2d40d; }
	.label-warning[href]:hover, .label-warning[href]:focus {
		background-color: #c2aa0a; }

.label-danger {
	background-color: #bc3331; }
	.label-danger[href]:hover, .label-danger[href]:focus {
		background-color: #942826; }

.alert {
	padding: 15px;
	margin-bottom: 23px;
	border: 1px solid transparent;
	border-radius: 4px; }
	.alert h4 {
		margin-top: 0;
		color: inherit; }
	.alert .alert-link {
		font-weight: bold; }
	.alert > p,
	.alert > ul {
		margin-bottom: 0; }
	.alert > p + p {
		margin-top: 5px; }

.alert-dismissable,
.alert-dismissible {
	padding-right: 35px; }
	.alert-dismissable .close,
	.alert-dismissible .close {
		position: relative;
		top: -2px;
		right: -21px;
		color: inherit; }

.alert-success {
	color: #3c763d;
	background-color: #dff0d8;
	border-color: #d6e9c6; }
	.alert-success hr {
		border-top-color: #c9e2b3; }
	.alert-success .alert-link {
		color: #2b542c; }

.alert-info {
	color: #31708f;
	background-color: #d9edf7;
	border-color: #bce8f1; }
	.alert-info hr {
		border-top-color: #a6e1ec; }
	.alert-info .alert-link {
		color: #245269; }

.alert-warning {
	color: #8a6d3b;
	background-color: #fcf8e3;
	border-color: #faebcc; }
	.alert-warning hr {
		border-top-color: #f7e1b5; }
	.alert-warning .alert-link {
		color: #66512c; }

.alert-danger {
	color: #a94442;
	background-color: #f2dede;
	border-color: #ebccd1; }
	.alert-danger hr {
		border-top-color: #e4b9c0; }
	.alert-danger .alert-link {
		color: #843534; }

/*
	WET-BOEW
	@title: Bootstrap overrides for WET-BOEW - Helper - Placeholders
 */
/*
 *  Alerts and labels
 */
.alert, .label {
	border-radius: 0;
	border-style: solid;
	border-width: 0 0 0 4px; }

.alert-success, .alert-info, .alert-warning, .alert-danger, .label-default, .label-default[href]:hover, .label-default[href]:focus, .label-default[href]:active, .label-primary, .label-primary[href]:hover, .label-primary[href]:focus, .label-primary[href]:active, .label-success, .label-success[href]:hover, .label-success[href]:focus, .label-success[href]:active, .label-info, .label-info[href]:hover, .label-info[href]:focus, .label-info[href]:active, .label-warning, .label-warning[href]:hover, .label-warning[href]:focus, .label-warning[href]:active, .label-danger, .label-danger[href]:hover, .label-danger[href]:focus, .label-danger[href]:active {
	color: #000; }

.label-default[href]:hover, .label-default[href]:focus, .label-default[href]:active, .label-primary[href]:hover, .label-primary[href]:focus, .label-primary[href]:active, .label-success[href]:hover, .label-success[href]:focus, .label-success[href]:active, .label-info[href]:hover, .label-info[href]:focus, .label-info[href]:active, .label-warning[href]:hover, .label-warning[href]:focus, .label-warning[href]:active, .label-danger[href]:hover, .label-danger[href]:focus, .label-danger[href]:active {
	text-decoration: underline; }

.label-default, .label-default[href]:hover, .label-default[href]:focus, .label-default[href]:active {
	background: #eee;
	border-color: #acacac; }

.label-primary, .label-primary[href]:hover, .label-primary[href]:focus, .label-primary[href]:active {
	background: #e8f2f4;
	border-color: #083c6c; }

.alert-success, .label-success, .label-success[href]:hover, .label-success[href]:focus, .label-success[href]:active, details.alert.alert-success, details.alert.alert-success[open] {
	background: #d8eeca;
	border-color: #278400; }

.alert-info, .label-info, .label-info[href]:hover, .label-info[href]:focus, .label-info[href]:active, details.alert.alert-info, details.alert.alert-info[open] {
	background: #d7faff;
	border-color: #269abc; }

.alert-warning, .label-warning, .label-warning[href]:hover, .label-warning[href]:focus, .label-warning[href]:active, details.alert.alert-warning, details.alert.alert-warning[open] {
	background: #f9f4d4;
	border-color: #f90; }

.alert-danger, .label-danger, .label-danger[href]:hover, .label-danger[href]:focus, .label-danger[href]:active, details.alert.alert-danger, details.alert.alert-danger[open] {
	background: #f3e9e8;
	border-color: #d3080c; }

/*
  WET-BOEW
  @title: Bootstrap overrides for WET-BOEW - Components - Alert
 */
/*
 *	Override the design of alerts and labels
 */
.alert > :first-child {
	margin-left: 1.2em;
	margin-top: auto; }
	.alert > :first-child:before {
		display: inline-block;
		font-family: "Glyphicons Halflings";
		margin-left: -1.3em;
		position: absolute; }

.alert > strong:first-child,
.alert > em:first-child,
.alert > span:first-child {
	display: inline-block; }

.alert-success > :first-child:before {
	color: #278400;
	content: "\e084"; }

.alert-info > :first-child:before {
	color: #269abc;
	content: "\e086"; }

.alert-warning > :first-child:before {
	color: #f90;
	content: "\e107"; }

.alert-danger > :first-child:before {
	color: #d3080c;
	content: "\e101"; }

/*
 *  Right-to-left support
 */
[dir=rtl] .alert > :first-child {
	margin-left: auto;
	margin-right: 1.2em; }
	[dir=rtl] .alert > :first-child:before {
		margin-left: auto;
		margin-right: -1.3em; }

[dir=rtl] details.alert {
	padding-right: 45px; }
	[dir=rtl] details.alert:before {
		margin-right: -1.3em; }
	[dir=rtl] details.alert > * {
		margin-right: .7em; }
	[dir=rtl] details.alert > :first-child {
		margin-right: .4em; }

/*
  WET-BOEW
  @title: Bootstrap overrides for WET-BOEW - Components - Alert
 */
/*
 *	Override the design of alerts and labels
 */
.badge {
	display: inline-block;
	min-width: 10px;
	padding: 3px 7px;
	font-size: 14px;
	font-weight: bold;
	line-height: 1;
	color: #fff;
	text-align: center;
	white-space: nowrap;
	vertical-align: middle;
	background-color: #6f6f6f;
	border-radius: 10px; }
	.badge:empty {
		display: none; }
	.btn .badge {
		position: relative;
		top: -1px; }
	.btn-xs .badge, .btn-group-xs > .btn .badge,
	.btn-group-xs > .btn .badge {
		top: 0;
		padding: 1px 5px; }
	.list-group-item.active > .badge,
	.nav-pills > .active > a > .badge {
		color: #295376;
		background-color: #fff; }
	.list-group-item > .badge {
		float: right; }
	.list-group-item > .badge + .badge {
		margin-right: 5px; }
	.nav-pills > li > a > .badge {
		margin-left: 3px; }

a.badge:hover, a.badge:focus {
	color: #fff;
	text-decoration: none;
	cursor: pointer; }

.jumbotron {
	padding-top: 30px;
	padding-bottom: 30px;
	margin-bottom: 30px;
	color: inherit;
	background-color: #eeeeee; }
	.jumbotron h1,
	.jumbotron .h1 {
		color: inherit; }
	.jumbotron p {
		margin-bottom: 15px;
		font-size: 24px;
		font-weight: 200; }
	.jumbotron > hr {
		border-top-color: #d5d5d5; }
	.container .jumbotron,
	.container-fluid .jumbotron {
		padding-right: 15px;
		padding-left: 15px;
		border-radius: 6px; }
	.jumbotron .container {
		max-width: 100%; }
	@media screen and (min-width: 768px) {
		.jumbotron {
			padding-top: 48px;
			padding-bottom: 48px; }
			.container .jumbotron,
			.container-fluid .jumbotron {
				padding-right: 60px;
				padding-left: 60px; }
			.jumbotron h1,
			.jumbotron .h1 {
				font-size: 72px; } }

.thumbnail {
	display: block;
	padding: 4px;
	margin-bottom: 23px;
	line-height: 1.4375;
	background-color: #fff;
	border: 1px solid #ddd;
	border-radius: 4px;
	-webkit-transition: border 0.2s ease-in-out;
	transition: border 0.2s ease-in-out; }
	.thumbnail > img,
	.thumbnail a > img {
		display: block;
		max-width: 100%;
		height: auto;
		margin-right: auto;
		margin-left: auto; }
	.thumbnail .caption {
		padding: 9px;
		color: #333333; }

a.thumbnail:hover,
a.thumbnail:focus,
a.thumbnail.active {
	border-color: #295376; }

@-webkit-keyframes progress-bar-stripes {
	from {
		background-position: 40px 0; }
	to {
		background-position: 0 0; } }

@keyframes progress-bar-stripes {
	from {
		background-position: 40px 0; }
	to {
		background-position: 0 0; } }

.progress {
	height: 23px;
	margin-bottom: 23px;
	overflow: hidden;
	background-color: #f5f5f5;
	border-radius: 4px;
	-webkit-box-shadow: inset 0 1px 2px rgba(0, 0, 0, 0.1);
	box-shadow: inset 0 1px 2px rgba(0, 0, 0, 0.1); }

.progress-bar {
	float: left;
	width: 0%;
	height: 100%;
	font-size: 14px;
	line-height: 23px;
	color: #fff;
	text-align: center;
	background-color: #2572b4;
	-webkit-box-shadow: inset 0 -1px 0 rgba(0, 0, 0, 0.15);
	box-shadow: inset 0 -1px 0 rgba(0, 0, 0, 0.15);
	-webkit-transition: width 0.6s ease;
	transition: width 0.6s ease; }

.progress-striped .progress-bar,
.progress-bar-striped {
	background-image: linear-gradient(45deg, rgba(255, 255, 255, 0.15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.15) 50%, rgba(255, 255, 255, 0.15) 75%, transparent 75%, transparent);
	background-size: 40px 40px; }

.progress.active .progress-bar,
.progress-bar.active {
	-webkit-animation: progress-bar-stripes 2s linear infinite;
	animation: progress-bar-stripes 2s linear infinite; }

.progress-bar-success {
	background-color: #1b6c1c; }
	.progress-striped .progress-bar-success {
		background-image: linear-gradient(45deg, rgba(255, 255, 255, 0.15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.15) 50%, rgba(255, 255, 255, 0.15) 75%, transparent 75%, transparent); }

.progress-bar-info {
	background-color: #4d4d4d; }
	.progress-striped .progress-bar-info {
		background-image: linear-gradient(45deg, rgba(255, 255, 255, 0.15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.15) 50%, rgba(255, 255, 255, 0.15) 75%, transparent 75%, transparent); }

.progress-bar-warning {
	background-color: #f2d40d; }
	.progress-striped .progress-bar-warning {
		background-image: linear-gradient(45deg, rgba(255, 255, 255, 0.15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.15) 50%, rgba(255, 255, 255, 0.15) 75%, transparent 75%, transparent); }

.progress-bar-danger {
	background-color: #bc3331; }
	.progress-striped .progress-bar-danger {
		background-image: linear-gradient(45deg, rgba(255, 255, 255, 0.15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.15) 50%, rgba(255, 255, 255, 0.15) 75%, transparent 75%, transparent); }

.media {
	margin-top: 15px; }
	.media:first-child {
		margin-top: 0; }

.media,
.media-body {
	overflow: hidden;
	zoom: 1; }

.media-body {
	width: 10000px; }

.media-object {
	display: block; }
	.media-object.img-thumbnail {
		max-width: none; }

.media-right,
.media > .pull-right {
	padding-left: 10px; }

.media-left,
.media > .pull-left {
	padding-right: 10px; }

.media-left,
.media-right,
.media-body {
	display: table-cell;
	vertical-align: top; }

.media-middle {
	vertical-align: middle; }

.media-bottom {
	vertical-align: bottom; }

.media-heading {
	margin-top: 0;
	margin-bottom: 5px; }

.media-list {
	padding-left: 0;
	list-style: none; }

.list-group {
	padding-left: 0;
	margin-bottom: 20px; }

.list-group-item {
	position: relative;
	display: block;
	padding: 10px 15px;
	margin-bottom: -1px;
	background-color: #fff;
	border: 1px solid #ddd; }
	.list-group-item:first-child {
		border-top-left-radius: 4px;
		border-top-right-radius: 4px; }
	.list-group-item:last-child {
		margin-bottom: 0;
		border-bottom-right-radius: 4px;
		border-bottom-left-radius: 4px; }
	.list-group-item.disabled, .list-group-item.disabled:hover, .list-group-item.disabled:focus {
		color: #6f6f6f;
		cursor: not-allowed;
		background-color: #eeeeee; }
		.list-group-item.disabled .list-group-item-heading, .list-group-item.disabled:hover .list-group-item-heading, .list-group-item.disabled:focus .list-group-item-heading {
			color: inherit; }
		.list-group-item.disabled .list-group-item-text, .list-group-item.disabled:hover .list-group-item-text, .list-group-item.disabled:focus .list-group-item-text {
			color: #6f6f6f; }
	.list-group-item.active, .list-group-item.active:hover, .list-group-item.active:focus {
		z-index: 2;
		color: #fff;
		background-color: #2572b4;
		border-color: #2572b4; }
		.list-group-item.active .list-group-item-heading,
		.list-group-item.active .list-group-item-heading > small,
		.list-group-item.active .list-group-item-heading > .small, .list-group-item.active:hover .list-group-item-heading,
		.list-group-item.active:hover .list-group-item-heading > small,
		.list-group-item.active:hover .list-group-item-heading > .small, .list-group-item.active:focus .list-group-item-heading,
		.list-group-item.active:focus .list-group-item-heading > small,
		.list-group-item.active:focus .list-group-item-heading > .small {
			color: inherit; }
		.list-group-item.active .list-group-item-text, .list-group-item.active:hover .list-group-item-text, .list-group-item.active:focus .list-group-item-text {
			color: #b5d5f0; }

a.list-group-item,
button.list-group-item {
	color: #555; }
	a.list-group-item .list-group-item-heading,
	button.list-group-item .list-group-item-heading {
		color: #333; }
	a.list-group-item:hover, a.list-group-item:focus,
	button.list-group-item:hover,
	button.list-group-item:focus {
		color: #555;
		text-decoration: none;
		background-color: #f5f5f5; }

button.list-group-item {
	width: 100%;
	text-align: left; }

.list-group-item-success {
	color: #3c763d;
	background-color: #dff0d8; }

a.list-group-item-success,
button.list-group-item-success {
	color: #3c763d; }
	a.list-group-item-success .list-group-item-heading,
	button.list-group-item-success .list-group-item-heading {
		color: inherit; }
	a.list-group-item-success:hover, a.list-group-item-success:focus,
	button.list-group-item-success:hover,
	button.list-group-item-success:focus {
		color: #3c763d;
		background-color: #d0e9c6; }
	a.list-group-item-success.active, a.list-group-item-success.active:hover, a.list-group-item-success.active:focus,
	button.list-group-item-success.active,
	button.list-group-item-success.active:hover,
	button.list-group-item-success.active:focus {
		color: #fff;
		background-color: #3c763d;
		border-color: #3c763d; }

.list-group-item-info {
	color: #31708f;
	background-color: #d9edf7; }

a.list-group-item-info,
button.list-group-item-info {
	color: #31708f; }
	a.list-group-item-info .list-group-item-heading,
	button.list-group-item-info .list-group-item-heading {
		color: inherit; }
	a.list-group-item-info:hover, a.list-group-item-info:focus,
	button.list-group-item-info:hover,
	button.list-group-item-info:focus {
		color: #31708f;
		background-color: #c4e3f3; }
	a.list-group-item-info.active, a.list-group-item-info.active:hover, a.list-group-item-info.active:focus,
	button.list-group-item-info.active,
	button.list-group-item-info.active:hover,
	button.list-group-item-info.active:focus {
		color: #fff;
		background-color: #31708f;
		border-color: #31708f; }

.list-group-item-warning {
	color: #8a6d3b;
	background-color: #fcf8e3; }

a.list-group-item-warning,
button.list-group-item-warning {
	color: #8a6d3b; }
	a.list-group-item-warning .list-group-item-heading,
	button.list-group-item-warning .list-group-item-heading {
		color: inherit; }
	a.list-group-item-warning:hover, a.list-group-item-warning:focus,
	button.list-group-item-warning:hover,
	button.list-group-item-warning:focus {
		color: #8a6d3b;
		background-color: #faf2cc; }
	a.list-group-item-warning.active, a.list-group-item-warning.active:hover, a.list-group-item-warning.active:focus,
	button.list-group-item-warning.active,
	button.list-group-item-warning.active:hover,
	button.list-group-item-warning.active:focus {
		color: #fff;
		background-color: #8a6d3b;
		border-color: #8a6d3b; }

.list-group-item-danger {
	color: #a94442;
	background-color: #f2dede; }

a.list-group-item-danger,
button.list-group-item-danger {
	color: #a94442; }
	a.list-group-item-danger .list-group-item-heading,
	button.list-group-item-danger .list-group-item-heading {
		color: inherit; }
	a.list-group-item-danger:hover, a.list-group-item-danger:focus,
	button.list-group-item-danger:hover,
	button.list-group-item-danger:focus {
		color: #a94442;
		background-color: #ebcccc; }
	a.list-group-item-danger.active, a.list-group-item-danger.active:hover, a.list-group-item-danger.active:focus,
	button.list-group-item-danger.active,
	button.list-group-item-danger.active:hover,
	button.list-group-item-danger.active:focus {
		color: #fff;
		background-color: #a94442;
		border-color: #a94442; }

.list-group-item-heading {
	margin-top: 0;
	margin-bottom: 5px; }

.list-group-item-text {
	margin-bottom: 0;
	line-height: 1.3; }

.panel {
	margin-bottom: 23px;
	background-color: #fff;
	border: 1px solid transparent;
	border-radius: 4px;
	-webkit-box-shadow: 0 1px 1px rgba(0, 0, 0, 0.05);
	box-shadow: 0 1px 1px rgba(0, 0, 0, 0.05); }

.panel-body {
	padding: 15px; }
	.panel-body:before, .panel-body:after {
		display: table;
		content: " "; }
	.panel-body:after {
		clear: both; }

.panel-heading {
	padding: 10px 15px;
	border-bottom: 1px solid transparent;
	border-top-left-radius: 3px;
	border-top-right-radius: 3px; }
	.panel-heading > .dropdown .dropdown-toggle {
		color: inherit; }

.panel-title {
	margin-top: 0;
	margin-bottom: 0;
	font-size: 18px;
	color: inherit; }
	.panel-title > a,
	.panel-title > small,
	.panel-title > .small,
	.panel-title > small > a,
	.panel-title > .small > a {
		color: inherit; }

.panel-footer {
	padding: 10px 15px;
	background-color: #f5f5f5;
	border-top: 1px solid #8e8e8e;
	border-bottom-right-radius: 3px;
	border-bottom-left-radius: 3px; }

.panel > .list-group,
.panel > .panel-collapse > .list-group {
	margin-bottom: 0; }
	.panel > .list-group .list-group-item,
	.panel > .panel-collapse > .list-group .list-group-item {
		border-width: 1px 0;
		border-radius: 0; }
	.panel > .list-group:first-child .list-group-item:first-child,
	.panel > .panel-collapse > .list-group:first-child .list-group-item:first-child {
		border-top: 0;
		border-top-left-radius: 3px;
		border-top-right-radius: 3px; }
	.panel > .list-group:last-child .list-group-item:last-child,
	.panel > .panel-collapse > .list-group:last-child .list-group-item:last-child {
		border-bottom: 0;
		border-bottom-right-radius: 3px;
		border-bottom-left-radius: 3px; }

.panel > .panel-heading + .panel-collapse > .list-group .list-group-item:first-child {
	border-top-left-radius: 0;
	border-top-right-radius: 0; }

.panel-heading + .list-group .list-group-item:first-child {
	border-top-width: 0; }

.list-group + .panel-footer {
	border-top-width: 0; }

.panel > .table,
.panel > .table-responsive > .table,
.panel > .panel-collapse > .table {
	margin-bottom: 0; }
	.panel > .table caption,
	.panel > .table-responsive > .table caption,
	.panel > .panel-collapse > .table caption {
		padding-right: 15px;
		padding-left: 15px; }

.panel > .table:first-child,
.panel > .table-responsive:first-child > .table:first-child {
	border-top-left-radius: 3px;
	border-top-right-radius: 3px; }
	.panel > .table:first-child > thead:first-child > tr:first-child,
	.panel > .table:first-child > tbody:first-child > tr:first-child,
	.panel > .table-responsive:first-child > .table:first-child > thead:first-child > tr:first-child,
	.panel > .table-responsive:first-child > .table:first-child > tbody:first-child > tr:first-child {
		border-top-left-radius: 3px;
		border-top-right-radius: 3px; }
		.panel > .table:first-child > thead:first-child > tr:first-child td:first-child,
		.panel > .table:first-child > thead:first-child > tr:first-child th:first-child,
		.panel > .table:first-child > tbody:first-child > tr:first-child td:first-child,
		.panel > .table:first-child > tbody:first-child > tr:first-child th:first-child,
		.panel > .table-responsive:first-child > .table:first-child > thead:first-child > tr:first-child td:first-child,
		.panel > .table-responsive:first-child > .table:first-child > thead:first-child > tr:first-child th:first-child,
		.panel > .table-responsive:first-child > .table:first-child > tbody:first-child > tr:first-child td:first-child,
		.panel > .table-responsive:first-child > .table:first-child > tbody:first-child > tr:first-child th:first-child {
			border-top-left-radius: 3px; }
		.panel > .table:first-child > thead:first-child > tr:first-child td:last-child,
		.panel > .table:first-child > thead:first-child > tr:first-child th:last-child,
		.panel > .table:first-child > tbody:first-child > tr:first-child td:last-child,
		.panel > .table:first-child > tbody:first-child > tr:first-child th:last-child,
		.panel > .table-responsive:first-child > .table:first-child > thead:first-child > tr:first-child td:last-child,
		.panel > .table-responsive:first-child > .table:first-child > thead:first-child > tr:first-child th:last-child,
		.panel > .table-responsive:first-child > .table:first-child > tbody:first-child > tr:first-child td:last-child,
		.panel > .table-responsive:first-child > .table:first-child > tbody:first-child > tr:first-child th:last-child {
			border-top-right-radius: 3px; }

.panel > .table:last-child,
.panel > .table-responsive:last-child > .table:last-child {
	border-bottom-right-radius: 3px;
	border-bottom-left-radius: 3px; }
	.panel > .table:last-child > tbody:last-child > tr:last-child,
	.panel > .table:last-child > tfoot:last-child > tr:last-child,
	.panel > .table-responsive:last-child > .table:last-child > tbody:last-child > tr:last-child,
	.panel > .table-responsive:last-child > .table:last-child > tfoot:last-child > tr:last-child {
		border-bottom-right-radius: 3px;
		border-bottom-left-radius: 3px; }
		.panel > .table:last-child > tbody:last-child > tr:last-child td:first-child,
		.panel > .table:last-child > tbody:last-child > tr:last-child th:first-child,
		.panel > .table:last-child > tfoot:last-child > tr:last-child td:first-child,
		.panel > .table:last-child > tfoot:last-child > tr:last-child th:first-child,
		.panel > .table-responsive:last-child > .table:last-child > tbody:last-child > tr:last-child td:first-child,
		.panel > .table-responsive:last-child > .table:last-child > tbody:last-child > tr:last-child th:first-child,
		.panel > .table-responsive:last-child > .table:last-child > tfoot:last-child > tr:last-child td:first-child,
		.panel > .table-responsive:last-child > .table:last-child > tfoot:last-child > tr:last-child th:first-child {
			border-bottom-left-radius: 3px; }
		.panel > .table:last-child > tbody:last-child > tr:last-child td:last-child,
		.panel > .table:last-child > tbody:last-child > tr:last-child th:last-child,
		.panel > .table:last-child > tfoot:last-child > tr:last-child td:last-child,
		.panel > .table:last-child > tfoot:last-child > tr:last-child th:last-child,
		.panel > .table-responsive:last-child > .table:last-child > tbody:last-child > tr:last-child td:last-child,
		.panel > .table-responsive:last-child > .table:last-child > tbody:last-child > tr:last-child th:last-child,
		.panel > .table-responsive:last-child > .table:last-child > tfoot:last-child > tr:last-child td:last-child,
		.panel > .table-responsive:last-child > .table:last-child > tfoot:last-child > tr:last-child th:last-child {
			border-bottom-right-radius: 3px; }

.panel > .panel-body + .table,
.panel > .panel-body + .table-responsive,
.panel > .table + .panel-body,
.panel > .table-responsive + .panel-body {
	border-top: 1px solid #ddd; }

.panel > .table > tbody:first-child > tr:first-child th,
.panel > .table > tbody:first-child > tr:first-child td {
	border-top: 0; }

.panel > .table-bordered,
.panel > .table-responsive > .table-bordered {
	border: 0; }
	.panel > .table-bordered > thead > tr > th:first-child,
	.panel > .table-bordered > thead > tr > td:first-child,
	.panel > .table-bordered > tbody > tr > th:first-child,
	.panel > .table-bordered > tbody > tr > td:first-child,
	.panel > .table-bordered > tfoot > tr > th:first-child,
	.panel > .table-bordered > tfoot > tr > td:first-child,
	.panel > .table-responsive > .table-bordered > thead > tr > th:first-child,
	.panel > .table-responsive > .table-bordered > thead > tr > td:first-child,
	.panel > .table-responsive > .table-bordered > tbody > tr > th:first-child,
	.panel > .table-responsive > .table-bordered > tbody > tr > td:first-child,
	.panel > .table-responsive > .table-bordered > tfoot > tr > th:first-child,
	.panel > .table-responsive > .table-bordered > tfoot > tr > td:first-child {
		border-left: 0; }
	.panel > .table-bordered > thead > tr > th:last-child,
	.panel > .table-bordered > thead > tr > td:last-child,
	.panel > .table-bordered > tbody > tr > th:last-child,
	.panel > .table-bordered > tbody > tr > td:last-child,
	.panel > .table-bordered > tfoot > tr > th:last-child,
	.panel > .table-bordered > tfoot > tr > td:last-child,
	.panel > .table-responsive > .table-bordered > thead > tr > th:last-child,
	.panel > .table-responsive > .table-bordered > thead > tr > td:last-child,
	.panel > .table-responsive > .table-bordered > tbody > tr > th:last-child,
	.panel > .table-responsive > .table-bordered > tbody > tr > td:last-child,
	.panel > .table-responsive > .table-bordered > tfoot > tr > th:last-child,
	.panel > .table-responsive > .table-bordered > tfoot > tr > td:last-child {
		border-right: 0; }
	.panel > .table-bordered > thead > tr:first-child > td,
	.panel > .table-bordered > thead > tr:first-child > th,
	.panel > .table-bordered > tbody > tr:first-child > td,
	.panel > .table-bordered > tbody > tr:first-child > th,
	.panel > .table-responsive > .table-bordered > thead > tr:first-child > td,
	.panel > .table-responsive > .table-bordered > thead > tr:first-child > th,
	.panel > .table-responsive > .table-bordered > tbody > tr:first-child > td,
	.panel > .table-responsive > .table-bordered > tbody > tr:first-child > th {
		border-bottom: 0; }
	.panel > .table-bordered > tbody > tr:last-child > td,
	.panel > .table-bordered > tbody > tr:last-child > th,
	.panel > .table-bordered > tfoot > tr:last-child > td,
	.panel > .table-bordered > tfoot > tr:last-child > th,
	.panel > .table-responsive > .table-bordered > tbody > tr:last-child > td,
	.panel > .table-responsive > .table-bordered > tbody > tr:last-child > th,
	.panel > .table-responsive > .table-bordered > tfoot > tr:last-child > td,
	.panel > .table-responsive > .table-bordered > tfoot > tr:last-child > th {
		border-bottom: 0; }

.panel > .table-responsive {
	margin-bottom: 0;
	border: 0; }

.panel-group {
	margin-bottom: 23px; }
	.panel-group .panel {
		margin-bottom: 0;
		border-radius: 4px; }
		.panel-group .panel + .panel {
			margin-top: 5px; }
	.panel-group .panel-heading {
		border-bottom: 0; }
		.panel-group .panel-heading + .panel-collapse > .panel-body,
		.panel-group .panel-heading + .panel-collapse > .list-group {
			border-top: 1px solid #8e8e8e; }
	.panel-group .panel-footer {
		border-top: 0; }
		.panel-group .panel-footer + .panel-collapse .panel-body {
			border-bottom: 1px solid #8e8e8e; }

.panel-default {
	border-color: #8e8e8e; }
	.panel-default > .panel-heading {
		color: #333333;
		background-color: #f5f5f5;
		border-color: #8e8e8e; }
		.panel-default > .panel-heading + .panel-collapse > .panel-body {
			border-top-color: #8e8e8e; }
		.panel-default > .panel-heading .badge {
			color: #f5f5f5;
			background-color: #333333; }
	.panel-default > .panel-footer + .panel-collapse > .panel-body {
		border-bottom-color: #8e8e8e; }

.panel-primary {
	border-color: #2572b4; }
	.panel-primary > .panel-heading {
		color: #fff;
		background-color: #2572b4;
		border-color: #2572b4; }
		.panel-primary > .panel-heading + .panel-collapse > .panel-body {
			border-top-color: #2572b4; }
		.panel-primary > .panel-heading .badge {
			color: #2572b4;
			background-color: #fff; }
	.panel-primary > .panel-footer + .panel-collapse > .panel-body {
		border-bottom-color: #2572b4; }

.panel-success {
	border-color: #629339; }
	.panel-success > .panel-heading {
		color: #3c763d;
		background-color: #dff0d8;
		border-color: #629339; }
		.panel-success > .panel-heading + .panel-collapse > .panel-body {
			border-top-color: #629339; }
		.panel-success > .panel-heading .badge {
			color: #dff0d8;
			background-color: #3c763d; }
	.panel-success > .panel-footer + .panel-collapse > .panel-body {
		border-bottom-color: #629339; }

.panel-info {
	border-color: #2392A9; }
	.panel-info > .panel-heading {
		color: #31708f;
		background-color: #d9edf7;
		border-color: #2392A9; }
		.panel-info > .panel-heading + .panel-collapse > .panel-body {
			border-top-color: #2392A9; }
		.panel-info > .panel-heading .badge {
			color: #d9edf7;
			background-color: #31708f; }
	.panel-info > .panel-footer + .panel-collapse > .panel-body {
		border-bottom-color: #2392A9; }

.panel-warning {
	border-color: #BA8312; }
	.panel-warning > .panel-heading {
		color: #8a6d3b;
		background-color: #fcf8e3;
		border-color: #BA8312; }
		.panel-warning > .panel-heading + .panel-collapse > .panel-body {
			border-top-color: #BA8312; }
		.panel-warning > .panel-heading .badge {
			color: #fcf8e3;
			background-color: #8a6d3b; }
	.panel-warning > .panel-footer + .panel-collapse > .panel-body {
		border-bottom-color: #BA8312; }

.panel-danger {
	border-color: #C16171; }
	.panel-danger > .panel-heading {
		color: #a94442;
		background-color: #f2dede;
		border-color: #C16171; }
		.panel-danger > .panel-heading + .panel-collapse > .panel-body {
			border-top-color: #C16171; }
		.panel-danger > .panel-heading .badge {
			color: #f2dede;
			background-color: #a94442; }
	.panel-danger > .panel-footer + .panel-collapse > .panel-body {
		border-bottom-color: #C16171; }

.embed-responsive {
	position: relative;
	display: block;
	height: 0;
	padding: 0;
	overflow: hidden; }
	.embed-responsive .embed-responsive-item,
	.embed-responsive iframe,
	.embed-responsive embed,
	.embed-responsive object,
	.embed-responsive video {
		position: absolute;
		top: 0;
		bottom: 0;
		left: 0;
		width: 100%;
		height: 100%;
		border: 0; }

.embed-responsive-16by9 {
	padding-bottom: 56.25%; }

.embed-responsive-4by3 {
	padding-bottom: 75%; }

.well {
	min-height: 20px;
	padding: 19px;
	margin-bottom: 20px;
	background-color: #f5f5f5;
	border: 1px solid #e3e3e3;
	border-radius: 4px;
	-webkit-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.05);
	box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.05); }
	.well blockquote {
		border-color: #ddd;
		border-color: rgba(0, 0, 0, 0.15); }

.well-lg {
	padding: 24px;
	border-radius: 6px; }

.well-sm {
	padding: 9px;
	border-radius: 3px; }

.close {
	float: right;
	font-size: 24px;
	font-weight: bold;
	line-height: 1;
	color: #000;
	text-shadow: 0 1px 0 #fff;
	filter: alpha(opacity=20);
	opacity: 0.2; }
	.close:hover, .close:focus {
		color: #000;
		text-decoration: none;
		cursor: pointer;
		filter: alpha(opacity=50);
		opacity: 0.5; }

button.close {
	padding: 0;
	cursor: pointer;
	background: transparent;
	border: 0;
	-webkit-appearance: none;
	-moz-appearance: none;
	     appearance: none; }

/*
	WET-BOEW
	@title: Bootstrap overrides for WET-BOEW - Components
 */
/*! Placeholders */
.pagination > li:first-child [rel="prev"]:before,
.pager > li:first-child [rel="prev"]:before, [dir=rtl] .pagination [rel="next"]:before,
[dir=rtl] .pager [rel="next"]:before, .dataTables_wrapper .dataTables_paginate .paginate_button.previous:before, [dir=rtl] .dataTables_wrapper .dataTables_paginate .paginate_button.next:before, .pagination > li:last-child [rel="next"]:after,
.pager > li:last-child [rel="next"]:after, [dir=rtl] .pagination [rel="prev"]:after,
[dir=rtl] .pager [rel="prev"]:after, .dataTables_wrapper .dataTables_paginate .paginate_button.next:after, [dir=rtl] .dataTables_wrapper .dataTables_paginate .paginate_button.previous:after, table.dataTable thead .sorting-icons:before, table.dataTable thead .sorting-icons:after {
	content: " ";
	font-family: "Glyphicons Halflings";
	font-weight: 400;
	line-height: 1em;
	position: relative;
	top: .1em; }

.pagination > li:first-child [rel="prev"]:before,
.pager > li:first-child [rel="prev"]:before, [dir=rtl] .pagination [rel="next"]:before,
[dir=rtl] .pager [rel="next"]:before, .dataTables_wrapper .dataTables_paginate .paginate_button.previous:before, [dir=rtl] .dataTables_wrapper .dataTables_paginate .paginate_button.next:before {
	content: "\e091";
	margin-right: .5em; }

.pagination > li:last-child [rel="next"]:after,
.pager > li:last-child [rel="next"]:after, [dir=rtl] .pagination [rel="prev"]:after,
[dir=rtl] .pager [rel="prev"]:after, .dataTables_wrapper .dataTables_paginate .paginate_button.next:after, [dir=rtl] .dataTables_wrapper .dataTables_paginate .paginate_button.previous:after {
	content: "\e092";
	margin-left: .5em; }

/*
 * btn-xs should be equal to btn-sm in >v4.0.*
*/
.btn-group-xs .btn,
.btn.btn-xs,
.btn-group-xs > .btn {
	min-height: 0; }

.dropdown-menu > li > a:visited {
	color: #333333; }

.nav > li > a:visited {
	color: #295376; }

.nav-pills > li.active > a:visited {
	color: #fff; }

.navbar-default .navbar-nav > li > a:visited {
	color: #777; }

@media (max-width: 767px) {
	.navbar-default .open .dropdown-menu > li > a {
		color: #777; } }

.navbar-default .navbar-link:visited {
	color: #777; }

.navbar-inverse .navbar-nav > li > a:visited {
	color: #959595; }

@media (max-width: 767px) {
	.navbar-inverse .open .dropdown-menu > li > a:visited {
		color: #959595; } }

.navbar-inverse .navbar-link:visited {
	color: #959595; }

/*
 *  Pagination
 *    * Add left/right arrows to previous/next buttons
 *    * Increase size of the pagination buttons
 *    * Prevent contrast ratio issues on active placeholder links
 */
.pagination > li > a,
.pager > li > a {
	cursor: pointer;
	display: inline-block;
	margin-bottom: .5em;
	padding: 10px 16px; }

.pagination > li.active > a,
.pager > li.active > a {
	cursor: default; }

.pagination > li.disabled + li > a,
.pager > li.disabled + li > a {
	border-top-left-radius: 4px;
	border-bottom-left-radius: 4px; }

.pager > li > a {
	text-decoration: none; }

.pager > li > a:hover, .pager > li > a:focus,
.pager > li > span:hover,
.pager > li > span:focus {
	border-color: #bbbfc5;
	color: #335075; }

.pagination > .active {
	color: #fff; }

/*
 *  Right-to-left support
 */
[dir=rtl] .pagination [rel="prev"],
[dir=rtl] .pager [rel="prev"] {
	border-top-left-radius: 0;
	border-bottom-left-radius: 0;
	border-top-right-radius: 4px;
	border-bottom-right-radius: 4px; }

[dir=rtl] .pagination [rel="next"],
[dir=rtl] .pager [rel="next"] {
	border-top-left-radius: 4px;
	border-bottom-left-radius: 4px;
	border-top-right-radius: 0;
	border-bottom-right-radius: 0; }

[dir=rtl] .pagination > li,
[dir=rtl] .pager > li {
	float: right; }
	[dir=rtl] .pagination > li.disabled + li > a,
	[dir=rtl] .pager > li.disabled + li > a {
		border-top-left-radius: 0;
		border-bottom-left-radius: 0;
		border-top-right-radius: 4px;
		border-bottom-right-radius: 4px; }

/*
  WET-BOEW
  @title: Ellipsis
 */
.wb-elps {
	overflow: hidden;
	text-overflow: ellipsis;
	white-space: nowrap; }

/*
 *
 * Web Experience Toolkit (WET) / Boîte à outils de l'expérience Web (BOEW)
 * wet-boew.github.io/wet-boew/License-en.html / wet-boew.github.io/wet-boew/Licence-fr.html
 *
 */
/*
.provisional {
	// Add provisional CSS here
}
*/
.modal-open {
	overflow: hidden; }

.modal {
	position: fixed;
	top: 0;
	right: 0;
	bottom: 0;
	left: 0;
	z-index: 1050;
	display: none;
	overflow: hidden;
	-webkit-overflow-scrolling: touch;
	outline: 0; }
	.modal.fade .modal-dialog {
		-webkit-transform: translate(0, -25%);
		transform: translate(0, -25%);
		-webkit-transition: -webkit-transform 0.3s ease-out;
		transition: -webkit-transform 0.3s ease-out;
		transition: transform 0.3s ease-out;
		transition: transform 0.3s ease-out, -webkit-transform 0.3s ease-out; }
	.modal.in .modal-dialog {
		-webkit-transform: translate(0, 0);
		transform: translate(0, 0); }

.modal-open .modal {
	overflow-x: hidden;
	overflow-y: auto; }

.modal-dialog {
	position: relative;
	width: auto;
	margin: 10px; }

.modal-content {
	position: relative;
	background-color: #fff;
	background-clip: padding-box;
	border: 1px solid #999;
	border: 1px solid rgba(0, 0, 0, 0.2);
	border-radius: 6px;
	-webkit-box-shadow: 0 3px 9px rgba(0, 0, 0, 0.5);
	box-shadow: 0 3px 9px rgba(0, 0, 0, 0.5);
	outline: 0; }

.modal-backdrop {
	position: fixed;
	top: 0;
	right: 0;
	bottom: 0;
	left: 0;
	z-index: 1040;
	background-color: #000; }
	.modal-backdrop.fade {
		filter: alpha(opacity=0);
		opacity: 0; }
	.modal-backdrop.in {
		filter: alpha(opacity=50);
		opacity: 0.5; }

.modal-header {
	padding: 15px;
	border-bottom: 1px solid #e5e5e5; }
	.modal-header:before, .modal-header:after {
		display: table;
		content: " "; }
	.modal-header:after {
		clear: both; }

.modal-header .close {
	margin-top: -2px; }

.modal-title {
	margin: 0;
	line-height: 1.4375; }

.modal-body {
	position: relative;
	padding: 15px; }

.modal-footer {
	padding: 15px;
	text-align: right;
	border-top: 1px solid #e5e5e5; }
	.modal-footer:before, .modal-footer:after {
		display: table;
		content: " "; }
	.modal-footer:after {
		clear: both; }
	.modal-footer .btn + .btn {
		margin-bottom: 0;
		margin-left: 5px; }
	.modal-footer .btn-group .btn + .btn {
		margin-left: -1px; }
	.modal-footer .btn-block + .btn-block {
		margin-left: 0; }

.modal-scrollbar-measure {
	position: absolute;
	top: -9999px;
	width: 50px;
	height: 50px;
	overflow: scroll; }

@media (min-width: 768px) {
	.modal-dialog {
		width: 600px;
		margin: 30px auto; }
	.modal-content {
		-webkit-box-shadow: 0 5px 15px rgba(0, 0, 0, 0.5);
		box-shadow: 0 5px 15px rgba(0, 0, 0, 0.5); }
	.modal-sm {
		width: 300px; } }

@media (min-width: 992px) {
	.modal-lg {
		width: 900px; } }

.tooltip {
	position: absolute;
	z-index: 1070;
	display: block;
	font-family: "Noto Sans", sans-serif;
	font-style: normal;
	font-weight: 400;
	line-height: 1.4375;
	line-break: auto;
	text-align: left;
	text-align: start;
	text-decoration: none;
	text-shadow: none;
	text-transform: none;
	letter-spacing: normal;
	word-break: normal;
	word-spacing: normal;
	word-wrap: normal;
	white-space: normal;
	font-size: 14px;
	filter: alpha(opacity=0);
	opacity: 0; }
	.tooltip.in {
		filter: alpha(opacity=90);
		opacity: 0.9; }
	.tooltip.top {
		padding: 5px 0;
		margin-top: -3px; }
	.tooltip.right {
		padding: 0 5px;
		margin-left: 3px; }
	.tooltip.bottom {
		padding: 5px 0;
		margin-top: 3px; }
	.tooltip.left {
		padding: 0 5px;
		margin-left: -3px; }
	.tooltip.top .tooltip-arrow {
		bottom: 0;
		left: 50%;
		margin-left: -5px;
		border-width: 5px 5px 0;
		border-top-color: #000; }
	.tooltip.top-left .tooltip-arrow {
		right: 5px;
		bottom: 0;
		margin-bottom: -5px;
		border-width: 5px 5px 0;
		border-top-color: #000; }
	.tooltip.top-right .tooltip-arrow {
		bottom: 0;
		left: 5px;
		margin-bottom: -5px;
		border-width: 5px 5px 0;
		border-top-color: #000; }
	.tooltip.right .tooltip-arrow {
		top: 50%;
		left: 0;
		margin-top: -5px;
		border-width: 5px 5px 5px 0;
		border-right-color: #000; }
	.tooltip.left .tooltip-arrow {
		top: 50%;
		right: 0;
		margin-top: -5px;
		border-width: 5px 0 5px 5px;
		border-left-color: #000; }
	.tooltip.bottom .tooltip-arrow {
		top: 0;
		left: 50%;
		margin-left: -5px;
		border-width: 0 5px 5px;
		border-bottom-color: #000; }
	.tooltip.bottom-left .tooltip-arrow {
		top: 0;
		right: 5px;
		margin-top: -5px;
		border-width: 0 5px 5px;
		border-bottom-color: #000; }
	.tooltip.bottom-right .tooltip-arrow {
		top: 0;
		left: 5px;
		margin-top: -5px;
		border-width: 0 5px 5px;
		border-bottom-color: #000; }

.tooltip-inner {
	max-width: 200px;
	padding: 3px 8px;
	color: #fff;
	text-align: center;
	background-color: #000;
	border-radius: 4px; }

.tooltip-arrow {
	position: absolute;
	width: 0;
	height: 0;
	border-color: transparent;
	border-style: solid; }

.popover {
	position: absolute;
	top: 0;
	left: 0;
	z-index: 1060;
	display: none;
	max-width: 276px;
	padding: 1px;
	font-family: "Noto Sans", sans-serif;
	font-style: normal;
	font-weight: 400;
	line-height: 1.4375;
	line-break: auto;
	text-align: left;
	text-align: start;
	text-decoration: none;
	text-shadow: none;
	text-transform: none;
	letter-spacing: normal;
	word-break: normal;
	word-spacing: normal;
	word-wrap: normal;
	white-space: normal;
	font-size: 16px;
	background-color: #fff;
	background-clip: padding-box;
	border: 1px solid #ccc;
	border: 1px solid rgba(0, 0, 0, 0.2);
	border-radius: 6px;
	-webkit-box-shadow: 0 5px 10px rgba(0, 0, 0, 0.2);
	box-shadow: 0 5px 10px rgba(0, 0, 0, 0.2); }
	.popover.top {
		margin-top: -10px; }
	.popover.right {
		margin-left: 10px; }
	.popover.bottom {
		margin-top: 10px; }
	.popover.left {
		margin-left: -10px; }
	.popover > .arrow {
		border-width: 11px; }
		.popover > .arrow, .popover > .arrow:after {
			position: absolute;
			display: block;
			width: 0;
			height: 0;
			border-color: transparent;
			border-style: solid; }
		.popover > .arrow:after {
			content: "";
			border-width: 10px; }
	.popover.top > .arrow {
		bottom: -11px;
		left: 50%;
		margin-left: -11px;
		border-top-color: #999999;
		border-top-color: rgba(0, 0, 0, 0.25);
		border-bottom-width: 0; }
		.popover.top > .arrow:after {
			bottom: 1px;
			margin-left: -10px;
			content: " ";
			border-top-color: #fff;
			border-bottom-width: 0; }
	.popover.right > .arrow {
		top: 50%;
		left: -11px;
		margin-top: -11px;
		border-right-color: #999999;
		border-right-color: rgba(0, 0, 0, 0.25);
		border-left-width: 0; }
		.popover.right > .arrow:after {
			bottom: -10px;
			left: 1px;
			content: " ";
			border-right-color: #fff;
			border-left-width: 0; }
	.popover.bottom > .arrow {
		top: -11px;
		left: 50%;
		margin-left: -11px;
		border-top-width: 0;
		border-bottom-color: #999999;
		border-bottom-color: rgba(0, 0, 0, 0.25); }
		.popover.bottom > .arrow:after {
			top: 1px;
			margin-left: -10px;
			content: " ";
			border-top-width: 0;
			border-bottom-color: #fff; }
	.popover.left > .arrow {
		top: 50%;
		right: -11px;
		margin-top: -11px;
		border-right-width: 0;
		border-left-color: #999999;
		border-left-color: rgba(0, 0, 0, 0.25); }
		.popover.left > .arrow:after {
			right: 1px;
			bottom: -10px;
			content: " ";
			border-right-width: 0;
			border-left-color: #fff; }

.popover-title {
	padding: 8px 14px;
	margin: 0;
	font-size: 16px;
	background-color: #f7f7f7;
	border-bottom: 1px solid #ebebeb;
	border-radius: 5px 5px 0 0; }

.popover-content {
	padding: 9px 14px; }

.carousel {
	position: relative; }

.carousel-inner {
	position: relative;
	width: 100%;
	overflow: hidden; }
	.carousel-inner > .item {
		position: relative;
		display: none;
		-webkit-transition: 0.6s ease-in-out left;
		transition: 0.6s ease-in-out left; }
		.carousel-inner > .item > img,
		.carousel-inner > .item > a > img {
			display: block;
			max-width: 100%;
			height: auto;
			line-height: 1; }
		@media all and (transform-3d), (-webkit-transform-3d) {
			.carousel-inner > .item {
				-webkit-transition: -webkit-transform 0.6s ease-in-out;
				transition: -webkit-transform 0.6s ease-in-out;
				transition: transform 0.6s ease-in-out;
				transition: transform 0.6s ease-in-out, -webkit-transform 0.6s ease-in-out;
				-webkit-backface-visibility: hidden;
				backface-visibility: hidden;
				-webkit-perspective: 1000px;
				perspective: 1000px; }
				.carousel-inner > .item.next, .carousel-inner > .item.active.right {
					-webkit-transform: translate3d(100%, 0, 0);
					transform: translate3d(100%, 0, 0);
					left: 0; }
				.carousel-inner > .item.prev, .carousel-inner > .item.active.left {
					-webkit-transform: translate3d(-100%, 0, 0);
					transform: translate3d(-100%, 0, 0);
					left: 0; }
				.carousel-inner > .item.next.left, .carousel-inner > .item.prev.right, .carousel-inner > .item.active {
					-webkit-transform: translate3d(0, 0, 0);
					transform: translate3d(0, 0, 0);
					left: 0; } }
	.carousel-inner > .active,
	.carousel-inner > .next,
	.carousel-inner > .prev {
		display: block; }
	.carousel-inner > .active {
		left: 0; }
	.carousel-inner > .next,
	.carousel-inner > .prev {
		position: absolute;
		top: 0;
		width: 100%; }
	.carousel-inner > .next {
		left: 100%; }
	.carousel-inner > .prev {
		left: -100%; }
	.carousel-inner > .next.left,
	.carousel-inner > .prev.right {
		left: 0; }
	.carousel-inner > .active.left {
		left: -100%; }
	.carousel-inner > .active.right {
		left: 100%; }

.carousel-control {
	position: absolute;
	top: 0;
	bottom: 0;
	left: 0;
	width: 15%;
	font-size: 20px;
	color: #fff;
	text-align: center;
	text-shadow: 0 1px 2px rgba(0, 0, 0, 0.6);
	background-color: rgba(0, 0, 0, 0);
	filter: alpha(opacity=50);
	opacity: 0.5; }
	.carousel-control.left {
		background-image: -webkit-gradient(linear, left top, right top, from(rgba(0, 0, 0, 0.5)), to(rgba(0, 0, 0, 0.0001)));
		background-image: linear-gradient(to right, rgba(0, 0, 0, 0.5) 0%, rgba(0, 0, 0, 0.0001) 100%);
		filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#80000000', endColorstr='#00000000', GradientType=1);
		background-repeat: repeat-x; }
	.carousel-control.right {
		right: 0;
		left: auto;
		background-image: -webkit-gradient(linear, left top, right top, from(rgba(0, 0, 0, 0.0001)), to(rgba(0, 0, 0, 0.5)));
		background-image: linear-gradient(to right, rgba(0, 0, 0, 0.0001) 0%, rgba(0, 0, 0, 0.5) 100%);
		filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#00000000', endColorstr='#80000000', GradientType=1);
		background-repeat: repeat-x; }
	.carousel-control:hover, .carousel-control:focus {
		color: #fff;
		text-decoration: none;
		outline: 0;
		filter: alpha(opacity=90);
		opacity: 0.9; }
	.carousel-control .icon-prev,
	.carousel-control .icon-next,
	.carousel-control .glyphicon-chevron-left,
	.carousel-control .glyphicon-chevron-right {
		position: absolute;
		top: 50%;
		z-index: 5;
		display: inline-block;
		margin-top: -10px; }
	.carousel-control .icon-prev,
	.carousel-control .glyphicon-chevron-left {
		left: 50%;
		margin-left: -10px; }
	.carousel-control .icon-next,
	.carousel-control .glyphicon-chevron-right {
		right: 50%;
		margin-right: -10px; }
	.carousel-control .icon-prev,
	.carousel-control .icon-next {
		width: 20px;
		height: 20px;
		font-family: serif;
		line-height: 1; }
	.carousel-control .icon-prev:before {
		content: "\2039"; }
	.carousel-control .icon-next:before {
		content: "\203a"; }

.carousel-indicators {
	position: absolute;
	bottom: 10px;
	left: 50%;
	z-index: 15;
	width: 60%;
	padding-left: 0;
	margin-left: -30%;
	text-align: center;
	list-style: none; }
	.carousel-indicators li {
		display: inline-block;
		width: 10px;
		height: 10px;
		margin: 1px;
		text-indent: -999px;
		cursor: pointer;
		background-color: #000 \9;
		background-color: rgba(0, 0, 0, 0);
		border: 1px solid #fff;
		border-radius: 10px; }
	.carousel-indicators .active {
		width: 12px;
		height: 12px;
		margin: 0;
		background-color: #fff; }

.carousel-caption {
	position: absolute;
	right: 15%;
	bottom: 20px;
	left: 15%;
	z-index: 10;
	padding-top: 20px;
	padding-bottom: 20px;
	color: #fff;
	text-align: center;
	text-shadow: 0 1px 2px rgba(0, 0, 0, 0.6); }
	.carousel-caption .btn {
		text-shadow: none; }

@media screen and (min-width: 768px) {
	.carousel-control .glyphicon-chevron-left,
	.carousel-control .glyphicon-chevron-right,
	.carousel-control .icon-prev,
	.carousel-control .icon-next {
		width: 30px;
		height: 30px;
		margin-top: -10px;
		font-size: 30px; }
	.carousel-control .glyphicon-chevron-left,
	.carousel-control .icon-prev {
		margin-left: -10px; }
	.carousel-control .glyphicon-chevron-right,
	.carousel-control .icon-next {
		margin-right: -10px; }
	.carousel-caption {
		right: 20%;
		left: 20%;
		padding-bottom: 30px; }
	.carousel-indicators {
		bottom: 20px; } }

/*! Base Site */
/*
	WET-BOEW
	@title: Accessibility Additions to WET-BOEW - Site template
 */
.wb-sl, #wb-lng h2, #wb-glb-mn h2, #wb-srch h2, #wb-srch label, #wb-sm h2, #wb-bc h2, #wb-sec h2, #wb-info h2, #mb-pnl h3, .wb-calevt-cal .cal-days td ul, .wb-fnote dt, #mb-pnl .srch-pnl label, .wb-invisible, .wb-inv, .wb-show-onfocus {
	clip: rect(1px, 1px, 1px, 1px);
	height: 1px;
	margin: 0;
	overflow: hidden;
	position: absolute;
	width: 1px; }

.wb-sl:focus, .wb-disable .wb-slc .wb-sl, .wb-show-onfocus:focus {
	clip: rect(auto, auto, auto, auto);
	height: inherit;
	margin: inherit;
	overflow: inherit;
	position: static;
	width: inherit; }

#wb-tphp {
	list-style-type: none;
	margin-bottom: 0; }

.wb-slc {
	left: 0;
	position: absolute;
	text-align: center;
	top: 10px;
	width: 100%;
	z-index: 3; }

.wb-sl {
	padding: 5px;
	z-index: 501; }

.wb-disable #wb-tphp {
	background: #fff; }

.wb-disable .wb-slc {
	position: static; }
	.wb-disable .wb-slc .wb-sl {
		background: none;
		color: #295376;
		display: block !important;
		font-weight: 400; }
		.wb-disable .wb-slc .wb-sl:hover, .wb-disable .wb-slc .wb-sl:focus {
			color: #0535d2; }

.wb-disable #wb-dtmd {
	float: none !important; }

.wb-disable #wb-tphp + section h2 {
	margin-left: 1.3em; }
	.wb-disable #wb-tphp + section h2::before {
		color: #f90;
		content: "\e107";
		display: inline-block;
		font-family: "Glyphicons Halflings";
		margin-left: -1.3em;
		position: absolute; }

/*
  WET-BOEW
  @title: Breadcrumb CSS
 */
#wb-bc ol {
	border-radius: 0;
	margin-bottom: 0;
	padding: 1px 13px; }

#wb-bc li {
	max-width: 100%;
	overflow: hidden;
	padding: 7px 2px;
	text-overflow: ellipsis;
	white-space: nowrap; }
	#wb-bc li:before {
		color: #333;
		content: ">";
		font-family: "Glyphicons Halflings";
		font-size: 0.7em; }

[dir=rtl] #wb-bc li:before {
	content: "<";
	display: inline-block; }

/*
  WET-BOEW
  @title: Language selector
 */
.wb-lng-lnks-horiz .wb-lng-lnk {
	display: inline-block; }

.wb-lng-lnks-vert .wb-lng-lnk {
	display: block; }

.wb-lng-lnks-rtl .wb-lng-lnk {
	float: right; }

.wb-lng-lnks-rtl:after {
	clear: both;
	content: "";
	display: table; }

#wb-so {
	text-align: right; }
	#wb-so .row {
		padding: 1em 0 0; }

/*
 Plugins
 */
/*
 * Web Experience Toolkit (WET) / Boîte à outils de l'expérience Web (BOEW)
 * wet-boew.github.io/wet-boew/License-en.html / wet-boew.github.io/wet-boew/Licence-fr.html
 */
.wb-calevt-cal .cal-days td ul.ev-details, .wb-calevt-cal .cal-days td:hover ul {
	background-color: #fff;
	border: 1px solid #333;
	clip: rect(auto, auto, auto, auto);
	color: #000;
	height: inherit;
	list-style-type: none;
	margin: 0;
	margin-top: -.5em;
	overflow: inherit;
	padding: 0;
	position: absolute;
	width: 10em;
	z-index: 5; }
	.wb-calevt-cal .cal-days td ul.ev-details a:hover, .wb-calevt-cal .cal-days td:hover ul a:hover, .wb-calevt-cal .cal-days td ul.ev-details a:focus, .wb-calevt-cal .cal-days td:hover ul a:focus {
		color: #fff; }

.wb-calevt-cal {
	width: 19em; }
	.wb-calevt-cal .cal-days .cal-evt {
		background: #176ca7;
		color: #fff; }
	.wb-calevt-cal .cal-evt-lnk {
		display: block;
		padding: .5em; }
	.wb-calevt-cal.cal-cnt-fluid {
		width: 100%; }

/*
 * Web Experience Toolkit (WET) / Boîte à outils de l'expérience Web (BOEW)
 * wet-boew.github.io/wet-boew/License-en.html / wet-boew.github.io/wet-boew/Licence-fr.html
 */
.wb-clndr td > a {
	display: block;
	height: 100%;
	width: 100%; }

.wb-clndr th abbr, .wb-clndr td > time, .wb-clndr td > a, .wb-clndr td div {
	color: #000;
	padding: 20% 0;
	text-align: center; }

.wb-clndr .cal-curr-day, .wb-clndr .cal-curr-day a,
.wb-clndr .cal-curr-day div {
	color: #000; }

.wb-clndr {
	background: #fff;
	position: relative;
	width: 100%; }
	.wb-clndr .cal-nav {
		background: #333;
		padding: .5em;
		text-align: center; }
	.wb-clndr .form-group {
		margin: 0;
		padding: 10px 14px; }
	.wb-clndr .btn {
		background: none;
		color: #fff; }
		.wb-clndr .btn[disabled] {
			color: #ccc; }
	.wb-clndr option[disabled] {
		color: #aaa; }
	.wb-clndr table {
		width: 100%; }
	.wb-clndr th {
		background: #555;
		border: 1px solid #333; }
		.wb-clndr th abbr {
			color: #fff;
			display: block; }
	.wb-clndr td {
		background: #fff;
		border: 1px solid #aaa;
		padding: 0;
		text-align: center; }
		.wb-clndr td > time {
			display: block; }
		.wb-clndr td a:hover, .wb-clndr td a:focus {
			background: #333;
			color: #fff; }
	.wb-clndr .cal-curr-day {
		background: #ccc;
		font-weight: bolder; }

/*
 * Web Experience Toolkit (WET) / Boîte à outils de l'expérience Web (BOEW)
 * wet-boew.github.io/wet-boew/License-en.html / wet-boew.github.io/wet-boew/Licence-fr.html
 */
figure .pieLabel {
	background-color: #fff;
	border: solid #000 1px;
	color: #000;
	padding: 1px; }

details.alert, details.alert[open] {
	border-radius: 0;
	border-width: 0 0 0 4px;
	padding-left: 45px;
	padding-right: 0;
	position: relative; }
	details.alert:before, details.alert[open]:before {
		display: inline-block;
		font-family: "Glyphicons Halflings";
		font-size: 24px;
		margin-left: -1.3em;
		margin-top: -3px;
		position: absolute;
		top: 15px; }
	details.alert summary, details.alert[open] summary {
		border-width: 0;
		margin-right: 15px;
		padding-left: 5px; }
		details.alert summary:focus, details.alert summary:hover, details.alert[open] summary:focus, details.alert[open] summary:hover {
			text-decoration: none; }
			details.alert summary:focus h2,
			details.alert summary:focus h3,
			details.alert summary:focus h4,
			details.alert summary:focus h5,
			details.alert summary:focus h6, details.alert summary:hover h2,
			details.alert summary:hover h3,
			details.alert summary:hover h4,
			details.alert summary:hover h5,
			details.alert summary:hover h6, details.alert[open] summary:focus h2,
			details.alert[open] summary:focus h3,
			details.alert[open] summary:focus h4,
			details.alert[open] summary:focus h5,
			details.alert[open] summary:focus h6, details.alert[open] summary:hover h2,
			details.alert[open] summary:hover h3,
			details.alert[open] summary:hover h4,
			details.alert[open] summary:hover h5,
			details.alert[open] summary:hover h6 {
				text-decoration: underline; }
	details.alert > *, details.alert[open] > * {
		margin-left: .7em; }
	details.alert > :first-child, details.alert[open] > :first-child {
		margin-left: .2em; }
		details.alert > :first-child:before, details.alert[open] > :first-child:before {
			color: #000;
			content: ""; }
	details.alert.alert-success:before, details.alert[open].alert-success:before {
		color: #278400;
		content: "\e084"; }
	details.alert.alert-info:before, details.alert[open].alert-info:before {
		color: #269abc;
		content: "\e086"; }
	details.alert.alert-warning:before, details.alert[open].alert-warning:before {
		color: #f90;
		content: "\e107"; }
	details.alert.alert-danger:before, details.alert[open].alert-danger:before {
		color: #d3080c;
		content: "\e101"; }

.wb-enable.no-details details.alert > summary {
	margin-left: 1.2em; }
	.wb-enable.no-details details.alert > summary:before {
		content: "\25BA\a0"; }

.wb-enable.no-details details.alert[open] > summary:before {
	content: "\25BC\a0"; }

.wb-enable.no-details[dir="rtl"] details.alert > summary {
	margin-right: 1.2em; }

/*
 * Web Experience Toolkit (WET) / Boîte à outils de l'expérience Web (BOEW)
 * wet-boew.github.io/wet-boew/License-en.html / wet-boew.github.io/wet-boew/Licence-fr.html
 */
/*
 *	Dismissable content container
 */
.wb-dismissable-container {
	background-color: #eee;
	display: table;
	margin: 10px 0;
	padding: 10px;
	width: 100%; }
	.wb-dismissable-container .mfp-close {
		color: #555;
		display: table-cell;
		position: static; }

/*
 *	Dismissable content wrapper
 */
.wb-dismissable-wrapper {
	display: table-cell;
	width: 100%; }

.wb-eqht-grd {
	-webkit-box-align: stretch;
	    -ms-flex-align: stretch;
	        align-items: stretch;
	display: -webkit-box;
	display: -ms-flexbox;
	display: flex;
	-ms-flex-wrap: wrap;
	    flex-wrap: wrap;
	height: 100%; }
	.wb-eqht-grd > [class*="col-"] {
		display: -webkit-box;
		display: -ms-flexbox;
		display: flex;
		-webkit-box-orient: vertical;
		-webkit-box-direction: normal;
		    -ms-flex-direction: column;
		        flex-direction: column; }
		.wb-eqht-grd > [class*="col-"] > section, .wb-eqht-grd > [class*="col-"] .hght-inhrt {
			display: -webkit-box;
			display: -ms-flexbox;
			display: flex;
			-webkit-box-flex: 1;
			    -ms-flex: 1 1 auto;
			        flex: 1 1 auto;
			-webkit-box-orient: vertical;
			-webkit-box-direction: normal;
			    -ms-flex-direction: column;
			        flex-direction: column; }
	.wb-eqht-grd.grow > [class*="col-"] {
		-webkit-box-flex: 1;
		    -ms-flex-positive: 1;
		        flex-grow: 1; }

/*
 * Web Experience Toolkit (WET) / Boîte à outils de l'expérience Web (BOEW)
 * wet-boew.github.io/wet-boew/License-en.html / wet-boew.github.io/wet-boew/Licence-fr.html
 */
.hght-inhrt {
	min-height: inherit; }

.wb-fltr-out {
	display: none !important; }

.wb-filter .input-group {
	max-width: 100%; }

/*
 * Web Experience Toolkit (WET) / Boîte à outils de l'expérience Web (BOEW)
 * wet-boew.github.io/wet-boew/License-en.html / wet-boew.github.io/wet-boew/Licence-fr.html
 */
/*
 * Web Experience Toolkit (WET) / Boîte à outils de l'expérience Web (BOEW)
 * wet-boew.github.io/wet-boew/License-en.html / wet-boew.github.io/wet-boew/Licence-fr.html
 */
/*
 * HOW TO USE THIS FILE
 * Use this file to override Bootstrap variables and WET custom variables.
 * If there is a Bootstrap variable not shown here that you want to override, go to "../node_modules/bootstrap-sass/assets/stylesheets/bootstrap/variables" to view the variables that you can override. Simply copy and paste the variable and its applicable section (if applicable) from the Bootstrap file into this override file and override the variables as applicable.
 */
.fn-lnk:hover, .fn-lnk:focus, .wb-fnote dd:focus .fn-rtn a, .wb-fnote .fn-rtn a:hover, .wb-fnote .fn-rtn a:focus {
	background-color: #555;
	border-color: #555;
	color: #fff !important; }

.fn-lnk, .wb-fnote .fn-rtn a {
	background-color: #eee;
	border: 1px solid #ccc;
	display: inline-block;
	padding: 1px 10px 2px;
	white-space: nowrap; }

.wb-fnote h2, .wb-fnote dd > ul:first-child,
.wb-fnote dd > ol:first-child, .wb-fnote table:first-child {
	margin-top: 0.375em; }

.fn-lnk {
	line-height: 1.15;
	margin-left: 5px; }

.wb-fnote {
	border-color: #ccc;
	border-style: solid;
	border-width: 1px 0;
	margin: 2em 0 0; }
	.wb-fnote h2 {
		margin-left: 0;
		margin-right: 0; }
	.wb-fnote dl {
		margin: 0; }
	.wb-fnote dd {
		border: 1px solid transparent;
		margin: 0.375em 0;
		position: relative; }
		.wb-fnote dd:focus {
			background-color: #eee;
			border-color: #555; }
		.wb-fnote dd > ul,
		.wb-fnote dd > ol {
			margin: 0 0.375em 0.375em 4.25em; }
	.wb-fnote p {
		margin: 0 0 0 3.875em;
		padding: 0 0.375em 0.375em; }
		.wb-fnote p:first-child {
			margin-top: .11em;
			padding-top: 0.375em; }
	.wb-fnote ul,
	.wb-fnote ol {
		margin-bottom: 0.375em; }
	.wb-fnote table {
		margin: 0 0.375em 0.375em 4.25em; }
	.wb-fnote .fn-rtn {
		margin: 0;
		overflow: hidden;
		padding-right: 0;
		padding-top: 0.375em;
		position: absolute;
		top: 0;
		width: 3.5em; }
		.wb-fnote .fn-rtn a {
			display: inline-block;
			margin-top: 0;
			padding-bottom: 0; }

/* Right to left (RTL) SCSS */
[dir="rtl"] sup .fn-lnk {
	margin-left: 0;
	margin-right: 5px; }

[dir="rtl"] .wb-fnote p {
	margin: 0 3.875em 0 0; }

[dir="rtl"] .wb-fnote .fn-rtn {
	margin-right: 0;
	padding-right: 0; }

/*
 * Web Experience Toolkit (WET) / Boîte à outils de l'expérience Web (BOEW)
 * wet-boew.github.io/wet-boew/License-en.html / wet-boew.github.io/wet-boew/Licence-fr.html
 */
.wb-frmvld label strong.error,
.wb-frm label strong.error, .wb-frmvld legend .error,
.wb-frm legend .error {
	display: inline-block;
	width: 100%; }

.wb-frmvld label strong.error .label,
.wb-frm label strong.error .label, .wb-frmvld legend .error .label,
.wb-frm legend .error .label {
	font-size: 100%;
	white-space: normal; }

.wb-server-error {
	display: block !important;
	font-size: 100% !important;
	text-align: left !important;
	white-space: normal !important; }

.css-implicite-input {
	font-weight: 400;
	margin-top: 5px; }

/*
 * Web Experience Toolkit (WET) / Boîte à outils de l'expérience Web (BOEW)
 * wet-boew.github.io/wet-boew/License-en.html / wet-boew.github.io/wet-boew/Licence-fr.html
 */
/*
 * Web Experience Toolkit (WET) / Boîte à outils de l'expérience Web (BOEW)
 * wet-boew.github.io/wet-boew/License-en.html / wet-boew.github.io/wet-boew/Licence-fr.html
 */
/*
 * HOW TO USE THIS FILE
 * Use this file to override Bootstrap variables and WET custom variables.
 * If there is a Bootstrap variable not shown here that you want to override, go to "../node_modules/bootstrap-sass/assets/stylesheets/bootstrap/variables" to view the variables that you can override. Simply copy and paste the variable and its applicable section (if applicable) from the Bootstrap file into this override file and override the variables as applicable.
 */
/* Magnific Popup CSS */
.mfp-bg {
	top: 0;
	left: 0;
	width: 100%;
	height: 100%;
	z-index: 1042;
	overflow: hidden;
	position: fixed;
	background: #0b0b0b;
	opacity: 0.8;
	filter: alpha(opacity=80); }

.mfp-wrap {
	top: 0;
	left: 0;
	width: 100%;
	height: 100%;
	z-index: 1043;
	position: fixed;
	outline: none !important;
	-webkit-backface-visibility: hidden; }

.mfp-container {
	text-align: center;
	position: absolute;
	width: 100%;
	height: 100%;
	left: 0;
	top: 0;
	padding: 0 8px;
	-webkit-box-sizing: border-box;
	box-sizing: border-box; }

.mfp-container:before {
	content: '';
	display: inline-block;
	height: 100%;
	vertical-align: middle; }

.mfp-align-top .mfp-container:before {
	display: none; }

.mfp-content {
	position: relative;
	display: inline-block;
	vertical-align: middle;
	margin: 0 auto;
	text-align: left;
	z-index: 1045; }

.mfp-inline-holder .mfp-content,
.mfp-ajax-holder .mfp-content {
	width: 100%;
	cursor: auto; }

.mfp-ajax-cur {
	cursor: progress; }

.mfp-zoom-out-cur, .mfp-zoom-out-cur .mfp-image-holder .mfp-close {
	cursor: -webkit-zoom-out;
	cursor: zoom-out; }

.mfp-zoom {
	cursor: pointer;
	cursor: -webkit-zoom-in;
	cursor: zoom-in; }

.mfp-auto-cursor .mfp-content {
	cursor: auto; }

.mfp-close,
.mfp-arrow,
.mfp-preloader,
.mfp-counter {
	-webkit-user-select: none;
	-moz-user-select: none;
	-ms-user-select: none;
	    user-select: none; }

.mfp-loading.mfp-figure {
	display: none; }

.mfp-hide {
	display: none !important; }

.mfp-preloader {
	color: #CCC;
	position: absolute;
	top: 50%;
	width: auto;
	text-align: center;
	margin-top: -0.8em;
	left: 8px;
	right: 8px;
	z-index: 1044; }
	.mfp-preloader a {
		color: #CCC; }
		.mfp-preloader a:hover {
			color: #FFF; }

.mfp-s-ready .mfp-preloader {
	display: none; }

.mfp-s-error .mfp-content {
	display: none; }

button.mfp-close, button.mfp-arrow {
	overflow: visible;
	cursor: pointer;
	background: transparent;
	border: 0;
	-webkit-appearance: none;
	display: block;
	outline: none;
	padding: 0;
	z-index: 1046;
	-webkit-box-shadow: none;
	box-shadow: none; }

button::-moz-focus-inner {
	padding: 0;
	border: 0; }

.mfp-close {
	width: 44px;
	height: 44px;
	line-height: 44px;
	position: absolute;
	right: 0;
	top: 0;
	text-decoration: none;
	text-align: center;
	opacity: 0.65;
	filter: alpha(opacity=65);
	padding: 0 0 18px 10px;
	color: #FFF;
	font-style: normal;
	font-size: 28px;
	font-family: Arial, Baskerville, monospace; }
	.mfp-close:hover, .mfp-close:focus {
		opacity: 1;
		filter: alpha(opacity=100); }
	.mfp-close:active {
		top: 1px; }

.mfp-close-btn-in .mfp-close {
	color: #333; }

.mfp-image-holder .mfp-close,
.mfp-iframe-holder .mfp-close {
	color: #FFF;
	right: -6px;
	text-align: right;
	padding-right: 6px;
	width: 100%; }

.mfp-counter {
	position: absolute;
	top: 0;
	right: 0;
	color: #CCC;
	font-size: 12px;
	line-height: 18px;
	white-space: nowrap; }

.mfp-arrow {
	position: absolute;
	opacity: 0.65;
	filter: alpha(opacity=65);
	margin: 0;
	top: 50%;
	margin-top: -55px;
	padding: 0;
	width: 90px;
	height: 110px;
	-webkit-tap-highlight-color: rgba(0, 0, 0, 0); }
	.mfp-arrow:active {
		margin-top: -54px; }
	.mfp-arrow:hover, .mfp-arrow:focus {
		opacity: 1;
		filter: alpha(opacity=100); }
	.mfp-arrow:before, .mfp-arrow:after,
	.mfp-arrow .mfp-b,
	.mfp-arrow .mfp-a {
		content: '';
		display: block;
		width: 0;
		height: 0;
		position: absolute;
		left: 0;
		top: 0;
		margin-top: 35px;
		margin-left: 35px;
		border: medium inset transparent; }
	.mfp-arrow:after,
	.mfp-arrow .mfp-a {
		border-top-width: 13px;
		border-bottom-width: 13px;
		top: 8px; }
	.mfp-arrow:before,
	.mfp-arrow .mfp-b {
		border-top-width: 21px;
		border-bottom-width: 21px;
		opacity: 0.7; }

.mfp-arrow-left {
	left: 0; }
	.mfp-arrow-left:after,
	.mfp-arrow-left .mfp-a {
		border-right: 17px solid #FFF;
		margin-left: 31px; }
	.mfp-arrow-left:before,
	.mfp-arrow-left .mfp-b {
		margin-left: 25px;
		border-right: 27px solid #3F3F3F; }

.mfp-arrow-right {
	right: 0; }
	.mfp-arrow-right:after,
	.mfp-arrow-right .mfp-a {
		border-left: 17px solid #FFF;
		margin-left: 39px; }
	.mfp-arrow-right:before,
	.mfp-arrow-right .mfp-b {
		border-left: 27px solid #3F3F3F; }

.mfp-iframe-holder {
	padding-top: 40px;
	padding-bottom: 40px; }
	.mfp-iframe-holder .mfp-content {
		line-height: 0;
		width: 100%;
		max-width: 900px; }
	.mfp-iframe-holder .mfp-close {
		top: -40px; }

.mfp-iframe-scaler {
	width: 100%;
	height: 0;
	overflow: hidden;
	padding-top: 56.25%; }
	.mfp-iframe-scaler iframe {
		position: absolute;
		display: block;
		top: 0;
		left: 0;
		width: 100%;
		height: 100%;
		-webkit-box-shadow: 0 0 8px rgba(0, 0, 0, 0.6);
		        box-shadow: 0 0 8px rgba(0, 0, 0, 0.6);
		background: #000; }

/* Main image in popup */
img.mfp-img {
	width: auto;
	max-width: 100%;
	height: auto;
	display: block;
	line-height: 0;
	-webkit-box-sizing: border-box;
	box-sizing: border-box;
	padding: 40px 0 40px;
	margin: 0 auto; }

/* The shadow behind the image */
.mfp-figure {
	line-height: 0; }
	.mfp-figure:after {
		content: '';
		position: absolute;
		left: 0;
		top: 40px;
		bottom: 40px;
		display: block;
		right: 0;
		width: auto;
		height: auto;
		z-index: -1;
		-webkit-box-shadow: 0 0 8px rgba(0, 0, 0, 0.6);
		        box-shadow: 0 0 8px rgba(0, 0, 0, 0.6);
		background: #444; }
	.mfp-figure small {
		color: #BDBDBD;
		display: block;
		font-size: 12px;
		line-height: 14px; }
	.mfp-figure figure {
		margin: 0; }

.mfp-bottom-bar {
	margin-top: -36px;
	position: absolute;
	top: 100%;
	left: 0;
	width: 100%;
	cursor: auto; }

.mfp-title {
	text-align: left;
	line-height: 18px;
	color: #F3F3F3;
	word-wrap: break-word;
	padding-right: 36px; }

.mfp-image-holder .mfp-content {
	max-width: 100%; }

.mfp-gallery .mfp-image-holder .mfp-figure {
	cursor: pointer; }

@media screen and (max-width: 800px) and (orientation: landscape), screen and (max-height: 300px) {
	/**
       * Remove all paddings around the image on small screen
       */
	.mfp-img-mobile .mfp-image-holder {
		padding-left: 0;
		padding-right: 0; }
	.mfp-img-mobile img.mfp-img {
		padding: 0; }
	.mfp-img-mobile .mfp-figure:after {
		top: 0;
		bottom: 0; }
	.mfp-img-mobile .mfp-figure small {
		display: inline;
		margin-left: 5px; }
	.mfp-img-mobile .mfp-bottom-bar {
		background: rgba(0, 0, 0, 0.6);
		bottom: 0;
		margin: 0;
		top: auto;
		padding: 3px 5px;
		position: fixed;
		-webkit-box-sizing: border-box;
		box-sizing: border-box; }
		.mfp-img-mobile .mfp-bottom-bar:empty {
			padding: 0; }
	.mfp-img-mobile .mfp-counter {
		right: 5px;
		top: 3px; }
	.mfp-img-mobile .mfp-close {
		top: 0;
		right: 0;
		width: 35px;
		height: 35px;
		line-height: 35px;
		background: rgba(0, 0, 0, 0.6);
		position: fixed;
		text-align: center;
		padding: 0; } }

@media all and (max-width: 900px) {
	.mfp-arrow {
		-webkit-transform: scale(0.75);
		transform: scale(0.75); }
	.mfp-arrow-left {
		-webkit-transform-origin: 0;
		transform-origin: 0; }
	.mfp-arrow-right {
		-webkit-transform-origin: 100%;
		transform-origin: 100%; }
	.mfp-container {
		padding-left: 6px;
		padding-right: 6px; } }

.mfp-ie7 .mfp-img {
	padding: 0; }

.mfp-ie7 .mfp-bottom-bar {
	width: 600px;
	left: 50%;
	margin-left: -300px;
	margin-top: 5px;
	padding-bottom: 5px; }

.mfp-ie7 .mfp-container {
	padding: 0; }

.mfp-ie7 .mfp-content {
	padding-top: 44px; }

.mfp-ie7 .mfp-close {
	top: 0;
	right: 0;
	padding-top: 0; }

.mfp-close:focus, .mfp-arrow:focus {
	outline: 1px dotted #fff;
	outline-offset: -2px; }

body.wb-modal > #wb-tphp,
body.wb-modal > header,
body.wb-modal > main,
body.wb-modal > footer, body.wb-modal summary {
	visibility: hidden !important; }

.lbx-hide-gal li {
	display: none;
	list-style-type: none; }
	.lbx-hide-gal li:first-child {
		display: block; }

body.wb-modal .modal-dialog summary {
	visibility: visible !important; }

.modal-dialog {
	left: auto;
	padding: 0;
	position: relative; }

.modal-content {
	background: transparent; }

.modal-body {
	background: #fff; }

.modal-footer {
	background: #fff;
	margin-top: 0; }

.mfp-gallery .modal-body {
	padding: 20px 30px; }

.mfp-close {
	cursor: pointer !important;
	font-weight: 700;
	/* Should fix upstream in Magnific Popup rather than overriding in WET */ }

/* Should fix upstream in Magnific Popup rather than overriding in WET */
.mfp-arrow {
	opacity: 1; }

.mfp-arrow-left:before,
.mfp-arrow-left .mfp-b {
	border-right: 27px solid #000000; }

.mfp-arrow-right:before,
.mfp-arrow-right .mfp-b {
	border-left: 27px solid #000000; }

/* Should fix upstream in Magnific Popup rather than overriding in WET */
.mfp-bottom-bar .mfp-title {
	padding-right: 5px;
	width: 75%; }

.mfp-bottom-bar .mfp-counter {
	font-size: 1em;
	text-align: right;
	width: 25%; }

.wb-modal dialog {
	background-color: transparent;
	border: none; }

/*
 * Web Experience Toolkit (WET) / Boîte à outils de l'expérience Web (BOEW)
 * wet-boew.github.io/wet-boew/License-en.html / wet-boew.github.io/wet-boew/Licence-fr.html
 */
/*
 * Menu Sass
 */
.expicon {
	font-size: .7em;
	margin: 0 -.35em 0 .7em; }

.wb-menu .sm {
	display: none;
	max-height: 0;
	overflow: hidden;
	position: relative; }
	.wb-menu .sm.open {
		display: inline;
		max-height: 1000px;
		min-width: 12.5em;
		position: absolute;
		text-transform: none;
		top: auto;
		z-index: 500; }
		.wb-menu .sm.open li a {
			text-align: left; }
	.wb-menu .sm details > * {
		margin-left: auto;
		margin-right: auto; }

.wb-menu .menu {
	margin-left: 0;
	position: relative; }
	.wb-menu .menu > li {
		float: left;
		margin: 0;
		padding: 0; }
		.wb-menu .menu > li a {
			display: block;
			padding: 1em;
			text-align: center; }
			.wb-menu .menu > li a[aria-haspopup]:hover, .wb-menu .menu > li a[aria-haspopup]:focus {
				cursor: default; }

.wb-menu .sm-open .expicon {
	z-index: -1; }

.wb-menu details, .wb-menu details[open] {
	border: 0;
	margin-bottom: 0; }
	.wb-menu details summary, .wb-menu details[open] summary {
		border: 0;
		color: inherit; }
		.wb-menu details summary:focus, .wb-menu details summary:hover, .wb-menu details[open] summary:focus, .wb-menu details[open] summary:hover {
			text-decoration: none; }

#mb-pnl nav a.wb-navcurr, #mb-pnl nav summary.wb-navcurr {
	outline: 1px solid; }

#mb-pnl nav a.wb-navcurr:focus, #mb-pnl nav summary.wb-navcurr:focus {
	outline-style: dotted; }

#mb-pnl .srch-pnl, #mb-pnl nav {
	padding: 10px 20px 8px; }

#mb-pnl .srch-pnl form {
	white-space: nowrap; }

#mb-pnl .lng-ofr {
	padding: 7px 15px 0;
	text-align: right; }
	#mb-pnl .lng-ofr ul {
		margin-bottom: 0; }
	#mb-pnl .lng-ofr li {
		line-height: normal;
		padding-left: 10px;
		padding-right: 0; }
		#mb-pnl .lng-ofr li a {
			padding: 5px; }

#mb-pnl nav ul li.no-sect {
	padding-left: 1.27em; }
	#mb-pnl nav ul li.no-sect .list-group {
		margin-bottom: 0; }
	#mb-pnl nav ul li.no-sect a {
		margin: 0 0 0 -6px; }

#mb-pnl nav .mb-menu > li {
	padding: 10px 0 2px; }

#mb-pnl nav a {
	display: inline-block;
	margin: 6px 0 6px -6px;
	padding: 0 6px;
	width: 100%; }

#mb-pnl nav summary {
	padding-left: 3px; }
	#mb-pnl nav summary.wb-navcurr:focus {
		outline-offset: -2px; }

#mb-pnl details[open] {
	padding-bottom: 0; }

#mb-pnl details ul {
	padding-left: 1.2em; }

#mb-pnl details details {
	margin: 6px 0 6px -1.28em; }

.wb-disable #wb-glb-mn {
	display: none !important; }

.wb-disable #wb-sm .menu {
	background: #0e4164; }

[dir=rtl] .wb-menu .menu {
	padding-right: 0; }
	[dir=rtl] .wb-menu .menu > li {
		float: right; }

[dir=rtl] .wb-menu .sm.open li a {
	text-align: right; }

[dir=rtl] .expicon {
	margin: 0 .7em 0 -.35em; }

[dir=rtl] #mb-pnl .lng-ofr {
	text-align: left; }
	[dir=rtl] #mb-pnl .lng-ofr li {
		padding-left: 0;
		padding-right: 10px; }

[dir=rtl] #mb-pnl nav ul li.no-sect {
	padding-left: 0;
	padding-right: 1.27em; }

[dir=rtl] #mb-pnl nav a {
	margin-left: 0;
	margin-right: -6px; }

[dir=rtl] #mb-pnl nav summary {
	margin-left: 0;
	margin-right: -3px;
	padding-left: 0;
	padding-right: 3px; }

[dir=rtl] #mb-pnl details ul {
	padding-left: 0;
	padding-right: .7em; }

/*
  Multimedia Player Code
 */
.wb-mltmd.audio .lastpnl, .wb-mltmd.youtube.cc_on .wb-mm-cc {
	display: none; }

.wb-mm-ctrls .btn:focus, .wb-mm-ctrls progress:focus, .wb-mm-ctrls input:focus[type=range] {
	outline: 1px solid #4aafff; }

.wb-mm-ctrls .fd-slider-bar, .wb-mm-ctrls .fd-slider-range {
	background: #aaa;
	border: 0; }

.xxsmallview .wb-mm-ctrls .frstpnl, .xxsmallview .wb-mm-ctrls .lastpnl {
	padding-top: 2em; }

.wb-mltmd video, .wb-mltmd object,
.wb-mltmd iframe {
	display: block;
	width: 100%; }

.wb-mm-cc {
	max-height: 0;
	padding: 0; }

.wb-mm-cc:before, .wb-mm-cc div {
	display: table-cell;
	height: 2.875em;
	vertical-align: middle; }

.wb-mltmd {
	display: block;
	position: relative;
	/*
	  Light Skinning of mediacontrols
	 */ }
	.wb-mltmd.video:not(.playing):not(.waiting) .display {
		cursor: pointer;
		position: relative; }
	.wb-mltmd.video:not(.playing):not(.waiting) .display:before {
		text-align: center; }
	.wb-mltmd.video:not(.playing):not(.waiting) .display:after {
		color: #fff;
		content: "";
		font-family: "Glyphicons Halflings";
		font-size: 65px;
		text-align: center; }
	.wb-mltmd.video.waiting .display {
		position: relative; }
		.wb-mltmd.video.waiting .display:before, .wb-mltmd.video.waiting .display:after {
			display: block; }
	.wb-mltmd.audio object {
		position: absolute; }
	.wb-mltmd video {
		height: auto;
		width: 100%; }
	.wb-mltmd.cc_on .wb-mm-cc {
		display: table;
		height: calc(2.875em + 1em);
		padding: 0.5em; }
	.wb-mltmd.cc_on:not(.errmsg) .cc:after {
		border-bottom: 3px solid #4aafff;
		content: " ";
		display: block;
		margin-left: -2px;
		width: 1.2em; }
	.wb-mltmd.youtube.video:not(.playing):not(.waiting) .display:before {
		background: #3e3e3e; }
	.wb-mltmd.skn-lt {
		border-bottom: 1px solid #ddd;
		color: #000; }
		.wb-mltmd.skn-lt .wb-mm-ctrls {
			background: #fff;
			color: #000; }
			.wb-mltmd.skn-lt .wb-mm-ctrls .btn {
				background: #fff;
				border: 0;
				color: #000; }
				.wb-mltmd.skn-lt .wb-mm-ctrls .btn[disabled]:active:hover {
					color: #000; }
	.wb-mltmd .wb-share {
		text-align: right; }
	.wb-mltmd summary,
	.wb-mltmd details[open] {
		border-top-left-radius: 0;
		border-top-right-radius: 0; }

.wb-mm-cc {
	background-color: #000;
	color: #fff;
	text-align: center;
	-webkit-transition: all .26s ease;
	transition: all .26s ease;
	width: 100%; }
	.wb-mm-cc:before {
		content: " "; }

.wb-mm-ctrls .frstpnl, .wb-mm-ctrls .lastpnl, .wb-mm-ctrls .tline {
	display: table-cell;
	vertical-align: middle; }

.wb-mm-ctrls {
	background: #3e3e3e;
	color: #fff;
	display: table;
	padding-top: 2em;
	position: relative;
	width: 100%;
	/* Progress Bar */
	/* Slider polyfill styles */ }
	.wb-mm-ctrls .btn {
		background: transparent;
		border: 0;
		border-top-left-radius: 0 !important;
		border-top-right-radius: 0 !important;
		color: #fff;
		font-size: 130%; }
		.wb-mm-ctrls .btn[disabled]:active:hover {
			color: #fff; }
		.wb-mm-ctrls .btn[disabled]:hover {
			background-color: transparent; }
	.wb-mm-ctrls .frstpnl {
		text-align: center;
		width: 13em; }
	.wb-mm-ctrls .lastpnl {
		text-align: center;
		width: 3em; }
	.wb-mm-ctrls .tline .wb-mm-tmln-crrnt:after {
		content: " / ";
		padding: 0 .5em; }
	.wb-mm-ctrls .wb-mm-txtonly {
		padding: 0 1em; }
		.wb-mm-ctrls .wb-mm-txtonly p {
			display: inline; }
	.wb-mm-ctrls .wb-mm-txtonly,
	.wb-mm-ctrls .wb-mm-prgrss {
		display: table-cell;
		vertical-align: middle; }
	.wb-mm-ctrls progress {
		/* Important Thing */
		-webkit-appearance: none;
		background: #fff;
		background-clip: padding-box;
		border: 7px solid #3e3e3e;
		border-radius: 14px;
		color: #176ca7;
		display: block;
		height: 30px;
		left: 0;
		padding: 2px;
		position: absolute;
		top: 0;
		width: 100%; }
		.wb-mm-ctrls progress.wb-progress-inited {
			overflow: hidden;
			padding: 0; }
		.wb-mm-ctrls progress::-webkit-progress-bar {
			background: #fff; }
		.wb-mm-ctrls progress::-webkit-progress-value {
			background: #176ca7;
			border-radius: 7px; }
		.wb-mm-ctrls progress::-moz-progress-bar {
			background: #176ca7;
			border-radius: 7px; }
	.wb-mm-ctrls .progress {
		height: 22px; }
	.wb-mm-ctrls input[type=range] {
		-webkit-appearance: none;
		background: transparent;
		display: inline-block;
		height: 2.5em;
		padding: 0;
		width: 7em; }
		.wb-mm-ctrls input[type=range]:focus {
			/* Prevent Webkit/Blink browsers from defaulting to a -2px outline offset. */
			outline-offset: 0; }
		.wb-mm-ctrls input[type=range]::-webkit-slider-runnable-track {
			background: #aaa;
			height: 4px; }
		.wb-mm-ctrls input[type=range]::-webkit-slider-thumb {
			-webkit-appearance: none;
			background: #fff;
			border: 1px solid #707070;
			-webkit-box-sizing: content-box;
			        box-sizing: content-box;
			height: 1.3em;
			margin-top: -9px;
			width: 10px; }
		.wb-mm-ctrls input[type=range]::-moz-range-track {
			background: #aaa;
			border: 0; }
		.wb-mm-ctrls input[type=range]::-moz-range-thumb {
			background: #fff;
			border: 1px solid #707070;
			border-radius: 0;
			height: 1.3em;
			width: 10px; }
		.wb-mm-ctrls input[type=range]::-ms-track {
			border: 0;
			color: transparent;
			height: 4px; }
		.wb-mm-ctrls input[type=range]::-ms-fill-upper {
			background: #aaa; }
		.wb-mm-ctrls input[type=range]::-ms-fill-lower {
			background: #aaa; }
		.wb-mm-ctrls input[type=range]::-ms-thumb {
			background: #fff;
			border: 1px solid #707070;
			height: 1.3em;
			width: 10px; }
	.wb-mm-ctrls .fd-slider {
		display: inline-block;
		height: 100%;
		margin-top: 10px;
		width: 7em; }
	.wb-mm-ctrls .fd-slider-handle {
		background: #fff;
		border: 1px solid #707070;
		-webkit-box-sizing: content-box;
		        box-sizing: content-box;
		width: 10px; }

.xxsmallview .wb-mm-ctrls .wb-mm-txtonly {
	left: 0;
	margin-top: -2em;
	position: absolute; }

/*
 * Web Experience Toolkit (WET) / Boîte à outils de l'expérience Web (BOEW)
 * wet-boew.github.io/wet-boew/License-en.html / wet-boew.github.io/wet-boew/Licence-fr.html
 */
/*
 *	Overlay base
 */
.wb-overlay {
	background-clip: border-box;
	background-color: #fff;
	border: 0;
	border-radius: 0;
	display: none;
	-webkit-transform: translateZ(0);
	        transform: translateZ(0);
	z-index: 1050; }
	.wb-overlay.wb-inview {
		display: block; }
	.wb-overlay.open {
		display: inline-block;
		position: fixed; }

.wb-panel-l, .wb-panel-r {
	height: 100%;
	max-width: 90%;
	top: 0; }

.wb-bar-t, .wb-bar-b {
	border-bottom: 0;
	left: 0;
	max-height: 90%;
	min-width: 100%; }

.wb-popup-mid {
	max-height: 90%;
	max-width: 90%; }

/*
 *	Overlay styles
 */
.wb-panel-l {
	left: 0; }

.wb-panel-r {
	right: 0; }

.wb-bar-t {
	top: 0; }

.wb-bar-b {
	bottom: 0; }

.wb-popup-mid {
	border-radius: 6px;
	bottom: 0;
	left: 0;
	margin: auto;
	right: 0;
	top: 0;
	width: 90%; }

.wb-popup-full {
	height: 100%;
	left: 0;
	top: 0;
	width: 100%; }

.mfp-bg {
	opacity: .97; }

.wb-overlay-dlg {
	overflow: hidden; }
	.wb-overlay-dlg .overlay-bg {
		-webkit-box-shadow: 0 0 1000px 1000px black;
		        box-shadow: 0 0 1000px 1000px black; }

/*
 *	Overlay parts
 */
.overlay-def {
	overflow-y: auto; }
	.overlay-def header {
		background-color: #2e5274;
		color: #fff;
		display: block;
		padding: 0 44px 0 1em; }
	.overlay-def .modal-title {
		font-size: 1.15em;
		padding: 10px 0; }
	.overlay-def.wb-bar-t, .overlay-def.wb-bar-b {
		background-color: #000; }
		.overlay-def.wb-bar-t header, .overlay-def.wb-bar-b header {
			background-color: #000; }
	.overlay-def .mfp-close {
		color: #fff; }

.hidden-hd .modal-body {
	padding-top: 50px; }

.hidden-hd .overlay-close:not(.btn) {
	background-color: #000;
	border-radius: 999px;
	height: 1em;
	line-height: 1em;
	margin-right: 20px;
	margin-top: 10px;
	width: 1em; }

[dir=rtl] .mfp-close {
	left: 0;
	right: auto; }

[dir=rtl] .wb-panel-l {
	left: auto;
	right: 0; }

[dir=rtl] .wb-panel-r {
	left: 0;
	right: auto; }

[dir=rtl] .overlay-def header {
	padding: 0 1em 0 44px; }

/*
 * Web Experience Toolkit (WET) / Boîte à outils de l'expérience Web (BOEW)
 * wet-boew.github.io/wet-boew/License-en.html / wet-boew.github.io/wet-boew/Licence-fr.html
 */
/* Pretty printing styles. Used with prettify.js. */
/* SPAN elements with the classes below are added by prettyprint. */
/* plain text */
.pln {
	color: #000; }

pre.prettyprint {
	background-color: #f5f5f5;
	border: 1px solid #ddd;
	color: #707070;
	font-size: 95%;
	padding: 8px;
	/* Specify class=linenums on a pre to get line numbering */ }
	pre.prettyprint.linenums {
		-webkit-box-shadow: 40px 0 0 #fbfbfc inset, 41px 0 0 #eee inset;
		        box-shadow: 40px 0 0 #fbfbfc inset, 41px 0 0 #eee inset; }
	pre.prettyprint code {
		-moz-tab-size: 20px;
		  -o-tab-size: 20px;
		     tab-size: 20px; }
		pre.prettyprint code ins {
			font-weight: bold;
			text-decoration: none; }

ol.linenums {
	margin: 0 !important; }
	ol.linenums li {
		padding-left: 10px;
		text-shadow: 0 1px 0 #fff; }

/* Right to left (RTL) CSS */
[dir="rtl"] pre.prettyprint {
	direction: ltr; }

/*
 * Web Experience Toolkit (WET) / Boîte à outils de l'expérience Web (BOEW)
 * wet-boew.github.io/wet-boew/License-en.html / wet-boew.github.io/wet-boew/Licence-fr.html
 */
#wb-rsz {
	clip: rect(1px, 1px, 1px, 1px);
	margin: 0;
	overflow: hidden;
	position: absolute;
	top: -1000px; }

/*
 * Web Experience Toolkit (WET) / Boîte à outils de l'expérience Web (BOEW)
 * wet-boew.github.io/wet-boew/License-en.html / wet-boew.github.io/wet-boew/Licence-fr.html
 */
.shr-opn span {
	padding-right: .2em; }

.shr-pg .shr-lnk {
	font-size: 115%;
	line-height: 32px;
	margin-bottom: 8px;
	min-height: 32px;
	text-align: left;
	text-decoration: none;
	width: 100%; }
	.shr-pg .shr-lnk:before {
		content: " ";
		display: inline-block;
		height: 32px;
		margin-right: .6em;
		vertical-align: middle;
		width: 32px; }

.shr-pg .blogger:before {
	background-image: url(../../wet-boew/assets/sprites_share.png);
	background-position: 0px 0px;
	width: 32px;
	height: 32px; }

.shr-pg .diigo:before {
	background-image: url(../../wet-boew/assets/sprites_share.png);
	background-position: -32px 0px;
	width: 32px;
	height: 32px; }

.shr-pg .facebook:before {
	background-image: url(../../wet-boew/assets/sprites_share.png);
	background-position: 0px -32px;
	width: 32px;
	height: 32px; }

.shr-pg .feed:before {
	background-image: url(../../wet-boew/assets/sprites_share.png);
	background-position: -32px -32px;
	width: 32px;
	height: 32px; }

.shr-pg .gmail:before {
	background-image: url(../../wet-boew/assets/sprites_share.png);
	background-position: -64px 0px;
	width: 32px;
	height: 32px; }

.shr-pg .linkedin:before {
	background-image: url(../../wet-boew/assets/sprites_share.png);
	background-position: -64px -32px;
	width: 32px;
	height: 32px; }

.shr-pg .myspace:before {
	background-image: url(../../wet-boew/assets/sprites_share.png);
	background-position: 0px -64px;
	width: 32px;
	height: 32px; }

.shr-pg .pinterest:before {
	background-image: url(../../wet-boew/assets/sprites_share.png);
	background-position: -32px -64px;
	width: 32px;
	height: 32px; }

.shr-pg .reddit:before {
	background-image: url(../../wet-boew/assets/sprites_share.png);
	background-position: -64px -64px;
	width: 32px;
	height: 32px; }

.shr-pg .tinyurl:before {
	background-image: url(../../wet-boew/assets/sprites_share.png);
	background-position: -96px 0px;
	width: 32px;
	height: 32px; }

.shr-pg .tumblr:before {
	background-image: url(../../wet-boew/assets/sprites_share.png);
	background-position: -96px -32px;
	width: 32px;
	height: 32px; }

.shr-pg .twitter:before {
	background-image: url(../../wet-boew/assets/sprites_share.png);
	background-position: -96px -64px;
	width: 32px;
	height: 32px; }

.shr-pg .whatsapp:before {
	background-image: url(../../wet-boew/assets/sprites_share.png);
	background-position: 0px -96px;
	width: 32px;
	height: 32px; }

.shr-pg .yahoomail:before {
	background-image: url(../../wet-boew/assets/sprites_share.png);
	background-position: -32px -96px;
	width: 32px;
	height: 32px; }

.shr-pg .shr-dscl {
	padding-bottom: 0; }

.shr-pg .email:before {
	content: "\2709";
	display: inline-block;
	font-family: "Glyphicons Halflings";
	font-size: 32px;
	margin-right: .3em; }

.shr-pg .shr-pg {
	text-align: left; }

.shr-pg ul {
	list-style-type: none;
	margin: 10px;
	padding: 0; }

[dir=rtl] .shr-opn span {
	padding-left: .2em;
	padding-right: 0; }

[dir=rtl] .shr-pg {
	text-align: right; }
	[dir=rtl] .shr-pg .shr-lnk {
		text-align: right; }
		[dir=rtl] .shr-pg .shr-lnk:before {
			margin-left: .4em;
			margin-right: auto; }

[dir=rtl] .email:before {
	margin-left: .6em;
	margin-right: auto; }

/*
* Web Experience Toolkit (WET) / Boîte à outils de l'expérience Web (BOEW)
* wet-boew.github.io/wet-boew/License-en.html / wet-boew.github.io/wet-boew/Licence-fr.html
*/
.provisional.wb-steps {
	counter-reset: fieldset_counter; }
	.provisional.wb-steps .wb-tggle-fildst > legend:before {
		content: counter(fieldset_counter) ". ";
		counter-increment: fieldset_counter; }
	.provisional.wb-steps .wb-tggle-fildst > legend.wb-steps-active {
		color: #1c578a; }
	.provisional.wb-steps .wb-tggle-fildst > legend.wb-steps-error {
		color: #942826; }
	.provisional.wb-steps .steps-wrapper {
		border-bottom: 1px solid #c0c0c0; }
	.provisional.wb-steps .subfields {
		border: 0; }

/*
 * Web Experience Toolkit (WET) / Boîte à outils de l'expérience Web (BOEW)
 * wet-boew.github.io/wet-boew/License-eng.html / wet-boew.github.io/wet-boew/Licence-fra.html
 */
table.dataTable, .dataTables_wrapper .dataTables_scroll {
	clear: both; }

table.dataTable thead th:active, table.dataTable thead td:active {
	outline: none; }

.dataTables_wrapper .dataTables_filter, .dataTables_wrapper .dataTables_length {
	font-weight: 400; }

table.dataTable thead th, table.dataTable tfoot th {
	font-weight: 700; }

table.dataTable thead th, table.dataTable thead td, table.dataTable tfoot th, table.dataTable tfoot td, table.dataTable.no-footer, .dataTables_wrapper.no-footer .dataTables_scrollBody {
	border-bottom: 1px solid #111; }

table.dataTable th.right, table.dataTable td.right {
	text-align: right; }

table.dataTable th.center, table.dataTable td.center, table.dataTable td.dataTables_empty {
	text-align: center; }

table.dataTable.rowborder tbody th,
table.dataTable.rowborder tbody td, table.dataTable.display tbody th,
table.dataTable.display tbody td {
	border-top: 1px solid #ddd; }

table.dataTable.rowborder tbody tr:first-child th,
table.dataTable.rowborder tbody tr:first-child td, table.dataTable.display tbody tr:first-child th,
table.dataTable.display tbody tr:first-child td, table.dataTable.cell-border tbody tr:first-child th,
table.dataTable.cell-border tbody tr:first-child td {
	border-top: 0; }

table.dataTable.cell-border tbody th,
table.dataTable.cell-border tbody td {
	border-right: 1px solid #ddd;
	border-top: 1px solid #ddd; }

table.dataTable.cell-border tbody tr th:first-child,
table.dataTable.cell-border tbody tr td:first-child {
	border-left: 1px solid #ddd; }

.dataTables_wrapper .dataTables_filter, .dataTables_wrapper .dataTables_length, .dataTables_wrapper .dataTables_info, .dataTables_wrapper .dataTables_processing {
	color: #333; }

table.dataTable.display tbody tr:hover.selected > .sorting_1, table.dataTable.display tbody tr.odd:hover.selected > .sorting_1, table.dataTable.display tbody tr.even:hover.selected > .sorting_1, table.dataTable.order-column.hover tbody tr:hover.selected > .sorting_1, table.dataTable.order-column.hover tbody tr.odd:hover.selected > .sorting_1, table.dataTable.order-column.hover tbody tr.even:hover.selected > .sorting_1 {
	background-color: #a1aec7; }

table.dataTable.display tbody tr:hover.selected > .sorting_2, table.dataTable.display tbody tr.odd:hover.selected > .sorting_2, table.dataTable.display tbody tr.even:hover.selected > .sorting_2, table.dataTable.order-column.hover tbody tr:hover.selected > .sorting_2, table.dataTable.order-column.hover tbody tr.odd:hover.selected > .sorting_2, table.dataTable.order-column.hover tbody tr.even:hover.selected > .sorting_2 {
	background-color: #a2afc8; }

table.dataTable.display tbody tr:hover.selected > .sorting_3, table.dataTable.display tbody tr.odd:hover.selected > .sorting_3, table.dataTable.display tbody tr.even:hover.selected > .sorting_3, table.dataTable.order-column.hover tbody tr:hover.selected > .sorting_3, table.dataTable.order-column.hover tbody tr.odd:hover.selected > .sorting_3, table.dataTable.order-column.hover tbody tr.even:hover.selected > .sorting_3 {
	background-color: #a4b2cb; }

table.dataTable.display tbody tr.odd.selected > .sorting_1, table.dataTable.order-column.stripe tbody tr.odd.selected > .sorting_1 {
	background-color: #a6b3cd; }

table.dataTable.display tbody tr.odd.selected > .sorting_2, table.dataTable.order-column.stripe tbody tr.odd.selected > .sorting_2 {
	background-color: #a7b5ce; }

table.dataTable.display tbody tr.odd.selected > .sorting_3, table.dataTable.order-column.stripe tbody tr.odd.selected > .sorting_3 {
	background-color: #a9b6d0; }

table.dataTable.display tbody tr.selected:hover, table.dataTable.display tbody tr.odd.selected:hover, table.dataTable.display tbody tr.even.selected:hover, table.dataTable.hover tbody tr.selected:hover, table.dataTable.hover tbody tr.odd.selected:hover, table.dataTable.hover tbody tr.even.selected:hover {
	background-color: #a9b7d1; }

table.dataTable.display tbody tr.odd.selected, table.dataTable.stripe tbody tr.odd.selected {
	background-color: #abb9d3; }

table.dataTable.display tbody tr.even.selected > .sorting_1, table.dataTable.display tbody tr.selected > .sorting_1, table.dataTable.display tbody tr.selected > .sorting_2, table.dataTable.display tbody tr.selected > .sorting_3, table.dataTable.order-column tbody tr.selected > .sorting_1, table.dataTable.order-column tbody tr.selected > .sorting_2, table.dataTable.order-column tbody tr.selected > .sorting_3, table.dataTable.order-column.stripe tbody tr.even.selected > .sorting_1 {
	background-color: #acbad4; }

table.dataTable.display tbody tr.even.selected > .sorting_2, table.dataTable.order-column.stripe tbody tr.even.selected > .sorting_2 {
	background-color: #adbbd6; }

table.dataTable.display tbody tr.even.selected > .sorting_3, table.dataTable.order-column.stripe tbody tr.even.selected > .sorting_3 {
	background-color: #afbdd8; }

table.dataTable thead .sorting_asc, table.dataTable thead .sorting_desc {
	background-color: #e7e7e7; }

table.dataTable.display tbody tr:hover > .sorting_1, table.dataTable.display tbody tr.odd:hover > .sorting_1, table.dataTable.display tbody tr.even:hover > .sorting_1, table.dataTable.order-column.hover tbody tr:hover > .sorting_1, table.dataTable.order-column.hover tbody tr.odd:hover > .sorting_1, table.dataTable.order-column.hover tbody tr.even:hover > .sorting_1 {
	background-color: #eaeaea; }

table.dataTable.display tbody tr:hover > .sorting_2, table.dataTable.display tbody tr.odd:hover > .sorting_2, table.dataTable.display tbody tr.even:hover > .sorting_2, table.dataTable.order-column.hover tbody tr:hover > .sorting_2, table.dataTable.order-column.hover tbody tr.odd:hover > .sorting_2, table.dataTable.order-column.hover tbody tr.even:hover > .sorting_2 {
	background-color: #ebebeb; }

table.dataTable.display tbody tr:hover > .sorting_3, table.dataTable.display tbody tr.odd:hover > .sorting_3, table.dataTable.display tbody tr.even:hover > .sorting_3, table.dataTable.order-column.hover tbody tr:hover > .sorting_3, table.dataTable.order-column.hover tbody tr.odd:hover > .sorting_3, table.dataTable.order-column.hover tbody tr.even:hover > .sorting_3 {
	background-color: #eee; }

table.dataTable.display tbody tr.odd > .sorting_1, table.dataTable.order-column.stripe tbody tr.odd > .sorting_1 {
	background-color: #f1f1f1; }

table.dataTable.display tbody tr.odd > .sorting_2, table.dataTable.order-column.stripe tbody tr.odd > .sorting_2 {
	background-color: #f3f3f3; }

table.dataTable.display tbody tr:hover, table.dataTable.display tbody tr.odd:hover, table.dataTable.display tbody tr.odd > .sorting_3, table.dataTable.display tbody tr.even:hover, table.dataTable.hover tbody tr:hover, table.dataTable.hover tbody tr.odd:hover, table.dataTable.hover tbody tr.even:hover, table.dataTable.order-column.stripe tbody tr.odd > .sorting_3 {
	background-color: #f5f5f5; }

table.dataTable.display tbody tr.odd, table.dataTable.display tbody tr.even > .sorting_1, table.dataTable.display tbody tr > .sorting_1, table.dataTable.display tbody tr > .sorting_2, table.dataTable.display tbody tr > .sorting_3, table.dataTable.stripe tbody tr.odd, table.dataTable.order-column tbody tr > .sorting_1, table.dataTable.order-column tbody tr > .sorting_2, table.dataTable.order-column tbody tr > .sorting_3, table.dataTable.order-column.stripe tbody tr.even > .sorting_1 {
	background-color: #f9f9f9; }

table.dataTable.display tbody tr.even > .sorting_2, table.dataTable.order-column.stripe tbody tr.even > .sorting_2 {
	background-color: #fbfbfb; }

table.dataTable.display tbody tr.even > .sorting_3, table.dataTable.order-column.stripe tbody tr.even > .sorting_3 {
	background-color: #fdfdfd; }

table.dataTable, table.dataTable th, table.dataTable td {
	-webkit-box-sizing: content-box;
	        box-sizing: content-box; }

table.dataTable thead .sorting .sorting-icons:before, table.dataTable thead .sorting .sorting-icons:after, table.dataTable thead .sorting_asc .sorting-icons:after, table.dataTable thead .sorting_desc .sorting-icons:before {
	background: #fff;
	border: 1px solid #aaa;
	color: #757575; }

table.dataTable thead .sorting_asc .sorting-icons:before, table.dataTable thead .sorting_desc .sorting-icons:after {
	background: #ccc;
	border: 1px solid #111;
	color: #000; }

table.dataTable thead .sorting, table.dataTable thead .sorting_asc, table.dataTable thead .sorting_desc {
	cursor: pointer; }

table.dataTable thead .sorting .sorting-icons, table.dataTable thead .sorting_asc .sorting-icons, table.dataTable thead .sorting_desc .sorting-icons, table.dataTable thead .sorting_asc_disabled .sorting-icons, table.dataTable thead .sorting_desc_disabled .sorting-icons {
	display: inline-block; }

/*
 * Table styles
 */
table.dataTable {
	border-collapse: separate;
	border-spacing: 0;
	margin: 0 auto;
	width: 100% !important; }
	table.dataTable thead button {
		-webkit-appearance: none;
		   -moz-appearance: none;
		        appearance: none;
		background: transparent;
		border: 0;
		font-family: inherit;
		padding: 0;
		text-align: left; }
	table.dataTable thead .sorting-cnt {
		white-space: nowrap; }
		table.dataTable thead .sorting-cnt:before {
			content: " "; }
	table.dataTable thead .sorting-icons {
		margin-top: 2px; }
		table.dataTable thead .sorting-icons:before {
			content: "\e093";
			padding: 0 .1em 0 0; }
		table.dataTable thead .sorting-icons:after {
			content: "\e094";
			padding: 0 .04em 0 .06em; }
	table.dataTable tbody tr {
		background-color: #fff; }
		table.dataTable tbody tr.selected {
			background-color: #b0bed9; }

/*
 * Control feature layout
 */
.dataTables_wrapper .dataTables_scroll div.dataTables_scrollBody th > div.dataTables_sizing,
.dataTables_wrapper .dataTables_scroll div.dataTables_scrollBody td > div.dataTables_sizing {
	height: 0;
	margin: 0 !important;
	overflow: hidden;
	padding: 0 !important; }

.dataTables_wrapper .dataTables_paginate .paginate_button.previous, .dataTables_wrapper .dataTables_paginate .paginate_button.current:first-child {
	border-top-left-radius: 4px;
	border-bottom-left-radius: 4px;
	margin-left: 0; }

.dataTables_wrapper .dataTables_paginate .paginate_button.next, .dataTables_wrapper .dataTables_paginate .paginate_button.current:last-child {
	border-top-right-radius: 4px;
	border-bottom-right-radius: 4px; }

.dataTables_wrapper {
	clear: both;
	position: relative;
	zoom: 1; }
	.dataTables_wrapper .dataTables_filter {
		float: left;
		margin-right: 15px; }
		.dataTables_wrapper .dataTables_filter input {
			margin-left: .5em; }
	.dataTables_wrapper .dataTables_length {
		display: inline-block;
		margin-top: 5px; }
	.dataTables_wrapper .dataTables_info {
		display: inline-block; }
	.dataTables_wrapper .dataTables_paginate {
		padding-top: 1.25em;
		text-align: center; }
		.dataTables_wrapper .dataTables_paginate .paginate_button {
			background-color: #eaebed;
			border: 1px solid #dcdee1;
			color: #335075;
			cursor: pointer;
			display: inline-block;
			line-height: 1.4375;
			margin-bottom: .5em;
			margin-left: -1px;
			padding: 10px 16px;
			position: relative;
			text-decoration: none; }
			.dataTables_wrapper .dataTables_paginate .paginate_button.current {
				background-color: #2572b4;
				border-color: #2572b4;
				color: #fff;
				cursor: default;
				z-index: 2; }
			.dataTables_wrapper .dataTables_paginate .paginate_button:hover, .dataTables_wrapper .dataTables_paginate .paginate_button:focus, .dataTables_wrapper .dataTables_paginate .paginate_button:active {
				background-color: #d4d6da;
				border-color: #bbbfc5;
				color: #335075; }
	.dataTables_wrapper .dataTables_processing {
		background: -webkit-gradient(linear, left top, right top, from(rgba(255, 255, 255, 0)), color-stop(25%, rgba(255, 255, 255, 0.9)), color-stop(75%, rgba(255, 255, 255, 0.9)), to(rgba(255, 255, 255, 0)));
		background: linear-gradient(to right, rgba(255, 255, 255, 0) 0%, rgba(255, 255, 255, 0.9) 25%, rgba(255, 255, 255, 0.9) 75%, rgba(255, 255, 255, 0) 100%);
		background-color: #fff;
		font-size: 1.2em;
		height: 40px;
		left: 50%;
		margin-left: -50%;
		margin-top: -25px;
		padding-top: 20px;
		position: absolute;
		text-align: center;
		top: 50%;
		width: 100%; }
	.dataTables_wrapper .dataTables_scroll div.dataTables_scrollBody {
		-webkit-overflow-scrolling: touch; }
	.dataTables_wrapper.no-footer div.dataTables_scrollHead table, .dataTables_wrapper.no-footer div.dataTables_scrollBody table {
		border-bottom: 0; }
	.dataTables_wrapper:after {
		clear: both;
		content: "";
		display: block;
		height: 0;
		visibility: hidden; }

[dir=rtl] table.dataTable thead .sorting,
[dir=rtl] table.dataTable thead .sorting_asc,
[dir=rtl] table.dataTable thead .sorting_desc,
[dir=rtl] table.dataTable thead .sorting_asc_disabled,
[dir=rtl] table.dataTable thead .sorting_desc_disabled {
	text-align: right; }

[dir=rtl] table.dataTable thead .sorting:after,
[dir=rtl] table.dataTable thead .sorting_asc:after,
[dir=rtl] table.dataTable thead .sorting_desc:after,
[dir=rtl] table.dataTable thead .sorting_asc_disabled:after,
[dir=rtl] table.dataTable thead .sorting_desc_disabled:after {
	margin-left: 0;
	margin-right: 5px; }

[dir=rtl] .dataTables_wrapper .dataTables_paginate .paginate_button.previous, [dir=rtl] .dataTables_wrapper .dataTables_paginate .paginate_button.current:first-child {
	border-top-left-radius: 0;
	border-bottom-left-radius: 0;
	border-top-right-radius: 4px;
	border-bottom-right-radius: 4px; }

[dir=rtl] .dataTables_wrapper .dataTables_paginate .paginate_button.next, [dir=rtl] .dataTables_wrapper .dataTables_paginate .paginate_button.current:last-child {
	border-top-left-radius: 4px;
	border-bottom-left-radius: 4px;
	border-top-right-radius: 0;
	border-bottom-right-radius: 0; }

[dir=rtl] .dataTables_wrapper .dataTables_info,
[dir=rtl] .dataTables_wrapper .dataTables_length {
	float: right; }

[dir=rtl] .dataTables_wrapper .dataTables_filter {
	float: left;
	text-align: left; }
	[dir=rtl] .dataTables_wrapper .dataTables_filter input {
		margin-left: auto;
		margin-right: .5em; }

/*
 * Web Experience Toolkit (WET) / Boîte à outils de l'expérience Web (BOEW)
 * wet-boew.github.io/wet-boew/License-en.html / wet-boew.github.io/wet-boew/Licence-fr.html
 */
.wb-tabs [role="tablist"].allow-wrap li, .wb-tabs.carousel-s1 [role="tablist"] > li, .wb-tabs.carousel-s2 [role="tablist"] > li {
	margin: 0 10px 0 0; }

.wb-tabs, .wb-tabs.carousel-s1 figure, .wb-tabs.carousel-s2 figure {
	position: relative; }

.wb-tabs.carousel-s1 [role="tablist"] > li, .wb-tabs.carousel-s2 [role="tablist"] > li {
	z-index: 100; }

.wb-tabs.carousel-s1 figure, .wb-tabs.carousel-s2 figure {
	background: #243850;
	background: rgba(36, 56, 80, 0.9); }
	.wb-tabs.carousel-s1 figure img, .wb-tabs.carousel-s2 figure img {
		height: auto;
		width: 100%; }

.wb-tabs.carousel-s1 figcaption, .wb-tabs.carousel-s2 figcaption {
	bottom: 0;
	color: #fff;
	left: 0;
	padding: .5em 1em;
	position: relative;
	right: 0;
	z-index: 101; }

.wb-tabs.carousel-s1 [role="tabpanel"] a figure::before, .wb-tabs.carousel-s2 [role="tabpanel"] a figure::before, .wb-tabs.carousel-s1 [role="tabpanel"] a figure::after, .wb-tabs.carousel-s2 [role="tabpanel"] a figure::after {
	content: "";
	outline: inherit;
	position: absolute; }

.wb-tabs.carousel-s1 [role="tabpanel"] a, .wb-tabs.carousel-s2 [role="tabpanel"] a {
	color: #000;
	outline-offset: 0; }
	.wb-tabs.carousel-s1 [role="tabpanel"] a figure, .wb-tabs.carousel-s2 [role="tabpanel"] a figure {
		outline: inherit; }
		.wb-tabs.carousel-s1 [role="tabpanel"] a figure::before, .wb-tabs.carousel-s2 [role="tabpanel"] a figure::before {
			height: calc(100% - 4px);
			margin: 2px;
			outline-color: #fff;
			width: calc(100% - 4px); }
		.wb-tabs.carousel-s1 [role="tabpanel"] a figure::after, .wb-tabs.carousel-s2 [role="tabpanel"] a figure::after {
			height: calc(100% - 2px);
			margin: 1px;
			top: 0;
			width: calc(100% - 2px); }
	.wb-tabs.carousel-s1 [role="tabpanel"] a figcaption, .wb-tabs.carousel-s2 [role="tabpanel"] a figcaption {
		color: #fff;
		text-decoration: underline; }

.wb-tabs.carousel-s1 [role="tabpanel"] figure a, .wb-tabs.carousel-s2 [role="tabpanel"] figure a {
	color: #fff; }

.wb-tabs.carousel-s1 .display:focus-within, .wb-tabs.carousel-s2 .display:focus-within {
	outline: 1px dotted #fff;
	outline-offset: -2px; }

.wb-tabs.carousel-s1 video:focus, .wb-tabs.carousel-s2 video:focus {
	outline-offset: -1px; }

.wb-tabs.carousel-s2 [role="tablist"] > li.prv, .wb-tabs.carousel-s2 [role="tablist"] > li.nxt {
	background: none;
	margin: 0;
	padding: 0; }

.wb-tabs.carousel-s2 [role="tablist"] > li.prv a, .wb-tabs.carousel-s2 [role="tablist"] > li.nxt a {
	border: 0;
	padding: 10px 5px;
	width: 100%; }

.wb-tabs.carousel-s2 [role="tablist"] > li.prv a .glyphicon, .wb-tabs.carousel-s2 [role="tablist"] > li.nxt a .glyphicon, .wb-tabs.carousel-s2 [role="tablist"] > li.plypause a {
	background: #fff;
	border-radius: 999px;
	-webkit-box-shadow: 0 0 4px #243850;
	        box-shadow: 0 0 4px #243850; }

.wb-tabs.carousel-s2 [role="tablist"] > li.prv a, .wb-tabs.carousel-s2 [role="tablist"] > li.nxt a, .wb-tabs.carousel-s2 [role="tablist"] > li.plypause a {
	color: #243850; }

.wb-tabs.carousel-s2 [role="tablist"] > li.prv a .glyphicon, .wb-tabs.carousel-s2 [role="tablist"] > li.nxt a .glyphicon {
	font-size: 1.75em;
	height: 1.75em;
	line-height: 1.75em;
	margin: auto 0;
	text-align: center;
	width: 1.75em; }

.wb-tabs.carousel-s2 [role="tablist"] > li.prv a:focus, .wb-tabs.carousel-s2 [role="tablist"] > li.prv a:hover, .wb-tabs.carousel-s2 [role="tablist"] > li.nxt a:focus, .wb-tabs.carousel-s2 [role="tablist"] > li.nxt a:hover {
	background: transparent; }

.wb-tabs.carousel-s2 [role="tablist"] > li.prv a:focus .glyphicon, .wb-tabs.carousel-s2 [role="tablist"] > li.prv a:hover .glyphicon, .wb-tabs.carousel-s2 [role="tablist"] > li.nxt a:focus .glyphicon, .wb-tabs.carousel-s2 [role="tablist"] > li.nxt a:hover .glyphicon, .wb-tabs.carousel-s2 [role="tablist"] > li.plypause a:focus, .wb-tabs.carousel-s2 [role="tablist"] > li.plypause a:hover {
	-webkit-box-shadow: none;
	        box-shadow: none; }

.wb-tabs.carousel-s1 [role="tablist"] > li.active a, .wb-tabs.carousel-s1 [role="tablist"] > li:focus a, .wb-tabs.carousel-s1 [role="tablist"] > li:hover a {
	border-top: 0;
	padding-top: 10px; }

.wb-tabs [role="tablist"] > li, .wb-tabs [role="tablist"] > li a, .wb-tabs.carousel-s1 [role="tablist"] > li.control, .wb-tabs.carousel-s2 [role="tablist"] > li.control {
	display: inline-block; }

.wb-tabs.carousel-s1 figcaption p, .wb-tabs.carousel-s2 figcaption p {
	margin-bottom: 0; }

.wb-tabs > details, .wb-tabs > .tabpanels > details {
	padding: 6px 12px; }
	.wb-tabs > details > summary, .wb-tabs > .tabpanels > details > summary {
		margin: -6px -12px;
		padding: 6px 12px; }

.csstransitions .wb-tabs [role="tabpanel"].out {
	position: absolute;
	top: 0;
	width: 100%;
	z-index: 0; }

.wb-tabs {
	/**
	 * Default, minimal, shared style
	 */
	/* For backwards compatibility. Should be removed in v4.1 */
	/**
	 * Style 1 - Basic carousel style
	 */
	/**
	 * Style 2 - Slider-like carousel style
	 */ }
	.wb-tabs details[open] {
		border-top-left-radius: 0; }
	.wb-tabs > .tabpanels {
		overflow: hidden;
		position: relative; }
	.wb-tabs [role="tablist"] {
		border-spacing: 10px 0;
		display: table;
		list-style: none;
		margin: 0;
		padding: 0;
		position: relative; }
		.wb-tabs [role="tablist"] > li {
			background: #ebf2fc;
			border-color: #ccc;
			border-style: solid;
			border-width: 1px;
			color: #000;
			cursor: pointer;
			display: table-cell;
			left: -10px;
			position: relative;
			text-align: center; }
			.wb-tabs [role="tablist"] > li a {
				color: #000;
				padding: 10px;
				text-decoration: none; }
			.wb-tabs [role="tablist"] > li:focus, .wb-tabs [role="tablist"] > li:hover {
				background: #ccc;
				background: rgba(204, 204, 204, 0.9); }
			.wb-tabs [role="tablist"] > li.active {
				background: #fff;
				border-bottom: 0;
				cursor: default;
				padding-bottom: 1px;
				z-index: 2; }
				.wb-tabs [role="tablist"] > li.active a {
					border-color: #666;
					border-style: solid;
					border-width: 4px 0 0 0;
					cursor: default;
					padding-top: 6px; }
			.wb-tabs [role="tablist"] > li.tab-count {
				line-height: normal; }
				.wb-tabs [role="tablist"] > li.tab-count > div {
					position: relative;
					top: 0; }
				.wb-tabs [role="tablist"] > li.tab-count .curr-count {
					font-size: 1.5em; }
				.wb-tabs [role="tablist"] > li.tab-count:focus, .wb-tabs [role="tablist"] > li.tab-count:hover {
					background: transparent;
					cursor: default; }
		.wb-tabs [role="tablist"].generated li {
			border-bottom: 0;
			top: 1px; }
		.wb-tabs [role="tablist"].allow-wrap {
			border-spacing: 0;
			display: block; }
			.wb-tabs [role="tablist"].allow-wrap li {
				display: inline-block;
				left: auto; }
	.wb-tabs [role="tabpanel"] {
		overflow-x: auto;
		position: relative;
		z-index: 1; }
	.wb-tabs.carousel-s1 {
		border-top: 0; }
		.wb-tabs.carousel-s1 [role="tablist"] {
			bottom: 1em;
			left: 1em;
			position: static; }
			.wb-tabs.carousel-s1 [role="tablist"] > li.prv {
				margin-right: 5px; }
			.wb-tabs.carousel-s1 [role="tablist"] > li.tab-count {
				background: none;
				border: 0;
				font-size: .9em;
				padding: 0 .1em;
				top: .55em; }
				.wb-tabs.carousel-s1 [role="tablist"] > li.tab-count.active, .wb-tabs.carousel-s1 [role="tablist"] > li.tab-count:focus, .wb-tabs.carousel-s1 [role="tablist"] > li.tab-count:hover {
					cursor: default; }
	.wb-tabs.carousel-s2 {
		background: #eee; }
		.wb-tabs.carousel-s2 [role="tablist"] {
			bottom: 0;
			position: absolute;
			width: 100%; }
			.wb-tabs.carousel-s2 [role="tablist"] > li {
				background: transparent;
				border: 0; }
				.wb-tabs.carousel-s2 [role="tablist"] > li.prv a {
					padding-left: 1em; }
				.wb-tabs.carousel-s2 [role="tablist"] > li.plypause {
					background: none;
					border: 0;
					float: right;
					margin-right: 0;
					padding: 2px 0; }
					.wb-tabs.carousel-s2 [role="tablist"] > li.plypause a {
						font-size: 1.5em;
						margin-right: .65em;
						margin-top: .4em;
						padding: 8px 10px 4px; }
			.wb-tabs.carousel-s2 [role="tablist"] a:focus {
				outline-offset: 0; }

.wb-disable.csstransitions .wb-tabs [role="tabpanel"].out {
	position: static;
	width: auto; }

.wb-disable .wb-tabs.carousel-s2 {
	background: transparent; }

.wb-disable .wb-tabs > details[open] > summary {
	display: list-item !important; }

.wb-disable .wb-tabs > .tabpanels > details[open] > summary {
	display: list-item !important; }

.wb-disable .wb-tabs .out {
	visibility: visible; }

.wb-disable .wb-tabs [role="tablist"] {
	display: none; }

.wb-disable .wb-tabs [role="tabpanel"] {
	-webkit-animation: none;
	        animation: none;
	display: block;
	margin-bottom: .5em;
	opacity: 1;
	-webkit-transform: none;
	        transform: none; }

/*
 * Web Experience Toolkit (WET) / Boîte à outils de l'expérience Web (BOEW)
 * wet-boew.github.io/wet-boew/License-en.html / wet-boew.github.io/wet-boew/Licence-fr.html
 */
.wb-disable .wb-twitter .twitter-timeline {
	text-indent: 0 !important; }

.wb-twitter .twitter-timeline {
	display: block; }

.wb-twitter iframe[style] {
	width: 100% !important; }

.wb-enable .wb-twitter .twitter-timeline {
	min-height: 100px;
	min-width: 100px;
	position: relative; }

/*
 * Web Experience Toolkit (WET) / Boîte à outils de l'expérience Web (BOEW)
 * wet-boew.github.io/wet-boew/License-en.html / wet-boew.github.io/wet-boew/Licence-fr.html
 */
/*
 * Web Experience Toolkit (WET) / Boîte à outils de l'expérience Web (BOEW)
 * wet-boew.github.io/wet-boew/License-eng.html / wet-boew.github.io/wet-boew/Licence-fra.html
*/
.ol-overlay-container {
	z-index: 1000; }

.ol-popup {
	-moz-box-shadow: 0 1px 4px rgba(0, 0, 0, 0.2);
	-webkit-filter: drop-shadow(0 1px 4px rgba(0, 0, 0, 0.2));
	background-color: white;
	border: 1px solid #cccccc;
	border-radius: 3px;
	bottom: 12px;
	-webkit-box-shadow: 0 1px 4px rgba(0, 0, 0, 0.2);
	        box-shadow: 0 1px 4px rgba(0, 0, 0, 0.2);
	display: block;
	filter: drop-shadow(0 1px 4px rgba(0, 0, 0, 0.2));
	font-size: .75em;
	left: -50px;
	min-width: 250px;
	padding: 15px;
	position: absolute; }

.ol-popup:after, .ol-popup:before {
	border: solid transparent;
	content: " ";
	height: 0;
	pointer-events: none;
	position: absolute;
	top: 100%;
	width: 0; }

.ol-popup:after {
	border-top-color: white;
	border-width: 10px;
	left: 48px;
	margin-left: -10px; }

.ol-popup:before {
	border-top-color: #cccccc;
	border-width: 11px;
	left: 48px;
	margin-left: -11px; }

.ol-popup-closer {
	color: #333;
	font-family: Arial, Baskerville, monospace;
	font-size: 24px;
	font-weight: 700;
	height: 28px;
	line-height: 28px;
	position: absolute;
	right: 0;
	text-align: center;
	text-decoration: none;
	top: 0;
	width: 28px; }

.ol-popup-closer:link, .ol-popup-closer:visited, .ol-popup-closer:hover, .ol-popup-closer:active {
	color: #333;
	text-decoration: none; }

.popup-content h5 {
	border-bottom: solid 1px #999;
	color: #999;
	font-size: 1.0em;
	margin: -5px 0px 5px 0px;
	padding-bottom: 3px; }

.popup-content table th, .popup-content table td {
	padding: 2px; }

/**
 * GeoMap
 */
.wb-geomap-map {
	outline: 1px solid #ccc;
	overflow: hidden;
	position: relative; }
	.wb-geomap-map.active {
		-webkit-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075), 0 0 8px rgba(102, 175, 233, 0.6);
		box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075), 0 0 8px rgba(102, 175, 233, 0.6);
		outline-color: #66afe9; }

.geomap-legend-detail {
	padding-top: 10px; }

.geomap-legend-element {
	overflow: hidden;
	width: 100%; }

.geomap-legend-symbol {
	float: left;
	margin-right: 5px; }

.geomap-legend-symbol-text {
	display: inline-block;
	line-height: 30px;
	vertical-align: middle; }

.geomap-clear-format {
	clear: both; }

.geomap-legend-label {
	display: inline; }

.geomap-lgnd-layer {
	margin-bottom: 10px;
	margin-top: 0px !important; }

.geomap-lgnd > :last-child {
	margin-bottom: 0px; }

.geomap-geoloc {
	background: transparent;
	left: .25em;
	top: .25em; }
	.geomap-geoloc input[type="text"] {
		border-color: #fff;
		border-radius: 2px;
		-webkit-box-shadow: 1px 2px 4px #999;
		        box-shadow: 1px 2px 4px #999;
		width: 100%; }

.geomap-aoi legend {
	border: 0;
	font-size: 1em;
	margin-bottom: 1em; }

.geomap-aoi button.geomap-geoloc-aoi-btn {
	position: absolute;
	right: 15px;
	top: auto; }

.geoloc-progress {
	-webkit-animation-duration: 500ms;
	        animation-duration: 500ms;
	-webkit-animation-iteration-count: infinite;
	        animation-iteration-count: infinite;
	-webkit-animation-name: spin;
	        animation-name: spin;
	-webkit-animation-timing-function: linear;
	        animation-timing-function: linear;
	color: #333;
	content: "\e031";
	font-family: "Glyphicons Halflings";
	font-size: 1em;
	height: 1em;
	line-height: 1.03;
	width: 1em;
	z-index: 2; }

/* OL3 */
.ol-geolocate {
	bottom: 8em;
	right: 1em; }

.ol-touch .ol-geolocate {
	bottom: 1.5em;
	right: .5em; }

.ol-mouse-position {
	background: #fff;
	background: rgba(255, 255, 255, 0.7);
	border-radius: 2px;
	bottom: 3em;
	font-size: .75em;
	left: .6666em;
	min-width: 100px;
	padding: 2px 6px 2px 6px;
	position: absolute;
	will-change: contents, width; }

.ol-mouse-position:before {
	content: "\e062";
	font-family: "Glyphicons Halflings";
	margin-right: 3px; }

.ol-mouse-position-inner {
	padding: 10px; }

.ol-mouse-position:empty {
	display: none; }

.ol-touch .ol-mouse-position {
	display: none; }

.ol-scale-line {
	background: #fff;
	background: rgba(255, 255, 255, 0.7);
	border-radius: 2px;
	bottom: .5em;
	left: .5em;
	padding: 2px;
	position: absolute; }

.ol-touch .ol-scale-line {
	display: none; }

.ol-scale-line-inner {
	border: 1px solid #000;
	border-top: none;
	color: #000;
	font-size: .75em;
	margin: 1px;
	text-align: center;
	will-change: contents, width; }

.ol-overlay-container {
	will-change: left, right, top, bottom; }

.ol-unsupported {
	display: none; }

.ol-viewport .ol-unselectable {
	-moz-user-select: none;
	-ms-user-select: none;
	-webkit-tap-highlight-color: transparent;
	-webkit-user-select: none;
	user-select: none; }

.ol-control {
	background-color: rgba(255, 255, 255, 0.4);
	border-radius: 4px;
	padding: 2px;
	position: absolute; }

.ol-control:hover {
	background-color: rgba(255, 255, 255, 0.4); }

.ol-zoom {
	bottom: 1.5em;
	right: 1em; }

.ol-touch .ol-zoom {
	display: none; }

.ol-rotate {
	bottom: 1.5em;
	right: 3.25em;
	-webkit-transition: opacity .25s linear, visibility 0s linear;
	transition: opacity .25s linear, visibility 0s linear; }

.ol-rotate.ol-hidden {
	opacity: 0;
	-webkit-transition: opacity .25s linear, visibility 0s linear .25s;
	transition: opacity .25s linear, visibility 0s linear .25s;
	visibility: hidden; }

.ol-zoom-extent {
	bottom: 6em;
	right: 1em; }

.ol-touch .ol-zoom-extent {
	display: none; }

.ol-zoom-extent span.glyphicon {
	top: 3px; }

.ol-full-screen {
	right: .5em;
	top: .5em; }

@media print {
	.ol-control {
		display: none; } }

.ol-control button {
	background-color: white;
	border: none;
	border-radius: 2px;
	-webkit-box-shadow: 1px 2px 4px #999;
	        box-shadow: 1px 2px 4px #999;
	color: #333;
	display: block;
	font-size: 1.14em;
	font-weight: 700;
	height: 1.5em;
	line-height: .4em;
	margin: 0;
	padding: 0;
	text-align: center;
	text-decoration: none;
	width: 1.5em; }

.ol-control button::-moz-focus-inner {
	border: none;
	padding: 0; }

.ol-zoom-extent button {
	line-height: 1.4em; }

ol-geolocate button {
	line-height: 1em; }

.ol-compass {
	display: block;
	font-size: 1.2em;
	font-weight: 400;
	will-change: transform; }

.ol-touch .ol-control button {
	font-size: 1.5em; }

.ol-control button:focus, .ol-control button:hover {
	text-decoration: none; }

.ol-zoom .ol-zoom-in {
	border-bottom: solid 1px #999;
	border-radius: 2px 2px 0 0; }

.ol-zoom .ol-zoom-out {
	border-radius: 0 0 2px 2px; }

.ol-attribution {
	background: rgba(255, 255, 255, 0.7);
	border-radius: 2px 0 0;
	bottom: 0;
	line-height: .75em;
	max-width: calc(80% - 1.3em);
	right: 0;
	text-align: right; }

.ol-attribution ul {
	color: #333;
	font-size: .75em;
	margin: 0;
	padding: .15em .25em;
	text-shadow: 0 0 2px #fff; }

.ol-attribution li {
	display: inline;
	line-height: inherit;
	list-style: none; }
	.ol-attribution li :after {
		content: " "; }
	.ol-attribution li :last-child:after {
		content: ""; }

.ol-attribution img {
	max-height: 2em;
	max-width: inherit; }

.ol-attribution a {
	color: #333;
	text-decoration: none; }

.ol-attribution a:visited, .ol-attribution a:active {
	color: #333; }

.ol-attribution button, .ol-attribution ul {
	display: inline-block; }

.ol-attribution.ol-collapsed ul {
	display: none; }

.ol-attribution.ol-logo-only ul {
	display: block; }

.ol-attribution.ol-uncollapsible {
	border-radius: 4px 0 0;
	bottom: 0;
	height: 1.3em;
	line-height: .75em;
	right: 0; }

.ol-attribution.ol-logo-only {
	background: 0 0;
	bottom: .4em;
	height: 1.1em;
	line-height: 1em; }

.ol-attribution.ol-uncollapsible img {
	margin-top: -.2em;
	max-height: 1.6em; }

.ol-attribution.ol-logo-only button, .ol-attribution.ol-uncollapsible button {
	display: none; }

.ol-box {
	border: 2px solid #2572b4;
	border-radius: 2px;
	-webkit-box-sizing: border-box;
	        box-sizing: border-box; }

.ol-dragbox {
	border: 2px solid #ff0033;
	border-radius: 2px;
	-webkit-box-sizing: border-box;
	        box-sizing: border-box; }

.ol-overviewmap {
	bottom: .5em;
	left: .5em; }

.ol-overviewmap.ol-uncollapsible {
	border-radius: 0 4px 0 0;
	bottom: 0;
	left: 0; }

.ol-overviewmap .ol-overviewmap-map, .ol-overviewmap button {
	display: inline-block; }

.ol-overviewmap .ol-overviewmap-map {
	border: 1px solid #7b98bc;
	height: 150px;
	margin: 2px;
	width: 150px; }

.ol-overviewmap:not(.ol-collapsed) button {
	bottom: 1px;
	left: 2px;
	position: absolute; }

.ol-overviewmap.ol-collapsed .ol-overviewmap-map, .ol-overviewmap.ol-uncollapsible button {
	display: none; }

.ol-overviewmap:not(.ol-collapsed) {
	background: rgba(255, 255, 255, 0.8); }

.ol-overviewmap-box {
	border: 2px dotted rgba(0, 60, 136, 0.7); }

.geomap-help-btn {
	background-color: transparent;
	right: .5em;
	top: .5em; }

.geomap-help-btn:focus, .geomap-help-btn:hover {
	background-color: transparent; }

.geomap-help-btn button {
	background-color: #333;
	border-radius: 50%;
	color: #fff; }

.ol-touch .geomap-help-btn {
	display: none; }

.geomap-help-dialog {
	background-color: white;
	height: auto;
	margin: 10px;
	right: 0;
	top: 0;
	width: auto; }
	.geomap-help-dialog header {
		position: static; }
	.geomap-help-dialog a.btn {
		color: #333;
		font-family: Arial, Baskerville, monospace;
		font-size: 28px;
		font-weight: 700;
		height: 44px;
		line-height: 44px;
		padding: 0;
		position: absolute;
		right: 0;
		text-align: center;
		text-decoration: none;
		top: 0;
		width: 44px; }

.geomap-help-dialog:hover {
	background-color: white; }

.tooltip-txt::after {
	border-color: silver transparent transparent transparent;
	border-style: solid;
	border-width: 5px;
	content: " ";
	left: 50%;
	margin-left: -5px;
	position: absolute;
	top: 100%; }

.tooltip-txt {
	-moz-box-shadow: 0 1px 4px rgba(0, 0, 0, 0.2);
	-webkit-filter: drop-shadow(0 1px 4px rgba(0, 0, 0, 0.2));
	background: silver;
	border: solid 1px silver;
	border-radius: 5px;
	bottom: 100%;
	-webkit-box-shadow: 0 1px 4px rgba(0, 0, 0, 0.2);
	        box-shadow: 0 1px 4px rgba(0, 0, 0, 0.2);
	color: #333333;
	cursor: default;
	filter: drop-shadow(0 1px 4px rgba(0, 0, 0, 0.2));
	font-size: .80em;
	left: 50%;
	margin-left: -60px;
	padding: 5px 0;
	position: absolute;
	text-align: center;
	width: 120px; }

.wb-geomap-geoloc-al-cnt, .wb-geomap-geoloc-al-cnt .wb-geomap-geoloc-al {
	max-height: 15em; }

.wb-geomap-geoloc-al-cnt {
	border: 1px solid transparent;
	left: 0;
	margin-top: 0;
	position: absolute;
	z-index: 50; }
	.wb-geomap-geoloc-al-cnt .wb-geomap-geoloc-al {
		-webkit-overflow-scrolling: touch;
		background: #fff;
		border: solid 1px #ccc;
		border-top: 0;
		font-size: .9em;
		list-style-type: none;
		overflow-y: scroll;
		padding: 0; }
		.wb-geomap-geoloc-al-cnt .wb-geomap-geoloc-al li {
			border-bottom: solid 1px #ccc; }
		.wb-geomap-geoloc-al-cnt .wb-geomap-geoloc-al li:last-of-type {
			border-bottom: 0; }
		.wb-geomap-geoloc-al-cnt .wb-geomap-geoloc-al a {
			color: #333;
			display: block;
			padding: 5px 5px;
			text-decoration: none; }
			.wb-geomap-geoloc-al-cnt .wb-geomap-geoloc-al a:hover, .wb-geomap-geoloc-al-cnt .wb-geomap-geoloc-al a:focus {
				background: #666;
				color: #fff; }
			.wb-geomap-geoloc-al-cnt .wb-geomap-geoloc-al a span.glyphicon {
				color: #ccc;
				margin-right: 5px; }

.glyphicon-spin {
	-webkit-animation: spin 1000ms infinite linear;
	animation: spin 1000ms infinite linear; }

@-webkit-keyframes spin {
	0% {
		-webkit-transform: rotate(0deg);
		transform: rotate(0deg); }
	100% {
		-webkit-transform: rotate(359deg);
		transform: rotate(359deg); } }

@keyframes spin {
	0% {
		-webkit-transform: rotate(0deg);
		transform: rotate(0deg); }
	100% {
		-webkit-transform: rotate(359deg);
		transform: rotate(359deg); } }

.skeleton-lgnd-1 {
	background-color: #f5f5f5;
	height: 25px;
	margin-top: 10px;
	width: 100%; }

.skeleton-lgnd-2 {
	background-color: #f5f5f5;
	height: 25px;
	margin: 20px 0 20px 0;
	width: 100%; }

.skeleton-lgnd-3 {
	background-color: #fff;
	display: block;
	height: 25px;
	margin-left: 25px;
	width: 15px; }

/*
 * Web Experience Toolkit (WET) / Boîte à outils de l'expérience Web (BOEW)
 * wet-boew.github.io/wet-boew/License-en.html / wet-boew.github.io/wet-boew/Licence-fr.html
 */
.wb-zebra-col-hover .wb-group-summary col.table-hover, .table-hover .wb-group-summary tr:hover td,
.table-hover .wb-group-summary tr:hover th {
	background-color: #fafaff; }

.wb-cell-layout {
	background-color: transparent; }

.wb-cell-key, .wb-cell-desc {
	font-style: italic; }

.wb-zebra > colgroup + colgroup {
	border-left: 2px solid #ddd; }

.wb-group-summary {
	background-color: #f0f2f4; }

.wb-zebra-col-hover col.table-hover {
	background-color: #f0f0f0; }

/*
 * Web Experience Toolkit (WET) / Boîte à outils de l'expérience Web (BOEW)
 * wet-boew.github.io/wet-boew/License-en.html / wet-boew.github.io/wet-boew/Licence-fr.html
 */
.feeds-cont.waiting:after, .feeds-cont.waiting:before {
	bottom: 0;
	content: " ";
	height: 50px;
	left: 0;
	margin: auto;
	position: absolute;
	right: 0;
	top: 0;
	width: 50px; }

.feeds-cont.waiting {
	min-height: 100px;
	min-width: 100px; }
	.feeds-cont.waiting:after {
		-webkit-animation-duration: 1000ms;
		        animation-duration: 1000ms;
		-webkit-animation-iteration-count: infinite;
		        animation-iteration-count: infinite;
		-webkit-animation-name: spin;
		        animation-name: spin;
		-webkit-animation-timing-function: linear;
		        animation-timing-function: linear;
		background: url("../../wet-boew/assets/loading.png") center center no-repeat;
		background-size: 30px 30px;
		z-index: 2; }
	.feeds-cont.waiting:before {
		background: rgba(0, 0, 0, 0);
		z-index: 1; }

.feeds-cont .feeds-date:before {
	content: "["; }

.feeds-cont .feeds-date:after {
	content: "]"; }

.feeds-cont button[data-youtube] {
	border: none;
	padding: 0; }

/*! Core - Utilities */
.clearfix:before, .clearfix:after {
	display: table;
	content: " "; }

.clearfix:after {
	clear: both; }

.center-block {
	display: block;
	margin-right: auto;
	margin-left: auto; }

.pull-right {
	float: right !important; }

.pull-left {
	float: left !important; }

.hide {
	display: none !important; }

.show {
	display: block !important; }

.invisible {
	visibility: hidden; }

.text-hide {
	font: 0/0 a;
	color: transparent;
	text-shadow: none;
	background-color: transparent;
	border: 0; }

.hidden {
	display: none !important; }

.affix {
	position: fixed; }

@-ms-viewport {
	width: device-width; }

.visible-xs {
	display: none !important; }

.visible-sm {
	display: none !important; }

.visible-md {
	display: none !important; }

.visible-lg {
	display: none !important; }

.visible-xs-block,
.visible-xs-inline,
.visible-xs-inline-block,
.visible-sm-block,
.visible-sm-inline,
.visible-sm-inline-block,
.visible-md-block,
.visible-md-inline,
.visible-md-inline-block,
.visible-lg-block,
.visible-lg-inline,
.visible-lg-inline-block {
	display: none !important; }

@media (max-width: 767px) {
	.visible-xs {
		display: block !important; }
	table.visible-xs {
		display: table !important; }
	tr.visible-xs {
		display: table-row !important; }
	th.visible-xs,
	td.visible-xs {
		display: table-cell !important; } }

@media (max-width: 767px) {
	.visible-xs-block {
		display: block !important; } }

@media (max-width: 767px) {
	.visible-xs-inline {
		display: inline !important; } }

@media (max-width: 767px) {
	.visible-xs-inline-block {
		display: inline-block !important; } }

@media (min-width: 768px) and (max-width: 991px) {
	.visible-sm {
		display: block !important; }
	table.visible-sm {
		display: table !important; }
	tr.visible-sm {
		display: table-row !important; }
	th.visible-sm,
	td.visible-sm {
		display: table-cell !important; } }

@media (min-width: 768px) and (max-width: 991px) {
	.visible-sm-block {
		display: block !important; } }

@media (min-width: 768px) and (max-width: 991px) {
	.visible-sm-inline {
		display: inline !important; } }

@media (min-width: 768px) and (max-width: 991px) {
	.visible-sm-inline-block {
		display: inline-block !important; } }

@media (min-width: 992px) and (max-width: 1199px) {
	.visible-md {
		display: block !important; }
	table.visible-md {
		display: table !important; }
	tr.visible-md {
		display: table-row !important; }
	th.visible-md,
	td.visible-md {
		display: table-cell !important; } }

@media (min-width: 992px) and (max-width: 1199px) {
	.visible-md-block {
		display: block !important; } }

@media (min-width: 992px) and (max-width: 1199px) {
	.visible-md-inline {
		display: inline !important; } }

@media (min-width: 992px) and (max-width: 1199px) {
	.visible-md-inline-block {
		display: inline-block !important; } }

@media (min-width: 1200px) {
	.visible-lg {
		display: block !important; }
	table.visible-lg {
		display: table !important; }
	tr.visible-lg {
		display: table-row !important; }
	th.visible-lg,
	td.visible-lg {
		display: table-cell !important; } }

@media (min-width: 1200px) {
	.visible-lg-block {
		display: block !important; } }

@media (min-width: 1200px) {
	.visible-lg-inline {
		display: inline !important; } }

@media (min-width: 1200px) {
	.visible-lg-inline-block {
		display: inline-block !important; } }

@media (max-width: 767px) {
	.hidden-xs {
		display: none !important; } }

@media (min-width: 768px) and (max-width: 991px) {
	.hidden-sm {
		display: none !important; } }

@media (min-width: 992px) and (max-width: 1199px) {
	.hidden-md {
		display: none !important; } }

@media (min-width: 1200px) {
	.hidden-lg {
		display: none !important; } }

.visible-print {
	display: none !important; }

@media print {
	.visible-print {
		display: block !important; }
	table.visible-print {
		display: table !important; }
	tr.visible-print {
		display: table-row !important; }
	th.visible-print,
	td.visible-print {
		display: table-cell !important; } }

.visible-print-block {
	display: none !important; }
	@media print {
		.visible-print-block {
			display: block !important; } }

.visible-print-inline {
	display: none !important; }
	@media print {
		.visible-print-inline {
			display: inline !important; } }

.visible-print-inline-block {
	display: none !important; }
	@media print {
		.visible-print-inline-block {
			display: inline-block !important; } }

@media print {
	.hidden-print {
		display: none !important; } }

/*
  WET-BOEW
  @title: Accessibility Additions to WET-BOEW - Utilities
 */
/*
  WET-BOEW
  @title: Proximity CSS
 */
.opct-100 {
	opacity: 1; }

.opct-90 {
	opacity: .9; }

.opct-80 {
	opacity: .8; }

.opct-70 {
	opacity: .7; }

.opct-60 {
	opacity: .6; }

.opct-50 {
	opacity: .5; }

.opct-40 {
	opacity: .4; }

.opct-30 {
	opacity: .3; }

.opct-20 {
	opacity: .2; }

.opct-10 {
	opacity: .1; }

/*
 *	Removes bold from elements
 */
.fnt-nrml {
	font-weight: normal; }

/*
 *	Fix for missing bullets in Chrome and Safari
 */
[class*=clmn-] {
	list-style: outside;
	padding-left: 1.3em; }
	[class*=clmn-] > li {
		margin-left: 1.3em; }

.pstn-lft-xs,
.pstn-lft-sm,
.pstn-lft-md,
.pstn-lft-lg,
.pstn-rght-xs,
.pstn-rght-sm,
.pstn-rght-md,
.pstn-rght-lg,
.pstn-tp-xs,
.pstn-tp-sm,
.pstn-tp-md,
.pstn-tp-lg,
.pstn-bttm-xs,
.pstn-bttm-sm,
.pstn-bttm-md,
.pstn-bttm-lg {
	margin: 0; }

.pstn-lft-xs {
	position: absolute;
	left: 0;
	right: auto; }

.pstn-rght-xs {
	position: absolute;
	right: 0;
	left: auto; }

.pstn-tp-xs {
	position: absolute;
	top: 0;
	bottom: auto; }

.pstn-bttm-xs {
	position: absolute;
	bottom: 0;
	top: auto; }

.mrgn-lft-0 {
	margin-left: 0; }

.mrgn-lft-sm {
	margin-left: 5px; }

.mrgn-lft-md {
	margin-left: 15px; }

.mrgn-lft-lg {
	margin-left: 30px; }

.mrgn-lft-xl {
	margin-left: 50px; }

.mrgn-bttm-0 {
	margin-bottom: 0; }

.mrgn-bttm-sm {
	margin-bottom: 5px; }

.mrgn-bttm-md {
	margin-bottom: 15px; }

.mrgn-bttm-lg {
	margin-bottom: 30px; }

.mrgn-bttm-xl {
	margin-bottom: 50px; }

.mrgn-tp-0 {
	margin-top: 0; }

.mrgn-tp-sm {
	margin-top: 5px; }

.mrgn-tp-md {
	margin-top: 15px; }

.mrgn-tp-lg {
	margin-top: 30px; }

.mrgn-tp-xl {
	margin-top: 50px; }

.mrgn-rght-0 {
	margin-right: 0; }

.mrgn-rght-sm {
	margin-right: 5px; }

.mrgn-rght-md {
	margin-right: 15px; }

.mrgn-rght-lg {
	margin-right: 30px; }

.mrgn-rght-xl {
	margin-right: 50px; }

.brdr-lft, .brdr-rght, .brdr-tp, .brdr-bttm {
	border: solid 0 #ccc; }

.brdr-lft {
	border-left-width: 1px; }

.brdr-rght {
	border-right-width: 1px; }

.brdr-tp {
	border-top-width: 1px; }

.brdr-bttm {
	border-bottom-width: 1px; }

.brdr-0 {
	border: 0 !important; }

.brdr-rds-0 {
	border-radius: 0 !important; }

.tbl-gridify thead,
.tbl-gridify tfoot {
	display: none; }

.tbl-gridify tbody,
.tbl-gridify td,
.tbl-gridify td {
	display: block; }

/*
 *	Fix for missing bullets in Chrome and Safari
 */
[class*=colcount-] {
	list-style-position: outside;
	padding-left: 1.3em; }
	[class*=colcount-] > li {
		margin-left: 1.3em; }
	[class*=colcount-].list-unstyled {
		list-style: none outside none;
		padding-left: 0; }
		[class*=colcount-].list-unstyled li {
			margin-left: 0; }

.colcount-xxs-2 {
	-webkit-column-count: 2;
	   -moz-column-count: 2;
	        column-count: 2; }

.colcount-xxs-3 {
	-webkit-column-count: 3;
	   -moz-column-count: 3;
	        column-count: 3; }

.colcount-xxs-4 {
	-webkit-column-count: 4;
	   -moz-column-count: 4;
	        column-count: 4; }

.full-width {
	width: 100%; }

/*
  WET-BOEW
  @title: Bootstrap 4 suplemental style for WET-BOEW
 */
/* Spacing */
.p-0 {
	padding: 0 !important; }

.pl-2,
.px-2 {
	padding-left: 5px !important; }

.pr-2,
.px-2 {
	padding-right: 5px !important; }

.pt-4,
.py-4 {
	padding-top: 30px !important; }

.pb-4,
.py-4 {
	padding-bottom: 30px !important; }

.mt-auto {
	margin-top: auto !important; }

/* Stretched link */
.stretched-link:after {
	background-color: rgba(0, 0, 0, 0);
	bottom: 0;
	content: "";
	left: 0;
	pointer-events: auto;
	position: absolute;
	right: 0;
	top: 0;
	z-index: 1; }

/* Sizing */
.h-100 {
	height: 100% !important; }

/* Positioning */
.position-relative {
	position: relative !important; }

/* Flexbox */
.d-flex {
	display: -webkit-box !important;
	display: -ms-flexbox !important;
	display: flex !important; }

.flex-column {
	-webkit-box-orient: vertical !important;
	-webkit-box-direction: normal !important;
	    -ms-flex-direction: column !important;
	        flex-direction: column !important; }

.align-items-center {
	-webkit-box-align: center !important;
	    -ms-flex-align: center !important;
	        align-items: center !important; }

.align-self-center {
	-ms-flex-item-align: center !important;
	    align-self: center !important; }

.align-self-end {
	-ms-flex-item-align: end !important;
	    align-self: flex-end !important; }

/* Vertical alignment */
.align-top {
	vertical-align: top !important; }

.align-middle {
	vertical-align: middle !important; }

.align-bottom {
	vertical-align: bottom !important; }

/* Color scheme */
.text-white, a.text-white:visited {
	color: #fff; }

a.text-white:hover, a.text-white:focus {
	color: #b3ffff; }

.btn.text-white:hover, .btn.text-white:focus {
	color: #b3ffff; }

/*
 *
 * Web Experience Toolkit (WET) / Boîte à outils de l'expérience Web (BOEW)
 * wet-boew.github.io/wet-boew/License-en.html / wet-boew.github.io/wet-boew/Licence-fr.html
 *
 * Components and helpers style for WET-BOEW
 */
/*
 Background Utility CSS
 */
.bg-cover {
	background-size: cover; }

.bg-center {
	background-position: center; }

.bg-norepeat {
	background-repeat: no-repeat; }

/*
 Additional color
 */
.bg-darker {
	background-color: #000; }

.bg-dark {
	background-color: #343a40; }

button.bg-dark:hover, button.bg-dark:focus {
	background-color: #1d2124; }

/*
Miscellaneous Utiliy CSS
 */
.max-content {
	max-width: -webkit-max-content;
	max-width: -moz-max-content;
	max-width: max-content; }

/*
 Views
 */
/* All screen views */
@media screen {
	/*
  WET-BOEW
  @title: All screen views
 */
	.mathml body > div > math,
	.no-mathml body > div > math, .nojs-show, .wb-disable .nojs-hide {
		display: none !important; }
	/* Hide MathML check */
	#wb-dtmd {
		margin: 2em 0 0; }
		#wb-dtmd dt,
		#wb-dtmd dd {
			display: inline;
			font-weight: normal;
			margin-right: 0; }
	.nowrap {
		white-space: nowrap; }
	.wb-disable .nojs-show {
		display: block !important; }
	.col-xs-auto, .col-sm-auto, .col-md-auto, .col-lg-auto {
		min-height: 1px;
		padding-left: 15px;
		padding-right: 15px; }
	.col-xs-auto {
		width: auto; }
	/*
 * Web Experience Toolkit (WET) / Boîte à outils de l'expérience Web (BOEW)
 * wet-boew.github.io/wet-boew/License-en.html / wet-boew.github.io/wet-boew/Licence-fr.html
 */
	/* Pretty printing styles. Used with prettify.js. */
	.typ, .atn, .dec, .var {
		color: #606; }
	.pun, .opn, .clo {
		color: #660; }
	.str, .atv {
		color: #2f6d2f; }
	/* string content - from #080 */
	/* a keyword - from #008 */
	.kwd {
		color: #024b6e; }
	/* a comment */
	.com {
		color: #800; }
	/* a type name */
	/* a literal value */
	.lit {
		color: #066; }
	/* punctuation, lisp open bracket, lisp close bracket */
	/* a markup tag name - from #008 */
	.tag {
		color: #125b7e; }
	/* a markup attribute name */
	/* a markup attribute value - from #080 */
	/* a declaration */
	/* a variable name */
	/* a function name */
	.fun {
		color: #f00; }
	/*
 * Web Experience Toolkit (WET) / Boîte à outils de l'expérience Web (BOEW)
 * wet-boew.github.io/wet-boew/License-en.html / wet-boew.github.io/wet-boew/Licence-fr.html
 */
	/**
 * Screen-only styles
 */
	.wb-tabs.carousel-s2.wb-init {
		padding-bottom: 4.375em; }
	.wb-tabs.carousel-s2.exclude-controls {
		padding-bottom: 0; } }

/* Extra-small view and under */
@media screen and (max-width: 767px) {
	/*
  WET-BOEW
  @title: Extra-small view and under (screen only)
 */
	.wb-eqht-grd > [class*="col-"] {
		width: 100%; } }

/* Small view and under */
@media screen and (max-width: 991px) {
	/*
  WET-BOEW
  @title: Small view and under (screen only)
 */
	/*
 * Web Experience Toolkit (WET) / Boîte à outils de l'expérience Web (BOEW)
 * wet-boew.github.io/wet-boew/License-en.html / wet-boew.github.io/wet-boew/Licence-fr.html
 */
	.dataTables_wrapper .dataTables_info {
		padding-bottom: 5px; }
	.dataTables_wrapper .dataTables_filter {
		float: left;
		text-align: left;
		width: 100%; }
	[dir=rtl] .dataTables_wrapper .dataTables_filter {
		float: right;
		text-align: right; }
	/*
 * Web Experience Toolkit (WET) / Boîte à outils de l'expérience Web (BOEW)
 * wet-boew.github.io/wet-boew/License-en.html / wet-boew.github.io/wet-boew/Licence-fr.html
 */
	/**
 * Mobile-friendly styles
 */
	.wb-tabs.carousel-s1, .wb-tabs.carousel-s2 {
		border: 0; }
	.wb-tabs > details, .wb-tabs > .tabpanels > details {
		border: 0;
		border-bottom: #ccc solid 1px;
		border-bottom-left-radius: 0;
		border-bottom-right-radius: 0; }
		.wb-tabs > details:last-of-type, .wb-tabs > .tabpanels > details:last-of-type {
			border-bottom: 0; }
		.wb-tabs > details[style], .wb-tabs > .tabpanels > details[style] {
			min-height: 0 !important; }
		.wb-tabs > details > summary, .wb-tabs > .tabpanels > details > summary {
			border: 0; }
		.wb-tabs > details[open] > summary, .wb-tabs > .tabpanels > details[open] > summary {
			border: 0;
			margin-bottom: 0; }
	.wb-tabs {
		/* Only for backwards compatibility. Should be removed in v4.1. */
		border-color: #ccc;
		border-radius: 4px;
		border-style: solid;
		border-width: 1px;
		margin-bottom: 15px;
		padding-left: 0;
		padding-right: 0; }
		.wb-tabs.tabs-acc > ul {
			display: none; } }

/* Medium view and under */
@media screen and (max-width: 1199px) {
	/*
  WET-BOEW
  @title: Medium view and under (screen only)
 */ }

/* Large view and under */
@media screen and (max-width: 1599px) {
	/*
  WET-BOEW
  @title: Large view and under (screen only)
 */ }

/* Extra-small view and over */
@media screen and (min-width: 480px) {
	/*
  WET-BOEW
  @title: Extra-small view and over (screen only)
 */
	/*
  WET-BOEW
  @title: Proximity CSS - Extra-small view and over
 */
	.colcount-xs-2 {
		-webkit-column-count: 2;
		   -moz-column-count: 2;
		        column-count: 2; }
	.colcount-xs-3 {
		-webkit-column-count: 3;
		   -moz-column-count: 3;
		        column-count: 3; }
	.colcount-xs-4 {
		-webkit-column-count: 4;
		   -moz-column-count: 4;
		        column-count: 4; }
	/*
 * Web Experience Toolkit (WET) / Boîte à outils de l'expérience Web (BOEW)
 * wet-boew.github.io/wet-boew/License-en.html / wet-boew.github.io/wet-boew/Licence-fr.html
 */
	#mb-pnl {
		min-width: 300px; }
	/*
 * Web Experience Toolkit (WET) / Boîte à outils de l'expérience Web (BOEW)
 * wet-boew.github.io/wet-boew/License-en.html / wet-boew.github.io/wet-boew/Licence-fr.html
 */
	.dataTables_wrapper .dataTables_info:after {
		content: "|";
		font-size: 1.2em;
		line-height: 1em;
		padding: 0 .25em; } }

/* Small view and over */
@media screen and (min-width: 768px) {
	/*
  WET-BOEW
  @title: Small view and over (screen only)
 */
	.col-sm-auto {
		width: auto; }
	.form-inline .label-inline {
		display: inline-block;
		padding-right: 10px; }
		.form-inline .label-inline:last-child {
			padding-right: 0; }
	/*
  WET-BOEW
  @title: Bootstrap 4 suplemental style for WET-BOEW - Small view and over (screen only)
 */
	/* Alignment */
	.text-sm-left {
		text-align: left; }
	.text-sm-right {
		text-align: right; }
	/* Flexbox */
	.d-sm-flex {
		display: -webkit-box;
		display: -ms-flexbox;
		display: flex; }
	.flex-sm-wrap {
		-ms-flex-wrap: wrap;
		    flex-wrap: wrap; }
	.align-items-sm-center {
		-webkit-box-align: center;
		    -ms-flex-align: center;
		        align-items: center; }
	/* Margin */
	.mb-sm-5 {
		margin-bottom: 50px; }
	/* Padding */
	.p-sm-3 {
		padding: 15px; }
	.px-sm-3 {
		padding-left: 15px;
		padding-right: 15px; }
	.pr-sm-3 {
		padding-right: 15px !important; }
	/*
  WET-BOEW
  @title: Proximity CSS - Small view and over
 */
	.colcount-sm-2 {
		-webkit-column-count: 2;
		   -moz-column-count: 2;
		        column-count: 2; }
	.colcount-sm-3 {
		-webkit-column-count: 3;
		   -moz-column-count: 3;
		        column-count: 3; }
	.colcount-sm-4 {
		-webkit-column-count: 4;
		   -moz-column-count: 4;
		        column-count: 4; }
	.pstn-lft-sm {
		position: absolute;
		left: 0;
		right: auto; }
	.pstn-rght-sm {
		position: absolute;
		right: 0;
		left: auto; }
	.pstn-tp-sm {
		position: absolute;
		top: 0;
		bottom: auto; }
	.pstn-bttm-sm {
		position: absolute;
		bottom: 0;
		top: auto; }
	.wb-filter .input-group {
		max-width: 80%; } }

/* Medium view and over */
@media screen and (min-width: 992px) {
	/*
  WET-BOEW
  @title: Medium view and over (screen only)
 */
	[dir=rtl] main.col-md-push-3 {
		left: auto; }
	[dir=rtl] #wb-sec.col-md-pull-9 {
		right: auto; }
	.col-md-auto {
		width: auto; }
	/*
  WET-BOEW
  @title: Proximity CSS - Medium view and over
 */
	.colcount-md-2 {
		-webkit-column-count: 2;
		   -moz-column-count: 2;
		        column-count: 2; }
	.colcount-md-3 {
		-webkit-column-count: 3;
		   -moz-column-count: 3;
		        column-count: 3; }
	.colcount-md-4 {
		-webkit-column-count: 4;
		   -moz-column-count: 4;
		        column-count: 4; }
	.pstn-lft-md {
		position: absolute;
		left: 0;
		right: auto; }
	.pstn-rght-md {
		position: absolute;
		right: 0;
		left: auto; }
	.pstn-tp-md {
		position: absolute;
		top: 0;
		bottom: auto; }
	.pstn-bttm-md {
		position: absolute;
		bottom: 0;
		top: auto; }
	/*
 * Web Experience Toolkit (WET) / Boîte à outils de l'expérience Web (BOEW)
 * wet-boew.github.io/wet-boew/License-en.html / wet-boew.github.io/wet-boew/Licence-fr.html
 */
	#details-flickr,
	#details-youtube {
		padding-left: 0;
		padding-right: 0; }
	/*
 * Web Experience Toolkit (WET) / Boîte à outils de l'expérience Web (BOEW)
 * wet-boew.github.io/wet-boew/License-en.html / wet-boew.github.io/wet-boew/Licence-fr.html
 */
	.wb-tabs > details, .wb-tabs > .tabpanels > details {
		border-color: #ccc;
		border-style: solid;
		border-width: 1px;
		display: none; }
		.wb-tabs > details[open], .wb-tabs > .tabpanels > details[open] {
			display: block; }
			.wb-tabs > details[open] > summary, .wb-tabs > .tabpanels > details[open] > summary {
				display: none !important; }
	.wb-tabs {
		/* Only for backwards compatibility. Should be removed in v4.1. */ }
		.wb-tabs.carousel-s2.show-thumbs [role="tablist"] li.active a {
			border-color: #666;
			border-style: solid;
			border-width: 10px;
			margin-bottom: 1px;
			padding: 0; }
			.wb-tabs.carousel-s2.show-thumbs [role="tablist"] li.active a:focus::before {
				content: "";
				height: calc(100% - 6px);
				left: 0;
				margin: 2px;
				outline: inherit;
					outline-color: #FFF;
				position: absolute;
				top: 0;
				width: calc(100% - 4px); }
		.wb-tabs.carousel-s2.show-thumbs [role="tablist"] li[role="presentation"] {
			display: inline-block; }
			.wb-tabs.carousel-s2.show-thumbs [role="tablist"] li[role="presentation"] img {
				opacity: .5;
				width: 140px; }
		.wb-tabs.carousel-s2.show-thumbs [role="tablist"] li[class="active"] img {
			opacity: 1; }
		.wb-tabs.carousel-s2.show-thumbs [role="tablist"] li.prv, .wb-tabs.carousel-s2.show-thumbs [role="tablist"] li.tab-count, .wb-tabs.carousel-s2.show-thumbs [role="tablist"] li.nxt {
			display: none; } }

/* Large view and over */
@media screen and (min-width: 1200px) {
	/*
  WET-BOEW
  @title: Large view and over (screen only)
 */
	.clr-lft-lg {
		clear: left; }
	.clr-rght-lg {
		clear: right; }
	.col-lg-auto {
		width: auto; }
	/*
  WET-BOEW
  @title: Proximity CSS - Medium view and over
 */
	.colcount-lg-2 {
		-webkit-column-count: 2;
		   -moz-column-count: 2;
		        column-count: 2; }
	.colcount-lg-3 {
		-webkit-column-count: 3;
		   -moz-column-count: 3;
		        column-count: 3; }
	.colcount-lg-4 {
		-webkit-column-count: 4;
		   -moz-column-count: 4;
		        column-count: 4; }
	.pstn-lft-lg {
		position: absolute;
		left: 0;
		right: auto; }
	.pstn-rght-lg {
		position: absolute;
		right: 0;
		left: auto; }
	.pstn-tp-lg {
		position: absolute;
		top: 0;
		bottom: auto; }
	.pstn-bttm-lg {
		position: absolute;
		bottom: 0;
		top: auto; }
	.wb-filter .input-group {
		max-width: 60%; } }

/* Extra-extra-small view */
@media screen and (max-width: 479px) {
	/*
  WET-BOEW
  @title: Extra-extra-small view (screen only)
 */
	/*
 * Web Experience Toolkit (WET) / Boîte à outils de l'expérience Web (BOEW)
 * wet-boew.github.io/wet-boew/License-en.html / wet-boew.github.io/wet-boew/Licence-fr.html
 */
	#mb-pnl {
		min-width: 65%; }
	/*
 * Web Experience Toolkit (WET) / Boîte à outils de l'expérience Web (BOEW)
 * wet-boew.github.io/wet-boew/License-en.html / wet-boew.github.io/wet-boew/Licence-fr.html
 */
	.dataTables_wrapper .dataTables_length {
		width: 100%; }
	/*
 * Web Experience Toolkit (WET) / Boîte à outils de l'expérience Web (BOEW)
 * wet-boew.github.io/wet-boew/License-en.html / wet-boew.github.io/wet-boew/Licence-fr.html
 */
	.wb-tabs.carousel-s2 [role="tablist"] li.prv, .wb-tabs.carousel-s2 [role="tablist"] li.nxt {
		margin-right: 0; }
	.wb-tabs.carousel-s2 [role="tablist"] li.prv {
		margin-left: 0; }
		.wb-tabs.carousel-s2 [role="tablist"] li.prv a {
			padding: 10px 0 10px .4em; }
	.wb-tabs.carousel-s2 [role="tablist"] li.nxt a {
		padding: 10px 0; }
	.wb-tabs.carousel-s2 [role="tablist"] li.tab-count {
		font-size: .9em;
		margin-right: 5px; }
	.wb-tabs.carousel-s2 [role="tablist"] li.plypause {
		margin-right: 2%; }
		.wb-tabs.carousel-s2 [role="tablist"] li.plypause a {
			font-size: 1.3em;
			margin-right: 0;
			padding: 12px 10px 7px; } }

/* Extra-small view */
@media screen and (min-width: 480px) and (max-width: 767px) {
	/*
  WET-BOEW
  @title: Extra-small view (screen only)
 */ }

/* Small view */
@media screen and (min-width: 768px) and (max-width: 991px) {
	/*
  WET-BOEW
  @title: Small view (screen only)
 */
	.clr-lft-sm {
		clear: left; }
	.clr-rght-sm {
		clear: right; } }

/* Medium view */
@media screen and (min-width: 992px) and (max-width: 1199px) {
	/*
  WET-BOEW
  @title: Medium view (screen only)
 */
	.clr-lft-md {
		clear: left; }
	.clr-rght-md {
		clear: right; } }

/* Large view */
@media screen and (min-width: 1200px) and (max-width: 1599px) {
	/*
  WET-BOEW
  @title: Large view (screen only)
 */ }

/* Extra-large view */
@media screen and (min-width: 1600px) {
	/*
  WET-BOEW
  @title: Extra-large view (screen only)
 */
	/*
  WET-BOEW
  @title: Proximity CSS - Medium view and over
 */
	.colcount-xl-2 {
		-webkit-column-count: 2;
		   -moz-column-count: 2;
		        column-count: 2; }
	.colcount-xl-3 {
		-webkit-column-count: 3;
		   -moz-column-count: 3;
		        column-count: 3; }
	.colcount-xl-4 {
		-webkit-column-count: 4;
		   -moz-column-count: 4;
		        column-count: 4; } }

/* Print view */
@media print {
	/*
  WET-BOEW
  @title: Print view
 */
	.pg-brk-aft {
		page-break-after: always; }
	a[href]:after {
		content: none; }
	#wb-tphp {
		display: none; }
	/*
  WET-BOEW
  @title: Breadcrumb print CSS overrides
 */
	#wb-bc .breadcrumb {
		margin-bottom: 0; }
	#wb-bc a[href]:after {
		content: ""; }
	/*
 * Web Experience Toolkit (WET) / Boîte à outils de l'expérience Web (BOEW)
 * wet-boew.github.io/wet-boew/License-en.html / wet-boew.github.io/wet-boew/Licence-fr.html
 */
	.fn-lnk, .wb-fnote .fn-rtn a {
		background-color: transparent;
		border: 0;
		padding: 0; }
	.wb-fnote {
		border-left: 0;
		border-right: 0;
		margin-bottom: 1em;
		margin-left: 0;
		margin-right: 0; }
		.wb-fnote dd {
			border: 0;
			display: inline-block;
			width: 100%; }
		.wb-fnote .fn-rtn {
			overflow: visible; }
	/*
 * Web Experience Toolkit (WET) / Boîte à outils de l'expérience Web (BOEW)
 * wet-boew.github.io/wet-boew/License-eng.html / wet-boew.github.io/wet-boew/Licence-fra.html
*/
	.wb-geomap-detail, .olControlMousePosition, .olControlPanZoomBar {
		visibility: hidden; }
	/*
 * Web Experience Toolkit (WET) / Boîte à outils de l'expérience Web (BOEW)
 * wet-boew.github.io/wet-boew/License-en.html / wet-boew.github.io/wet-boew/Licence-fr.html
 */
	.mfp-wrap,
	.mfp-container {
		position: static; }
	.mfp-arrow,
	.mfp-close {
		display: none !important; }
	/*
  Multimedia Player Code (print view)
 */
	.wb-mm-ctrls,
	.wb-mm-ovrly, .wb-mltmd.cc_on .wb-mm-cc {
		display: none; }
	/*
 * Web Experience Toolkit (WET) / Boîte à outils de l'expérience Web (BOEW)
 * wet-boew.github.io/wet-boew/License-en.html / wet-boew.github.io/wet-boew/Licence-fr.html
 */
	/**
 * Print styles
 */
	.wb-overlay-dlg main > *, .wb-modal main > * {
		display: none; }
	.wb-overlay-dlg main .wb-overlay.open, .wb-overlay-dlg main .mfp-content, .wb-modal main .wb-overlay.open, .wb-modal main .mfp-content {
		display: block; }
	.wb-overlay.open {
		position: static; }
		.wb-overlay.open.no-print {
			display: none; }
	.mfp-content:before, .wb-overlay.open:before {
		content: attr(data-pgtitle);
		display: block;
		font-size: 1.9em; }
	/*
 * Web Experience Toolkit (WET) / Boîte à outils de l'expérience Web (BOEW)
 * wet-boew.github.io/wet-boew/License-en.html / wet-boew.github.io/wet-boew/Licence-fr.html
 */
	/* Use higher contrast and text-weight for printable form. */
	.kwd, .typ, .tag {
		font-weight: 700; }
	.kwd, .tag {
		color: #006; }
	.str, .atv {
		color: #060; }
	.pun, .opn, .clo {
		color: #440; }
	.typ, .atn {
		color: #404; }
	.com {
		color: #600;
		font-style: italic; }
	.lit {
		color: #044; }
	/*
 * Web Experience Toolkit (WET) / Boîte à outils de l'expérience Web (BOEW)
 * wet-boew.github.io/wet-boew/License-en.html / wet-boew.github.io/wet-boew/Licence-fr.html
 */
	/**
 * Print styles
 */
	.wb-tabs [role="tablist"], .wb-tabs.print-active > .tabpanels > div.out, .wb-tabs.print-active > .tabpanels > details.out .tgl-panel, .wb-tabs.print-active > .tabpanels > details > summary[aria-expanded="false"] + .tgl-panel {
		display: none !important; }
	.wb-tabs.carousel-s1 [role="tabpanel"], .wb-tabs.carousel-s2 [role="tabpanel"] {
		margin-bottom: .5em; }
	.wb-tabs.carousel-s1 figure, .wb-tabs.carousel-s2 figure {
		page-break-inside: avoid; }
	.wb-tabs.carousel-s1 figcaption, .wb-tabs.carousel-s2 figcaption {
		border: 1px solid #000; }
	.wb-tabs [role="tabpanel"] {
		display: block !important;
		opacity: 1 !important;
		overflow: visible !important;
		position: static !important;
		-webkit-transform: none;
		        transform: none;
		visibility: visible !important; }
		.wb-tabs [role="tabpanel"] figcaption {
			position: static; }
		.wb-tabs [role="tabpanel"] summary {
			display: list-item !important; }
		.wb-tabs [role="tabpanel"].noheight {
			max-height: none; }
	.wb-tabs > .tabpanels {
		overflow: visible !important; } }

/*
 Views
 */
/* All screen views */
@media screen {
	/*
 *
 * Web Experience Toolkit (WET) / Boîte à outils de l'expérience Web (BOEW)
 * wet-boew.github.io/wet-boew/License-en.html / wet-boew.github.io/wet-boew/Licence-fr.html
 *
 */
	/*
  @title: All screen views - Splash page
 */
	#gcwu-sig,
	#wmms {
		height: 2em; }
	#wmms {
		float: right; }
	header {
		margin-top: 1.2em; } }
